@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2014 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2008-2016 Sébastien Helleu <flashcode@flashtux.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,22 +16,24 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-#
-# Documentation generator for WeeChat: build include files with commands,
-# options, infos, infolists, hdata and completions for WeeChat core and
-# plugins.
-#
-# Instructions to build config files yourself in WeeChat directories (replace
-# all paths with your path to WeeChat):
-#     1.  run WeeChat and load this script, with following command:
-#           /python load ~/src/weechat/doc/docgen.py
-#     2.  change path to build in your doc/ directory:
-#           /set plugins.var.python.docgen.path "~/src/weechat/doc"
-#     3.  run docgen command:
-#           /docgen
-# Note: it is recommended to load only this script when building doc.
-# Files should be in ~/src/weechat/doc/xx/autogen/ (where xx is language).
-#
+"""
+Documentation generator for WeeChat: build include files with commands,
+options, infos, infolists, hdata and completions for WeeChat core and
+plugins.
+
+Instructions to build config files yourself in WeeChat directories (replace
+all paths with your path to WeeChat):
+    1.  run WeeChat and load this script, with following command:
+          /python load ~/src/weechat/doc/docgen.py
+    2.  change path to build in your doc/ directory:
+          /set plugins.var.python.docgen.path "~/src/weechat/doc"
+    3.  run docgen command:
+          /docgen
+Note: it is recommended to load only this script when building doc.
+Files should be in ~/src/weechat/doc/xx/autogen/ (where xx is language).
+"""
+
+from __future__ import print_function
 
 SCRIPT_NAME = 'docgen'
 SCRIPT_AUTHOR = 'Sébastien Helleu <flashcode@flashtux.org>'
@@ -41,15 +43,9 @@ SCRIPT_DESC = 'Documentation generator for WeeChat'
 
 SCRIPT_COMMAND = 'docgen'
 
-import_ok = True
-
-try:
-    import weechat
-except ImportError:
-    print('This script must be run under WeeChat.')
-    print('Get WeeChat now at: http://www.weechat.org/')
-    import_ok = False
+IMPORT_OK = True
 
+# pylint: disable=wrong-import-position
 try:
     import gettext
     import hashlib
@@ -59,7 +55,14 @@ try:
     from operator import itemgetter
 except ImportError as message:
     print('Missing package(s) for {0}: {1}'.format(SCRIPT_NAME, message))
-    import_ok = False
+    IMPORT_OK = False
+
+try:
+    import weechat  # pylint: disable=import-error
+except ImportError:
+    print('This script must be run under WeeChat.')
+    print('Get WeeChat now at: https://weechat.org/')
+    IMPORT_OK = False
 
 # default path where doc files will be written (should be doc/ in sources
 # package tree)
@@ -73,7 +76,7 @@ except ImportError as message:
 DEFAULT_PATH = '~/src/weechat/doc'
 
 # list of locales for which we want to build doc files to include
-locale_list = ('en_US', 'fr_FR', 'it_IT', 'de_DE', 'ja_JP', 'pl_PL')
+LOCALE_LIST = ('en_US', 'fr_FR', 'it_IT', 'de_DE', 'ja_JP', 'pl_PL')
 
 # all commands/options/.. of following plugins will produce a file
 # non-listed plugins will be ignored
@@ -82,69 +85,121 @@ locale_list = ('en_US', 'fr_FR', 'it_IT', 'de_DE', 'ja_JP', 'pl_PL')
 # if plugin is listed without "c", that means plugin has only one command
 # /name (where "name" is name of plugin)
 # Note: we consider core is a plugin called "weechat"
-plugin_list = {
+PLUGIN_LIST = {
     'sec': 'o',
     'weechat': 'co',
     'alias': '',
     'aspell': 'o',
-    'charset': 'co',
-    'fifo': 'co',
+    'charset': 'o',
+    'exec': 'o',
+    'fifo': 'o',
     'irc': 'co',
-    'logger': 'co',
-    'relay': 'co',
-    'rmodifier': 'co',
-    'script': 'co',
+    'logger': 'o',
+    'relay': 'o',
+    'script': 'o',
     'perl': '',
     'python': '',
+    'javascript': '',
     'ruby': '',
     'lua': '',
     'tcl': '',
     'guile': '',
+    'trigger': 'o',
     'xfer': 'co',
 }
 
 # options to ignore
-ignore_options = (
-    'aspell\.dict\..*',
-    'aspell\.option\..*',
-    'charset\.decode\..*',
-    'charset\.encode\..*',
-    'irc\.msgbuffer\..*',
-    'irc\.ctcp\..*',
-    'irc\.ignore\..*',
-    'irc\.server\..*',
-    'jabber\.server\..*',
-    'logger\.level\..*',
-    'logger\.mask\..*',
-    'relay\.port\..*',
-    'rmodifier\.modifier\..*',
-    'weechat\.palette\..*',
-    'weechat\.proxy\..*',
-    'weechat\.bar\..*',
-    'weechat\.debug\..*',
-    'weechat\.notify\..*',
+IGNORE_OPTIONS = (
+    r'aspell\.dict\..*',
+    r'aspell\.option\..*',
+    r'charset\.decode\..*',
+    r'charset\.encode\..*',
+    r'irc\.msgbuffer\..*',
+    r'irc\.ctcp\..*',
+    r'irc\.ignore\..*',
+    r'irc\.server\..*',
+    r'jabber\.server\..*',
+    r'logger\.level\..*',
+    r'logger\.mask\..*',
+    r'relay\.port\..*',
+    r'trigger\.trigger\..*',
+    r'weechat\.palette\..*',
+    r'weechat\.proxy\..*',
+    r'weechat\.bar\..*',
+    r'weechat\.debug\..*',
+    r'weechat\.notify\..*',
 )
 
 # completions to ignore
-ignore_completions_items = (
+IGNORE_COMPLETIONS_ITEMS = (
     'docgen.*',
     'jabber.*',
     'weeget.*',
 )
 
 
+class AutogenDoc(object):
+    """A class to write auto-generated doc files."""
+
+    def __init__(self, directory, doc, name):
+        """Initialize auto-generated doc file."""
+        self.filename = os.path.join(directory, doc, name + '.asciidoc')
+        self.filename_tmp = self.filename + '.tmp'
+        self._file = open(self.filename_tmp, 'w')
+        self.write('//\n')
+        self.write('// This file is auto-generated by script docgen.py.\n')
+        self.write('// DO NOT EDIT BY HAND!\n')
+        self.write('//\n')
+
+    def write(self, string):
+        """Write a line in auto-generated doc file."""
+        self._file.write(string)
+
+    def update(self, obj_name, num_files, num_files_updated):
+        """Update doc file if needed (if content has changed)."""
+        # close temp file
+        self._file.close()
+        # compute checksum on old file
+        try:
+            with open(self.filename, 'r') as _file:
+                shaold = hashlib.sha256(_file.read()).hexdigest()
+        except IOError:
+            shaold = ''
+        # compute checksum on new (temp) file
+        try:
+            with open(self.filename_tmp, 'r') as _file:
+                shanew = hashlib.sha256(_file.read()).hexdigest()
+        except IOError:
+            shanew = ''
+        # compare checksums
+        if shaold != shanew:
+            # update doc file
+            if os.path.exists(self.filename):
+                os.unlink(self.filename)
+            os.rename(self.filename_tmp, self.filename)
+            num_files_updated['total1'] += 1
+            num_files_updated['total2'] += 1
+            num_files_updated[obj_name] += 1
+        else:
+            os.unlink(self.filename_tmp)
+        # update counters
+        num_files['total1'] += 1
+        num_files['total2'] += 1
+        num_files[obj_name] += 1
+
+
 def get_commands():
     """
-    Get list of commands in a dict with 3 indexes: plugin, command, xxx.
+    Get list of WeeChat/plugins commands as dictionary with 3 indexes: plugin,
+    command, xxx.
     """
-    global plugin_list
     commands = defaultdict(lambda: defaultdict(defaultdict))
     infolist = weechat.infolist_get('hook', '', 'command')
     while weechat.infolist_next(infolist):
         plugin = weechat.infolist_string(infolist, 'plugin_name') or 'weechat'
-        if plugin in plugin_list:
+        if plugin in PLUGIN_LIST:
             command = weechat.infolist_string(infolist, 'command')
-            if command == plugin or 'c' in plugin_list[plugin]:
+            if command == plugin or 'c' in PLUGIN_LIST[plugin]:
                 for key in ('description', 'args', 'args_description',
                             'completion'):
                     commands[plugin][command][key] = \
@@ -155,18 +210,17 @@ def get_commands():
 
 def get_options():
     """
-    Get list of config options in a dict with 4 indexes: config,
-    section, option, xxx.
+    Get list of WeeChat/plugins config options as dictionary with 4 indexes:
+    config, section, option, xxx.
     """
-    global plugin_list, ignore_options
     options = \
         defaultdict(lambda: defaultdict(lambda: defaultdict(defaultdict)))
     infolist = weechat.infolist_get('option', '', '')
     while weechat.infolist_next(infolist):
         full_name = weechat.infolist_string(infolist, 'full_name')
-        if not re.search('|'.join(ignore_options), full_name):
+        if not re.search('|'.join(IGNORE_OPTIONS), full_name):
             config = weechat.infolist_string(infolist, 'config_name')
-            if config in plugin_list and 'o' in plugin_list[config]:
+            if config in PLUGIN_LIST and 'o' in PLUGIN_LIST[config]:
                 section = weechat.infolist_string(infolist, 'section_name')
                 option = weechat.infolist_string(infolist, 'option_name')
                 for key in ('type', 'string_values', 'default_value',
@@ -182,8 +236,8 @@ def get_options():
 
 def get_infos():
     """
-    Get list of infos hooked by plugins in a dict with 3 indexes:
-    plugin, name, xxx.
+    Get list of WeeChat/plugins infos as dictionary with 3 indexes: plugin,
+    name, xxx.
     """
     infos = defaultdict(lambda: defaultdict(defaultdict))
     infolist = weechat.infolist_get('hook', '', 'info')
@@ -199,8 +253,8 @@ def get_infos():
 
 def get_infos_hashtable():
     """
-    Get list of infos (hashtable) hooked by plugins in a dict with 3
-    indexes: plugin, name, xxx.
+    Get list of WeeChat/plugins infos (hashtable) as dictionary with 3 indexes:
+    plugin, name, xxx.
     """
     infos_hashtable = defaultdict(lambda: defaultdict(defaultdict))
     infolist = weechat.infolist_get('hook', '', 'info_hashtable')
@@ -216,8 +270,8 @@ def get_infos_hashtable():
 
 def get_infolists():
     """
-    Get list of infolists hooked by plugins in a dict with 3 indexes:
-    plugin, name, xxx.
+    Get list of WeeChat/plugins infolists as dictionary with 3 indexes: plugin,
+    name, xxx.
     """
     infolists = defaultdict(lambda: defaultdict(defaultdict))
     infolist = weechat.infolist_get('hook', '', 'infolist')
@@ -231,10 +285,11 @@ def get_infolists():
     return infolists
 
 
+# pylint: disable=too-many-locals
 def get_hdata():
     """
-    Get list of hdata hooked by plugins in a dict with 3 indexes:
-    plugin, name, xxx.
+    Get list of WeeChat/plugins hdata as dictionary with 3 indexes: plugin,
+    name, xxx.
     """
     hdata = defaultdict(lambda: defaultdict(defaultdict))
     infolist = weechat.infolist_get('hook', '', 'hdata')
@@ -265,15 +320,14 @@ def get_hdata():
                         var_hdata = ', hdata: "{0}"'.format(var_hdata)
                     type_string = weechat.hdata_get_var_type_string(ptr_hdata,
                                                                     key)
-                    d = {'__update_allowed': key}
-                    hdata2.append({'offset': var_offset,
-                                   'text': '\'{0}\' ({1})'.format(key,
-                                                                  type_string),
-                                   'textlong': '\'{0}\' ({1}{2}{3})'
-                                   ''.format(key, type_string, var_array_size,
-                                             var_hdata),
-                                   'update': weechat.hdata_update(ptr_hdata,
-                                                                  '', d)})
+                    hdata2.append({
+                        'offset': var_offset,
+                        'text': '\'{0}\' ({1})'.format(key, type_string),
+                        'textlong': '\'{0}\' ({1}{2}{3})'.format(
+                            key, type_string, var_array_size, var_hdata),
+                        'update': weechat.hdata_update(
+                            ptr_hdata, '', {'__update_allowed': key}),
+                    })
                 hdata2 = sorted(hdata2, key=itemgetter('offset'))
                 for item in hdata2:
                     variables += '*** {0}\n'.format(item['textlong'])
@@ -299,15 +353,14 @@ def get_hdata():
 
 def get_completions():
     """
-    Get list of completions hooked by plugins in a dict with 3 indexes:
+    Get list of WeeChat/plugins completions as dictionary with 3 indexes:
     plugin, item, xxx.
     """
-    global ignore_completions_items
     completions = defaultdict(lambda: defaultdict(defaultdict))
     infolist = weechat.infolist_get('hook', '', 'completion')
     while weechat.infolist_next(infolist):
         completion_item = weechat.infolist_string(infolist, 'completion_item')
-        if not re.search('|'.join(ignore_completions_items), completion_item):
+        if not re.search('|'.join(IGNORE_COMPLETIONS_ITEMS), completion_item):
             plugin = weechat.infolist_string(infolist, 'plugin_name') or \
                 'weechat'
             completions[plugin][completion_item]['description'] = \
@@ -318,56 +371,63 @@ def get_completions():
 
 def get_url_options():
     """
-    Get list of completions hooked by plugins in a dict with 3 indexes:
-    plugin, item, xxx.
+    Get list of URL options as list of dictionaries.
     """
     url_options = []
     infolist = weechat.infolist_get('url_options', '', '')
     while weechat.infolist_next(infolist):
-        url_options.append(
-            {
-                'name': weechat.infolist_string(infolist, 'name').lower(),
-                'option': weechat.infolist_integer(infolist, 'option'),
-                'type': weechat.infolist_string(infolist, 'type'),
-                'constants': weechat.infolist_string(infolist, 'constants')
-                .lower().replace(',', ', ')
-            })
+        url_options.append({
+            'name': weechat.infolist_string(infolist, 'name').lower(),
+            'option': weechat.infolist_integer(infolist, 'option'),
+            'type': weechat.infolist_string(infolist, 'type'),
+            'constants': weechat.infolist_string(
+                infolist, 'constants').lower().replace(',', ', ')
+        })
     weechat.infolist_free(infolist)
     return url_options
 
 
-def update_file(oldfile, newfile, num_files, num_files_updated, obj):
-    """Update a doc file."""
-    try:
-        shaold = hashlib.sha224(open(oldfile, 'r').read()).hexdigest()
-    except:
-        shaold = ''
-    try:
-        shanew = hashlib.sha224(open(newfile, 'r').read()).hexdigest()
-    except:
-        shanew = ''
-    if shaold != shanew:
-        if os.path.exists(oldfile):
-            os.unlink(oldfile)
-        os.rename(newfile, oldfile)
-        num_files_updated['total1'] += 1
-        num_files_updated['total2'] += 1
-        num_files_updated[obj] += 1
-    else:
-        if os.path.exists(oldfile):
-            os.unlink(newfile)
-    num_files['total1'] += 1
-    num_files['total2'] += 1
-    num_files[obj] += 1
+def get_irc_colors():
+    """
+    Get list of IRC colors as list of dictionaries.
+    """
+    irc_colors = []
+    infolist = weechat.infolist_get('irc_color_weechat', '', '')
+    while weechat.infolist_next(infolist):
+        irc_colors.append({
+            'color_irc': weechat.infolist_string(infolist, 'color_irc'),
+            'color_weechat': weechat.infolist_string(infolist,
+                                                     'color_weechat'),
+        })
+    weechat.infolist_free(infolist)
+    return irc_colors
 
 
-def docgen_cmd_cb(data, buffer, args):
+def get_plugins_priority():
+    """
+    Get priority of default WeeChat plugins as a dictionary.
+    """
+    plugins_priority = {}
+    infolist = weechat.infolist_get('plugin', '', '')
+    while weechat.infolist_next(infolist):
+        name = weechat.infolist_string(infolist, 'name')
+        priority = weechat.infolist_integer(infolist, 'priority')
+        if priority in plugins_priority:
+            plugins_priority[priority].append(name)
+        else:
+            plugins_priority[priority] = [name]
+    weechat.infolist_free(infolist)
+    return plugins_priority
+
+
+# pylint: disable=too-many-locals, too-many-branches, too-many-statements
+# pylint: disable=too-many-nested-blocks
+def docgen_cmd_cb(data, buf, args):
     """Callback for /docgen command."""
-    global locale_list
     if args:
         locales = args.split(' ')
     else:
-        locales = locale_list
+        locales = LOCALE_LIST
     commands = get_commands()
     options = get_options()
     infos = get_infos()
@@ -376,6 +436,8 @@ def docgen_cmd_cb(data, buffer, args):
     hdata = get_hdata()
     completions = get_completions()
     url_options = get_url_options()
+    irc_colors = get_irc_colors()
+    plugins_priority = get_plugins_priority()
 
     # get path and replace ~ by home if needed
     path = weechat.config_get_plugin('path')
@@ -386,6 +448,7 @@ def docgen_cmd_cb(data, buffer, args):
     num_files = defaultdict(int)
     num_files_updated = defaultdict(int)
 
+    # pylint: disable=undefined-variable
     translate = lambda s: (s and _(s)) or s
     escape = lambda s: s.replace('|', '\\|')
 
@@ -394,10 +457,11 @@ def docgen_cmd_cb(data, buffer, args):
             if key != 'total2':
                 num_files[key] = 0
                 num_files_updated[key] = 0
-        t = gettext.translation('weechat',
-                                weechat.info_get('weechat_localedir', ''),
-                                languages=[locale + '.UTF-8'], fallback=True)
-        t.install()
+        trans = gettext.translation('weechat',
+                                    weechat.info_get('weechat_localedir', ''),
+                                    languages=[locale + '.UTF-8'],
+                                    fallback=True)
+        trans.install()
         directory = path + '/' + locale[0:2] + '/autogen'
         if not os.path.isdir(directory):
             weechat.prnt('',
@@ -407,39 +471,39 @@ def docgen_cmd_cb(data, buffer, args):
 
         # write commands
         for plugin in commands:
-            filename = directory + '/user/' + plugin + '_commands.txt'
-            tmpfilename = filename + '.tmp'
-            f = open(tmpfilename, 'w')
-            for command in sorted(commands[plugin]):
+            doc = AutogenDoc(directory, 'user', plugin + '_commands')
+            for i, command in enumerate(sorted(commands[plugin])):
+                if i > 0:
+                    doc.write('\n')
                 _cmd = commands[plugin][command]
                 args = translate(_cmd['args'])
                 args_formats = args.split(' || ')
                 desc = translate(_cmd['description'])
                 args_desc = translate(_cmd['args_description'])
-                f.write('[[command_{0}_{1}]]\n'.format(plugin, command))
-                f.write('[command]*`{0}`* {1}::\n\n'.format(command, desc))
-                f.write('----\n')
+                doc.write('[[command_{0}_{1}]]\n'.format(plugin, command))
+                doc.write('[command]*`{0}`* {1}::\n\n'.format(command, desc))
+                doc.write('----\n')
                 prefix = '/' + command + '  '
                 if args_formats != ['']:
                     for fmt in args_formats:
-                        f.write(prefix + fmt + '\n')
+                        doc.write(prefix + fmt + '\n')
                         prefix = ' ' * len(prefix)
                 if args_desc:
-                    f.write('\n')
+                    doc.write('\n')
                     for line in args_desc.split('\n'):
-                        f.write(line + '\n')
-                f.write('----\n\n')
-            f.close()
-            update_file(filename, tmpfilename, num_files, num_files_updated,
-                        'commands')
+                        doc.write(line + '\n')
+                doc.write('----\n')
+            doc.update('commands', num_files, num_files_updated)
 
         # write config options
         for config in options:
-            filename = directory + '/user/' + config + '_options.txt'
-            tmpfilename = filename + '.tmp'
-            f = open(tmpfilename, 'w')
+            doc = AutogenDoc(directory, 'user', config + '_options')
+            i = 0
             for section in sorted(options[config]):
                 for option in sorted(options[config][section]):
+                    if i > 0:
+                        doc.write('\n')
+                    i += 1
                     _opt = options[config][section][option]
                     opt_type = _opt['type']
                     string_values = _opt['string_values']
@@ -480,201 +544,178 @@ def docgen_cmd_cb(data, buffer, args):
                                    'only, not background): \"*\" for bold, '
                                    '\"!\" for reverse, \"/\" for italic, '
                                    '\"_\" for underline')
-                    f.write('* [[option_{0}.{1}.{2}]] *{3}.{4}.{5}*\n'
-                            ''.format(config, section, option, config, section,
-                                      option))
-                    f.write('** {0}: `{1}`\n'.format(_('description'), desc))
-                    f.write('** {0}: {1}\n'.format(_('type'), type_nls))
-                    f.write('** {0}: {1} ({2}: `{3}`)\n'
-                            ''.format(_('values'), values, _('default value'),
-                                      default_value))
+                    doc.write('* [[option_{0}.{1}.{2}]] *{3}.{4}.{5}*\n'
+                              ''.format(config, section, option, config,
+                                        section, option))
+                    doc.write('** {0}: `{1}`\n'.format(_('description'), desc))
+                    doc.write('** {0}: {1}\n'.format(_('type'), type_nls))
+                    doc.write('** {0}: {1} ({2}: `{3}`)\n'
+                              ''.format(_('values'), values,
+                                        _('default value'), default_value))
                     if null_value_allowed:
-                        f.write('** {0}\n'
-                                ''.format(_('undefined value allowed (null)')))
-                    f.write('\n')
-            f.close()
-            update_file(filename, tmpfilename, num_files, num_files_updated,
-                        'options')
+                        doc.write('** {0}\n'.format(
+                            _('undefined value allowed (null)')))
+            doc.update('options', num_files, num_files_updated)
+
+        # write IRC colors
+        doc = AutogenDoc(directory, 'user', 'irc_colors')
+        doc.write('[width="30%",cols="^2m,3",options="header"]\n')
+        doc.write('|===\n')
+        doc.write('| {0} | {1}\n\n'
+                  ''.format(_('IRC color'), _('WeeChat color')))
+        for color in irc_colors:
+            doc.write('| {0} | {1}\n'
+                      ''.format(escape(color['color_irc']),
+                                escape(color['color_weechat'])))
+        doc.write('|===\n')
+        doc.update('irc_colors', num_files, num_files_updated)
 
         # write infos hooked
-        filename = directory + '/plugin_api/infos.txt'
-        tmpfilename = filename + '.tmp'
-        f = open(tmpfilename, 'w')
-        f.write('[width="100%",cols="^1,^2,6,6",options="header"]\n')
-        f.write('|===\n')
-        f.write('| {0} | {1} | {2} | {3}\n\n'
-                ''.format(_('Plugin'), _('Name'), _('Description'),
-                          _('Arguments')))
+        doc = AutogenDoc(directory, 'plugin_api', 'infos')
+        doc.write('[width="100%",cols="^1,^2,6,6",options="header"]\n')
+        doc.write('|===\n')
+        doc.write('| {0} | {1} | {2} | {3}\n\n'
+                  ''.format(_('Plugin'), _('Name'), _('Description'),
+                            _('Arguments')))
         for plugin in sorted(infos):
             for info in sorted(infos[plugin]):
                 _inf = infos[plugin][info]
                 desc = translate(_inf['description'])
                 args_desc = translate(_inf['args_description'] or '-')
-                f.write('| {0} | {1} | {2} | {3}\n\n'
-                        ''.format(escape(plugin), escape(info),
-                                  escape(desc), escape(args_desc)))
-        f.write('|===\n')
-        f.close()
-        update_file(filename, tmpfilename, num_files, num_files_updated,
-                    'infos')
+                doc.write('| {0} | {1} | {2} | {3}\n\n'
+                          ''.format(escape(plugin), escape(info),
+                                    escape(desc), escape(args_desc)))
+        doc.write('|===\n')
+        doc.update('infos', num_files, num_files_updated)
 
         # write infos (hashtable) hooked
-        filename = directory + '/plugin_api/infos_hashtable.txt'
-        tmpfilename = filename + '.tmp'
-        f = open(tmpfilename, 'w')
-        f.write('[width="100%",cols="^1,^2,6,6,6",options="header"]\n')
-        f.write('|===\n')
-        f.write('| {0} | {1} | {2} | {3} | {4}\n\n'
-                ''.format(_('Plugin'), _('Name'), _('Description'),
-                          _('Hashtable (input)'), _('Hashtable (output)')))
+        doc = AutogenDoc(directory, 'plugin_api', 'infos_hashtable')
+        doc.write('[width="100%",cols="^1,^2,6,6,6",options="header"]\n')
+        doc.write('|===\n')
+        doc.write('| {0} | {1} | {2} | {3} | {4}\n\n'
+                  ''.format(_('Plugin'), _('Name'), _('Description'),
+                            _('Hashtable (input)'), _('Hashtable (output)')))
         for plugin in sorted(infos_hashtable):
             for info in sorted(infos_hashtable[plugin]):
                 _inh = infos_hashtable[plugin][info]
                 desc = translate(_inh['description'])
                 args_desc = translate(_inh['args_description'])
                 output_desc = translate(_inh['output_description']) or '-'
-                f.write('| {0} | {1} | {2} | {3} | {4}\n\n'
-                        ''.format(escape(plugin), escape(info),
-                                  escape(desc), escape(args_desc),
-                                  escape(output_desc)))
-        f.write('|===\n')
-        f.close()
-        update_file(filename, tmpfilename, num_files, num_files_updated,
-                    'infos_hashtable')
+                doc.write('| {0} | {1} | {2} | {3} | {4}\n\n'
+                          ''.format(escape(plugin), escape(info),
+                                    escape(desc), escape(args_desc),
+                                    escape(output_desc)))
+        doc.write('|===\n')
+        doc.update('infos_hashtable', num_files, num_files_updated)
 
         # write infolists hooked
-        filename = directory + '/plugin_api/infolists.txt'
-        tmpfilename = filename + '.tmp'
-        f = open(tmpfilename, 'w')
-        f.write('[width="100%",cols="^1,^2,5,5,5",options="header"]\n')
-        f.write('|===\n')
-        f.write('| {0} | {1} | {2} | {3} | {4}\n\n'
-                ''.format(_('Plugin'), _('Name'), _('Description'),
-                          _('Pointer'), _('Arguments')))
+        doc = AutogenDoc(directory, 'plugin_api', 'infolists')
+        doc.write('[width="100%",cols="^1,^2,5,5,5",options="header"]\n')
+        doc.write('|===\n')
+        doc.write('| {0} | {1} | {2} | {3} | {4}\n\n'
+                  ''.format(_('Plugin'), _('Name'), _('Description'),
+                            _('Pointer'), _('Arguments')))
         for plugin in sorted(infolists):
             for infolist in sorted(infolists[plugin]):
                 _inl = infolists[plugin][infolist]
                 desc = translate(_inl['description'])
                 pointer_desc = translate(_inl['pointer_description']) or '-'
                 args_desc = translate(_inl['args_description']) or '-'
-                f.write('| {0} | {1} | {2} | {3} | {4}\n\n'
-                        ''.format(escape(plugin), escape(infolist),
-                                  escape(desc), escape(pointer_desc),
-                                  escape(args_desc)))
-        f.write('|===\n')
-        f.close()
-        update_file(filename, tmpfilename, num_files, num_files_updated,
-                    'infolists')
+                doc.write('| {0} | {1} | {2} | {3} | {4}\n\n'
+                          ''.format(escape(plugin), escape(infolist),
+                                    escape(desc), escape(pointer_desc),
+                                    escape(args_desc)))
+        doc.write('|===\n')
+        doc.update('infolists', num_files, num_files_updated)
 
         # write hdata hooked
-        filename = directory + '/plugin_api/hdata.txt'
-        tmpfilename = filename + '.tmp'
-        f = open(tmpfilename, 'w')
+        doc = AutogenDoc(directory, 'plugin_api', 'hdata')
         for plugin in sorted(hdata):
             for hdata_name in sorted(hdata[plugin]):
+                anchor = 'hdata_{0}'.format(hdata_name)
                 _hda = hdata[plugin][hdata_name]
                 desc = translate(_hda['description'])
                 variables = _hda['vars']
                 variables_update = _hda['vars_update']
                 lists = _hda['lists']
-                f.write('* \'{0}\': {1}\n'.format(escape(hdata_name),
-                                                  escape(desc)))
-                f.write('** {0}: {1}\n'.format(_('plugin'), escape(plugin)))
-                f.write('** {0}:\n{1}'.format(_('variables'),
-                                              escape(variables)))
+                doc.write('* [[{0}]]<<{0},\'{1}\'>>: {2}\n'
+                          ''.format(escape(anchor), escape(hdata_name),
+                                    escape(desc)))
+                doc.write('** {0}: {1}\n'.format(_('plugin'),
+                                                 escape(plugin)))
+                doc.write('** {0}:\n{1}'.format(_('variables'),
+                                                escape(variables)))
                 if variables_update:
-                    f.write('** {0}:\n{1}'.format(_('update allowed'),
-                                                  escape(variables_update)))
+                    doc.write('** {0}:\n{1}'.format(
+                        _('update allowed'),
+                        escape(variables_update)))
                 if lists:
-                    f.write('** {0}:\n{1}'.format(_('lists'), escape(lists)))
-        f.close()
-        update_file(filename, tmpfilename, num_files, num_files_updated,
-                    'hdata')
+                    doc.write('** {0}:\n{1}'.format(_('lists'),
+                                                    escape(lists)))
+        doc.update('hdata', num_files, num_files_updated)
 
         # write completions hooked
-        filename = directory + '/plugin_api/completions.txt'
-        tmpfilename = filename + '.tmp'
-        f = open(tmpfilename, 'w')
-        f.write('[width="65%",cols="^1,^2,8",options="header"]\n')
-        f.write('|===\n')
-        f.write('| {0} | {1} | {2}\n\n'
-                ''.format(_('Plugin'), _('Name'), _('Description')))
+        doc = AutogenDoc(directory, 'plugin_api', 'completions')
+        doc.write('[width="65%",cols="^1,^2,8",options="header"]\n')
+        doc.write('|===\n')
+        doc.write('| {0} | {1} | {2}\n\n'
+                  ''.format(_('Plugin'), _('Name'), _('Description')))
         for plugin in sorted(completions):
             for completion_item in sorted(completions[plugin]):
                 _cmp = completions[plugin][completion_item]
                 desc = translate(_cmp['description'])
-                f.write('| {0} | {1} | {2}\n\n'
-                        ''.format(escape(plugin), escape(completion_item),
-                                  escape(desc)))
-        f.write('|===\n')
-        f.close()
-        update_file(filename, tmpfilename, num_files, num_files_updated,
-                    'completions')
+                doc.write('| {0} | {1} | {2}\n\n'
+                          ''.format(escape(plugin), escape(completion_item),
+                                    escape(desc)))
+        doc.write('|===\n')
+        doc.update('completions', num_files, num_files_updated)
 
         # write url options
-        filename = directory + '/plugin_api/url_options.txt'
-        tmpfilename = filename + '.tmp'
-        f = open(tmpfilename, 'w')
-        f.write('[width="100%",cols="2,^1,7",options="header"]\n')
-        f.write('|===\n')
-        f.write('| {0} | {1} | {2}\n\n'
-                ''.format(_('Option'), _('Type'), _('Constants') + ' ^(1)^'))
+        doc = AutogenDoc(directory, 'plugin_api', 'url_options')
+        doc.write('[width="100%",cols="2,^1,7",options="header"]\n')
+        doc.write('|===\n')
+        doc.write('| {0} | {1} | {2}\n\n'
+                  ''.format(_('Option'), _('Type'),
+                            _('Constants') + ' ^(1)^'))
         for option in url_options:
             constants = option['constants']
             if constants:
                 constants = ' ' + constants
-            f.write('| {0} | {1} |{2}\n\n'
-                    ''.format(escape(option['name']), escape(option['type']),
-                              escape(constants)))
-        f.write('|===\n')
-        f.close()
-        update_file(filename, tmpfilename, num_files, num_files_updated,
-                    'url_options')
+            doc.write('| {0} | {1} |{2}\n\n'
+                      ''.format(escape(option['name']),
+                                escape(option['type']),
+                                escape(constants)))
+        doc.write('|===\n')
+        doc.update('url_options', num_files, num_files_updated)
+
+        # write plugins priority
+        doc = AutogenDoc(directory, 'plugin_api', 'plugins_priority')
+        for priority in sorted(plugins_priority, reverse=True):
+            plugins = ', '.join(sorted(plugins_priority[priority]))
+            doc.write('. {0} ({1})\n'.format(escape(plugins), priority))
+        doc.update('plugins_priority', num_files, num_files_updated)
 
         # write counters
         weechat.prnt('',
-                     'docgen: {0}: {1:3d} files   '
-                     '({2:2d} cmd, {3:2d} opt, {4:2d} infos, '
-                     '{5:2d} infos_hash, {6:2d} infolists, {7:2d} hdata, '
-                     '{8:2d} complt)'
+                     'docgen: {0}: {1} files, {2} updated'
                      ''.format(locale,
                                num_files['total1'],
-                               num_files['commands'],
-                               num_files['options'],
-                               num_files['infos'],
-                               num_files['infos_hashtable'],
-                               num_files['infolists'],
-                               num_files['hdata'],
-                               num_files['completions']))
-        weechat.prnt('',
-                     '               '
-                     '{0:3d} updated ({1:2d} cmd, {2:2d} opt, {3:2d} infos, '
-                     '{4:2d} infos_hash, {5:2d} infolists, {6:2d} hdata, '
-                     '{7:2d} complt)'
-                     ''.format(num_files_updated['total1'],
-                               num_files_updated['commands'],
-                               num_files_updated['options'],
-                               num_files_updated['infos'],
-                               num_files_updated['infos_hashtable'],
-                               num_files_updated['infolists'],
-                               num_files_updated['hdata'],
-                               num_files_updated['completions']))
+                               num_files_updated['total1']))
     weechat.prnt('',
                  'docgen: total: {0} files, {1} updated'
                  ''.format(num_files['total2'], num_files_updated['total2']))
     return weechat.WEECHAT_RC_OK
 
 
-def docgen_completion_cb(data, completion_item, buffer, completion):
+def docgen_completion_cb(data, completion_item, buf, completion):
     """Callback for completion."""
-    global locale_list
-    for locale in locale_list:
+    for locale in LOCALE_LIST:
         weechat.hook_completion_list_add(completion, locale, 0,
                                          weechat.WEECHAT_LIST_POS_SORT)
     return weechat.WEECHAT_RC_OK
 
 
-if __name__ == '__main__' and import_ok:
+if __name__ == '__main__' and IMPORT_OK:
     if weechat.register(SCRIPT_NAME, SCRIPT_AUTHOR, SCRIPT_VERSION,
                         SCRIPT_LICENSE, SCRIPT_DESC, '', ''):
         weechat.hook_command(SCRIPT_COMMAND,
