@@ -1,7 +1,7 @@
 /*
  * wee-backtrace.c - backtrace after a segfault
  *
- * Copyright (C) 2003-2013 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -111,12 +111,13 @@ weechat_backtrace_addr2line (int number, void *address, const char *symbol)
                 pos[0] = '\0';
             if (strchr (ptr_line, ':'))
             {
-                weechat_backtrace_printf ("%03d  %s%s%s%s",
-                                          number,
-                                          ptr_line,
-                                          (function_name[0]) ? " [function " : "",
-                                          function_name,
-                                          (function_name[0]) ? "]" : "");
+                weechat_backtrace_printf (
+                    "%03d  %s%s%s%s",
+                    number,
+                    ptr_line,
+                    (function_name[0]) ? " [function " : "",
+                    function_name,
+                    (function_name[0]) ? "]" : "");
                 function_name[0] = '\0';
             }
             else
@@ -140,7 +141,7 @@ weechat_backtrace_addr2line (int number, void *address, const char *symbol)
     (void) symbol;
 
     /* no backtrace possible, we display nothing */
-#endif
+#endif /* HAVE_BACKTRACE */
 }
 
 /*
@@ -154,7 +155,7 @@ weechat_backtrace ()
     void *trace[BACKTRACE_MAX];
     int trace_size, i;
     char **symbols;
-#endif
+#endif /* HAVE_BACKTRACE */
 
     weechat_backtrace_printf ("======= WeeChat backtrace =======");
     weechat_backtrace_printf ("(written by WeeChat %s, compiled on %s %s)",
@@ -173,7 +174,7 @@ weechat_backtrace ()
 #else
     weechat_backtrace_printf ("  No backtrace info (no debug info available "
                               "or no backtrace possible on your system).");
-#endif
+#endif /* HAVE_BACKTRACE */
 
     weechat_backtrace_printf ("======= End of  backtrace =======");
 }
