@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,11 +17,11 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_BACKTACE_H
-#define __WEECHAT_BACKTACE_H 1
+#ifndef WEECHAT_BACKTACE_H
+#define WEECHAT_BACKTACE_H 1
 
 #define BACKTRACE_MAX 128
 
 extern void weechat_backtrace ();
 
-#endif /* __WEECHAT_BACKTACE_H */
+#endif /* WEECHAT_BACKTACE_H */
