@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_COMMAND_H
-#define __WEECHAT_COMMAND_H 1
+#ifndef WEECHAT_COMMAND_H
+#define WEECHAT_COMMAND_H 1
 
 #define COMMAND_CALLBACK(__command)                                     \
     int                                                                 \
@@ -45,18 +45,39 @@
         return WEECHAT_RC_OK;                                           \
     }
 
-#define COMMAND_MIN_ARGS(__min, __command)                              \
-    if (argc < __min)                                                   \
+/*
+ * macro to return error in case of missing arguments in callback of
+ * hook_command
+ */
+#define COMMAND_MIN_ARGS(__min_args, __option)                          \
+    if (argc < __min_args)                                              \
     {                                                                   \
         gui_chat_printf_date_tags (                                     \
-            NULL, 0,                                                    \
-            GUI_FILTER_TAG_NO_FILTER,                                   \
-            _("%sError: missing arguments for \"%s\" command"),         \
+            NULL, 0, GUI_FILTER_TAG_NO_FILTER,                          \
+            _("%sToo few arguments for command \"%s%s%s\" "             \
+              "(help on command: /help %s)"),                           \
             gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],                     \
-            __command);                                                 \
+            argv[0],                                                    \
+            (__option && __option[0]) ? " " : "",                       \
+            (__option && __option[0]) ? __option : "",                  \
+            argv[0] + 1);                                               \
         return WEECHAT_RC_ERROR;                                        \
     }
 
+/* macro to return error in callback of hook_command */
+#define COMMAND_ERROR                                                   \
+    {                                                                   \
+        gui_chat_printf_date_tags (                                     \
+            NULL, 0, GUI_FILTER_TAG_NO_FILTER,                          \
+            _("%sError with command \"%s\" "                            \
+              "(help on command: /help %s)"),                           \
+            gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],                     \
+            argv_eol[0],                                                \
+            argv[0] + 1);                                               \
+        return WEECHAT_RC_ERROR;                                        \
+    }
+
+
 struct t_gui_buffer;
 
 extern int command_reload (void *data, struct t_gui_buffer *buffer,
@@ -68,4 +89,4 @@ extern void command_version_display (struct t_gui_buffer *buffer,
                                      int translated_string,
                                      int display_git_version);
 
-#endif /* __WEECHAT_COMMAND_H */
+#endif /* WEECHAT_COMMAND_H */
