@@ -1,7 +1,7 @@
 /*
  * wee-completion.c - completion for WeeChat commands
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -288,6 +288,62 @@ completion_list_add_windows_numbers_cb (void *data,
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Adds colors to completion list.
+ */
+
+int
+completion_list_add_colors_cb (void *data,
+                               const char *completion_item,
+                               struct t_gui_buffer *buffer,
+                               struct t_gui_completion *completion)
+{
+    char str_number[64];
+    const char *color_name;
+    int i, num_colors;
+    struct t_gui_color_palette *color_palette;
+
+    /* make C compiler happy */
+    (void) data;
+    (void) completion_item;
+    (void) buffer;
+
+    num_colors = gui_color_get_weechat_colors_number ();
+    for (i = 0; i < num_colors; i++)
+    {
+        color_name = gui_color_get_name (i);
+        if (color_name)
+        {
+            gui_completion_list_add (completion,
+                                     color_name,
+                                     0, WEECHAT_LIST_POS_SORT);
+        }
+    }
+    num_colors = gui_color_get_term_colors ();
+    for (i = 0; i <= num_colors; i++)
+    {
+        color_palette = gui_color_palette_get (i);
+        if (color_palette)
+        {
+            gui_completion_list_add (completion,
+                                     color_palette->alias,
+                                     0, WEECHAT_LIST_POS_END);
+        }
+        else
+        {
+            snprintf (str_number,
+                      sizeof (str_number),
+                      "%d",
+                      i);
+            gui_completion_list_add (completion,
+                                     str_number,
+                                     0, WEECHAT_LIST_POS_END);
+        }
+    }
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Adds a palette color to completion list.
  */
@@ -410,7 +466,8 @@ completion_list_add_filename_cb (void *data,
     if (!real_prefix || !prefix)
         goto end;
 
-    snprintf (buf, sizeof (buf), "%s", completion->base_word + strlen (prefix));
+    snprintf (buf, sizeof (buf),
+              "%s", completion->base_word + strlen (prefix));
     pos = strrchr (buf, DIR_SEPARATOR_CHAR);
     if (pos)
     {
@@ -792,15 +849,17 @@ completion_list_add_plugins_installed_cb (void *data,
         && CONFIG_STRING(config_plugin_path)[0])
     {
         plugin_path = string_expand_home (CONFIG_STRING(config_plugin_path));
-        plugin_path2 = string_replace ((plugin_path) ?
-                                       plugin_path : CONFIG_STRING(config_plugin_path),
-                                       "%h", weechat_home);
-        util_exec_on_files ((plugin_path2) ?
-                            plugin_path2 : ((plugin_path) ?
-                                            plugin_path : CONFIG_STRING(config_plugin_path)),
-                            0,
-                            completion,
-                            &completion_list_add_plugins_installed_exec_cb);
+        plugin_path2 = string_replace (
+            (plugin_path) ?
+            plugin_path : CONFIG_STRING(config_plugin_path),
+            "%h", weechat_home);
+        util_exec_on_files (
+            (plugin_path2) ?
+            plugin_path2 : ((plugin_path) ?
+                            plugin_path : CONFIG_STRING(config_plugin_path)),
+            0,
+            completion,
+            &completion_list_add_plugins_installed_exec_cb);
         if (plugin_path)
             free (plugin_path);
         if (plugin_path2)
@@ -898,13 +957,12 @@ completion_list_add_config_option_values_cb (void *data,
                                              struct t_gui_completion *completion)
 {
     char *pos_space, *option_full_name, *pos_section, *pos_option;
-    char *file, *section, *value_string, str_number[64];
+    char *file, *section, *value_string;
     const char *color_name;
-    int length, i, num_colors;
+    int length, i;
     struct t_config_file *ptr_config;
     struct t_config_section *ptr_section, *section_found;
     struct t_config_option *option_found;
-    struct t_gui_color_palette *color_palette;
 
     /* make C compiler happy */
     (void) data;
@@ -1063,38 +1121,8 @@ completion_list_add_config_option_values_cb (void *data,
                             }
                             break;
                         case CONFIG_OPTION_TYPE_COLOR:
-                            num_colors = gui_color_get_weechat_colors_number ();
-                            for (i = 0; i < num_colors; i++)
-                            {
-                                color_name = gui_color_get_name (i);
-                                if (color_name)
-                                {
-                                    gui_completion_list_add (completion,
-                                                             color_name,
-                                                             0, WEECHAT_LIST_POS_SORT);
-                                }
-                            }
-                            num_colors = gui_color_get_term_colors ();
-                            for (i = 0; i <= num_colors; i++)
-                            {
-                                color_palette = gui_color_palette_get (i);
-                                if (color_palette)
-                                {
-                                    gui_completion_list_add (completion,
-                                                             color_palette->alias,
-                                                             0, WEECHAT_LIST_POS_END);
-                                }
-                                else
-                                {
-                                    snprintf (str_number,
-                                              sizeof (str_number),
-                                              "%d",
-                                              i);
-                                    gui_completion_list_add (completion,
-                                                             str_number,
-                                                             0, WEECHAT_LIST_POS_END);
-                                }
-                            }
+                            completion_list_add_colors_cb (
+                                data, completion_item, buffer, completion);
                             gui_completion_list_add (completion, "++1",
                                                      0, WEECHAT_LIST_POS_END);
                             gui_completion_list_add (completion, "--1",
@@ -1279,9 +1307,10 @@ completion_list_add_keys_codes_cb (void *data,
         for (ptr_key = gui_keys[i]; ptr_key; ptr_key = ptr_key->next_key)
         {
             expanded_name = gui_key_get_expanded_name (ptr_key->key);
-            gui_completion_list_add (completion,
-                                     (expanded_name) ? expanded_name : ptr_key->key,
-                                     0, WEECHAT_LIST_POS_SORT);
+            gui_completion_list_add (
+                completion,
+                (expanded_name) ? expanded_name : ptr_key->key,
+                0, WEECHAT_LIST_POS_SORT);
             if (expanded_name)
                 free (expanded_name);
         }
@@ -1320,9 +1349,10 @@ completion_list_add_keys_codes_for_reset_cb (void *data,
                 || (strcmp (ptr_default_key->command, ptr_key->command) != 0))
             {
                 expanded_name = gui_key_get_expanded_name (ptr_key->key);
-                gui_completion_list_add (completion,
-                                         (expanded_name) ? expanded_name : ptr_key->key,
-                                         0, WEECHAT_LIST_POS_SORT);
+                gui_completion_list_add (
+                    completion,
+                    (expanded_name) ? expanded_name : ptr_key->key,
+                    0, WEECHAT_LIST_POS_SORT);
                 if (expanded_name)
                     free (expanded_name);
             }
@@ -1336,9 +1366,10 @@ completion_list_add_keys_codes_for_reset_cb (void *data,
             if (!ptr_key)
             {
                 expanded_name = gui_key_get_expanded_name (ptr_default_key->key);
-                gui_completion_list_add (completion,
-                                         (expanded_name) ? expanded_name : ptr_default_key->key,
-                                         0, WEECHAT_LIST_POS_SORT);
+                gui_completion_list_add (
+                    completion,
+                    (expanded_name) ? expanded_name : ptr_default_key->key,
+                    0, WEECHAT_LIST_POS_SORT);
                 if (expanded_name)
                     free (expanded_name);
             }
@@ -1559,6 +1590,9 @@ completion_init ()
     hook_completion (NULL, "windows_numbers",
                      N_("numbers of windows"),
                      &completion_list_add_windows_numbers_cb, NULL);
+    hook_completion (NULL, "colors",
+                     N_("color names"),
+                     &completion_list_add_colors_cb, NULL);
     hook_completion (NULL, "palette_colors",
                      N_("palette colors"),
                      &completion_list_add_palette_colors_cb, NULL);
@@ -1627,7 +1661,8 @@ completion_init ()
                         "or removed)"),
                      &completion_list_add_keys_codes_for_reset_cb, NULL);
     hook_completion (NULL, "cursor_areas",
-                     N_("areas (\"chat\" or bar name) for free cursor movement"),
+                     N_("areas (\"chat\" or bar name) for free cursor "
+                        "movement"),
                      &completion_list_add_cursor_areas_cb, NULL);
     hook_completion (NULL, "layouts_names",
                      N_("names of layouts"),
