@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -22,6 +22,7 @@
 #define WEECHAT_CONFIG_H 1
 
 #include <regex.h>
+#include <wctype.h>
 #include "wee-config-file.h"
 
 struct t_gui_buffer;
@@ -105,6 +106,14 @@ enum t_config_look_save_layout_on_exit
     CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_ALL,
 };
 
+struct t_config_look_word_char_item
+{
+    char exclude;                      /* 1 if char is NOT a word char      */
+    wctype_t wc_class;                 /* class of wide characters (wctype) */
+    wint_t char1;                      /* first char of range               */
+    wint_t char2;                      /* second char of range              */
+};
+
 extern struct t_config_file *weechat_config_file;
 extern struct t_config_section *weechat_config_section_color;
 extern struct t_config_section *weechat_config_section_proxy;
@@ -118,10 +127,12 @@ extern struct t_config_option *config_startup_display_version;
 extern struct t_config_option *config_startup_sys_rlimit;
 
 extern struct t_config_option *config_look_align_end_of_lines;
+extern struct t_config_option *config_look_bar_more_down;
 extern struct t_config_option *config_look_bar_more_left;
 extern struct t_config_option *config_look_bar_more_right;
 extern struct t_config_option *config_look_bar_more_up;
-extern struct t_config_option *config_look_bar_more_down;
+extern struct t_config_option *config_look_bare_display_exit_on_input;
+extern struct t_config_option *config_look_bare_display_time_format;
 extern struct t_config_option *config_look_buffer_auto_renumber;
 extern struct t_config_option *config_look_buffer_notify_default;
 extern struct t_config_option *config_look_buffer_position;
@@ -131,18 +142,19 @@ extern struct t_config_option *config_look_buffer_search_regex;
 extern struct t_config_option *config_look_buffer_search_where;
 extern struct t_config_option *config_look_buffer_time_format;
 extern struct t_config_option *config_look_color_basic_force_bold;
-extern struct t_config_option *config_look_color_inactive_window;
 extern struct t_config_option *config_look_color_inactive_buffer;
-extern struct t_config_option *config_look_color_inactive_time;
-extern struct t_config_option *config_look_color_inactive_prefix_buffer;
-extern struct t_config_option *config_look_color_inactive_prefix;
 extern struct t_config_option *config_look_color_inactive_message;
+extern struct t_config_option *config_look_color_inactive_prefix;
+extern struct t_config_option *config_look_color_inactive_prefix_buffer;
+extern struct t_config_option *config_look_color_inactive_time;
+extern struct t_config_option *config_look_color_inactive_window;
 extern struct t_config_option *config_look_color_nick_offline;
 extern struct t_config_option *config_look_color_pairs_auto_reset;
 extern struct t_config_option *config_look_color_real_white;
 extern struct t_config_option *config_look_command_chars;
 extern struct t_config_option *config_look_command_incomplete;
 extern struct t_config_option *config_look_confirm_quit;
+extern struct t_config_option *config_look_confirm_upgrade;
 extern struct t_config_option *config_look_day_change;
 extern struct t_config_option *config_look_day_change_message_1date;
 extern struct t_config_option *config_look_day_change_message_2dates;
@@ -169,18 +181,20 @@ extern struct t_config_option *config_look_input_cursor_scroll;
 extern struct t_config_option *config_look_input_share;
 extern struct t_config_option *config_look_input_share_overwrite;
 extern struct t_config_option *config_look_input_undo_max;
-extern struct t_config_option *config_look_item_time_format;
 extern struct t_config_option *config_look_item_buffer_filter;
 extern struct t_config_option *config_look_item_buffer_zoom;
 extern struct t_config_option *config_look_item_mouse_status;
+extern struct t_config_option *config_look_item_time_format;
 extern struct t_config_option *config_look_jump_current_to_previous_buffer;
 extern struct t_config_option *config_look_jump_previous_buffer_when_closing;
 extern struct t_config_option *config_look_jump_smart_back_to_buffer;
 extern struct t_config_option *config_look_key_bind_safe;
-extern struct t_config_option *config_look_nick_prefix;
-extern struct t_config_option *config_look_nick_suffix;
+extern struct t_config_option *config_look_key_grab_delay;
 extern struct t_config_option *config_look_mouse;
 extern struct t_config_option *config_look_mouse_timer_delay;
+extern struct t_config_option *config_look_nick_prefix;
+extern struct t_config_option *config_look_nick_suffix;
+extern struct t_config_option *config_look_paste_auto_add_newline;
 extern struct t_config_option *config_look_paste_bracketed;
 extern struct t_config_option *config_look_paste_bracketed_timer_delay;
 extern struct t_config_option *config_look_paste_max_lines;
@@ -196,8 +210,9 @@ extern struct t_config_option *config_look_prefix_buffer_align_more;
 extern struct t_config_option *config_look_prefix_buffer_align_more_after;
 extern struct t_config_option *config_look_prefix_same_nick;
 extern struct t_config_option *config_look_prefix_suffix;
-extern struct t_config_option *config_look_bare_display_exit_on_input;
-extern struct t_config_option *config_look_bare_display_time_format;
+extern struct t_config_option *config_look_quote_nick_prefix;
+extern struct t_config_option *config_look_quote_nick_suffix;
+extern struct t_config_option *config_look_quote_time_format;
 extern struct t_config_option *config_look_read_marker;
 extern struct t_config_option *config_look_read_marker_always_show;
 extern struct t_config_option *config_look_read_marker_string;
@@ -215,6 +230,8 @@ extern struct t_config_option *config_look_window_auto_zoom;
 extern struct t_config_option *config_look_window_separator_horizontal;
 extern struct t_config_option *config_look_window_separator_vertical;
 extern struct t_config_option *config_look_window_title;
+extern struct t_config_option *config_look_word_chars_highlight;
+extern struct t_config_option *config_look_word_chars_input;
 
 extern struct t_config_option *config_color_bar_more;
 extern struct t_config_option *config_color_chat;
@@ -223,23 +240,23 @@ extern struct t_config_option *config_color_chat_buffer;
 extern struct t_config_option *config_color_chat_channel;
 extern struct t_config_option *config_color_chat_day_change;
 extern struct t_config_option *config_color_chat_delimiters;
+extern struct t_config_option *config_color_chat_highlight;
+extern struct t_config_option *config_color_chat_highlight_bg;
+extern struct t_config_option *config_color_chat_host;
 extern struct t_config_option *config_color_chat_inactive_buffer;
 extern struct t_config_option *config_color_chat_inactive_window;
 extern struct t_config_option *config_color_chat_nick;
 extern struct t_config_option *config_color_chat_nick_colors;
-extern struct t_config_option *config_color_chat_nick_prefix;
 extern struct t_config_option *config_color_chat_nick_offline;
 extern struct t_config_option *config_color_chat_nick_offline_highlight;
 extern struct t_config_option *config_color_chat_nick_offline_highlight_bg;
 extern struct t_config_option *config_color_chat_nick_other;
+extern struct t_config_option *config_color_chat_nick_prefix;
 extern struct t_config_option *config_color_chat_nick_self;
 extern struct t_config_option *config_color_chat_nick_suffix;
-extern struct t_config_option *config_color_chat_highlight;
-extern struct t_config_option *config_color_chat_highlight_bg;
-extern struct t_config_option *config_color_chat_host;
+extern struct t_config_option *config_color_chat_prefix[];
 extern struct t_config_option *config_color_chat_prefix_buffer;
 extern struct t_config_option *config_color_chat_prefix_buffer_inactive_buffer;
-extern struct t_config_option *config_color_chat_prefix[];
 extern struct t_config_option *config_color_chat_prefix_more;
 extern struct t_config_option *config_color_chat_prefix_suffix;
 extern struct t_config_option *config_color_chat_read_marker;
@@ -251,10 +268,13 @@ extern struct t_config_option *config_color_chat_text_found_bg;
 extern struct t_config_option *config_color_chat_time;
 extern struct t_config_option *config_color_chat_time_delimiters;
 extern struct t_config_option *config_color_chat_value;
+extern struct t_config_option *config_color_chat_value_null;
 extern struct t_config_option *config_color_emphasized;
 extern struct t_config_option *config_color_emphasized_bg;
 extern struct t_config_option *config_color_input_actions;
 extern struct t_config_option *config_color_input_text_not_found;
+extern struct t_config_option *config_color_nicklist_away;
+extern struct t_config_option *config_color_nicklist_group;
 extern struct t_config_option *config_color_separator;
 extern struct t_config_option *config_color_status_count_highlight;
 extern struct t_config_option *config_color_status_count_msg;
@@ -265,16 +285,13 @@ extern struct t_config_option *config_color_status_data_msg;
 extern struct t_config_option *config_color_status_data_other;
 extern struct t_config_option *config_color_status_data_private;
 extern struct t_config_option *config_color_status_filter;
+extern struct t_config_option *config_color_status_more;
 extern struct t_config_option *config_color_status_mouse;
 extern struct t_config_option *config_color_status_name;
 extern struct t_config_option *config_color_status_name_ssl;
 extern struct t_config_option *config_color_status_nicklist_count;
 extern struct t_config_option *config_color_status_number;
-extern struct t_config_option *config_color_status_more;
 extern struct t_config_option *config_color_status_time;
-extern struct t_config_option *config_color_nicklist_away;
-extern struct t_config_option *config_color_nicklist_group;
-extern struct t_config_option *config_color_nicklist_offline;
 
 extern struct t_config_option *config_completion_base_word_until_cursor;
 extern struct t_config_option *config_completion_command_inline;
@@ -315,6 +332,10 @@ extern int config_num_highlight_tags;
 extern char **config_plugin_extensions;
 extern int config_num_plugin_extensions;
 extern char config_tab_spaces[];
+extern struct t_config_look_word_char_item *config_word_chars_highlight;
+extern int config_word_chars_highlight_count;
+extern struct t_config_look_word_char_item *config_word_chars_input;
+extern int config_word_chars_input_count;
 
 extern struct t_config_option *config_weechat_debug_get (const char *plugin_name);
 extern int config_weechat_debug_set (const char *plugin_name,
