@@ -1,7 +1,7 @@
 /*
  * wee-eval.c - evaluate expressions with references to internal vars
  *
- * Copyright (C) 2012-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2012-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,6 +26,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <regex.h>
+#include <time.h>
 
 #include "weechat.h"
 #include "wee-eval.h"
@@ -35,17 +36,23 @@
 #include "wee-hook.h"
 #include "wee-secure.h"
 #include "wee-string.h"
+#include "wee-utf8.h"
 #include "../gui/gui-buffer.h"
 #include "../gui/gui-color.h"
 #include "../gui/gui-window.h"
 #include "../plugins/plugin.h"
 
 
-char *logical_ops[EVAL_NUM_LOGICAL_OPS] = { "||", "&&" };
-char *comparisons[EVAL_NUM_COMPARISONS] = { "==", "!=", "<=", "<", ">=", ">",
-                                            "=~", "!~" };
+char *logical_ops[EVAL_NUM_LOGICAL_OPS] =
+{ "||", "&&" };
 
-struct t_hashtable *eval_hashtable_pointers = NULL;
+char *comparisons[EVAL_NUM_COMPARISONS] =
+{ "=~", "!~", "==", "!=", "<=", "<", ">=", ">" };
+
+char *eval_replace_vars (const char *expr, struct t_hashtable *pointers,
+                         struct t_hashtable *extra_vars,
+                         const char *prefix, const char *suffix,
+                         struct t_eval_regex *eval_regex);
 
 
 /*
@@ -217,34 +224,50 @@ end:
 
 /*
  * Replaces variables, which can be, by order of priority:
- *   1. an extra variable (from hashtable "extra_vars")
- *   2. a color (format: color:xxx)
- *   3. an option (format: file.section.option)
- *   4. a buffer local variable
- *   5. a hdata name/variable
+ *   1. an extra variable from hashtable "extra_vars"
+ *   2. a string to evaluate (format: eval:xxx)
+ *   3. a string with escaped chars (format: esc:xxx or \xxx)
+ *   4. a string with chars to hide (format: hide:char,string)
+ *   5. a regex group captured (format: re:N (0.99) or re:+)
+ *   6. a color (format: color:xxx)
+ *   7. an info (format: info:name,arguments)
+ *   8. current date/time (format: date or date:xxx)
+ *   9. an environment variable (format: env:XXX)
+ *  10. an option (format: file.section.option)
+ *  11. a buffer local variable
+ *  12. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
+ *                        or hdata[ptr].var1.var2)
  *
- * Examples:
- *   option: ${weechat.look.scroll_amount}
- *   hdata : ${window.buffer.full_name}
- *           ${window.buffer.local_variables.type}
+ * See /help in WeeChat for examples.
+ *
+ * Note: result must be freed after use.
  */
 
 char *
 eval_replace_vars_cb (void *data, const char *text)
 {
     struct t_hashtable *pointers, *extra_vars;
+    struct t_eval_regex *eval_regex;
     struct t_config_option *ptr_option;
     struct t_gui_buffer *ptr_buffer;
-    char str_value[64], *value, *pos, *pos1, *pos2, *hdata_name, *list_name;
-    char *tmp, *info_name;
-    const char *ptr_value, *ptr_arguments;
+    char str_value[512], *value, *pos, *pos1, *pos2, *hdata_name, *list_name;
+    char *tmp, *info_name, *hide_char, *hidden_string, *error;
+    const char *prefix, *suffix, *ptr_value, *ptr_arguments, *ptr_string;
     struct t_hdata *hdata;
     void *pointer;
+    int i, length_hide_char, length, index, rc;
+    long number;
+    long unsigned int ptr;
+    time_t date;
+    struct tm *date_tmp;
 
     pointers = (struct t_hashtable *)(((void **)data)[0]);
     extra_vars = (struct t_hashtable *)(((void **)data)[1]);
+    prefix = (const char *)(((void **)data)[2]);
+    suffix = (const char *)(((void **)data)[3]);
+    eval_regex = (struct t_eval_regex *)(((void **)data)[4]);
 
-    /* 1. look for var in hashtable "extra_vars" */
+    /* 1. variable in hashtable "extra_vars" */
     if (extra_vars)
     {
         ptr_value = hashtable_get (extra_vars, text);
@@ -252,14 +275,86 @@ eval_replace_vars_cb (void *data, const char *text)
             return strdup (ptr_value);
     }
 
-    /* 2. look for a color */
+    /*
+     * 2. force evaluation of string (recursive call)
+     *    --> use with caution: the text must be safe!
+     */
+    if (strncmp (text, "eval:", 5) == 0)
+    {
+        return eval_replace_vars (text + 5, pointers, extra_vars,
+                                  prefix, suffix, eval_regex);
+    }
+
+    /* 3. convert escaped chars */
+    if (strncmp (text, "esc:", 4) == 0)
+        return string_convert_escaped_chars (text + 4);
+    if ((text[0] == '\\') && text[1] && (text[1] != '\\'))
+        return string_convert_escaped_chars (text);
+
+    /* 4. hide chars: replace all chars by a given char/string */
+    if (strncmp (text, "hide:", 5) == 0)
+    {
+        hidden_string = NULL;
+        ptr_string = strchr (text + 5,
+                             (text[5] == ',') ? ';' : ',');
+        if (!ptr_string)
+            return strdup ("");
+        hide_char = string_strndup (text + 5, ptr_string - text - 5);
+        if (hide_char)
+        {
+            length_hide_char = strlen (hide_char);
+            length = utf8_strlen (ptr_string + 1);
+            hidden_string = malloc ((length * length_hide_char) + 1);
+            if (hidden_string)
+            {
+                index = 0;
+                for (i = 0; i < length; i++)
+                {
+                    memcpy (hidden_string + index, hide_char,
+                            length_hide_char);
+                    index += length_hide_char;
+                }
+                hidden_string[length * length_hide_char] = '\0';
+            }
+            free (hide_char);
+        }
+        return (hidden_string) ? hidden_string : strdup ("");
+    }
+
+    /* 5. regex group captured */
+    if (strncmp (text, "re:", 3) == 0)
+    {
+        if (eval_regex && eval_regex->result)
+        {
+            if (strcmp (text + 3, "+") == 0)
+                number = eval_regex->last_match;
+            else
+            {
+                number = strtol (text + 3, &error, 10);
+                if (!error || error[0])
+                    number = -1;
+            }
+            if ((number >= 0) && (number <= eval_regex->last_match))
+            {
+                return string_strndup (
+                    eval_regex->result + eval_regex->match[number].rm_so,
+                    eval_regex->match[number].rm_eo - eval_regex->match[number].rm_so);
+            }
+        }
+        return strdup ("");
+    }
+
+    /* 6. color code */
     if (strncmp (text, "color:", 6) == 0)
     {
+        ptr_value = gui_color_search_config (text + 6);
+        if (ptr_value)
+            return strdup (ptr_value);
         ptr_value = gui_color_get_custom (text + 6);
         return strdup ((ptr_value) ? ptr_value : "");
     }
 
-    /* 3. look for an info */
+    /* 7. info */
     if (strncmp (text, "info:", 5) == 0)
     {
         ptr_value = NULL;
@@ -279,7 +374,28 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ((ptr_value) ? ptr_value : "");
     }
 
-    /* 4. look for name of option: if found, return this value */
+    /* 8. current date/time */
+    if ((strncmp (text, "date", 4) == 0) && (!text[4] || (text[4] == ':')))
+    {
+        date = time (NULL);
+        date_tmp = localtime (&date);
+        if (!date_tmp)
+            return strdup ("");
+        rc = (int) strftime (str_value, sizeof (str_value),
+                             (text[4] == ':') ? text + 5 : "%F %T",
+                             date_tmp);
+        return strdup ((rc > 0) ? str_value : "");
+    }
+
+    /* 9. environment variable */
+    if (strncmp (text, "env:", 4) == 0)
+    {
+        ptr_value = getenv (text + 4);
+        if (ptr_value)
+            return strdup (ptr_value);
+    }
+
+    /* 10. option: if found, return this value */
     if (strncmp (text, "sec.data.", 9) == 0)
     {
         ptr_value = hashtable_get (secure_hashtable_data, text + 9);
@@ -312,7 +428,7 @@ eval_replace_vars_cb (void *data, const char *text)
         }
     }
 
-    /* 5. look for local variable in buffer */
+    /* 11. local variable in buffer */
     ptr_buffer = hashtable_get (pointers, "buffer");
     if (ptr_buffer)
     {
@@ -321,7 +437,7 @@ eval_replace_vars_cb (void *data, const char *text)
             return strdup (ptr_value);
     }
 
-    /* 6. look for hdata */
+    /* 12. hdata */
     value = NULL;
     hdata_name = NULL;
     list_name = NULL;
@@ -357,7 +473,23 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
 
     if (list_name)
-        pointer = hdata_get_list (hdata, list_name);
+    {
+        if (strncmp (list_name, "0x", 2) == 0)
+        {
+            rc = sscanf (list_name, "%lx", &ptr);
+            if ((rc != EOF) && (rc != 0))
+            {
+                pointer = (void *)ptr;
+                if (!hdata_check_pointer (hdata, NULL, pointer))
+                    goto end;
+            }
+            else
+                goto end;
+        }
+        else
+            pointer = hdata_get_list (hdata, list_name);
+    }
+
     if (!pointer)
     {
         pointer = hashtable_get (pointers, hdata_name);
@@ -385,18 +517,19 @@ end:
 char *
 eval_replace_vars (const char *expr, struct t_hashtable *pointers,
                    struct t_hashtable *extra_vars,
-                   const char *prefix, const char *suffix)
+                   const char *prefix, const char *suffix,
+                   struct t_eval_regex *eval_regex)
 {
-    int errors;
-    void *ptr[2];
+    const void *ptr[5];
 
     ptr[0] = pointers;
     ptr[1] = extra_vars;
+    ptr[2] = prefix;
+    ptr[3] = suffix;
+    ptr[4] = eval_regex;
 
     return string_replace_with_callback (expr, prefix, suffix,
-                                         &eval_replace_vars_cb,
-                                         ptr,
-                                         &errors);
+                                         &eval_replace_vars_cb, ptr, NULL);
 }
 
 /*
@@ -502,10 +635,52 @@ end:
 }
 
 /*
- * Evaluates a condition (this function must not be called directly).
+ * Searches a string in another at same level (skip sub-expressions between
+ * parentheses).
  *
- * Argument keep_parentheses is almost always 0, it is 1 only if the expression
- * is a regex (to keep flags inside the parentheses).
+ * For example: eval_strstr_level ("(x || y) || z", "||")
+ * will return a pointer on  "|| z" (because the first "||" is
+ * in a sub-expression, which is skipped).
+ *
+ * Returns pointer to string found, or NULL if not found.
+ */
+
+const char *
+eval_strstr_level (const char *string, const char *search)
+{
+    const char *ptr_string;
+    int level, length;
+
+    if (!string || !search)
+        return NULL;
+
+    length = strlen (search);
+
+    ptr_string = string;
+    level = 0;
+    while (ptr_string[0])
+    {
+        if (ptr_string[0] == '(')
+        {
+            level++;
+        }
+        else if (ptr_string[0] == ')')
+        {
+            if (level > 0)
+                level--;
+        }
+
+        if ((level == 0) && (strncmp (ptr_string, search, length) == 0))
+            return ptr_string;
+
+        ptr_string++;
+    }
+
+    return NULL;
+}
+
+/*
+ * Evaluates a condition (this function must not be called directly).
  *
  * For return value, see function eval_expression().
  *
@@ -513,14 +688,15 @@ end:
  */
 
 char *
-eval_expression_condition (const char *expr, struct t_hashtable *pointers,
+eval_expression_condition (const char *expr,
+                           struct t_hashtable *pointers,
                            struct t_hashtable *extra_vars,
-                           int keep_parentheses,
-                           const char *prefix, const char *suffix)
+                           const char *prefix,
+                           const char *suffix)
 {
     int logic, comp, length, level, rc;
-    const char *pos_end;
-    char *expr2, *sub_expr, *pos, *pos2, *value, *tmp_value, *tmp_value2;
+    const char *pos, *pos_end;
+    char *expr2, *sub_expr, *value, *tmp_value, *tmp_value2;
 
     value = NULL;
 
@@ -549,73 +725,6 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
     if (!expr2)
         return NULL;
 
-    /*
-     * evaluate sub-expressions between parentheses and replace them with their
-     * value
-     */
-    if (!keep_parentheses)
-    {
-        while ((pos = strchr (expr2, '(')) != NULL)
-        {
-            level = 0;
-            pos2 = pos + 1;
-            while (pos2[0])
-            {
-                if (pos2[0] == '(')
-                    level++;
-                else if (pos2[0] == ')')
-                {
-                    if (level == 0)
-                        break;
-                    level--;
-                }
-                pos2++;
-            }
-            /* closing parenthesis not found */
-            if (pos2[0] != ')')
-                goto end;
-            sub_expr = string_strndup (pos + 1, pos2 - pos - 1);
-            if (!sub_expr)
-                goto end;
-            tmp_value = eval_expression_condition (sub_expr, pointers,
-                                                   extra_vars,
-                                                   0, prefix, suffix);
-            free (sub_expr);
-            if (!pos[1])
-            {
-                /* nothing around parentheses, then return value of sub-expression as-is */
-                value = tmp_value;
-                goto end;
-            }
-            /*
-             * build a string with string before '(' +
-             * result of sub-expression + string after ')'
-             */
-            length = (pos - expr2) + 1
-                + ((tmp_value) ? strlen (tmp_value) : 0)
-                + 1 + strlen (pos2 + 1)
-                + 1;
-            tmp_value2 = malloc (length);
-            if (!tmp_value2)
-                goto end;
-            tmp_value2[0] = '\0';
-            if (pos > expr2)
-            {
-                strncat (tmp_value2, expr2, pos - expr2);
-                strcat (tmp_value2, " ");
-            }
-            if (tmp_value)
-                strcat (tmp_value2, tmp_value);
-            if (pos2[1])
-            {
-                strcat (tmp_value2, " ");
-                strcat (tmp_value2, pos2 + 1);
-            }
-            free (expr2);
-            expr2 = tmp_value2;
-        }
-    }
-
     /*
      * search for a logical operator, and if one is found:
      * - split expression into two sub-expressions
@@ -625,7 +734,7 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
      */
     for (logic = 0; logic < EVAL_NUM_LOGICAL_OPS; logic++)
     {
-        pos = strstr (expr2, logical_ops[logic]);
+        pos = eval_strstr_level (expr2, logical_ops[logic]);
         if (pos > expr2)
         {
             pos_end = pos - 1;
@@ -638,14 +747,14 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
                 goto end;
             tmp_value = eval_expression_condition (sub_expr, pointers,
                                                    extra_vars,
-                                                   0, prefix, suffix);
+                                                   prefix, suffix);
             free (sub_expr);
             rc = eval_is_true (tmp_value);
             if (tmp_value)
                 free (tmp_value);
             /*
-             * if rc == 0 with "&&" or rc == 1 with "||", no need to evaluate
-             * second sub-expression, just return the rc
+             * if rc == 0 with "&&" or rc == 1 with "||", no need to
+             * evaluate second sub-expression, just return the rc
              */
             if ((!rc && (logic == EVAL_LOGICAL_OP_AND))
                 || (rc && (logic == EVAL_LOGICAL_OP_OR)))
@@ -659,7 +768,7 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
                 pos++;
             }
             tmp_value = eval_expression_condition (pos, pointers, extra_vars,
-                                                   0, prefix, suffix);
+                                                   prefix, suffix);
             rc = eval_is_true (tmp_value);
             if (tmp_value)
                 free (tmp_value);
@@ -677,7 +786,7 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
      */
     for (comp = 0; comp < EVAL_NUM_COMPARISONS; comp++)
     {
-        pos = strstr (expr2, comparisons[comp]);
+        pos = eval_strstr_level (expr2, comparisons[comp]);
         if (pos > expr2)
         {
             pos_end = pos - 1;
@@ -688,19 +797,35 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
             sub_expr = string_strndup (expr2, pos_end + 1 - expr2);
             if (!sub_expr)
                 goto end;
-            tmp_value = eval_expression_condition (sub_expr, pointers,
-                                                   extra_vars,
-                                                   0, prefix, suffix);
-            free (sub_expr);
             pos += strlen (comparisons[comp]);
             while (pos[0] == ' ')
             {
                 pos++;
             }
-            tmp_value2 = eval_expression_condition (pos, pointers, extra_vars,
-                                                    ((comp == EVAL_COMPARE_REGEX_MATCHING)
-                                                     || (comp == EVAL_COMPARE_REGEX_NOT_MATCHING)) ? 1 : 0,
-                                                    prefix, suffix);
+            if ((comp == EVAL_COMPARE_REGEX_MATCHING)
+                || (comp == EVAL_COMPARE_REGEX_NOT_MATCHING))
+            {
+                /* for regex: just replace vars in both expressions */
+                tmp_value = eval_replace_vars (sub_expr, pointers,
+                                               extra_vars,
+                                               prefix, suffix,
+                                               NULL);
+                tmp_value2 = eval_replace_vars (pos, pointers,
+                                                extra_vars,
+                                                prefix, suffix,
+                                                NULL);
+            }
+            else
+            {
+                /* other comparison: fully evaluate both expressions */
+                tmp_value = eval_expression_condition (sub_expr, pointers,
+                                                       extra_vars,
+                                                       prefix, suffix);
+                tmp_value2 = eval_expression_condition (pos, pointers,
+                                                        extra_vars,
+                                                        prefix, suffix);
+            }
+            free (sub_expr);
             value = eval_compare (tmp_value, comp, tmp_value2);
             if (tmp_value)
                 free (tmp_value);
@@ -710,11 +835,70 @@ eval_expression_condition (const char *expr, struct t_hashtable *pointers,
         }
     }
 
+    /*
+     * evaluate sub-expressions between parentheses and replace them with their
+     * value
+     */
+    while (expr2[0] == '(')
+    {
+        level = 0;
+        pos = expr2 + 1;
+        while (pos[0])
+        {
+            if (pos[0] == '(')
+                level++;
+            else if (pos[0] == ')')
+            {
+                if (level == 0)
+                    break;
+                level--;
+            }
+            pos++;
+        }
+        /* closing parenthesis not found */
+        if (pos[0] != ')')
+            goto end;
+        sub_expr = string_strndup (expr2 + 1, pos - expr2 - 1);
+        if (!sub_expr)
+            goto end;
+        tmp_value = eval_expression_condition (sub_expr, pointers, extra_vars,
+                                               prefix, suffix);
+        free (sub_expr);
+        if (!pos[1])
+        {
+            /*
+             * nothing around parentheses, then return value of
+             * sub-expression as-is
+             */
+            value = tmp_value;
+            goto end;
+        }
+        length = ((tmp_value) ? strlen (tmp_value) : 0) + 1 +
+            strlen (pos + 1) + 1;
+        tmp_value2 = malloc (length);
+        if (!tmp_value2)
+        {
+            if (tmp_value)
+                free (tmp_value);
+            goto end;
+        }
+        tmp_value2[0] = '\0';
+        if (tmp_value)
+            strcat (tmp_value2, tmp_value);
+        strcat (tmp_value2, " ");
+        strcat (tmp_value2, pos + 1);
+        free (expr2);
+        expr2 = tmp_value2;
+        if (tmp_value)
+            free (tmp_value);
+    }
+
     /*
      * at this point, there is no more logical operator neither comparison,
      * so we just replace variables in string and return the result
      */
-    value = eval_replace_vars (expr2, pointers, extra_vars, prefix, suffix);
+    value = eval_replace_vars (expr2, pointers, extra_vars, prefix, suffix,
+                               NULL);
 
 end:
     if (expr2)
@@ -723,6 +907,125 @@ end:
     return value;
 }
 
+/*
+ * Replaces text in a string using a regular expression and replacement text.
+ *
+ * The argument "regex" is a pointer to a regex compiled with WeeChat function
+ * string_regcomp (or function regcomp).
+ *
+ * The argument "replace" is evaluated and can contain any valid expression,
+ * and these ones:
+ *   ${re:0} .. ${re:99}  match 0 to 99 (0 is whole match, 1 .. 99 are groups
+ *                        captured)
+ *   ${re:+}              the last match (with highest number)
+ *
+ * Examples:
+ *
+ *    string   | regex         | replace                    | result
+ *   ----------+---------------+----------------------------+-------------
+ *    test foo | test          | Z                          | Z foo
+ *    test foo | ^(test +)(.*) | ${re:2}                    | foo
+ *    test foo | ^(test +)(.*) | ${re:1}/ ${hide:*,${re:2}} | test / ***
+ *    test foo | ^(test +)(.*) | ${hide:%,${re:+}}          | %%%
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+eval_replace_regex (const char *string, regex_t *regex, const char *replace,
+                    struct t_hashtable *pointers,
+                    struct t_hashtable *extra_vars,
+                    const char *prefix, const char *suffix)
+{
+    char *result, *result2, *str_replace;
+    int length, length_replace, start_offset, i, rc, end;
+    struct t_eval_regex eval_regex;
+
+    if (!string || !regex || !replace)
+        return NULL;
+
+    length = strlen (string) + 1;
+    result = malloc (length);
+    if (!result)
+        return NULL;
+    snprintf (result, length, "%s", string);
+
+    start_offset = 0;
+    while (result && result[start_offset])
+    {
+        for (i = 0; i < 100; i++)
+        {
+            eval_regex.match[i].rm_so = -1;
+        }
+
+        rc = regexec (regex, result + start_offset, 100, eval_regex.match, 0);
+        /*
+         * no match found: exit the loop (if rm_eo == 0, it is an empty match
+         * at beginning of string: we consider there is no match, to prevent an
+         * infinite loop)
+         */
+        if ((rc != 0)
+            || (eval_regex.match[0].rm_so < 0)
+            || (eval_regex.match[0].rm_eo <= 0))
+        {
+            break;
+        }
+
+        /* adjust the start/end offsets */
+        eval_regex.last_match = 0;
+        for (i = 0; i < 100; i++)
+        {
+            if (eval_regex.match[i].rm_so >= 0)
+            {
+                eval_regex.last_match = i;
+                eval_regex.match[i].rm_so += start_offset;
+                eval_regex.match[i].rm_eo += start_offset;
+            }
+        }
+
+        /* check if the regex matched the end of string */
+        end = !result[eval_regex.match[0].rm_eo];
+
+        eval_regex.result = result;
+
+        str_replace = eval_replace_vars (replace, pointers, extra_vars,
+                                         prefix, suffix, &eval_regex);
+
+        length_replace = (str_replace) ? strlen (str_replace) : 0;
+
+        length = eval_regex.match[0].rm_so + length_replace +
+            strlen (result + eval_regex.match[0].rm_eo) + 1;
+        result2 = malloc (length);
+        if (!result2)
+        {
+            free (result);
+            return NULL;
+        }
+        result2[0] = '\0';
+        if (eval_regex.match[0].rm_so > 0)
+        {
+            memcpy (result2, result, eval_regex.match[0].rm_so);
+            result2[eval_regex.match[0].rm_so] = '\0';
+        }
+        if (str_replace)
+            strcat (result2, str_replace);
+        strcat (result2, result + eval_regex.match[0].rm_eo);
+
+        free (result);
+        result = result2;
+
+        if (str_replace)
+            free (str_replace);
+
+        if (end)
+            break;
+
+        start_offset = eval_regex.match[0].rm_so + length_replace;
+    }
+
+    return result;
+}
+
 /*
  * Evaluates an expression.
  *
@@ -768,35 +1071,41 @@ char *
 eval_expression (const char *expr, struct t_hashtable *pointers,
                  struct t_hashtable *extra_vars, struct t_hashtable *options)
 {
-    int condition, rc;
+    int condition, rc, pointers_allocated, regex_allocated;
     char *value;
-    const char *prefix, *suffix, *default_prefix = "${", *default_suffix = "}";
-    const char *ptr_value;
+    const char *prefix, *suffix;
+    const char *default_prefix = EVAL_DEFAULT_PREFIX;
+    const char *default_suffix = EVAL_DEFAULT_SUFFIX;
+    const char *ptr_value, *regex_replace;
     struct t_gui_window *window;
+    regex_t *regex;
 
     if (!expr)
         return NULL;
 
     condition = 0;
+    pointers_allocated = 0;
+    regex_allocated = 0;
     prefix = default_prefix;
     suffix = default_suffix;
+    regex = NULL;
+    regex_replace = NULL;
 
-    /* create hashtable pointers if it's NULL */
-    if (!pointers)
+    if (pointers)
     {
-        if (eval_hashtable_pointers)
-            hashtable_remove_all (eval_hashtable_pointers);
-        else
-        {
-            eval_hashtable_pointers = hashtable_new (32,
-                                                     WEECHAT_HASHTABLE_STRING,
-                                                     WEECHAT_HASHTABLE_POINTER,
-                                                     NULL,
-                                                     NULL);
-            if (!eval_hashtable_pointers)
-                return NULL;
-        }
-        pointers = eval_hashtable_pointers;
+        regex = (regex_t *)hashtable_get (pointers, "regex");
+    }
+    else
+    {
+        /* create hashtable pointers if it's NULL */
+        pointers = hashtable_new (32,
+                                  WEECHAT_HASHTABLE_STRING,
+                                  WEECHAT_HASHTABLE_POINTER,
+                                  NULL,
+                                  NULL);
+        if (!pointers)
+            return NULL;
+        pointers_allocated = 1;
     }
 
     /*
@@ -832,6 +1141,30 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         ptr_value = hashtable_get (options, "suffix");
         if (ptr_value && ptr_value[0])
             suffix = ptr_value;
+
+        /* check for regex */
+        ptr_value = hashtable_get (options, "regex");
+        if (ptr_value)
+        {
+            regex = malloc (sizeof (*regex));
+            if (string_regcomp (regex, ptr_value,
+                                REG_EXTENDED | REG_ICASE) == 0)
+            {
+                regex_allocated = 1;
+            }
+            else
+            {
+                free (regex);
+                regex = NULL;
+            }
+        }
+
+        /* check for regex replacement (evaluated later) */
+        ptr_value = hashtable_get (options, "regex_replace");
+        if (ptr_value)
+        {
+            regex_replace = ptr_value;
+        }
     }
 
     /* evaluate expression */
@@ -839,7 +1172,7 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
     {
         /* evaluate as condition (return a boolean: "0" or "1") */
         value = eval_expression_condition (expr, pointers, extra_vars,
-                                           0, prefix, suffix);
+                                           prefix, suffix);
         rc = eval_is_true (value);
         if (value)
             free (value);
@@ -847,23 +1180,28 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
     }
     else
     {
-        /* only replace variables in expression */
-        value = eval_replace_vars (expr, pointers, extra_vars, prefix, suffix);
+        if (regex && regex_replace)
+        {
+            /* replace with regex */
+            value = eval_replace_regex (expr, regex, regex_replace,
+                                        pointers, extra_vars,
+                                        prefix, suffix);
+        }
+        else
+        {
+            /* only replace variables in expression */
+            value = eval_replace_vars (expr, pointers, extra_vars,
+                                       prefix, suffix, NULL);
+        }
+    }
+
+    if (pointers_allocated)
+        hashtable_free (pointers);
+    if (regex && regex_allocated)
+    {
+        regfree (regex);
+        free (regex);
     }
 
     return value;
 }
-
-/*
- * Frees all allocated data.
- */
-
-void
-eval_end ()
-{
-    if (eval_hashtable_pointers)
-    {
-        hashtable_free (eval_hashtable_pointers);
-        eval_hashtable_pointers = NULL;
-    }
-}
