@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,15 +17,16 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_HDATA_H
-#define __WEECHAT_HDATA_H 1
+#ifndef WEECHAT_HDATA_H
+#define WEECHAT_HDATA_H 1
 
 #define HDATA_VAR(__struct, __name, __type, __update_allowed,           \
                   __array_size, __hdata_name)                           \
     hdata_new_var (hdata, #__name, offsetof (__struct, __name),         \
                    WEECHAT_HDATA_##__type, __update_allowed,            \
                    __array_size, __hdata_name)
-#define HDATA_LIST(__name) hdata_new_list (hdata, #__name, &(__name));
+#define HDATA_LIST(__name, __flags)                                     \
+    hdata_new_list (hdata, #__name, &(__name), __flags);
 
 struct t_hdata_var
 {
@@ -36,6 +37,12 @@ struct t_hdata_var
     char *hdata_name;                  /* hdata name                        */
 };
 
+struct t_hdata_list
+{
+    void *pointer;                     /* list pointer                      */
+    int flags;                         /* flags for list                    */
+};
+
 struct t_hdata
 {
     char *name;                        /* name of hdata                     */
@@ -79,7 +86,7 @@ extern void hdata_new_var (struct t_hdata *hdata, const char *name, int offset,
                            int type, int update_allowed, const char *array_size,
                            const char *hdata_name);
 extern void hdata_new_list (struct t_hdata *hdata, const char *name,
-                            void *pointer);
+                            void *pointer, int flags);
 extern int hdata_get_var_offset (struct t_hdata *hdata, const char *name);
 extern int hdata_get_var_type (struct t_hdata *hdata, const char *name);
 extern const char *hdata_get_var_type_string (struct t_hdata *hdata,
@@ -127,4 +134,4 @@ extern void hdata_print_log ();
 extern void hdata_init ();
 extern void hdata_end ();
 
-#endif /* __WEECHAT_HDATA_H */
+#endif /* WEECHAT_HDATA_H */
