@@ -1,7 +1,7 @@
 /*
  * wee-log.c - WeeChat log file (weechat.log)
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -98,7 +98,7 @@ log_open (const char *filename, const char *mode)
             return 0;
         }
     }
-#endif
+#endif /* HAVE_FLOCK */
 
     return 1;
 }
@@ -115,7 +115,7 @@ log_init ()
         string_iconv_fprintf (stderr,
                               _("Error: unable to create/append to log file (weechat.log)\n"
                                 "If another WeeChat process is using this file, try to run WeeChat\n"
-                                "with another home using \"--dir\" command line option.\n"));
+                                "with another home using the \"--dir\" command line option.\n"));
         exit (1);
     }
     log_printf ("WeeChat %s (%s %s %s)",
@@ -224,7 +224,7 @@ log_close ()
     {
 #ifdef HAVE_FLOCK
         flock (fileno (weechat_log_file), LOCK_UN);
-#endif
+#endif /* HAVE_FLOCK */
         fclose (weechat_log_file);
         weechat_log_file = NULL;
     }
