@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -38,12 +38,16 @@ extern int string_strcmp_ignore_chars (const char *string1,
                                        const char *string2,
                                        const char *chars_ignored,
                                        int case_sensitive);
-extern char *string_strcasestr (const char *string, const char *search);
+extern const char *string_strcasestr (const char *string, const char *search);
 extern int string_match (const char *string, const char *mask,
                          int case_sensitive);
 extern char *string_replace (const char *string, const char *search,
                              const char *replace);
 extern char *string_expand_home (const char *path);
+extern char *string_eval_path_home (const char *path,
+                                    struct t_hashtable *pointers,
+                                    struct t_hashtable *extra_vars,
+                                    struct t_hashtable *options);
 extern char *string_remove_quotes (const char *string, const char *quotes);
 extern char *string_strip (const char *string, int left, int right,
                            const char *chars);
@@ -87,6 +91,9 @@ extern void string_encode_base16 (const char *from, int length, char *to);
 extern int string_decode_base16 (const char *from, char *to);
 extern void string_encode_base64 (const char *from, int length, char *to);
 extern int string_decode_base64 (const char *from, char *to);
+extern char *string_hex_dump (const char *data, int data_size,
+                              int bytes_per_line,
+                              const char *prefix, const char *suffix);
 extern int string_is_command_char (const char *string);
 extern const char *string_input_for_buffer (const char *string);
 extern char *string_replace_with_callback (const char *string,
