@@ -1,7 +1,7 @@
 /*
  * wee-utf8.c - UTF-8 string functions
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -70,42 +70,65 @@ utf8_has_8bits (const char *string)
 /*
  * Checks if a string is UTF-8 valid.
  *
+ * If length is <= 0, checks whole string.
+ * If length is > 0, checks only this number of chars (not bytes).
+ *
  * Returns:
  *   1: string is UTF-8 valid
- *   0: string it not UTF-8 valid, and then if error is not NULL, it is set with
- *      first non valid UTF-8 char in string
+ *   0: string it not UTF-8 valid, and then if error is not NULL, it is set
+ *      with first non valid UTF-8 char in string
  */
 
 int
-utf8_is_valid (const char *string, char **error)
+utf8_is_valid (const char *string, int length, char **error)
 {
-    while (string && string[0])
+    int code_point, current_char;
+
+    current_char = 0;
+
+    while (string && string[0]
+           && ((length <= 0) || (current_char < length)))
     {
-        /* UTF-8, 2 bytes, should be: 110vvvvv 10vvvvvv */
+        /*
+         * UTF-8, 2 bytes, should be: 110vvvvv 10vvvvvv
+         * and in range: U+0080 - U+07FF
+         */
         if (((unsigned char)(string[0]) & 0xE0) == 0xC0)
         {
             if (!string[1] || (((unsigned char)(string[1]) & 0xC0) != 0x80))
-            {
-                if (error)
-                    *error = (char *)string;
-                return 0;
-            }
+                goto invalid;
+            code_point = utf8_char_int (string);
+            if ((code_point < 0x0080) || (code_point > 0x07FF))
+                goto invalid;
             string += 2;
         }
-        /* UTF-8, 3 bytes, should be: 1110vvvv 10vvvvvv 10vvvvvv */
+        /*
+         * UTF-8, 3 bytes, should be: 1110vvvv 10vvvvvv 10vvvvvv
+         * and in range: U+0800 - U+FFFF
+         * (note: high and low surrogate halves used by UTF-16 (U+D800 through
+         * U+DFFF) are not legal Unicode values)
+         */
         else if (((unsigned char)(string[0]) & 0xF0) == 0xE0)
         {
             if (!string[1] || !string[2]
                 || (((unsigned char)(string[1]) & 0xC0) != 0x80)
                 || (((unsigned char)(string[2]) & 0xC0) != 0x80))
             {
-                if (error)
-                    *error = (char *)string;
-                return 0;
+                goto invalid;
+            }
+            code_point = utf8_char_int (string);
+            if ((code_point < 0x0800)
+                || (code_point > 0xFFFF)
+                || ((code_point >= 0xD800) && (code_point <= 0xDFFF)))
+            {
+                goto invalid;
             }
             string += 3;
         }
-        /* UTF-8, 4 bytes, should be: 11110vvv 10vvvvvv 10vvvvvv 10vvvvvv */
+        /*
+         * UTF-8, 4 bytes, should be: 11110vvv 10vvvvvv 10vvvvvv 10vvvvvv
+         * and in range: U+10000 - U+1FFFFF
+         */
         else if (((unsigned char)(string[0]) & 0xF8) == 0xF0)
         {
             if (!string[1] || !string[2] || !string[3]
@@ -113,25 +136,28 @@ utf8_is_valid (const char *string, char **error)
                 || (((unsigned char)(string[2]) & 0xC0) != 0x80)
                 || (((unsigned char)(string[3]) & 0xC0) != 0x80))
             {
-                if (error)
-                    *error = (char *)string;
-                return 0;
+                goto invalid;
             }
+            code_point = utf8_char_int(string);
+            if ((code_point < 0x10000) || (code_point > 0x1FFFFF))
+                goto invalid;
             string += 4;
         }
         /* UTF-8, 1 byte, should be: 0vvvvvvv */
         else if ((unsigned char)(string[0]) >= 0x80)
-        {
-            if (error)
-                *error = (char *)string;
-            return 0;
-        }
+            goto invalid;
         else
             string++;
+        current_char++;
     }
     if (error)
         *error = NULL;
     return 1;
+
+invalid:
+    if (error)
+        *error = (char *)string;
+    return 0;
 }
 
 /*
@@ -146,7 +172,7 @@ utf8_normalize (char *string, char replacement)
 
     while (string && string[0])
     {
-        if (utf8_is_valid (string, &error))
+        if (utf8_is_valid (string, -1, &error))
             return;
         error[0] = replacement;
         string = error + 1;
@@ -160,7 +186,7 @@ utf8_normalize (char *string, char replacement)
  * "string_start" was reached).
  */
 
-char *
+const char *
 utf8_prev_char (const char *string_start, const char *string)
 {
     if (!string || (string <= string_start))
@@ -203,7 +229,7 @@ utf8_prev_char (const char *string_start, const char *string)
  * Returns pointer to next UTF-8 char, NULL if string was NULL.
  */
 
-char *
+const char *
 utf8_next_char (const char *string)
 {
     if (!string)
@@ -524,9 +550,9 @@ utf8_strlen_screen (const char *string)
  * Compares two UTF-8 chars (case sensitive).
  *
  * Returns:
- *   < 0: char1 < char2
- *     0: char1 == char2
- *   > 0: char1 > char2
+ *   -1: string1 < string2
+ *    0: string1 == string2
+ *    1: string1 > string2
  */
 
 int
@@ -545,7 +571,7 @@ utf8_charcmp (const char *string1, const char *string2)
     {
         diff = (int)((unsigned char) string1[i]) - (int)((unsigned char) string2[i]);
         if (diff != 0)
-            return diff;
+            return (diff < 0) ? -1 : 1;
         i++;
     }
     /* string1 == string2 ? */
@@ -562,9 +588,9 @@ utf8_charcmp (const char *string1, const char *string2)
  * Compares two UTF-8 chars (case is ignored).
  *
  * Returns:
- *   < 0: char1 < char2
- *     0: char1 == char2
- *   > 0: char1 > char2
+ *   -1: string1 < string2
+ *    0: string1 == string2
+ *    1: string1 > string2
  */
 
 int
@@ -654,7 +680,7 @@ utf8_char_size_screen (const char *string)
  * Returns pointer to the new position in string.
  */
 
-char *
+const char *
 utf8_add_offset (const char *string, int offset)
 {
     if (!string)
@@ -665,7 +691,7 @@ utf8_add_offset (const char *string, int offset)
         string = utf8_next_char (string);
         offset--;
     }
-    return (char *)string;
+    return string;
 }
 
 /*
@@ -682,7 +708,7 @@ int
 utf8_real_pos (const char *string, int pos)
 {
     int count, real_pos;
-    char *next_char;
+    const char *next_char;
 
     if (!string)
         return pos;
