@@ -1,7 +1,7 @@
 /*
  * wee-util.c - some useful functions
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -305,7 +305,7 @@ util_timeval_add (struct timeval *tv, long long interval)
  * (can be localized).
  */
 
-char *
+const char *
 util_get_time_string (const time_t *date)
 {
     struct tm *local_time;
@@ -718,7 +718,8 @@ util_file_get_content (const char *filename)
 int
 util_version_number (const char *version)
 {
-    char **items, buf[64], *ptr_item, *error;
+    char **items, buf[64], *error;
+    const char *ptr_item;
     int num_items, i, version_int[4], index_buf;
     long number;
 
