@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_UTIL_H
-#define __WEECHAT_UTIL_H 1
+#ifndef WEECHAT_UTIL_H
+#define WEECHAT_UTIL_H 1
 
 #ifdef HAVE_SYS_RESOURCE_H
 struct t_rlimit_resource
@@ -28,11 +28,18 @@ struct t_rlimit_resource
 };
 #endif /* HAVE_SYS_RESOURCE_H */
 
+struct t_util_signal
+{
+    char *name;                        /* name of signal                    */
+    int signal;                        /* signal number                     */
+};
+
 extern void util_setrlimit ();
 extern int util_timeval_cmp (struct timeval *tv1, struct timeval *tv2);
-extern long util_timeval_diff (struct timeval *tv1, struct timeval *tv2);
-extern void util_timeval_add (struct timeval *tv, long interval);
-extern char *util_get_time_string (const time_t *date);
+extern long long util_timeval_diff (struct timeval *tv1, struct timeval *tv2);
+extern void util_timeval_add (struct timeval *tv, long long interval);
+extern const char *util_get_time_string (const time_t *date);
+extern int util_signal_search (const char *name);
 extern void util_catch_signal (int signum, void (*handler)(int));
 extern int util_mkdir_home (const char *directory, int mode);
 extern int util_mkdir (const char *directory, int mode);
@@ -46,4 +53,4 @@ extern char *util_search_full_lib_name (const char *filename,
 extern char *util_file_get_content (const char *filename);
 extern int util_version_number (const char *version);
 
-#endif /* __WEECHAT_UTIL_H */
+#endif /* WEECHAT_UTIL_H */
