@@ -17,7 +17,7 @@
  *
  * weechat.c - WeeChat main functions
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -191,7 +191,11 @@ weechat_parse_args (int argc, char *argv[])
             || (strcmp (argv[i], "--dir") == 0))
         {
             if (i + 1 < argc)
+            {
+                if (weechat_home)
+                    free (weechat_home);
                 weechat_home = strdup (argv[++i]);
+            }
             else
             {
                 string_iconv_fprintf (stderr,
@@ -255,7 +259,11 @@ weechat_parse_args (int argc, char *argv[])
                  || (strcmp (argv[i], "--run-command") == 0))
         {
             if (i + 1 < argc)
+            {
+                if (weechat_startup_commands)
+                    free (weechat_startup_commands);
                 weechat_startup_commands = strdup (argv[++i]);
+            }
             else
             {
                 string_iconv_fprintf (stderr,
@@ -462,35 +470,62 @@ void
 weechat_term_check ()
 {
     char *term, *sty, *tmux;
+    const char *screen_terms = "screen-256color, screen";
+    const char *tmux_terms = "tmux-256color, tmux, screen-256color, screen";
+    const char *ptr_terms;
     int is_term_ok, is_screen, is_tmux;
 
     term = getenv ("TERM");
     sty = getenv ("STY");
     tmux = getenv ("TMUX");
 
-    is_term_ok = (term && (strncmp (term, "screen", 6) == 0));
     is_screen = (sty && sty[0]);
     is_tmux = (tmux && tmux[0]);
 
-    if ((is_screen || is_tmux) && !is_term_ok)
+    if (is_screen || is_tmux)
     {
-        gui_chat_printf (
-            NULL,
-            /* TRANSLATORS: the "under %s" can be "under screen" or "under tmux" */
-            _("%sWarning: WeeChat is running under %s and $TERM is \"%s\", "
-              "which can cause display bugs; $TERM should be set to "
-              "\"screen-256color\" or \"screen\""),
-            gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
-            (is_screen) ? "screen" : "tmux",
-            (term) ? term : "");
-        gui_chat_printf (
-            NULL,
-            _("%sYou should add this line in the file %s:  %s"),
-            gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
-            (is_screen) ? "~/.screenrc" : "~/.tmux.conf",
-            (is_screen) ?
-            "term screen-256color" :
-            "set -g default-terminal \"screen-256color\"");
+        /* check if $TERM is OK (according to screen/tmux) */
+        is_term_ok = 0;
+        ptr_terms = NULL;
+        if (is_screen)
+        {
+            is_term_ok = (term && (strncmp (term, "screen", 6) == 0));
+            ptr_terms = screen_terms;
+        }
+        else if (is_tmux)
+        {
+            is_term_ok = (term
+                          && ((strncmp (term, "screen", 6) == 0)
+                              || (strncmp (term, "tmux", 4) == 0)));
+            ptr_terms = tmux_terms;
+        }
+
+        /* display a warning if $TERM is NOT OK */
+        if (!is_term_ok)
+        {
+            gui_chat_printf_date_tags (
+                NULL,
+                0,
+                "term_warning",
+                /* TRANSLATORS: the "under %s" can be "under screen" or "under tmux" */
+                _("%sWarning: WeeChat is running under %s and $TERM is \"%s\", "
+                  "which can cause display bugs; $TERM should be set to one "
+                  "of these values: %s"),
+                gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
+                (is_screen) ? "screen" : "tmux",
+                (term) ? term : "",
+                ptr_terms);
+            gui_chat_printf_date_tags (
+                NULL,
+                0,
+                "term_warning",
+                _("%sYou should add this line in the file %s:  %s"),
+                gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
+                (is_screen) ? "~/.screenrc" : "~/.tmux.conf",
+                (is_screen) ?
+                "term screen-256color" :
+                "set -g default-terminal \"tmux-256color\"");
+        }
     }
 }
 
@@ -578,18 +613,17 @@ weechat_shutdown (int return_code, int crash)
 {
     gui_chat_print_lines_waiting_buffer (stderr);
 
+    log_close ();
+    network_end ();
+    debug_end ();
+
     if (weechat_argv0)
         free (weechat_argv0);
     if (weechat_home)
         free (weechat_home);
-    log_close ();
     if (weechat_local_charset)
         free (weechat_local_charset);
 
-    network_end ();
-
-    debug_end ();
-
     if (crash)
         abort();
     else if (return_code >= 0)
