@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_H
-#define __WEECHAT_H 1
+#ifndef WEECHAT_H
+#define WEECHAT_H 1
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -35,25 +35,25 @@
         #include <libintl.h>
     #else
         #include "../../intl/libintl.h"
-    #endif
+    #endif /* HAVE_LIBINTL_H */
     #define _(string) gettext(string)
     #define NG_(single,plural,number) ngettext(single,plural,number)
     #ifdef gettext_noop
         #define N_(string) gettext_noop(string)
     #else
         #define N_(string) (string)
-    #endif
-#endif
+    #endif /* gettext_noop */
+#endif /* defined(ENABLE_NLS) && !defined(_) */
 #if !defined(_)
     #define _(string) (string)
     #define NG_(single,plural,number) (plural)
     #define N_(string) (string)
-#endif
+#endif /* !defined(_) */
 
 
-#define WEECHAT_COPYRIGHT_DATE   "(C) 2003-2014"
-#define WEECHAT_WEBSITE          "http://www.weechat.org/"
-#define WEECHAT_WEBSITE_DOWNLOAD "http://www.weechat.org/download"
+#define WEECHAT_COPYRIGHT_DATE   "(C) 2003-2016"
+#define WEECHAT_WEBSITE          "https://weechat.org/"
+#define WEECHAT_WEBSITE_DOWNLOAD "https://weechat.org/download"
 
 /* log file */
 #define WEECHAT_LOG_NAME "weechat.log"
@@ -81,12 +81,12 @@
 #else
     #define DIR_SEPARATOR       "/"
     #define DIR_SEPARATOR_CHAR  '/'
-#endif
+#endif /* _WIN32 */
 
 /* some systems like GNU/Hurd do not define PATH_MAX */
 #ifndef PATH_MAX
     #define PATH_MAX 4096
-#endif
+#endif /* PATH_MAX */
 
 /* internal charset */
 #define WEECHAT_INTERNAL_CHARSET "UTF-8"
@@ -95,6 +95,7 @@
 extern int weechat_debug_core;
 extern char *weechat_argv0;
 extern int weechat_upgrading;
+extern int weechat_first_start;
 extern time_t weechat_first_start_time;
 extern struct timeval weechat_current_start_timeval;
 extern int weechat_upgrade_count;
@@ -106,6 +107,9 @@ extern int weechat_no_gnutls;
 extern int weechat_no_gcrypt;
 extern char *weechat_startup_commands;
 
+extern void weechat_term_check ();
 extern void weechat_shutdown (int return_code, int crash);
+extern void weechat_init (int argc, char *argv[], void (*gui_init_cb)());
+extern void weechat_end (void (*gui_end_cb)(int clean_exit));
 
-#endif /* __WEECHAT_H */
+#endif /* WEECHAT_H */
