@@ -1,7 +1,7 @@
 /*
  * gui-curses-color.c - color functions for Curses GUI
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -383,9 +383,9 @@ gui_color_get_pair (int fg, int bg)
         return COLOR_WHITE;
 
     /* if invalid color, use default fg/bg */
-    if (fg > gui_color_term_colors)
+    if (fg >= gui_color_term_colors)
         fg = -1;
-    if (bg > gui_color_term_colors)
+    if (bg >= gui_color_term_colors)
         bg = -1;
 
     /* compute index for gui_color_pairs with foreground and background */
@@ -822,7 +822,8 @@ gui_color_buffer_display ()
     else
     {
         gui_chat_printf_y (gui_color_buffer, y++,
-                           _("WeeChat color pairs (in use: %d, left: %d):"),
+                           _("WeeChat color pairs auto-allocated "
+                             "(in use: %d, left: %d):"),
                            gui_color_pairs_used,
                            gui_color_num_pairs - gui_color_pairs_used);
     }
@@ -876,6 +877,10 @@ gui_color_buffer_display ()
                            " %s",
                            str_line);
     }
+    gui_chat_printf_y (gui_color_buffer, y++,
+                       (gui_color_use_term_colors) ?
+                       "" : _("(press alt-c to see the colors you can use "
+                              "in options)"));
 
     if (gui_color_buffer_extra_info)
     {
@@ -902,7 +907,8 @@ gui_color_buffer_display ()
             else
             {
                 snprintf (str_color, sizeof (str_color),
-                          "%c%c%02d %s",
+                          "%c %c%c%02d%s",
+                          GUI_COLOR_RESET_CHAR,
                           GUI_COLOR_COLOR_CHAR,
                           GUI_COLOR_FG_CHAR,
                           i,
@@ -942,7 +948,8 @@ gui_color_buffer_display ()
                 else
                 {
                     snprintf (str_color, sizeof (str_color),
-                              "%s %s",
+                              "%c %s%s",
+                              GUI_COLOR_RESET_CHAR,
                               gui_color_get_custom (items[i]),
                               items[i]);
                 }
@@ -1177,7 +1184,8 @@ gui_color_buffer_assign ()
 {
     if (!gui_color_buffer)
     {
-        gui_color_buffer = gui_buffer_search_by_name (NULL, "color");
+        gui_color_buffer = gui_buffer_search_by_name (NULL,
+                                                      GUI_COLOR_BUFFER_NAME);
         if (gui_color_buffer)
         {
             gui_color_buffer->input_callback = &gui_color_buffer_input_cb;
@@ -1195,13 +1203,13 @@ gui_color_buffer_open ()
 {
     if (!gui_color_buffer)
     {
-        gui_color_buffer = gui_buffer_new (NULL, "color",
+        gui_color_buffer = gui_buffer_new (NULL, GUI_COLOR_BUFFER_NAME,
                                            &gui_color_buffer_input_cb, NULL,
                                            &gui_color_buffer_close_cb, NULL);
         if (gui_color_buffer)
         {
             if (!gui_color_buffer->short_name)
-                gui_color_buffer->short_name = strdup ("color");
+                gui_color_buffer->short_name = strdup (GUI_COLOR_BUFFER_NAME);
             gui_buffer_set (gui_color_buffer, "type", "free");
             gui_buffer_set (gui_color_buffer, "localvar_set_no_log", "1");
             gui_buffer_set (gui_color_buffer, "key_bind_meta-c", "/color switch");
@@ -1454,6 +1462,7 @@ gui_color_init_weechat ()
     gui_color_build (GUI_COLOR_CHAT_NICK_SUFFIX, CONFIG_COLOR(config_color_chat_nick_suffix), CONFIG_COLOR(config_color_chat_bg));
     gui_color_build (GUI_COLOR_EMPHASIS, CONFIG_COLOR(config_color_emphasized), CONFIG_COLOR(config_color_emphasized_bg));
     gui_color_build (GUI_COLOR_CHAT_DAY_CHANGE, CONFIG_COLOR(config_color_chat_day_change), CONFIG_COLOR(config_color_chat_bg));
+    gui_color_build (GUI_COLOR_CHAT_VALUE_NULL, CONFIG_COLOR(config_color_chat_value_null), CONFIG_COLOR(config_color_chat_bg));
 
     /*
      * define old nick colors for compatibility on /upgrade with previous
@@ -1474,26 +1483,11 @@ gui_color_init_weechat ()
 }
 
 /*
- * Pre-initializes colors.
+ * Allocates GUI colors.
  */
 
 void
-gui_color_pre_init ()
-{
-    int i;
-
-    for (i = 0; i < GUI_COLOR_NUM_COLORS; i++)
-    {
-        gui_color[i] = NULL;
-    }
-}
-
-/*
- * Initializes GUI colors.
- */
-
-void
-gui_color_init ()
+gui_color_alloc ()
 {
     if (has_colors())
     {
@@ -1539,20 +1533,3 @@ gui_color_dump ()
         }
     }
 }
-
-/*
- * Ends GUI colors.
- */
-
-void
-gui_color_end ()
-{
-    int i;
-
-    for (i = 0; i < GUI_COLOR_NUM_COLORS; i++)
-    {
-        gui_color_free (gui_color[i]);
-    }
-    gui_color_palette_free_structs ();
-    gui_color_free_vars ();
-}
