@@ -1,7 +1,7 @@
 /*
  * gui-curses-main.c - main loop for Curses GUI
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -29,7 +29,6 @@
 #include <string.h>
 #include <signal.h>
 #include <time.h>
-#include <sys/select.h>
 
 #include "../../core/weechat.h"
 #include "../../core/wee-command.h"
@@ -74,22 +73,26 @@ int gui_term_lines = 0;                /* number of lines in terminal       */
  */
 
 void
-gui_main_get_password (const char *prompt1, const char *prompt2,
-                       const char *prompt3,
-                       char *password, int size)
+gui_main_get_password (const char **prompt, char *password, int size)
 {
-    int i, ch;
+    int line, i, ch;
 
     initscr ();
     cbreak ();
     noecho ();
+    raw ();
 
     clear();
 
-    mvaddstr (0, 0, prompt1);
-    mvaddstr (1, 0, prompt2);
-    mvaddstr (2, 0, prompt3);
-    mvaddstr (3, 0, "=> ");
+    line = 0;
+
+    while (prompt[line])
+    {
+        mvaddstr (line, 0, prompt[line]);
+        line++;
+    }
+
+    mvaddstr (line, 0, "=> ");
     refresh ();
 
     memset (password, '\0', size);
@@ -97,22 +100,30 @@ gui_main_get_password (const char *prompt1, const char *prompt2,
     while (i < size - 1)
     {
         ch = getch ();
+        /* enter */
         if (ch == '\n')
             break;
+        /* ctrl-C */
+        if (ch == 3)
+        {
+            password[0] = 3;
+            i = 1;
+            break;
+        }
         if (ch == 127)
         {
             if (i > 0)
             {
                 i--;
                 password[i] = '\0';
-                mvaddstr (3, 3 + i, " ");
-                move (3, 3 + i);
+                mvaddstr (line, 3 + i, " ");
+                move (line, 3 + i);
             }
         }
         else
         {
             password[i] = ch;
-            mvaddstr (3, 3 + i, "*");
+            mvaddstr (line, 3 + i, "*");
             i++;
         }
         refresh ();
@@ -371,10 +382,6 @@ void
 gui_main_loop ()
 {
     struct t_hook *hook_fd_keyboard;
-    struct timeval tv_timeout;
-    fd_set read_fds, write_fds, except_fds;
-    int max_fd;
-    int ready;
 
     /* catch SIGWINCH signal: redraw screen */
     util_catch_signal (SIGWINCH, &gui_main_signal_sigwinch);
@@ -387,7 +394,7 @@ gui_main_loop ()
 
     while (!weechat_quit)
     {
-        /* execute hook timers */
+        /* execute timer hooks */
         hook_timer_exec ();
 
         /* auto reset of color pairs */
@@ -412,18 +419,8 @@ gui_main_loop ()
 
         gui_color_pairs_auto_reset_pending = 0;
 
-        /* wait for keyboard or network activity */
-        FD_ZERO (&read_fds);
-        FD_ZERO (&write_fds);
-        FD_ZERO (&except_fds);
-        max_fd = hook_fd_set (&read_fds, &write_fds, &except_fds);
-        hook_timer_time_to_next (&tv_timeout);
-        ready = select (max_fd + 1, &read_fds, &write_fds, &except_fds,
-                        &tv_timeout);
-        if (ready > 0)
-        {
-            hook_fd_exec (&read_fds, &write_fds, &except_fds);
-        }
+        /* execute fd hooks */
+        hook_fd_exec ();
     }
 
     /* remove keyboard hook */
