@@ -1,7 +1,7 @@
 /*
  * gui-curses-mouse.c - mouse functions for Curses GUI
  *
- * Copyright (C) 2011-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -89,6 +89,7 @@ gui_mouse_enable ()
 {
     gui_mouse_enabled = 1;
     fprintf (stderr, "\033[?1005h\033[?1000h\033[?1002h");
+    fflush (stderr);
 
     (void) hook_signal_send ("mouse_enabled",
                              WEECHAT_HOOK_SIGNAL_STRING, NULL);
@@ -103,6 +104,7 @@ gui_mouse_disable ()
 {
     gui_mouse_enabled = 0;
     fprintf (stderr, "\033[?1002l\033[?1000l\033[?1005l");
+    fflush (stderr);
 
     (void) hook_signal_send ("mouse_disabled",
                              WEECHAT_HOOK_SIGNAL_STRING, NULL);
@@ -139,7 +141,7 @@ gui_mouse_grab_init (int area)
  *              @*
  */
 
-char *
+const char *
 gui_mouse_grab_event2input ()
 {
     struct t_gui_focus_info *focus_info;
@@ -255,7 +257,7 @@ gui_mouse_event_code2key (const char *code)
     int i, x, y, code_utf8, length;
     double diff_x, diff_y, distance, angle, pi4;
     static char key[128];
-    char *ptr_code;
+    const char *ptr_code;
 
     key[0] = '\0';
 
@@ -263,7 +265,7 @@ gui_mouse_event_code2key (const char *code)
      * mouse code must have at least:
      *   one code (for event) + X + Y == 3 bytes or 3 UTF-8 chars
      */
-    code_utf8 = utf8_is_valid (code, NULL);
+    code_utf8 = utf8_is_valid (code, -1, NULL);
     length = (code_utf8) ? utf8_strlen (code) : (int)strlen (code);
     if (length < 3)
         return NULL;
