@@ -1,7 +1,7 @@
 /*
  * gui-curses-term.c - terminal functions for Curses GUI
  *
- * Copyright (C) 2011-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -24,10 +24,14 @@
 #endif
 
 #ifdef HAVE_NCURSESW_CURSES_H
+#ifdef __sun
+#include <ncurses/term.h>
+#else
 #include <ncursesw/term.h>
+#endif /* __sun */
 #else
 #include <term.h>
-#endif
+#endif /* HAVE_NCURSESW_CURSES_H */
 
 
 /*
@@ -46,5 +50,5 @@ gui_term_set_eat_newline_glitch (int value)
 #else
     /* make C compiler happy */
     (void) value;
-#endif
+#endif /* HAVE_EAT_NEWLINE_GLITCH */
 }
