@@ -1,7 +1,7 @@
 /*
  * gui-bar-item.c - bar item functions (used by all GUI)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -29,6 +29,7 @@
 #include <time.h>
 
 #include "../core/weechat.h"
+#include "../core/wee-arraylist.h"
 #include "../core/wee-config.h"
 #include "../core/wee-hashtable.h"
 #include "../core/wee-hdata.h"
@@ -52,6 +53,7 @@
 #include "gui-line.h"
 #include "gui-nicklist.h"
 #include "gui-window.h"
+#include "gui-mouse.h"
 
 
 struct t_gui_bar_item *gui_bar_items = NULL;     /* first bar item          */
@@ -59,9 +61,9 @@ struct t_gui_bar_item *last_gui_bar_item = NULL; /* last bar item           */
 char *gui_bar_item_names[GUI_BAR_NUM_ITEMS] =
 { "input_paste", "input_prompt", "input_search", "input_text", "time",
   "buffer_count", "buffer_last_number", "buffer_plugin", "buffer_number",
-  "buffer_name", "buffer_modes", "buffer_filter", "buffer_zoom",
-  "buffer_nicklist_count", "scroll", "hotlist", "completion", "buffer_title",
-  "buffer_nicklist", "window_number"
+  "buffer_name", "buffer_short_name", "buffer_modes", "buffer_filter",
+  "buffer_zoom", "buffer_nicklist_count", "scroll", "hotlist", "completion",
+  "buffer_title", "buffer_nicklist", "window_number", "mouse_status"
 };
 char *gui_bar_items_default_for_bars[][2] =
 { { GUI_BAR_DEFAULT_NAME_INPUT,
@@ -69,9 +71,9 @@ char *gui_bar_items_default_for_bars[][2] =
   { GUI_BAR_DEFAULT_NAME_TITLE,
     "buffer_title" },
   { GUI_BAR_DEFAULT_NAME_STATUS,
-    "[time],[buffer_count],[buffer_plugin],buffer_number+:+"
+    "[time],[buffer_last_number],[buffer_plugin],buffer_number+:+"
     "buffer_name+(buffer_modes)+{buffer_nicklist_count}+buffer_zoom+"
-    "buffer_filter,[lag],[hotlist],completion,scroll" },
+    "buffer_filter,scroll,[lag],[hotlist],completion" },
   { GUI_BAR_DEFAULT_NAME_NICKLIST,
     "buffer_nicklist" },
   { NULL,
@@ -193,6 +195,9 @@ gui_bar_item_used_in_bar (struct t_gui_bar *bar, const char *item_name,
 {
     int i, j, length;
 
+    if (!bar || !item_name)
+        return 0;
+
     length = strlen (item_name);
 
     for (i = 0; i < bar->items_count; i++)
@@ -236,6 +241,9 @@ gui_bar_item_used_in_at_least_one_bar (const char *item_name, int partial_name,
     struct t_gui_bar *ptr_bar;
     int i, j, length;
 
+    if (!item_name)
+        return 0;
+
     length = strlen (item_name);
 
     for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
@@ -357,6 +365,8 @@ gui_bar_item_get_vars (const char *item_name,
  * For example:  if item == "[time]"
  *               returns: color(delimiter) + "[" +
  *                        (value of item "time") + color(delimiter) + "]"
+ *
+ * Note: result must be freed after use.
  */
 
 char *
@@ -369,7 +379,7 @@ gui_bar_item_get_value (struct t_gui_bar *bar, struct t_gui_window *window,
     struct t_gui_buffer *buffer;
     struct t_gui_bar_item *ptr_item;
 
-    if (!bar->items_array[item][subitem])
+    if (!bar || !bar->items_array[item][subitem])
         return NULL;
 
     buffer = (window) ?
@@ -567,10 +577,15 @@ gui_bar_item_update (const char *item_name)
     struct t_gui_bar *ptr_bar;
     struct t_gui_window *ptr_window;
     struct t_gui_bar_window *ptr_bar_window;
-    int i, j;
+    int i, j, check_bar_conditions, condition_ok;
+
+    if (!item_name)
+        return;
 
     for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
     {
+        check_bar_conditions = 0;
+
         for (i = 0; i < ptr_bar->items_count; i++)
         {
             for (j = 0; j < ptr_bar->items_subcount[i]; j++)
@@ -578,9 +593,15 @@ gui_bar_item_update (const char *item_name)
                 if (ptr_bar->items_name[i][j]
                     && (strcmp (ptr_bar->items_name[i][j], item_name) == 0))
                 {
-                    if (ptr_bar->bar_window)
+                    if (!CONFIG_BOOLEAN(ptr_bar->options[GUI_BAR_OPTION_HIDDEN]))
+                        check_bar_conditions = 1;
+
+                    if (CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
                     {
-                        ptr_bar->bar_window->items_refresh_needed[i][j] = 1;
+                        if (ptr_bar->bar_window)
+                        {
+                            ptr_bar->bar_window->items_refresh_needed[i][j] = 1;
+                        }
                     }
                     else
                     {
@@ -602,6 +623,39 @@ gui_bar_item_update (const char *item_name)
                 }
             }
         }
+
+        /*
+         * evaluate bar conditions (if needed) to check if bar must be toggled
+         * (hidden if shown, or shown if hidden)
+         */
+        if (check_bar_conditions)
+        {
+            if (CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
+            {
+                condition_ok = gui_bar_check_conditions (ptr_bar, NULL);
+                if ((condition_ok && !ptr_bar->bar_window)
+                    || (!condition_ok && ptr_bar->bar_window))
+                {
+                    gui_window_ask_refresh (1);
+                }
+            }
+            else
+            {
+                for (ptr_window = gui_windows; ptr_window;
+                     ptr_window = ptr_window->next_window)
+                {
+                    condition_ok = gui_bar_check_conditions (ptr_bar,
+                                                             ptr_window);
+                    ptr_bar_window = gui_bar_window_search_bar (ptr_window,
+                                                                ptr_bar);
+                    if ((condition_ok && !ptr_bar_window)
+                        || (!condition_ok && ptr_bar_window))
+                    {
+                        gui_window_ask_refresh (1);
+                    }
+                }
+            }
+        }
     }
 }
 
@@ -612,6 +666,9 @@ gui_bar_item_update (const char *item_name)
 void
 gui_bar_item_free (struct t_gui_bar_item *item)
 {
+    if (!item)
+        return;
+
     /* force refresh of bars displaying this bar item */
     gui_bar_item_update (item->name);
 
@@ -1056,12 +1113,43 @@ gui_bar_item_default_buffer_name (void *data, struct t_gui_bar_item *item,
         return NULL;
 
     snprintf (str_name, sizeof (str_name), "%s%s",
-              gui_color_get_custom (gui_color_get_name (CONFIG_COLOR(config_color_status_name))),
+              gui_color_get_custom (
+                  gui_color_get_name (CONFIG_COLOR(config_color_status_name))),
               buffer->name);
 
     return strdup (str_name);
 }
 
+/*
+ * Default item for short name of buffer.
+ */
+
+char *
+gui_bar_item_default_buffer_short_name (void *data,
+                                        struct t_gui_bar_item *item,
+                                        struct t_gui_window *window,
+                                        struct t_gui_buffer *buffer,
+                                        struct t_hashtable *extra_info)
+{
+    char str_short_name[256];
+
+    /* make C compiler happy */
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
+    if (!buffer)
+        return NULL;
+
+    snprintf (str_short_name, sizeof (str_short_name), "%s%s",
+              gui_color_get_custom (
+                  gui_color_get_name (CONFIG_COLOR(config_color_status_name))),
+              gui_buffer_get_short_name (buffer));
+
+    return strdup (str_short_name);
+}
+
 /*
  * Default item for modes of buffer.
  *
@@ -1106,8 +1194,11 @@ gui_bar_item_default_buffer_filter (void *data, struct t_gui_bar_item *item,
     if (!buffer)
         return NULL;
 
-    if (!gui_filters_enabled || !gui_filters || !buffer->lines->lines_hidden)
+    if (!gui_filters_enabled || !gui_filters
+        || !buffer->filter || !buffer->lines->lines_hidden)
+    {
         return NULL;
+    }
 
     snprintf (str_filter, sizeof (str_filter),
               "%s%s",
@@ -1139,7 +1230,9 @@ gui_bar_item_default_buffer_nicklist_count (void *data,
     if (!buffer || !buffer->nicklist)
         return NULL;
 
-    snprintf (str_count, sizeof (str_count), "%d",
+    snprintf (str_count, sizeof (str_count),
+              "%s%d",
+              gui_color_get_custom (gui_color_get_name (CONFIG_COLOR(config_color_status_nicklist_count))),
               buffer->nicklist_visible_count);
 
     return strdup (str_count);
@@ -1326,11 +1419,11 @@ gui_bar_item_default_hotlist (void *data, struct t_gui_bar_item *item,
                 strcat (str_hotlist, GUI_COLOR_CUSTOM_BAR_FG);
                 if (CONFIG_INTEGER(config_look_hotlist_names_length) == 0)
                 {
-                    snprintf (format, sizeof (format) - 1, "%%s");
+                    snprintf (format, sizeof (format), "%%s");
                 }
                 else
                 {
-                    snprintf (format, sizeof (format) - 1,
+                    snprintf (format, sizeof (format),
                               "%%.%ds",
                               CONFIG_INTEGER(config_look_hotlist_names_length));
                 }
@@ -1448,9 +1541,9 @@ gui_bar_item_default_completion (void *data, struct t_gui_bar_item *item,
                                  struct t_gui_buffer *buffer,
                                  struct t_hashtable *extra_info)
 {
-    int length;
+    int length, i;
     char *buf, str_number[64];
-    struct t_gui_completion_partial *ptr_item;
+    struct t_gui_completion_word *ptr_completion_word;
 
     /* make C compiler happy */
     (void) data;
@@ -1459,37 +1552,39 @@ gui_bar_item_default_completion (void *data, struct t_gui_bar_item *item,
     (void) extra_info;
 
     if (!buffer || !buffer->completion
-        || !buffer->completion->partial_completion_list)
+        || (buffer->completion->partial_list->size == 0))
     {
         return NULL;
     }
 
     length = 1;
-    for (ptr_item = buffer->completion->partial_completion_list;
-         ptr_item; ptr_item = ptr_item->next_item)
+    for (i = 0; i < buffer->completion->partial_list->size; i++)
     {
-        length += strlen (ptr_item->word) + 32;
+        ptr_completion_word =
+            (struct t_gui_completion_word *)(buffer->completion->partial_list->data[i]);
+        length += strlen (ptr_completion_word->word) + 32;
     }
 
     buf = malloc (length);
     if (buf)
     {
         buf[0] = '\0';
-        for (ptr_item = buffer->completion->partial_completion_list;
-             ptr_item; ptr_item = ptr_item->next_item)
+        for (i = 0; i < buffer->completion->partial_list->size; i++)
         {
+            ptr_completion_word =
+                (struct t_gui_completion_word *)(buffer->completion->partial_list->data[i]);
             strcat (buf, GUI_COLOR_CUSTOM_BAR_FG);
-            strcat (buf, ptr_item->word);
-            if (ptr_item->count > 0)
+            strcat (buf, ptr_completion_word->word);
+            if (ptr_completion_word->count > 0)
             {
                 strcat (buf, GUI_COLOR_CUSTOM_BAR_DELIM);
                 strcat (buf, "(");
                 snprintf (str_number, sizeof (str_number),
-                          "%d", ptr_item->count);
+                          "%d", ptr_completion_word->count);
                 strcat (buf, str_number);
                 strcat (buf, ")");
             }
-            if (ptr_item->next_item)
+            if (i < buffer->completion->partial_list->size - 1)
                 strcat (buf, " ");
         }
     }
@@ -1686,6 +1781,35 @@ gui_bar_item_default_window_number (void *data, struct t_gui_bar_item *item,
     return strdup (str_number);
 }
 
+/*
+ * Default item for mouse status.
+ */
+
+char *
+gui_bar_item_default_mouse_status (void *data, struct t_gui_bar_item *item,
+                                   struct t_gui_window *window,
+                                   struct t_gui_buffer *buffer,
+                                   struct t_hashtable *extra_info)
+{
+    char str_mouse[512];
+
+    /* make C compiler happy */
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
+    if (!buffer || !gui_mouse_enabled)
+        return NULL;
+
+    snprintf (str_mouse, sizeof (str_mouse),
+              "%s%s",
+              gui_color_get_custom (gui_color_get_name (CONFIG_COLOR(config_color_status_mouse))),
+              CONFIG_STRING(config_look_item_mouse_status));
+
+    return strdup (str_mouse);
+}
+
 /*
  * Focus on nicklist.
  */
@@ -1976,6 +2100,19 @@ gui_bar_item_init ()
     gui_bar_item_hook_signal ("buffer_moved",
                               gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NAME]);
 
+    /* buffer short name */
+    gui_bar_item_new (NULL,
+                      gui_bar_item_names[GUI_BAR_ITEM_BUFFER_SHORT_NAME],
+                      &gui_bar_item_default_buffer_short_name, NULL);
+    gui_bar_item_hook_signal ("window_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_SHORT_NAME]);
+    gui_bar_item_hook_signal ("buffer_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_SHORT_NAME]);
+    gui_bar_item_hook_signal ("buffer_renamed",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_SHORT_NAME]);
+    gui_bar_item_hook_signal ("buffer_moved",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_SHORT_NAME]);
+
     /* buffer modes */
     gui_bar_item_new (NULL,
                       gui_bar_item_names[GUI_BAR_ITEM_BUFFER_MODES],
@@ -2006,6 +2143,8 @@ gui_bar_item_init ()
                               gui_bar_item_names[GUI_BAR_ITEM_BUFFER_ZOOM]);
     gui_bar_item_hook_signal ("buffer_unzoomed",
                               gui_bar_item_names[GUI_BAR_ITEM_BUFFER_ZOOM]);
+    gui_bar_item_hook_signal ("buffer_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_ZOOM]);
 
     /* buffer nicklist count */
     gui_bar_item_new (NULL,
@@ -2080,6 +2219,15 @@ gui_bar_item_init ()
                               gui_bar_item_names[GUI_BAR_ITEM_WINDOW_NUMBER]);
     gui_bar_item_hook_signal ("window_closed",
                               gui_bar_item_names[GUI_BAR_ITEM_WINDOW_NUMBER]);
+
+    /* mouse status */
+    gui_bar_item_new (NULL,
+                      gui_bar_item_names[GUI_BAR_ITEM_MOUSE_STATUS],
+                      &gui_bar_item_default_mouse_status, NULL);
+    gui_bar_item_hook_signal ("mouse_enabled",
+                              gui_bar_item_names[GUI_BAR_ITEM_MOUSE_STATUS]);
+    gui_bar_item_hook_signal ("mouse_disabled",
+                              gui_bar_item_names[GUI_BAR_ITEM_MOUSE_STATUS]);
 }
 
 /*
@@ -2128,8 +2276,8 @@ gui_bar_item_hdata_bar_item_cb (void *data, const char *hdata_name)
         HDATA_VAR(struct t_gui_bar_item, build_callback_data, POINTER, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_bar_item, prev_item, POINTER, 0, NULL, hdata_name);
         HDATA_VAR(struct t_gui_bar_item, next_item, POINTER, 0, NULL, hdata_name);
-        HDATA_LIST(gui_bar_items);
-        HDATA_LIST(last_gui_bar_item);
+        HDATA_LIST(gui_bar_items, WEECHAT_HDATA_LIST_CHECK_POINTERS);
+        HDATA_LIST(last_gui_bar_item, 0);
     }
     return hdata;
 }
