@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_BAR_ITEM_H
-#define __WEECHAT_GUI_BAR_ITEM_H 1
+#ifndef WEECHAT_GUI_BAR_ITEM_H
+#define WEECHAT_GUI_BAR_ITEM_H 1
 
 enum t_gui_bar_item_weechat
 {
@@ -32,6 +32,7 @@ enum t_gui_bar_item_weechat
     GUI_BAR_ITEM_BUFFER_PLUGIN,
     GUI_BAR_ITEM_BUFFER_NUMBER,
     GUI_BAR_ITEM_BUFFER_NAME,
+    GUI_BAR_ITEM_BUFFER_SHORT_NAME,
     GUI_BAR_ITEM_BUFFER_MODES,
     GUI_BAR_ITEM_BUFFER_FILTER,
     GUI_BAR_ITEM_BUFFER_ZOOM,
@@ -42,6 +43,7 @@ enum t_gui_bar_item_weechat
     GUI_BAR_ITEM_BUFFER_TITLE,
     GUI_BAR_ITEM_BUFFER_NICKLIST,
     GUI_BAR_ITEM_WINDOW_NUMBER,
+    GUI_BAR_ITEM_MOUSE_STATUS,
     /* number of bar items */
     GUI_BAR_NUM_ITEMS,
 };
@@ -113,4 +115,4 @@ extern int gui_bar_item_add_to_infolist (struct t_infolist *infolist,
                                          struct t_gui_bar_item *bar_item);
 extern void gui_bar_item_print_log ();
 
-#endif /* __WEECHAT_GUI_BAR_ITEM_H */
+#endif /* WEECHAT_GUI_BAR_ITEM_H */
