@@ -1,7 +1,7 @@
 /*
  * gui-bar-window.c - bar window functions (used by all GUI)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -96,6 +96,9 @@ gui_bar_window_search_bar (struct t_gui_window *window, struct t_gui_bar *bar)
 {
     struct t_gui_bar_window *ptr_bar_win;
 
+    if (!window)
+        return NULL;
+
     for (ptr_bar_win = window->bar_windows; ptr_bar_win;
          ptr_bar_win = ptr_bar_win->next_bar_window)
     {
@@ -283,6 +286,10 @@ gui_bar_window_get_size (struct t_gui_bar *bar, struct t_gui_window *window,
     int total_size;
 
     total_size = 0;
+
+    if (!window)
+        return total_size;
+
     for (ptr_bar_window = window->bar_windows; ptr_bar_window;
          ptr_bar_window = ptr_bar_window->next_bar_window)
     {
@@ -313,6 +320,7 @@ gui_bar_window_get_size (struct t_gui_bar *bar, struct t_gui_window *window,
             }
         }
     }
+
     return total_size;
 }
 
@@ -327,8 +335,11 @@ gui_bar_window_calculate_pos_size (struct t_gui_bar_window *bar_window,
     int x1, y1, x2, y2;
     int add_bottom, add_top, add_left, add_right;
 
-    if (CONFIG_BOOLEAN(bar_window->bar->options[GUI_BAR_OPTION_HIDDEN]))
+    if (!bar_window
+        || CONFIG_BOOLEAN(bar_window->bar->options[GUI_BAR_OPTION_HIDDEN]))
+    {
         return;
+    }
 
     if (window)
     {
@@ -405,6 +416,9 @@ gui_bar_window_find_pos (struct t_gui_bar *bar, struct t_gui_window *window)
 {
     struct t_gui_bar_window *ptr_bar_window;
 
+    if (!window)
+        return NULL;
+
     for (ptr_bar_window = window->bar_windows; ptr_bar_window;
          ptr_bar_window = ptr_bar_window->next_bar_window)
     {
@@ -426,6 +440,9 @@ gui_bar_window_content_alloc (struct t_gui_bar_window *bar_window)
 {
     int i, j;
 
+    if (!bar_window)
+        return;
+
     bar_window->items_count = bar_window->bar->items_count;
     bar_window->items_subcount = NULL;
     bar_window->items_content = NULL;
@@ -433,19 +450,23 @@ gui_bar_window_content_alloc (struct t_gui_bar_window *bar_window)
     bar_window->items_refresh_needed = NULL;
     bar_window->screen_col_size = 0;
     bar_window->screen_lines = 0;
-    bar_window->items_subcount = malloc (bar_window->items_count *
+    bar_window->items_subcount = calloc (1,
+                                         bar_window->items_count *
                                          sizeof (*bar_window->items_subcount));
     if (!bar_window->items_subcount)
         goto error;
-    bar_window->items_content = malloc ((bar_window->items_count) *
+    bar_window->items_content = calloc (1,
+                                        (bar_window->items_count) *
                                         sizeof (*bar_window->items_content));
     if (!bar_window->items_content)
         goto error;
-    bar_window->items_num_lines = malloc ((bar_window->items_count) *
+    bar_window->items_num_lines = calloc (1,
+                                          (bar_window->items_count) *
                                           sizeof (*bar_window->items_num_lines));
     if (!bar_window->items_num_lines)
         goto error;
-    bar_window->items_refresh_needed = malloc (bar_window->items_count *
+    bar_window->items_refresh_needed = calloc (1,
+                                               bar_window->items_count *
                                                sizeof (*bar_window->items_refresh_needed));
     if (!bar_window->items_refresh_needed)
         goto error;
@@ -531,6 +552,9 @@ gui_bar_window_content_free (struct t_gui_bar_window *bar_window)
 {
     int i, j;
 
+    if (!bar_window)
+        return;
+
     if (bar_window->items_content)
     {
         for (i = 0; i < bar_window->items_count; i++)
@@ -567,6 +591,9 @@ gui_bar_window_content_build_item (struct t_gui_bar_window *bar_window,
                                    struct t_gui_window *window,
                                    int index_item, int index_subitem)
 {
+    if (!bar_window)
+        return;
+
     if (bar_window->items_content)
     {
         if (bar_window->items_content[index_item][index_subitem])
@@ -601,6 +628,9 @@ gui_bar_window_content_build (struct t_gui_bar_window *bar_window,
 {
     int i, j;
 
+    if (!bar_window)
+        return;
+
     gui_bar_window_content_free (bar_window);
     gui_bar_window_content_alloc (bar_window);
 
@@ -617,11 +647,14 @@ gui_bar_window_content_build (struct t_gui_bar_window *bar_window,
  * Gets item or subitem content (first rebuilds content if refresh is needed).
  */
 
-char *
+const char *
 gui_bar_window_content_get (struct t_gui_bar_window *bar_window,
                             struct t_gui_window *window,
                             int index_item, int index_subitem)
 {
+    if (!bar_window)
+        return NULL;
+
     /* rebuild content if refresh is needed */
     if (bar_window->items_refresh_needed[index_item][index_subitem])
     {
@@ -634,8 +667,10 @@ gui_bar_window_content_get (struct t_gui_bar_window *bar_window,
 }
 
 /*
- * Gets content of a bar window, formatted for display, according to filling for
- * bar position.
+ * Gets content of a bar window, formatted for display, according to filling
+ * for bar position.
+ *
+ * Note: result must be freed after use.
  */
 
 char *
@@ -643,7 +678,8 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
                                          struct t_gui_window *window)
 {
     enum t_gui_bar_filling filling;
-    char *ptr_content, *content, *content2, str_reinit_color[32];
+    const char *ptr_content;
+    char *content, *content2, str_reinit_color[32];
     char str_reinit_color_space[32], str_reinit_color_space_start_line[32];
     char str_start_item[32];
     char *item_value, *item_value2, ****split_items, **linear_items;
@@ -653,9 +689,12 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
     int max_length, max_length_screen;
     int total_items, columns, lines;
 
-    if (!bar_window->items_subcount || !bar_window->items_content
+    if (!bar_window
+        || !bar_window->items_subcount || !bar_window->items_content
         || !bar_window->items_num_lines || !bar_window->items_refresh_needed)
+    {
         return NULL;
+    }
 
     snprintf (str_reinit_color, sizeof (str_reinit_color),
               "%c",
@@ -960,6 +999,9 @@ gui_bar_window_coords_add (struct t_gui_bar_window *bar_window,
 {
     struct t_gui_bar_window_coords **coords2;
 
+    if (!bar_window)
+        return;
+
     if (!bar_window->coords)
     {
         bar_window->coords_count = 1;
@@ -999,6 +1041,9 @@ gui_bar_window_coords_free (struct t_gui_bar_window *bar_window)
 {
     int i;
 
+    if (!bar_window)
+        return;
+
     if (bar_window->coords)
     {
         for (i = 0; i < bar_window->coords_count; i++)
@@ -1022,6 +1067,9 @@ gui_bar_window_insert (struct t_gui_bar_window *bar_window,
 {
     struct t_gui_bar_window *pos_bar_window;
 
+    if (!bar_window || !window)
+        return;
+
     if (window->bar_windows)
     {
         pos_bar_window = gui_bar_window_find_pos (bar_window->bar, window);
@@ -1071,7 +1119,7 @@ gui_bar_window_new (struct t_gui_bar *bar, struct t_gui_window *window)
     if (window)
     {
         if ((CONFIG_INTEGER(bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_WINDOW)
-            && (!gui_bar_check_conditions_for_window (bar, window)))
+            && (!gui_bar_check_conditions (bar, window)))
             return;
     }
 
@@ -1131,7 +1179,7 @@ gui_bar_window_new (struct t_gui_bar *bar, struct t_gui_window *window)
 int
 gui_bar_window_get_current_size (struct t_gui_bar_window *bar_window)
 {
-    return bar_window->current_size;
+    return (bar_window) ? bar_window->current_size : 0;
 }
 
 /*
@@ -1210,6 +1258,9 @@ gui_bar_window_set_current_size (struct t_gui_bar_window *bar_window,
 {
     int new_size, max_size;
 
+    if (!bar_window)
+        return;
+
     if (size == 0)
         new_size = 1;
     else
@@ -1252,6 +1303,9 @@ void
 gui_bar_window_free (struct t_gui_bar_window *bar_window,
                      struct t_gui_window *window)
 {
+    if (!bar_window)
+        return;
+
     /* remove window bar from list */
     if (window)
     {
@@ -1264,6 +1318,11 @@ gui_bar_window_free (struct t_gui_bar_window *bar_window,
         if (window->last_bar_window == bar_window)
             window->last_bar_window = bar_window->prev_bar_window;
     }
+    else
+    {
+        if (bar_window->bar)
+            (bar_window->bar)->bar_window = NULL;
+    }
 
     /* free data */
     gui_bar_window_content_free (bar_window);
@@ -1277,7 +1336,10 @@ gui_bar_window_free (struct t_gui_bar_window *bar_window,
 }
 
 /*
- * Removes unused bars for a window.
+ * Removes unused bars, according to bars conditions.
+ *
+ * If window is NULL, unused root bars are removed.
+ * If window is not NULL, unused window bars in this window are removed.
  *
  * Returns:
  *   1: at least one bar was removed
@@ -1289,29 +1351,51 @@ gui_bar_window_remove_unused_bars (struct t_gui_window *window)
 {
     int rc;
     struct t_gui_bar_window *ptr_bar_win, *next_bar_win;
+    struct t_gui_bar *ptr_bar;
 
     rc = 0;
 
-    ptr_bar_win = window->bar_windows;
-    while (ptr_bar_win)
+    if (window)
     {
-        next_bar_win = ptr_bar_win->next_bar_window;
-
-        if ((CONFIG_INTEGER(ptr_bar_win->bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_WINDOW)
-            && (!gui_bar_check_conditions_for_window (ptr_bar_win->bar, window)))
+        /* remove unused window bars in window */
+        ptr_bar_win = window->bar_windows;
+        while (ptr_bar_win)
         {
-            gui_bar_window_free (ptr_bar_win, window);
-            rc = 1;
-        }
+            next_bar_win = ptr_bar_win->next_bar_window;
 
-        ptr_bar_win = next_bar_win;
+            if ((CONFIG_INTEGER(ptr_bar_win->bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_WINDOW)
+                && (!gui_bar_check_conditions (ptr_bar_win->bar, window)))
+            {
+                gui_bar_window_free (ptr_bar_win, window);
+                rc = 1;
+            }
+
+            ptr_bar_win = next_bar_win;
+        }
+    }
+    else
+    {
+        /* remove unused root bars */
+        for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
+        {
+            if ((CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
+                && ptr_bar->bar_window
+                && (!gui_bar_check_conditions (ptr_bar, NULL)))
+            {
+                gui_bar_window_free (ptr_bar->bar_window, NULL);
+                rc = 1;
+            }
+        }
     }
 
     return rc;
 }
 
 /*
- * Adds missing bars for a window.
+ * Adds missing bars, according to bars conditions.
+ *
+ * If window is NULL, missing root bars are added.
+ * If window is not NULL, missing window bars in this window are added.
  *
  * Returns:
  *   1: at least one bar was created
@@ -1326,18 +1410,34 @@ gui_bar_window_add_missing_bars (struct t_gui_window *window)
 
     rc = 0;
 
-    for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
+    if (window)
     {
-        if ((CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_WINDOW)
-            && gui_bar_check_conditions_for_window (ptr_bar, window))
+        /* add missing window bars in window */
+        for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
         {
-            if (!gui_bar_window_search_bar (window, ptr_bar))
+            if ((CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_WINDOW)
+                && (!gui_bar_window_search_bar (window, ptr_bar))
+                && (gui_bar_check_conditions (ptr_bar, window)))
             {
                 gui_bar_window_new (ptr_bar, window);
                 rc = 1;
             }
         }
     }
+    else
+    {
+        /* add missing root bars */
+        for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
+        {
+            if ((CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
+                && !ptr_bar->bar_window
+                && (gui_bar_check_conditions (ptr_bar, NULL)))
+            {
+                gui_bar_window_new (ptr_bar, NULL);
+                rc = 1;
+            }
+        }
+    }
 
     return rc;
 }
@@ -1358,6 +1458,9 @@ gui_bar_window_scroll (struct t_gui_bar_window *bar_window,
 {
     int old_scroll_x, old_scroll_y;
 
+    if (!bar_window)
+        return;
+
     old_scroll_x = bar_window->scroll_x;
     old_scroll_y = bar_window->scroll_y;
 
