@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_BAR_H
-#define __WEECHAT_GUI_BAR_H 1
+#ifndef WEECHAT_GUI_BAR_H
+#define WEECHAT_GUI_BAR_H 1
 
 struct t_infolist;
 struct t_weechat_plugin;
@@ -116,8 +116,8 @@ extern int gui_bar_search_option (const char *option_name);
 extern int gui_bar_search_type (const char *type);
 extern int gui_bar_search_position (const char *position);
 extern enum t_gui_bar_filling gui_bar_get_filling (struct t_gui_bar *bar);
-extern int gui_bar_check_conditions_for_window (struct t_gui_bar *bar,
-                                                struct t_gui_window *window);
+extern int gui_bar_check_conditions (struct t_gui_bar *bar,
+                                     struct t_gui_window *window);
 extern int gui_bar_root_get_size (struct t_gui_bar *bar,
                                   enum t_gui_bar_position position);
 extern struct t_gui_bar *gui_bar_search (const char *name);
@@ -159,4 +159,4 @@ extern int gui_bar_add_to_infolist (struct t_infolist *infolist,
                                     struct t_gui_bar *bar);
 extern void gui_bar_print_log ();
 
-#endif /* __WEECHAT_GUI_BAR_H */
+#endif /* WEECHAT_GUI_BAR_H */
