@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_BUFFER_H
-#define __WEECHAT_GUI_BUFFER_H 1
+#ifndef WEECHAT_GUI_BUFFER_H
+#define WEECHAT_GUI_BUFFER_H 1
 
 #include <limits.h>
 #include <regex.h>
@@ -96,13 +96,20 @@ struct t_gui_buffer
     int active;                        /* 0 = buffer merged and not active  */
                                        /* 1 = active (merged or not)        */
                                        /* 2 = the only active (merged)      */
+    int hidden;                        /* 1 = buffer hidden                 */
+    int zoomed;                        /* 1 if a merged buffer is zoomed    */
+                                       /* (it can be another buffer)        */
     int print_hooks_enabled;           /* 1 if print hooks are enabled      */
     int day_change;                    /* 1 if "day change" displayed       */
+    int clear;                         /* 1 if clear of buffer is allowed   */
+                                       /* with command /buffer clear        */
+    int filter;                        /* 1 if filters enabled for buffer   */
 
     /* close callback */
     int (*close_callback)(void *data,  /* called when buffer is closed      */
                           struct t_gui_buffer *buffer);
     void *close_callback_data;         /* data for callback                 */
+    int closing;                       /* 1 if the buffer is being closed   */
 
     /* buffer title */
     char *title;                       /* buffer title                      */
@@ -276,13 +283,14 @@ extern void gui_buffer_set (struct t_gui_buffer *buffer, const char *property,
                             const char *value);
 extern void gui_buffer_set_pointer (struct t_gui_buffer *buffer,
                                     const char *property, void *pointer);
+extern void gui_buffer_compute_num_displayed ();
 extern void gui_buffer_add_value_num_displayed (struct t_gui_buffer *buffer,
                                                 int value);
 extern int gui_buffer_is_main (const char *plugin_name, const char *name);
 extern struct t_gui_buffer *gui_buffer_search_main ();
+extern struct t_gui_buffer *gui_buffer_search_by_full_name (const char *full_name);
 extern struct t_gui_buffer *gui_buffer_search_by_name (const char *plugin,
                                                        const char *name);
-extern struct t_gui_buffer *gui_buffer_search_by_full_name (const char *full_name);
 extern struct t_gui_buffer *gui_buffer_search_by_partial_name (const char *plugin,
                                                                const char *name);
 extern struct t_gui_buffer *gui_buffer_search_by_number (int number);
@@ -297,8 +305,10 @@ extern void gui_buffer_close (struct t_gui_buffer *buffer);
 extern void gui_buffer_switch_by_number (struct t_gui_window *window,
                                          int number);
 extern void gui_buffer_set_active_buffer (struct t_gui_buffer *buffer);
-extern struct t_gui_buffer *gui_buffer_get_next_active_buffer (struct t_gui_buffer *buffer);
-extern struct t_gui_buffer *gui_buffer_get_previous_active_buffer (struct t_gui_buffer *buffer);
+extern struct t_gui_buffer *gui_buffer_get_next_active_buffer (struct t_gui_buffer *buffer,
+                                                               int allow_hidden_buffer);
+extern struct t_gui_buffer *gui_buffer_get_previous_active_buffer (struct t_gui_buffer *buffer,
+                                                                   int allow_hidden_buffer);
 extern void gui_buffer_renumber (int number1, int number2, int start_number);
 extern void gui_buffer_move_to_number (struct t_gui_buffer *buffer, int number);
 extern void gui_buffer_swap (int number1, int number2);
@@ -306,6 +316,10 @@ extern void gui_buffer_merge (struct t_gui_buffer *buffer,
                               struct t_gui_buffer *target_buffer);
 extern void gui_buffer_unmerge (struct t_gui_buffer *buffer, int number);
 extern void gui_buffer_unmerge_all ();
+extern void gui_buffer_hide (struct t_gui_buffer *buffer);
+extern void gui_buffer_hide_all ();
+extern void gui_buffer_unhide (struct t_gui_buffer *buffer);
+extern void gui_buffer_unhide_all ();
 extern void gui_buffer_sort_by_layout_number ();
 extern void gui_buffer_undo_snap (struct t_gui_buffer *buffer);
 extern void gui_buffer_undo_snap_free (struct t_gui_buffer *buffer);
@@ -330,4 +344,4 @@ extern int gui_buffer_add_to_infolist (struct t_infolist *infolist,
 extern void gui_buffer_dump_hexa (struct t_gui_buffer *buffer);
 extern void gui_buffer_print_log ();
 
-#endif /* __WEECHAT_GUI_BUFFER_H */
+#endif /* WEECHAT_GUI_BUFFER_H */
