@@ -1,7 +1,7 @@
 /*
  * gui-chat.c - chat functions (used by all GUI)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -197,7 +197,7 @@ gui_chat_strlen_screen (const char *string)
  * colors/attributes).
  */
 
-char *
+const char *
 gui_chat_string_add_offset (const char *string, int offset)
 {
     while (string && string[0] && (offset > 0))
@@ -211,7 +211,7 @@ gui_chat_string_add_offset (const char *string, int offset)
             offset--;
         }
     }
-    return (char *)string;
+    return string;
 }
 
 /*
@@ -219,7 +219,7 @@ gui_chat_string_add_offset (const char *string, int offset)
  * formatting chars (like colors/attributes).
  */
 
-char *
+const char *
 gui_chat_string_add_offset_screen (const char *string, int offset_screen)
 {
     int size_on_screen;
@@ -236,7 +236,7 @@ gui_chat_string_add_offset_screen (const char *string, int offset_screen)
             string = utf8_next_char (string);
         }
     }
-    return (char *)string;
+    return string;
 }
 
 /*
@@ -326,14 +326,13 @@ gui_chat_get_word_info (struct t_gui_window *window,
                         int *word_start_offset, int *word_end_offset,
                         int *word_length_with_spaces, int *word_length)
 {
-    const char *start_data;
-    char *next_char, *next_char2;
+    const char *start_data, *next_char, *next_char2;
     int leading_spaces, char_size_screen;
 
     *word_start_offset = 0;
     *word_end_offset = 0;
     *word_length_with_spaces = 0;
-    *word_length = 0;
+    *word_length = -1;
 
     start_data = data;
 
@@ -355,6 +354,8 @@ gui_chat_get_word_info (struct t_gui_window *window,
                     *word_end_offset = next_char2 - start_data - 1;
                     char_size_screen = gui_chat_char_size_screen (next_char);
                     (*word_length_with_spaces) += char_size_screen;
+                    if (*word_length < 0)
+                        *word_length = 0;
                     (*word_length) += char_size_screen;
                 }
                 else
@@ -548,6 +549,8 @@ gui_chat_change_time_format ()
 
 /*
  * Builds a string with prefix and message.
+ *
+ * Note: result must be freed after use.
  */
 
 char *
@@ -590,6 +593,8 @@ gui_chat_build_string_prefix_message (struct t_gui_line *line)
 
 /*
  * Builds a string with message and tags.
+ *
+ * Note: result must be freed after use.
  */
 
 
@@ -639,15 +644,15 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
                            const char *tags, const char *message, ...)
 {
     time_t date_printed;
-    int display_time, length, at_least_one_message_printed;
+    int display_time, length, at_least_one_message_printed, msg_discarded;
     char *pos, *pos_prefix, *pos_tab, *pos_end, *pos_lines;
     char *modifier_data, *new_msg, *ptr_msg, *lines_waiting;
     struct t_gui_line *ptr_line;
 
-    if (!gui_buffer_valid (buffer))
+    if (!message)
         return;
 
-    if (!message)
+    if (!gui_buffer_valid (buffer))
         return;
 
     if (gui_init_ok)
@@ -655,7 +660,7 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
         if (!buffer)
             buffer = gui_buffer_search_main ();
 
-        if (!buffer)
+        if (!buffer || buffer->closing)
             return;
 
         if (buffer->type != GUI_BUFFER_TYPE_FORMATTED)
@@ -693,6 +698,7 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
 
         /* call modifier for message printed ("weechat_print") */
         new_msg = NULL;
+        msg_discarded = 0;
         if (buffer)
         {
             length = strlen (gui_buffer_get_plugin_name (buffer)) + 1 +
@@ -718,9 +724,10 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
                          * print anything
                          */
                         free (new_msg);
-                        goto end;
+                        new_msg = NULL;
+                        msg_discarded = 1;
                     }
-                    if (strcmp (message, new_msg) == 0)
+                    else if (strcmp (message, new_msg) == 0)
                     {
                         /* no changes in new message */
                         free (new_msg);
@@ -730,89 +737,92 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
             }
         }
 
-        pos_prefix = NULL;
-        display_time = 1;
-        ptr_msg = (new_msg) ? new_msg : pos;
+        if (!msg_discarded)
+        {
+            pos_prefix = NULL;
+            display_time = 1;
+            ptr_msg = (new_msg) ? new_msg : pos;
 
-        /* space followed by tab => prefix ignored */
-        if ((ptr_msg[0] == ' ') && (ptr_msg[1] == '\t'))
-        {
-            ptr_msg += 2;
-        }
-        else
-        {
-            /* if two first chars are tab, then do not display time */
-            if ((ptr_msg[0] == '\t') && (ptr_msg[1] == '\t'))
+            /* space followed by tab => prefix ignored */
+            if ((ptr_msg[0] == ' ') && (ptr_msg[1] == '\t'))
             {
-                display_time = 0;
                 ptr_msg += 2;
             }
             else
             {
-                /* if tab found, use prefix (before tab) */
-                pos_tab = strchr (ptr_msg, '\t');
-                if (pos_tab)
+                /* if two first chars are tab, then do not display time */
+                if ((ptr_msg[0] == '\t') && (ptr_msg[1] == '\t'))
                 {
-                    pos_tab[0] = '\0';
-                    pos_prefix = ptr_msg;
-                    ptr_msg = pos_tab + 1;
-                }
-            }
-        }
-
-        if (gui_init_ok)
-        {
-            ptr_line = gui_line_add (buffer, (display_time) ? date : 0,
-                                     date_printed, tags, pos_prefix, ptr_msg);
-            if (ptr_line)
-            {
-                if (buffer && buffer->print_hooks_enabled)
-                    hook_print_exec (buffer, ptr_line);
-                if (ptr_line->data->displayed)
-                    at_least_one_message_printed = 1;
-            }
-        }
-        else
-        {
-            length = ((pos_prefix) ? strlen (pos_prefix) + 1 : 0) +
-                strlen (ptr_msg) + 1;
-            if (gui_chat_lines_waiting_buffer)
-            {
-                length += strlen (gui_chat_lines_waiting_buffer) + 1;
-                lines_waiting = realloc (gui_chat_lines_waiting_buffer, length);
-                if (lines_waiting)
-                {
-                    gui_chat_lines_waiting_buffer = lines_waiting;
+                    display_time = 0;
+                    ptr_msg += 2;
                 }
                 else
                 {
-                    free (gui_chat_lines_waiting_buffer);
-                    gui_chat_lines_waiting_buffer = NULL;
+                    /* if tab found, use prefix (before tab) */
+                    pos_tab = strchr (ptr_msg, '\t');
+                    if (pos_tab)
+                    {
+                        pos_tab[0] = '\0';
+                        pos_prefix = ptr_msg;
+                        ptr_msg = pos_tab + 1;
+                    }
+                }
+            }
+
+            if (gui_init_ok)
+            {
+                ptr_line = gui_line_add (buffer, (display_time) ? date : 0,
+                                         date_printed, tags, pos_prefix, ptr_msg);
+                if (ptr_line)
+                {
+                    if (buffer && buffer->print_hooks_enabled)
+                        hook_print_exec (buffer, ptr_line);
+                    if (ptr_line->data->displayed)
+                        at_least_one_message_printed = 1;
                 }
             }
             else
             {
-                gui_chat_lines_waiting_buffer = malloc (length);
+                length = ((pos_prefix) ? strlen (pos_prefix) + 1 : 0) +
+                    strlen (ptr_msg) + 1;
                 if (gui_chat_lines_waiting_buffer)
-                    gui_chat_lines_waiting_buffer[0] = '\0';
-            }
-            if (gui_chat_lines_waiting_buffer)
-            {
-                pos_lines = gui_chat_lines_waiting_buffer +
-                    strlen (gui_chat_lines_waiting_buffer);
-                if (pos_lines > gui_chat_lines_waiting_buffer)
                 {
-                    pos_lines[0] = '\n';
-                    pos_lines++;
+                    length += strlen (gui_chat_lines_waiting_buffer) + 1;
+                    lines_waiting = realloc (gui_chat_lines_waiting_buffer, length);
+                    if (lines_waiting)
+                    {
+                        gui_chat_lines_waiting_buffer = lines_waiting;
+                    }
+                    else
+                    {
+                        free (gui_chat_lines_waiting_buffer);
+                        gui_chat_lines_waiting_buffer = NULL;
+                    }
                 }
-                if (pos_prefix)
+                else
                 {
-                    memcpy (pos_lines, pos_prefix, strlen (pos_prefix));
-                    pos_lines += strlen (pos_prefix);
-                    pos_lines[0] = '\t';
-                    pos_lines++;
+                    gui_chat_lines_waiting_buffer = malloc (length);
+                    if (gui_chat_lines_waiting_buffer)
+                        gui_chat_lines_waiting_buffer[0] = '\0';
+                }
+                if (gui_chat_lines_waiting_buffer)
+                {
+                    pos_lines = gui_chat_lines_waiting_buffer +
+                        strlen (gui_chat_lines_waiting_buffer);
+                    if (pos_lines > gui_chat_lines_waiting_buffer)
+                    {
+                        pos_lines[0] = '\n';
+                        pos_lines++;
+                    }
+                    if (pos_prefix)
+                    {
+                        memcpy (pos_lines, pos_prefix, strlen (pos_prefix));
+                        pos_lines += strlen (pos_prefix);
+                        pos_lines[0] = '\t';
+                        pos_lines++;
+                    }
+                    memcpy (pos_lines, ptr_msg, strlen (ptr_msg) + 1);
                 }
-                memcpy (pos_lines, ptr_msg, strlen (ptr_msg) + 1);
             }
         }
 
@@ -825,7 +835,6 @@ gui_chat_printf_date_tags (struct t_gui_buffer *buffer, time_t date,
     if (gui_init_ok && at_least_one_message_printed)
         gui_buffer_ask_chat_refresh (buffer, 1);
 
-end:
     free (vbuffer);
 }
 
@@ -842,11 +851,17 @@ gui_chat_printf_y (struct t_gui_buffer *buffer, int y, const char *message, ...)
     struct t_gui_line *ptr_line;
     int i, num_lines_to_add;
 
+    if (!gui_buffer_valid (buffer))
+        return;
+
     if (gui_init_ok)
     {
         if (!buffer)
             buffer = gui_buffer_search_main ();
 
+        if (!buffer || buffer->closing)
+            return;
+
         if (buffer->type != GUI_BUFFER_TYPE_FREE)
             buffer = gui_buffers;
 
@@ -863,7 +878,7 @@ gui_chat_printf_y (struct t_gui_buffer *buffer, int y, const char *message, ...)
     /* no message: delete line */
     if (!vbuffer[0])
     {
-        if (gui_init_ok)
+        if (gui_init_ok && (y >= 0))
         {
             for (ptr_line = buffer->own_lines->first_line; ptr_line;
                  ptr_line = ptr_line->next_line)
@@ -885,7 +900,13 @@ gui_chat_printf_y (struct t_gui_buffer *buffer, int y, const char *message, ...)
     {
         if (gui_init_ok)
         {
-            num_lines_to_add = 0;
+            /* if y is negative, add a line -N lines after the last line */
+            if (y < 0)
+            {
+                y = (buffer->own_lines && buffer->own_lines->last_line) ?
+                    buffer->own_lines->last_line->data->y - y : (-1 * y) - 1;
+            }
+            /* compute the number of lines to add before y */
             if (buffer->own_lines && buffer->own_lines->last_line)
                 num_lines_to_add = y - buffer->own_lines->last_line->data->y - 1;
             else
@@ -962,9 +983,15 @@ int
 gui_chat_hsignal_quote_line_cb (void *data, const char *signal,
                                 struct t_hashtable *hashtable)
 {
-    const char *time, *prefix, *message;
-    int length_time, length_prefix, length_message, length;
-    char *str;
+    const char *date, *line, *prefix, *ptr_prefix, *message;
+    long unsigned int value;
+    long number;
+    struct tm *local_time;
+    struct t_gui_line *ptr_line;
+    int is_nick, length_time, length_nick_prefix, length_prefix;
+    int length_nick_suffix, length_message, length, rc;
+    time_t line_date;
+    char str_time[128], *str, *error;
 
     /* make C compiler happy */
     (void) data;
@@ -972,33 +999,75 @@ gui_chat_hsignal_quote_line_cb (void *data, const char *signal,
     if (!gui_current_window->buffer->input)
         return WEECHAT_RC_OK;
 
-    time = (strstr (signal, "time")) ?
-        hashtable_get (hashtable, "_chat_line_time") : NULL;
+    /* get time */
+    str_time[0] = '\0';
+    date = (strstr (signal, "time")) ?
+        hashtable_get (hashtable, "_chat_line_date") : NULL;
+    if (date)
+    {
+        number = strtol (date, &error, 10);
+        if (error && !error[0])
+        {
+            line_date = (time_t)number;
+            local_time = localtime (&line_date);
+            if (local_time)
+            {
+                strftime (str_time, sizeof (str_time),
+                          CONFIG_STRING(config_look_quote_time_format),
+                          local_time);
+            }
+        }
+    }
+
+    /* check if the prefix is a nick */
+    is_nick = 0;
+    line = hashtable_get (hashtable, "_chat_line");
+    if (line && line[0])
+    {
+        rc = sscanf (line, "%lx", &value);
+        if ((rc != EOF) && (rc != 0))
+        {
+            ptr_line = (struct t_gui_line *)value;
+            if (gui_line_search_tag_starting_with (ptr_line, "prefix_nick"))
+                is_nick = 1;
+        }
+    }
+
+    /* get prefix + message */
     prefix = (strstr (signal, "prefix")) ?
         hashtable_get (hashtable, "_chat_line_prefix") : NULL;
+    ptr_prefix = prefix;
+    if (ptr_prefix)
+    {
+        while (ptr_prefix[0] == ' ')
+        {
+            ptr_prefix++;
+        }
+    }
     message = hashtable_get (hashtable, "_chat_line_message");
 
     if (!message)
         return WEECHAT_RC_OK;
 
-    length_time = (time) ? strlen (time) : 0;
-    length_prefix = (prefix) ? strlen (prefix) : 0;
+    length_time = strlen (str_time);
+    length_nick_prefix = strlen (CONFIG_STRING(config_look_quote_nick_prefix));
+    length_prefix = (ptr_prefix) ? strlen (ptr_prefix) : 0;
+    length_nick_suffix = strlen (CONFIG_STRING(config_look_quote_nick_suffix));
     length_message = strlen (message);
 
-    length = length_time + 1 + length_prefix + 1 +
-        strlen (CONFIG_STRING(config_look_prefix_suffix)) + 1 +
+    length = length_time + 1 +
+        length_nick_prefix + length_prefix + length_nick_suffix + 1 +
         length_message + 1 + 1;
     str = malloc (length);
     if (str)
     {
         snprintf (str, length, "%s%s%s%s%s%s%s ",
-                  (time) ? time : "",
-                  (time) ? " " : "",
-                  (prefix) ? prefix : "",
-                  (prefix) ? " " : "",
-                  (time || prefix) ? CONFIG_STRING(config_look_prefix_suffix) : "",
-                  ((time || prefix) && CONFIG_STRING(config_look_prefix_suffix)
-                   && CONFIG_STRING(config_look_prefix_suffix)[0]) ? " " : "",
+                  str_time,
+                  (str_time[0]) ? " " : "",
+                  (ptr_prefix && ptr_prefix[0] && is_nick) ? CONFIG_STRING(config_look_quote_nick_prefix) : "",
+                  (ptr_prefix) ? ptr_prefix : "",
+                  (ptr_prefix && ptr_prefix[0] && is_nick) ? CONFIG_STRING(config_look_quote_nick_suffix) : "",
+                  (ptr_prefix && ptr_prefix[0]) ? " " : "",
                   message);
         gui_input_insert_string (gui_current_window->buffer, str, -1);
         gui_input_text_changed_modifier_and_signal (gui_current_window->buffer,
