@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,17 +17,22 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_COLOR_H
-#define __WEECHAT_GUI_COLOR_H 1
+#ifndef WEECHAT_GUI_COLOR_H
+#define WEECHAT_GUI_COLOR_H 1
 
 #include <regex.h>
 
+struct t_config_option;
+
 /*
  * Color from configuration options.
+ *
  * When changing some colors below:
  * - always add to the end
  * - never remove a color (mark it as obsolete if needed)
  * - do not re-use an obsolete color
+ * - add build of color in file src/gui/curses/gui-curses-color.c,
+ *   function gui_color_init_weechat ()
  * - update the Developer's guide
  */
 
@@ -82,6 +87,7 @@ enum t_gui_color_enum
     GUI_COLOR_CHAT_NICK_SUFFIX,
     GUI_COLOR_EMPHASIS,
     GUI_COLOR_CHAT_DAY_CHANGE,
+    GUI_COLOR_CHAT_VALUE_NULL,
 
     /* number of colors */
     GUI_COLOR_NUM_COLORS,
@@ -138,6 +144,14 @@ enum t_gui_color_enum
 #define GUI_COLOR_EXTENDED_MASK               0x00FFFFF
 #define GUI_COLOR_EXTENDED_MAX                99999
 
+#define GUI_COLOR_REGEX_ANSI_DECODE             \
+    "\33("                                      \
+    "([()].)|"                                  \
+    "([<>])|"                                   \
+    "(\\[[0-9;?]*[A-Za-z]))"
+
+#define GUI_COLOR_BUFFER_NAME "color"
+
 /* color structure */
 
 struct t_gui_color
@@ -165,11 +179,15 @@ extern struct t_weelist *gui_color_list_with_alias;
 
 /* color functions */
 
+extern const char *gui_color_from_option (struct t_config_option *option);
 extern const char *gui_color_search_config (const char *color_name);
 extern int gui_color_attr_get_flag (char c);
 extern void gui_color_attr_build_string (int color, char *str_attr);
 extern const char *gui_color_get_custom (const char *color_name);
+extern int gui_color_convert_term_to_rgb (int color);
+extern int gui_color_convert_rgb_to_term (int rgb, int limit);
 extern char *gui_color_decode (const char *string, const char *replacement);
+extern char *gui_color_decode_ansi (const char *string, int keep_colors);
 extern char *gui_color_emphasize (const char *string, const char *search,
                                   int case_sensitive, regex_t *regex);
 extern void gui_color_free (struct t_gui_color *color);
@@ -178,7 +196,8 @@ extern int gui_color_palette_get_alias (const char *alias);
 extern struct t_gui_color_palette *gui_color_palette_get (int number);
 extern void gui_color_palette_add (int number, const char *value);
 extern void gui_color_palette_remove (int number);
-extern void gui_color_palette_free_structs ();
+extern void gui_color_init ();
+extern void gui_color_end ();
 
 /* color functions (GUI dependent) */
 
@@ -189,6 +208,7 @@ extern int gui_color_assign_by_diff (int *color, const char *color_name,
 extern int gui_color_get_weechat_colors_number ();
 extern int gui_color_get_term_colors ();
 extern const char *gui_color_get_name (int num_color);
+extern void gui_color_free_vars ();
 extern void gui_color_init_weechat ();
 extern void gui_color_display_terminal_colors ();
 extern void gui_color_info_term_colors (char *buffer, int size);
@@ -203,4 +223,4 @@ extern struct t_gui_color_palette *gui_color_palette_new (int number,
 extern void gui_color_palette_free (struct t_gui_color_palette *color_palette);
 extern void gui_color_dump ();
 
-#endif /* __WEECHAT_GUI_COLOR_H */
+#endif /* WEECHAT_GUI_COLOR_H */
