@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,20 +17,20 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_COMPLETION_H
-#define __WEECHAT_GUI_COMPLETION_H 1
+#ifndef WEECHAT_GUI_COMPLETION_H
+#define WEECHAT_GUI_COMPLETION_H 1
 
 #define GUI_COMPLETION_NULL         0
 #define GUI_COMPLETION_COMMAND      1
 #define GUI_COMPLETION_COMMAND_ARG  2
 #define GUI_COMPLETION_AUTO         3
 
-struct t_gui_completion_partial
+struct t_gui_completion_word
 {
-    char *word;                   /* (partial) word matching completion      */
+    char *word;                   /* word matching completion                */
+    char nick_completion;         /* 1 if it is completion of a nick         */
     int count;                    /* number of matching items with this word */
-    struct t_gui_completion_partial *prev_item;
-    struct t_gui_completion_partial *next_item;
+                                  /* (for partial completion)                */
 };
 
 struct t_gui_completion
@@ -49,7 +49,7 @@ struct t_gui_completion
     int force_partial_completion; /* force partial completion?               */
 
     /* for command argument completion */
-    struct t_weelist *completion_list; /* data list for completion           */
+    struct t_arraylist *list;     /* data list for completion                */
 
     /* completion found */
     char *word_found;             /* word found (to replace base word)       */
@@ -59,8 +59,7 @@ struct t_gui_completion
     int diff_length;              /* length difference (<= diff_size)        */
 
     /* partial completion */
-    struct t_gui_completion_partial *partial_completion_list;
-    struct t_gui_completion_partial *last_partial_completion;
+    struct t_arraylist *partial_list;
 };
 
 /* completion variables */
@@ -87,4 +86,4 @@ extern struct t_hdata *gui_completion_hdata_completion_partial_cb (void *data,
                                                                    const char *hdata_name);
 extern void gui_completion_print_log (struct t_gui_completion *completion);
 
-#endif /* __WEECHAT_GUI_COMPLETION_H */
+#endif /* WEECHAT_GUI_COMPLETION_H */
