@@ -1,7 +1,7 @@
 /*
  * gui-filter.c - filter functions (used by all GUI)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -38,6 +38,7 @@
 #include "../plugins/plugin.h"
 #include "gui-filter.h"
 #include "gui-buffer.h"
+#include "gui-chat.h"
 #include "gui-line.h"
 #include "gui-window.h"
 
@@ -61,8 +62,8 @@ gui_filter_check_line (struct t_gui_line_data *line_data)
     struct t_gui_filter *ptr_filter;
     int rc;
 
-    /* line is always displayed if filters are disabled */
-    if (!gui_filters_enabled)
+    /* line is always displayed if filters are disabled (globally or in buffer) */
+    if (!gui_filters_enabled || !line_data->buffer->filter)
         return 1;
 
     if (gui_line_has_tag_no_filter (line_data))
@@ -154,8 +155,8 @@ gui_filter_buffer (struct t_gui_buffer *buffer,
     if (buffer->lines->lines_hidden != lines_hidden)
     {
         buffer->lines->lines_hidden = lines_hidden;
-        hook_signal_send ("buffer_lines_hidden",
-                          WEECHAT_HOOK_SIGNAL_POINTER, buffer);
+        (void) hook_signal_send ("buffer_lines_hidden",
+                                 WEECHAT_HOOK_SIGNAL_POINTER, buffer);
     }
 
     if (lines_changed)
@@ -210,8 +211,8 @@ gui_filter_global_enable ()
     {
         gui_filters_enabled = 1;
         gui_filter_all_buffers ();
-        hook_signal_send ("filters_enabled",
-                          WEECHAT_HOOK_SIGNAL_STRING, NULL);
+        (void) hook_signal_send ("filters_enabled",
+                                 WEECHAT_HOOK_SIGNAL_STRING, NULL);
     }
 }
 
@@ -226,8 +227,8 @@ gui_filter_global_disable ()
     {
         gui_filters_enabled = 0;
         gui_filter_all_buffers ();
-        hook_signal_send ("filters_disabled",
-                          WEECHAT_HOOK_SIGNAL_STRING, NULL);
+        (void) hook_signal_send ("filters_disabled",
+                                 WEECHAT_HOOK_SIGNAL_STRING, NULL);
     }
 }
 
@@ -253,6 +254,21 @@ gui_filter_search_by_name (const char *name)
     return NULL;
 }
 
+/*
+ * Displays an error when a new filter is created.
+ */
+
+void
+gui_filter_new_error (const char *name, const char *error)
+{
+    gui_chat_printf_date_tags (
+        NULL, 0, GUI_FILTER_TAG_NO_FILTER,
+        _("%sError adding filter \"%s\": %s"),
+        gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
+        (name) ? name : "",
+        error);
+}
+
 /*
  * Creates a new filter.
  *
@@ -265,15 +281,22 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
 {
     struct t_gui_filter *new_filter;
     regex_t *regex1, *regex2;
-    char *pos_tab, *regex_prefix, **tags_array;
+    char *pos_tab, *regex_prefix, **tags_array, buf[512], str_error[512];
     const char *ptr_start_regex, *pos_regex_message;
-    int i;
+    int i, rc;
 
     if (!name || !buffer_name || !tags || !regex)
+    {
+        gui_filter_new_error (name, _("not enough arguments"));
         return NULL;
+    }
 
     if (gui_filter_search_by_name (name))
+    {
+        gui_filter_new_error (name,
+                              _("a filter with same name already exists"));
         return NULL;
+    }
 
     ptr_start_regex = regex;
     if ((ptr_start_regex[0] == '!')
@@ -284,6 +307,7 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
 
     regex1 = NULL;
     regex2 = NULL;
+
     if (strcmp (ptr_start_regex, "*") != 0)
     {
         pos_tab = strstr (ptr_start_regex, "\\t");
@@ -299,14 +323,21 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
             pos_regex_message = ptr_start_regex;
         }
 
-        if (regex_prefix)
+        if (regex_prefix && regex_prefix[0])
         {
             regex1 = malloc (sizeof (*regex1));
             if (regex1)
             {
-                if (string_regcomp (regex1, regex_prefix,
-                                    REG_EXTENDED | REG_ICASE | REG_NOSUB) != 0)
+                rc = string_regcomp (regex1, regex_prefix,
+                                     REG_EXTENDED | REG_ICASE | REG_NOSUB);
+                if (rc != 0)
                 {
+                    regerror (rc, regex1, buf, sizeof (buf));
+                    snprintf (str_error, sizeof (str_error),
+                              /* TRANSLATORS: %s is the error returned by regerror */
+                              _("invalid regular expression (%s)"),
+                              buf);
+                    gui_filter_new_error (name, str_error);
                     free (regex_prefix);
                     free (regex1);
                     return NULL;
@@ -314,18 +345,31 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
             }
         }
 
-        regex2 = malloc (sizeof (*regex2));
-        if (regex2)
+        if (pos_regex_message && pos_regex_message[0])
         {
-            if (string_regcomp (regex2, pos_regex_message,
-                                REG_EXTENDED | REG_ICASE | REG_NOSUB) != 0)
+            regex2 = malloc (sizeof (*regex2));
+            if (regex2)
             {
-                if (regex_prefix)
-                    free (regex_prefix);
-                if (regex1)
-                    free (regex1);
-                free (regex2);
-                return NULL;
+                rc = string_regcomp (regex2, pos_regex_message,
+                                     REG_EXTENDED | REG_ICASE | REG_NOSUB);
+                if (rc != 0)
+                {
+                    regerror (rc, regex2, buf, sizeof (buf));
+                    snprintf (str_error, sizeof (str_error),
+                              /* TRANSLATORS: %s is the error returned by regerror */
+                              _("invalid regular expression (%s)"),
+                              buf);
+                    gui_filter_new_error (name, str_error);
+                    if (regex_prefix)
+                        free (regex_prefix);
+                    if (regex1)
+                    {
+                        regfree (regex1);
+                        free (regex1);
+                    }
+                    free (regex2);
+                    return NULL;
+                }
             }
         }
 
@@ -380,8 +424,12 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
         last_gui_filter = new_filter;
         new_filter->next_filter = NULL;
 
-        hook_signal_send ("filter_added",
-                          WEECHAT_HOOK_SIGNAL_POINTER, new_filter);
+        (void) hook_signal_send ("filter_added",
+                                 WEECHAT_HOOK_SIGNAL_POINTER, new_filter);
+    }
+    else
+    {
+        gui_filter_new_error (name, _("not enough memory"));
     }
 
     return new_filter;
@@ -419,8 +467,8 @@ gui_filter_free (struct t_gui_filter *filter)
 {
     int i;
 
-    hook_signal_send ("filter_removing",
-                      WEECHAT_HOOK_SIGNAL_POINTER, filter);
+    (void) hook_signal_send ("filter_removing",
+                             WEECHAT_HOOK_SIGNAL_POINTER, filter);
 
     /* free data */
     if (filter->name)
@@ -464,7 +512,7 @@ gui_filter_free (struct t_gui_filter *filter)
 
     free (filter);
 
-    hook_signal_send ("filter_removed", WEECHAT_HOOK_SIGNAL_STRING, NULL);
+    (void) hook_signal_send ("filter_removed", WEECHAT_HOOK_SIGNAL_STRING, NULL);
 }
 
 /*
@@ -509,8 +557,8 @@ gui_filter_hdata_filter_cb (void *data, const char *hdata_name)
         HDATA_VAR(struct t_gui_filter, regex_message, POINTER, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_filter, prev_filter, POINTER, 0, NULL, hdata_name);
         HDATA_VAR(struct t_gui_filter, next_filter, POINTER, 0, NULL, hdata_name);
-        HDATA_LIST(gui_filters);
-        HDATA_LIST(last_gui_filter);
+        HDATA_LIST(gui_filters, WEECHAT_HDATA_LIST_CHECK_POINTERS);
+        HDATA_LIST(last_gui_filter, 0);
     }
     return hdata;
 }
