@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_HOTLIST_H
-#define __WEECHAT_GUI_HOTLIST_H 1
+#ifndef WEECHAT_GUI_HOTLIST_H
+#define WEECHAT_GUI_HOTLIST_H 1
 
 enum t_gui_hotlist_priority
 {
@@ -59,11 +59,13 @@ extern struct t_gui_hotlist *gui_hotlist_add (struct t_gui_buffer *buffer,
                                               struct timeval *creation_time);
 extern void gui_hotlist_resort ();
 extern void gui_hotlist_clear ();
-extern void gui_hotlist_remove_buffer (struct t_gui_buffer *buffer);
+extern void gui_hotlist_remove_buffer (struct t_gui_buffer *buffer,
+                                       int force_remove_buffer);
 extern struct t_hdata *gui_hotlist_hdata_hotlist_cb (void *data,
                                                      const char *hdata_name);
 extern int gui_hotlist_add_to_infolist (struct t_infolist *infolist,
                                         struct t_gui_hotlist *hotlist);
 extern void gui_hotlist_print_log ();
+extern void gui_hotlist_end ();
 
-#endif /* __WEECHAT_GUI_HOTLIST_H */
+#endif /* WEECHAT_GUI_HOTLIST_H */
