@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_INPUT_H
-#define __WEECHAT_GUI_INPUT_H 1
+#ifndef WEECHAT_GUI_INPUT_H
+#define WEECHAT_GUI_INPUT_H 1
 
 struct t_gui_buffer;
 
@@ -43,6 +43,7 @@ extern void gui_input_clipboard_paste (struct t_gui_buffer *buffer);
 extern void gui_input_return (struct t_gui_buffer *buffer);
 extern void gui_input_complete_next (struct t_gui_buffer *buffer);
 extern void gui_input_complete_previous (struct t_gui_buffer *buffer);
+extern void gui_input_search_text_here (struct t_gui_buffer *buffer);
 extern void gui_input_search_text (struct t_gui_buffer *buffer);
 extern void gui_input_search_compile_regex (struct t_gui_buffer *buffer);
 extern void gui_input_search_switch_case (struct t_gui_buffer *buffer);
@@ -50,6 +51,7 @@ extern void gui_input_search_switch_regex (struct t_gui_buffer *buffer);
 extern void gui_input_search_switch_where (struct t_gui_buffer *buffer);
 extern void gui_input_search_previous (struct t_gui_buffer *buffer);
 extern void gui_input_search_next (struct t_gui_buffer *buffer);
+extern void gui_input_search_stop_here (struct t_gui_buffer *buffer);
 extern void gui_input_search_stop (struct t_gui_buffer *buffer);
 extern void gui_input_delete_previous_char (struct t_gui_buffer *buffer);
 extern void gui_input_delete_next_char (struct t_gui_buffer *buffer);
@@ -70,7 +72,6 @@ extern void gui_input_history_local_next (struct t_gui_buffer *buffer);
 extern void gui_input_history_global_previous (struct t_gui_buffer *buffer);
 extern void gui_input_history_global_next (struct t_gui_buffer *buffer);
 extern void gui_input_jump_smart (struct t_gui_buffer *buffer);
-extern void gui_input_jump_last_buffer (struct t_gui_buffer *buffer);
 extern void gui_input_jump_last_buffer_displayed (struct t_gui_buffer *buffer);
 extern void gui_input_jump_previously_visited_buffer (struct t_gui_buffer *buffer);
 extern void gui_input_jump_next_visited_buffer (struct t_gui_buffer *buffer);
@@ -87,4 +88,4 @@ extern void gui_input_insert (struct t_gui_buffer *buffer, const char *args);
 extern void gui_input_undo (struct t_gui_buffer *buffer);
 extern void gui_input_redo (struct t_gui_buffer *buffer);
 
-#endif /* __WEECHAT_GUI_INPUT_H */
+#endif /* WEECHAT_GUI_INPUT_H */
