@@ -1,7 +1,7 @@
 /*
  * gui-key.c - keyboard functions (used by all GUI)
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -214,7 +214,7 @@ gui_key_grab_end_timer_cb (void *data, int remaining_calls)
          * but some mouse codes can return ISO chars (for coordinates),
          * then we will convert them to UTF-8 string
          */
-        if (!utf8_is_valid (expanded_key, NULL))
+        if (!utf8_is_valid (expanded_key, -1, NULL))
         {
             expanded_key2 = string_iconv_to_internal ("iso-8859-1",
                                                       expanded_key);
@@ -1816,7 +1816,8 @@ gui_key_paste_accept ()
      * add final newline if there is not in pasted text
      * (for at least 2 lines pasted)
      */
-    if ((gui_key_get_paste_lines () > 1)
+    if (CONFIG_BOOLEAN(config_look_paste_auto_add_newline)
+        && (gui_key_get_paste_lines () > 1)
         && (gui_key_buffer_size > 0)
         && (gui_key_buffer[gui_key_buffer_size - 1] != '\r')
         && (gui_key_buffer[gui_key_buffer_size - 1] != '\n'))
