@@ -1,7 +1,7 @@
 /*
  * gui-line.c - line functions (used by all GUI)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -276,7 +276,7 @@ gui_line_get_align (struct t_gui_buffer *buffer, struct t_gui_line *line,
     {
         if ((CONFIG_INTEGER(config_look_prefix_buffer_align) == CONFIG_LOOK_PREFIX_BUFFER_ALIGN_NONE)
             && (CONFIG_INTEGER(config_look_prefix_align) == CONFIG_LOOK_PREFIX_ALIGN_NONE))
-            length_buffer = gui_chat_strlen_screen (gui_buffer_get_short_name (buffer)) + 1;
+            length_buffer = gui_chat_strlen_screen (gui_buffer_get_short_name (line->data->buffer)) + 1;
         else
         {
             if (CONFIG_INTEGER(config_look_prefix_buffer_align) == CONFIG_LOOK_PREFIX_BUFFER_ALIGN_NONE)
@@ -597,7 +597,7 @@ int
 gui_line_match_tags (struct t_gui_line_data *line_data,
                      int tags_count, char ***tags_array)
 {
-    int i, j, k, match, tag_found;
+    int i, j, k, match, tag_found, tag_negated;
 
     if (!line_data)
         return 0;
@@ -611,17 +611,23 @@ gui_line_match_tags (struct t_gui_line_data *line_data,
         for (j = 0; tags_array[i][j]; j++)
         {
             tag_found = 0;
+            tag_negated = 0;
+
+            /* check if tag is negated (prefixed with a '!') */
+            if ((tags_array[i][j][0] == '!') && tags_array[i][j][1])
+                tag_negated = 1;
+
             for (k = 0; k < line_data->tags_count; k++)
             {
                 if (string_match (line_data->tags_array[k],
-                                  tags_array[i][j],
+                                  (tag_negated) ? tags_array[i][j] + 1 : tags_array[i][j],
                                   0))
                 {
                     tag_found = 1;
                     break;
                 }
             }
-            if (!tag_found)
+            if ((!tag_found && !tag_negated) || (tag_found && tag_negated))
             {
                 match = 0;
                 break;
@@ -776,7 +782,16 @@ gui_line_has_highlight (struct t_gui_line *line)
     {
         length = strlen (ptr_nick);
         if (strncmp (ptr_msg_no_color, ptr_nick, length) == 0)
+        {
+            /* skip nick at beginning (for example: "FlashCode") */
             ptr_msg_no_color += length;
+        }
+        else if (ptr_msg_no_color[0]
+                 && (strncmp (ptr_msg_no_color + 1, ptr_nick, length) == 0))
+        {
+            /* skip prefix and nick at beginning (for example: "@FlashCode") */
+            ptr_msg_no_color += length + 1;
+        }
     }
 
     /*
@@ -932,6 +947,10 @@ gui_line_add_to_list (struct t_gui_lines *lines,
     if (prefix_length > lines->prefix_max_length)
         lines->prefix_max_length = prefix_length;
 
+    /* adjust "lines_hidden" if the line is hidden */
+    if (!line->data->displayed)
+        (lines->lines_hidden)++;
+
     lines->lines_count++;
 }
 
@@ -959,8 +978,21 @@ gui_line_remove_from_list (struct t_gui_buffer *buffer,
             {
                 ptr_scroll->start_line = ptr_scroll->start_line->next_line;
                 ptr_scroll->start_line_pos = 0;
-                gui_buffer_ask_chat_refresh (buffer, 2);
+                if (ptr_scroll->start_line)
+                {
+                    gui_buffer_ask_chat_refresh (buffer, 2);
+                }
+                else
+                {
+                    ptr_scroll->first_line_displayed = 1;
+                    ptr_scroll->scrolling = 0;
+                    ptr_scroll->lines_after = 0;
+                    gui_window_ask_refresh (1);
+                }
             }
+
+            if (ptr_scroll->text_search_start_line == line)
+                ptr_scroll->text_search_start_line = NULL;
         }
         /* remove line from coords */
         gui_window_coords_remove_line (ptr_win, line);
@@ -981,6 +1013,10 @@ gui_line_remove_from_list (struct t_gui_buffer *buffer,
         gui_buffer_ask_chat_refresh (buffer, 1);
     }
 
+    /* adjust "lines_hidden" if the line was hidden */
+    if (!line->data->displayed && (lines->lines_hidden > 0))
+        (lines->lines_hidden)--;
+
     /* free data */
     if (free_data)
     {
@@ -1246,9 +1282,9 @@ gui_line_add (struct t_gui_buffer *buffer, time_t date,
                 message_for_signal = gui_chat_build_string_prefix_message (new_line);
                 if (message_for_signal)
                 {
-                    hook_signal_send ("weechat_highlight",
-                                      WEECHAT_HOOK_SIGNAL_STRING,
-                                      message_for_signal);
+                    (void) hook_signal_send ("weechat_highlight",
+                                             WEECHAT_HOOK_SIGNAL_STRING,
+                                             message_for_signal);
                     free (message_for_signal);
                 }
             }
@@ -1260,9 +1296,9 @@ gui_line_add (struct t_gui_buffer *buffer, time_t date,
                 message_for_signal = gui_chat_build_string_prefix_message (new_line);
                 if (message_for_signal)
                 {
-                    hook_signal_send ("weechat_pv",
-                                      WEECHAT_HOOK_SIGNAL_STRING,
-                                      message_for_signal);
+                    (void) hook_signal_send ("weechat_pv",
+                                             WEECHAT_HOOK_SIGNAL_STRING,
+                                             message_for_signal);
                     free (message_for_signal);
                 }
             }
@@ -1272,11 +1308,8 @@ gui_line_add (struct t_gui_buffer *buffer, time_t date,
     }
     else
     {
-        buffer->own_lines->lines_hidden++;
-        if (buffer->mixed_lines)
-            buffer->mixed_lines->lines_hidden++;
-        hook_signal_send ("buffer_lines_hidden",
-                          WEECHAT_HOOK_SIGNAL_POINTER, buffer);
+        (void) hook_signal_send ("buffer_lines_hidden",
+                                 WEECHAT_HOOK_SIGNAL_POINTER, buffer);
     }
 
     /* add mixed line, if buffer is attached to at least one other buffer */
@@ -1303,8 +1336,8 @@ gui_line_add (struct t_gui_buffer *buffer, time_t date,
         }
     }
 
-    hook_signal_send ("buffer_line_added",
-                      WEECHAT_HOOK_SIGNAL_POINTER, new_line);
+    (void) hook_signal_send ("buffer_line_added",
+                             WEECHAT_HOOK_SIGNAL_POINTER, new_line);
 
     return new_line;
 }
@@ -1408,8 +1441,8 @@ gui_line_add_y (struct t_gui_buffer *buffer, int y, const char *message)
     if (!ptr_line->data->displayed)
     {
         buffer->own_lines->lines_hidden++;
-        hook_signal_send ("buffer_lines_hidden",
-                          WEECHAT_HOOK_SIGNAL_POINTER, buffer);
+        (void) hook_signal_send ("buffer_lines_hidden",
+                                 WEECHAT_HOOK_SIGNAL_POINTER, buffer);
     }
 
     ptr_line->data->refresh_needed = 1;
