@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_NICKLIST_H
-#define __WEECHAT_GUI_NICKLIST_H 1
+#ifndef WEECHAT_GUI_NICKLIST_H
+#define WEECHAT_GUI_NICKLIST_H 1
 
 struct t_gui_buffer;
 struct t_infolist;
@@ -118,4 +118,4 @@ extern int gui_nicklist_add_to_infolist (struct t_infolist *infolist,
 extern void gui_nicklist_print_log (struct t_gui_nick_group *group, int indent);
 extern void gui_nicklist_end ();
 
-#endif /* __WEECHAT_GUI_NICKLIST_H */
+#endif /* WEECHAT_GUI_NICKLIST_H */
