@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_WINDOW_H
-#define __WEECHAT_GUI_WINDOW_H 1
+#ifndef WEECHAT_GUI_WINDOW_H
+#define WEECHAT_GUI_WINDOW_H 1
 
 struct t_infolist;
 struct t_gui_bar_window;
@@ -96,6 +96,8 @@ struct t_gui_window_scroll
                                        /* (for horizontal scrolling)        */
     int lines_after;                   /* number of lines after last line   */
                                        /* displayed (with scrolling)        */
+    struct t_gui_line *text_search_start_line; /* starting line for search  */
+
     struct t_gui_window_scroll *prev_scroll; /* link to prev. buf. scrolled */
     struct t_gui_window_scroll *next_scroll; /* link to next buf. scrolled  */
 };
@@ -124,6 +126,8 @@ extern struct t_gui_window *gui_current_window;
 extern struct t_gui_window_tree *gui_windows_tree;
 extern int gui_window_cursor_x;
 extern int gui_window_cursor_y;
+extern int gui_window_bare_display;
+extern struct t_hook *gui_window_bare_display_timer;
 
 /* window functions */
 
@@ -179,8 +183,10 @@ extern void gui_window_scroll_horiz (struct t_gui_window *window, char *scroll);
 extern void gui_window_scroll_previous_highlight (struct t_gui_window *window);
 extern void gui_window_scroll_next_highlight (struct t_gui_window *window);
 extern void gui_window_scroll_unread (struct t_gui_window *window);
-extern void gui_window_search_start (struct t_gui_window *window);
+extern void gui_window_search_start (struct t_gui_window *window,
+                                     struct t_gui_line *text_search_start_line);
 extern void gui_window_search_restart (struct t_gui_window *window);
+extern void gui_window_search_stop_here (struct t_gui_window *window);
 extern void gui_window_search_stop (struct t_gui_window *window);
 extern int gui_window_search_text (struct t_gui_window *window);
 extern void gui_window_zoom (struct t_gui_window *window);
@@ -229,6 +235,7 @@ extern void gui_window_switch_right (struct t_gui_window *window);
 extern int gui_window_balance (struct t_gui_window_tree *tree);
 extern void gui_window_swap (struct t_gui_window *window, int direction);
 extern void gui_window_refresh_screen (int full_refresh);
+extern void gui_window_bare_display_toggle (const char *delay);
 extern void gui_window_set_title (const char *title);
 extern void gui_window_send_clipboard (const char *storage_unit,
                                        const char *text);
@@ -237,4 +244,4 @@ extern void gui_window_move_cursor ();
 extern void gui_window_term_display_infos ();
 extern void gui_window_objects_print_log (struct t_gui_window *window);
 
-#endif /* __WEECHAT_GUI_WINDOW_H */
+#endif /* WEECHAT_GUI_WINDOW_H */
