@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,9 +17,9 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_ALIAS_INFO_H
-#define __WEECHAT_ALIAS_INFO_H 1
+#ifndef WEECHAT_ALIAS_INFO_H
+#define WEECHAT_ALIAS_INFO_H 1
 
 extern void alias_info_init ();
 
-#endif /* __WEECHAT_ALIAS_INFO_H */
+#endif /* WEECHAT_ALIAS_INFO_H */
