@@ -1,7 +1,7 @@
 /*
  * alias.c - alias plugin for WeeChat: command aliases
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -25,6 +25,8 @@
 
 #include "../weechat-plugin.h"
 #include "alias.h"
+#include "alias-command.h"
+#include "alias-completion.h"
 #include "alias-config.h"
 #include "alias-info.h"
 
@@ -34,6 +36,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Alias commands"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(8000);
 
 #define ALIAS_IS_ARG_NUMBER(number) ((number >= '1') && (number <= '9'))
 
@@ -176,6 +179,8 @@ alias_string_add_arguments (char **alias, int *length, char **argv, int start,
  *   $n-m arguments from n to m
  *   $*   all arguments
  *   $~   last argument
+ *
+ * Note: result must be freed after use.
  */
 
 char *
@@ -521,7 +526,7 @@ alias_hook_command (struct t_alias *alias)
     /*
      * if alias has no custom completion, then default is to complete with
      * completion template of target command, for example if alias is
-     * "/alias test /buffer", then str_completion will be "%%buffer"
+     * "/alias add test /buffer", then str_completion will be "%%buffer"
      */
     str_completion = NULL;
     if (!alias->completion)
@@ -566,6 +571,33 @@ alias_update_completion (struct t_alias *alias, const char *completion)
     alias_hook_command (alias);
 }
 
+/*
+ * Checks if an alias name is valid: it must not contain any slashes nor
+ * any spaces.
+ *
+ * Returns:
+ *   1: name is valid
+ *   0: name is invalid
+ */
+
+int
+alias_name_valid (const char *name)
+{
+    if (!name || !name[0])
+        return 0;
+
+    /* no spaces allowed */
+    if (strchr (name, ' '))
+        return 0;
+
+    /* no slashes allowed */
+    if (strchr (name, '/'))
+        return 0;
+
+    /* name is valid */
+    return 1;
+}
+
 /*
  * Creates a new alias and adds it to alias list.
  *
@@ -577,7 +609,16 @@ alias_new (const char *name, const char *command, const char *completion)
 {
     struct t_alias *new_alias, *ptr_alias, *pos_alias;
 
-    if (!name || !name[0] || !command || !command[0])
+    if (!alias_name_valid (name))
+    {
+        weechat_printf (NULL,
+                        _("%s%s: invalid alias name: \"%s\""),
+                        weechat_prefix ("error"), ALIAS_PLUGIN_NAME,
+                        name);
+        return NULL;
+    }
+
+    if (!command || !command[0])
         return NULL;
 
     while (weechat_string_is_command_char (name))
@@ -635,302 +676,6 @@ alias_new (const char *name, const char *command, const char *completion)
     return new_alias;
 }
 
-/*
- * Gets final command pointer by an alias.
- */
-
-char *
-alias_get_final_command (struct t_alias *alias)
-{
-    struct t_alias *ptr_alias;
-    char *result;
-
-    if (alias->running)
-    {
-        weechat_printf (NULL,
-                        _("%s%s: error, circular reference when calling "
-                          "alias \"%s\""),
-                        weechat_prefix ("error"), ALIAS_PLUGIN_NAME,
-                        alias->name);
-        return NULL;
-    }
-
-    ptr_alias = alias_search ((weechat_string_is_command_char (alias->command)) ?
-                              weechat_utf8_next_char (alias->command) : alias->command);
-    if (ptr_alias)
-    {
-        alias->running = 1;
-        result = alias_get_final_command (ptr_alias);
-        alias->running = 0;
-        return result;
-    }
-    return (weechat_string_is_command_char (alias->command)) ?
-        weechat_utf8_next_char (alias->command) : alias->command;
-}
-
-/*
- * Callback for command "/alias": displays or creates alias.
- */
-
-int
-alias_command_cb (void *data, struct t_gui_buffer *buffer, int argc,
-                  char **argv, char **argv_eol)
-{
-    char *ptr_completion, *ptr_alias_name, *ptr_command;
-    struct t_alias *ptr_alias;
-    struct t_config_option *ptr_option;
-    int alias_found;
-
-    /* make C compiler happy */
-    (void) data;
-    (void) buffer;
-
-    if (argc > 1)
-    {
-        if (argc > 2)
-        {
-            /* get pointers to completion, alias name and command (+ args) */
-            ptr_completion = NULL;
-            ptr_alias_name = NULL;
-            ptr_command = NULL;
-            if ((argc > 4) && (weechat_strcasecmp (argv[1], "-completion") == 0))
-            {
-                ptr_completion = argv[2];
-                ptr_alias_name = (weechat_string_is_command_char (argv[3])) ?
-                    weechat_utf8_next_char (argv[3]) : argv[3];
-                ptr_command = argv_eol[4];
-            }
-            else
-            {
-                ptr_alias_name = (weechat_string_is_command_char (argv[1])) ?
-                    weechat_utf8_next_char (argv[1]) : argv[1];
-                ptr_command = argv_eol[2];
-            }
-
-            /* define new alias */
-            if (!alias_new (ptr_alias_name, ptr_command, ptr_completion))
-            {
-                weechat_printf (NULL,
-                                _("%s%s: error creating alias \"%s\" "
-                                  "=> \"%s\""),
-                                weechat_prefix ("error"), ALIAS_PLUGIN_NAME,
-                                ptr_alias_name, ptr_command);
-                return WEECHAT_RC_OK;
-            }
-
-            /* create configuration option for command */
-            ptr_option = weechat_config_search_option (alias_config_file,
-                                                       alias_config_section_cmd,
-                                                       ptr_alias_name);
-            if (ptr_option)
-                weechat_config_option_free (ptr_option);
-            alias_config_cmd_new_option (ptr_alias_name, ptr_command);
-
-            /* create configuration option for completion */
-            ptr_option = weechat_config_search_option (alias_config_file,
-                                                       alias_config_section_completion,
-                                                       ptr_alias_name);
-            if (ptr_option)
-                weechat_config_option_free (ptr_option);
-            if (ptr_completion)
-                alias_config_completion_new_option (ptr_alias_name, ptr_completion);
-
-            /* display message */
-            weechat_printf (NULL,
-                            _("Alias \"%s\" => \"%s\" created"),
-                            ptr_alias_name, ptr_command);
-        }
-        else
-        {
-            /* get pointer to alias name */
-            ptr_alias_name = (weechat_string_is_command_char (argv[1])) ?
-                weechat_utf8_next_char (argv[1]) : argv[1];
-
-            /* display list of aliases */
-            alias_found = 0;
-            for (ptr_alias = alias_list; ptr_alias;
-                 ptr_alias = ptr_alias->next_alias)
-            {
-                if (weechat_string_match (ptr_alias->name, ptr_alias_name, 0))
-                {
-                    if (!alias_found)
-                    {
-                        weechat_printf (NULL, "");
-                        weechat_printf (NULL, _("List of aliases:"));
-                    }
-                    weechat_printf (NULL, "  %s %s=>%s %s",
-                                    ptr_alias->name,
-                                    weechat_color ("chat_delimiters"),
-                                    weechat_color ("chat"),
-                                    ptr_alias->command);
-                    alias_found = 1;
-                }
-            }
-            if (!alias_found)
-            {
-                weechat_printf (NULL, _("No alias found matching \"%s\""),
-                                ptr_alias_name);
-            }
-        }
-    }
-    else
-    {
-        /* List all aliases */
-        if (alias_list)
-        {
-            weechat_printf (NULL, "");
-            weechat_printf (NULL, _("List of aliases:"));
-            for (ptr_alias = alias_list; ptr_alias;
-                 ptr_alias = ptr_alias->next_alias)
-            {
-                weechat_printf (NULL,
-                                "  %s %s=>%s %s",
-                                ptr_alias->name,
-                                weechat_color ("chat_delimiters"),
-                                weechat_color ("chat"),
-                                ptr_alias->command);
-            }
-        }
-        else
-            weechat_printf (NULL, _("No alias defined"));
-    }
-
-    return WEECHAT_RC_OK;
-}
-
-/*
- * Callback for command "/unalias": removes an alias.
- */
-
-int
-unalias_command_cb (void *data, struct t_gui_buffer *buffer, int argc,
-                    char **argv, char **argv_eol)
-{
-    int i;
-    char *alias_name;
-    struct t_alias *ptr_alias;
-    struct t_config_option *ptr_option;
-
-    /* make C compiler happy */
-    (void) data;
-    (void) buffer;
-    (void) argv_eol;
-
-    if (argc > 1)
-    {
-        for (i = 1; i < argc; i++)
-        {
-            alias_name = (weechat_string_is_command_char (argv[i])) ?
-                weechat_utf8_next_char (argv[i]) : argv[i];
-            ptr_alias = alias_search (alias_name);
-            if (!ptr_alias)
-            {
-                weechat_printf (NULL,
-                                _("%sAlias \"%s\" not found"),
-                                weechat_prefix ("error"),
-                                alias_name);
-            }
-            else
-            {
-                /* remove alias */
-                alias_free (ptr_alias);
-
-                /* remove options */
-                ptr_option = weechat_config_search_option (alias_config_file,
-                                                           alias_config_section_cmd,
-                                                           alias_name);
-                if (ptr_option)
-                    weechat_config_option_free (ptr_option);
-                ptr_option = weechat_config_search_option (alias_config_file,
-                                                           alias_config_section_completion,
-                                                           alias_name);
-                if (ptr_option)
-                    weechat_config_option_free (ptr_option);
-
-                weechat_printf (NULL,
-                                _("Alias \"%s\" removed"),
-                                alias_name);
-            }
-        }
-    }
-    return WEECHAT_RC_OK;
-}
-
-/*
- * Adds list of aliases to completion list.
- */
-
-int
-alias_completion_cb (void *data, const char *completion_item,
-                     struct t_gui_buffer *buffer,
-                     struct t_gui_completion *completion)
-{
-    struct t_alias *ptr_alias;
-
-    /* make C compiler happy */
-    (void) data;
-    (void) completion_item;
-    (void) buffer;
-
-    for (ptr_alias = alias_list; ptr_alias;
-         ptr_alias = ptr_alias->next_alias)
-    {
-        weechat_hook_completion_list_add (completion, ptr_alias->name,
-                                          0, WEECHAT_LIST_POS_SORT);
-    }
-
-    return WEECHAT_RC_OK;
-}
-
-/*
- * Adds value of an alias to completion list.
- */
-
-int
-alias_value_completion_cb (void *data, const char *completion_item,
-                           struct t_gui_buffer *buffer,
-                           struct t_gui_completion *completion)
-{
-    const char *args;
-    char **argv, *alias_name;
-    int argc;
-    struct t_alias *ptr_alias;
-
-    /* make C compiler happy */
-    (void) data;
-    (void) completion_item;
-    (void) buffer;
-
-    args = weechat_hook_completion_get_string (completion, "args");
-    if (args)
-    {
-        argv = weechat_string_split (args, " ", 0, 0, &argc);
-        if (argv)
-        {
-            if (argc > 0)
-                alias_name = strdup (argv[argc - 1]);
-            else
-                alias_name = strdup (args);
-
-            if (alias_name)
-            {
-                ptr_alias = alias_search (alias_name);
-                if (ptr_alias)
-                {
-                    weechat_hook_completion_list_add (completion,
-                                                      ptr_alias->command,
-                                                      0,
-                                                      WEECHAT_LIST_POS_BEGINNING);
-                }
-                free (alias_name);
-            }
-            weechat_string_free_split (argv);
-        }
-    }
-
-    return WEECHAT_RC_OK;
-}
-
 /*
  * Adds an alias in an infolist.
  *
@@ -983,57 +728,9 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 
     alias_config_read ();
 
-    weechat_hook_command (
-        "alias",
-        N_("create an alias for a command"),
-        N_("[-completion <completion>] <alias> [<command> [;<command>...]]"),
-        N_("completion: completion for alias (optional, by default completion "
-           "is done with target command)\n"
-           "            note: you can use %%command to use completion of an "
-           "existing command\n"
-           "     alias: name of alias (can start or end with \"*\" for alias "
-           "listing)\n"
-           "   command: command name with arguments (many commands can be "
-           "separated by semicolons)\n"
-           "\n"
-           "Without argument, this command lists all defined alias.\n"
-           "\n"
-           "Note: in command, special variables are replaced:\n"
-           "        $n: argument 'n' (between 1 and 9)\n"
-           "       $-m: arguments from 1 to 'm'\n"
-           "       $n-: arguments from 'n' to last\n"
-           "      $n-m: arguments from 'n' to 'm'\n"
-           "        $*: all arguments\n"
-           "        $~: last argument\n"
-           "      $var: where \"var\" is a local variable of buffer (see "
-           "/buffer localvar)\n"
-           "            examples: $nick, $channel, $server, $plugin, $name\n"
-           "\n"
-           "To remove an alias, use command /unalias.\n"
-           "\n"
-           "Examples:\n"
-           "  alias /split to split window horizontally:\n"
-           "    /alias split /window splith\n"
-           "  alias /hello to say \"hello\" on all channels but not on "
-           "#weechat:\n"
-           "    /alias hello /allchan -exclude=#weechat msg * hello\n"
-           "  alias /forcejoin to send IRC command \"forcejoin\" with "
-           "completion of /sajoin:\n"
-           "    /alias -completion %%sajoin forcejoin /quote forcejoin"),
-        "-completion %- %(alias) %(commands)|%(alias_value)"
-        " || %(alias) %(commands)|%(alias_value)",
-        &alias_command_cb, NULL);
-    weechat_hook_command (
-        "unalias", N_("remove aliases"),
-        N_("<alias> [<alias>...]"),
-        N_("alias: name of alias to remove"),
-        "%(alias)|%*",
-        &unalias_command_cb, NULL);
+    alias_command_init ();
 
-    weechat_hook_completion ("alias", N_("list of aliases"),
-                             &alias_completion_cb, NULL);
-    weechat_hook_completion ("alias_value", N_("value of alias"),
-                             &alias_value_completion_cb, NULL);
+    alias_completion_init ();
 
     alias_info_init ();
 
