@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_ALIAS_H
-#define __WEECHAT_ALIAS_H 1
+#ifndef WEECHAT_ALIAS_H
+#define WEECHAT_ALIAS_H 1
 
 #define weechat_plugin weechat_alias_plugin
 #define ALIAS_PLUGIN_NAME "alias"
@@ -52,4 +52,4 @@ extern void alias_free_all ();
 extern int alias_add_to_infolist (struct t_infolist *infolist,
                                   struct t_alias *alias);
 
-#endif /* __WEECHAT_ALIAS_H */
+#endif /* WEECHAT_ALIAS_H */
