@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_ASPELL_SPELLER_H
-#define __WEECHAT_ASPELL_SPELLER_H 1
+#ifndef WEECHAT_ASPELL_SPELLER_H
+#define WEECHAT_ASPELL_SPELLER_H 1
 
 struct t_aspell_speller_buffer
 {
@@ -27,7 +27,7 @@ struct t_aspell_speller_buffer
     EnchantDict **spellers;                /* enchant spellers for buffer   */
 #else
     AspellSpeller **spellers;              /* aspell spellers for buffer    */
-#endif
+#endif /* USE_ENCHANT */
     char *modifier_string;                 /* last modifier string          */
     int input_pos;                         /* position of cursor in input   */
     char *modifier_result;                 /* last modifier result          */
@@ -42,10 +42,10 @@ extern void weechat_aspell_speller_check_dictionaries (const char *dict_list);
 extern EnchantDict *weechat_aspell_speller_new (const char *lang);
 #else
 extern AspellSpeller *weechat_aspell_speller_new (const char *lang);
-#endif
+#endif /* USE_ENCHANT */
 extern void weechat_aspell_speller_remove_unused ();
 extern struct t_aspell_speller_buffer *weechat_aspell_speller_buffer_new (struct t_gui_buffer *buffer);
 extern int weechat_aspell_speller_init ();
 extern void weechat_aspell_speller_end ();
 
-#endif /* __WEECHAT_ASPELL_SPELLER_H */
+#endif /* WEECHAT_ASPELL_SPELLER_H */
