@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -18,14 +18,14 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_ASPELL_H
-#define __WEECHAT_ASPELL_H 1
+#ifndef WEECHAT_ASPELL_H
+#define WEECHAT_ASPELL_H 1
 
 #ifdef USE_ENCHANT
 #include <enchant.h>
 #else
 #include <aspell.h>
-#endif
+#endif /* USE_ENCHANT */
 
 #define weechat_plugin weechat_aspell_plugin
 #define ASPELL_PLUGIN_NAME "aspell"
@@ -38,7 +38,7 @@ struct t_aspell_code
 
 #ifdef USE_ENCHANT
 extern EnchantBroker *broker;
-#endif
+#endif /* USE_ENCHANT */
 
 extern struct t_weechat_plugin *weechat_aspell_plugin;
 extern int aspell_enabled;
@@ -49,4 +49,4 @@ extern char *weechat_aspell_build_option_name (struct t_gui_buffer *buffer);
 extern const char *weechat_aspell_get_dict_with_buffer_name (const char *name);
 extern const char *weechat_aspell_get_dict (struct t_gui_buffer *buffer);
 
-#endif /* __WEECHAT_ASPELL_H */
+#endif /* WEECHAT_ASPELL_H */
