@@ -1,7 +1,7 @@
 /*
  * fifo.c - fifo plugin for WeeChat: remote control with FIFO pipe
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -32,6 +32,7 @@
 
 #include "../weechat-plugin.h"
 #include "fifo.h"
+#include "fifo-command.h"
 #include "fifo-info.h"
 
 
@@ -40,6 +41,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("FIFO pipe for remote control"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(7000);
 
 #define FIFO_FILENAME_PREFIX "weechat_fifo_"
 
@@ -157,8 +159,9 @@ fifo_create ()
                     if ((weechat_fifo_plugin->debug >= 1) || !fifo_quiet)
                     {
                         weechat_printf (NULL,
-                                        _("%s: pipe opened"),
-                                        FIFO_PLUGIN_NAME);
+                                        _("%s: pipe opened (file: %s)"),
+                                        FIFO_PLUGIN_NAME,
+                                        fifo_filename);
                     }
                     fifo_fd_hook = weechat_hook_fd (fifo_fd, 1, 0, 0,
                                                     &fifo_read, NULL);
@@ -233,7 +236,7 @@ fifo_remove ()
 void
 fifo_exec (const char *text)
 {
-    char *text2, *pos_msg, *pos_buffer;
+    char *text2, *pos_msg;
     struct t_gui_buffer *ptr_buffer;
 
     text2 = strdup (text);
@@ -258,37 +261,23 @@ fifo_exec (const char *text)
         if (!pos_msg)
         {
             weechat_printf (NULL,
-                            _("%s%s: error, invalid text received on pipe"),
+                            _("%s%s: invalid text received in pipe"),
                             weechat_prefix ("error"), FIFO_PLUGIN_NAME);
             free (text2);
             return;
         }
         pos_msg[0] = '\0';
         pos_msg += 2;
-
-        pos_buffer = strchr (text2, '.');
-        if (!pos_buffer)
+        ptr_buffer = weechat_buffer_search ("==", text2);
+        if (!ptr_buffer)
         {
             weechat_printf (NULL,
-                            _("%s%s: error, invalid text received on pipe"),
-                            weechat_prefix ("error"), FIFO_PLUGIN_NAME);
+                            _("%s%s: buffer \"%s\" not found"),
+                            weechat_prefix ("error"), FIFO_PLUGIN_NAME,
+                            text2);
             free (text2);
             return;
         }
-        pos_buffer[0] = '\0';
-        pos_buffer++;
-
-        if (text2[0] && pos_buffer[0])
-            ptr_buffer = weechat_buffer_search (text2, pos_buffer);
-    }
-
-    if (!ptr_buffer)
-    {
-        weechat_printf (NULL,
-                        _("%s%s: error, buffer not found for pipe data"),
-                        weechat_prefix ("error"), FIFO_PLUGIN_NAME);
-        free (text2);
-        return;
     }
 
     weechat_command (ptr_buffer, pos_msg);
@@ -370,7 +359,11 @@ fifo_read (void *data, int fd)
     {
         if (num_read < 0)
         {
+#ifdef __CYGWIN__
+            if ((errno == EAGAIN) || (errno == ECOMM))
+#else
             if (errno == EAGAIN)
+#endif /* __CYGWIN__ */
                 return WEECHAT_RC_OK;
 
             weechat_printf (NULL,
@@ -433,6 +426,8 @@ fifo_config_cb (void *data, const char *option, const char *value)
 int
 weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 {
+    char str_option[256];
+
     /* make C compiler happy */
     (void) argc;
     (void) argv;
@@ -443,8 +438,11 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 
     fifo_create ();
 
-    weechat_hook_config ("plugins.var.fifo.fifo", &fifo_config_cb, NULL);
+    snprintf (str_option, sizeof (str_option),
+              "plugins.var.fifo.%s", FIFO_OPTION_NAME);
+    weechat_hook_config (str_option, &fifo_config_cb, NULL);
 
+    fifo_command_init ();
     fifo_info_init ();
 
     fifo_quiet = 0;
