@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,8 +22,10 @@
 
 #define weechat_plugin weechat_fifo_plugin
 #define FIFO_PLUGIN_NAME "fifo"
+#define FIFO_OPTION_NAME "fifo"
 
 extern struct t_weechat_plugin *weechat_fifo_plugin;
+extern int fifo_fd;
 extern char *fifo_filename;
 
 #endif /* WEECHAT_FIFO_H */
