@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUILE_API_H
-#define __WEECHAT_GUILE_API_H 1
+#ifndef WEECHAT_GUILE_API_H
+#define WEECHAT_GUILE_API_H 1
 
 extern int weechat_guile_api_buffer_input_data_cb (void *data,
                                                    struct t_gui_buffer *buffer,
@@ -27,4 +27,4 @@ extern int weechat_guile_api_buffer_close_cb (void *data,
                                               struct t_gui_buffer *buffer);
 extern void weechat_guile_api_module_init (void *data);
 
-#endif /* __WEECHAT_GUILE_API_H */
+#endif /* WEECHAT_GUILE_API_H */
