@@ -1,7 +1,7 @@
 /*
  * weechat-guile.c - guile (scheme) plugin for WeeChat
  *
- * Copyright (C) 2011-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,6 +19,10 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #undef _
 
 #include <libguile.h>
@@ -38,6 +42,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Support of scheme scripts (with Guile)"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(3000);
 
 struct t_weechat_plugin *weechat_guile_plugin = NULL;
 
@@ -185,7 +190,7 @@ weechat_guile_hashtable_map_cb (void *data,
 }
 
 /*
- * Gets guile alist with a WeeChat hashtable.
+ * Converts a WeeChat hashtable to a guile alist.
  */
 
 SCM
@@ -203,7 +208,7 @@ weechat_guile_hashtable_to_alist (struct t_hashtable *hashtable)
 }
 
 /*
- * Gets WeeChat hashtable with guile alist.
+ * Converts a guile alist to a WeeChat hashtable.
  *
  * Note: hashtable must be free after use.
  */
@@ -217,11 +222,8 @@ weechat_guile_alist_to_hashtable (SCM alist, int size, const char *type_keys,
     SCM pair;
     char *str, *str2;
 
-    hashtable = weechat_hashtable_new (size,
-                                       type_keys,
-                                       type_values,
-                                       NULL,
-                                       NULL);
+    hashtable = weechat_hashtable_new (size, type_keys, type_values,
+                                       NULL, NULL);
     if (!hashtable)
         return NULL;
 
@@ -436,8 +438,9 @@ weechat_guile_load (const char *filename)
                                         &weechat_guile_api_buffer_input_data_cb,
                                         &weechat_guile_api_buffer_close_cb);
 
-    weechat_hook_signal_send ("guile_script_loaded", WEECHAT_HOOK_SIGNAL_STRING,
-                              guile_current_script->filename);
+    (void) weechat_hook_signal_send ("guile_script_loaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING,
+                                     guile_current_script->filename);
 
     return 1;
 }
@@ -494,8 +497,11 @@ weechat_guile_unload (struct t_plugin_script *script)
     if (interpreter)
         weechat_guile_catch (scm_gc_unprotect_object, interpreter);
 
-    weechat_hook_signal_send ("guile_script_unloaded",
-                              WEECHAT_HOOK_SIGNAL_STRING, filename);
+    if (guile_current_script)
+        scm_set_current_module ((SCM)(guile_current_script->interpreter));
+
+    (void) weechat_hook_signal_send ("guile_script_unloaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING, filename);
     if (filename)
         free (filename);
 }
@@ -621,6 +627,8 @@ weechat_guile_command_cb (void *data, struct t_gui_buffer *buffer,
         {
             weechat_guile_unload_all ();
         }
+        else
+            WEECHAT_COMMAND_ERROR;
     }
     else
     {
@@ -681,13 +689,7 @@ weechat_guile_command_cb (void *data, struct t_gui_buffer *buffer,
             weechat_guile_stdout_flush ();
         }
         else
-        {
-            weechat_printf (NULL,
-                            weechat_gettext ("%s%s: unknown option for "
-                                             "command \"%s\""),
-                            weechat_prefix ("error"), GUILE_PLUGIN_NAME,
-                            "guile");
-        }
+            WEECHAT_COMMAND_ERROR;
     }
 
     return WEECHAT_RC_OK;
@@ -795,7 +797,7 @@ weechat_guile_signal_debug_libs_cb (void *data, const char *signal,
                     SCM_MICRO_VERSION);
 #else
     weechat_printf (NULL, "  %s: (?)", GUILE_PLUGIN_NAME);
-#endif
+#endif /* defined(SCM_MAJOR_VERSION) && defined(SCM_MINOR_VERSION) && defined(SCM_MICRO_VERSION) */
 
     return WEECHAT_RC_OK;
 }
@@ -971,12 +973,14 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 
     guile_stdout = NULL;
 
+#ifdef HAVE_GUILE_GMP_MEMORY_FUNCTIONS
     /*
      * prevent guile to use its own gmp allocator, because it can conflict
      * with other plugins using GnuTLS like relay, which can crash WeeChat
      * on unload (or exit)
      */
     scm_install_gmp_memory_functions = 0;
+#endif /* HAVE_GUILE_GMP_MEMORY_FUNCTIONS */
 
     scm_init_guile ();
 
