@@ -1,7 +1,7 @@
 /*
  * irc-buffer.c - buffer functions for IRC plugin
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -87,7 +87,7 @@ irc_buffer_get_server_and_channel (struct t_gui_buffer *buffer,
  * Builds buffer name with a server and a channel.
  */
 
-char *
+const char *
 irc_buffer_build_name (const char *server, const char *channel)
 {
     static char buffer[128];
