@@ -1,7 +1,7 @@
 /*
  * irc-channel.c - channel and private chat management for IRC plugin
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -76,59 +76,69 @@ irc_channel_move_near_server (struct t_irc_server *server, int channel_type,
     int number, number_channel, number_last_channel, number_last_private;
     int number_found;
     char str_number[32];
-    struct t_irc_channel *ptr_channel;
+    const char *ptr_type, *ptr_server_name;
+    struct t_hdata *hdata_buffer;
+    struct t_gui_buffer *ptr_buffer;
 
     number = weechat_buffer_get_integer (buffer, "number");
     number_last_channel = 0;
     number_last_private = 0;
     number_found = 0;
 
-    if (server->channels)
+    hdata_buffer = weechat_hdata_get ("buffer");
+    ptr_buffer = weechat_hdata_get_list (hdata_buffer, "gui_buffers");
+    while (ptr_buffer)
     {
-        /* search last channel/pv number for server */
-        for (ptr_channel = server->channels; ptr_channel;
-             ptr_channel = ptr_channel->next_channel)
+        if ((ptr_buffer != buffer)
+            && (weechat_buffer_get_pointer (ptr_buffer,
+                                            "plugin") == weechat_irc_plugin))
         {
-            if (ptr_channel->buffer)
+            ptr_type = weechat_buffer_get_string (ptr_buffer,
+                                                  "localvar_type");
+            ptr_server_name = weechat_buffer_get_string (ptr_buffer,
+                                                         "localvar_server");
+            number_channel = weechat_buffer_get_integer (ptr_buffer,
+                                                         "number");
+            if (ptr_type && ptr_type[0]
+                && ptr_server_name && ptr_server_name[0]
+                && (strcmp (ptr_server_name, server->name) == 0))
             {
-                number_channel = weechat_buffer_get_integer (ptr_channel->buffer,
-                                                             "number");
-                switch (ptr_channel->type)
+                if (strcmp (ptr_type, "channel") == 0)
                 {
-                    case IRC_CHANNEL_TYPE_CHANNEL:
-                        if (number_channel > number_last_channel)
-                            number_last_channel = number_channel;
-                        break;
-                    case IRC_CHANNEL_TYPE_PRIVATE:
-                        if (number_channel > number_last_private)
-                            number_last_private = number_channel;
-                        break;
+                    if (number_channel > number_last_channel)
+                        number_last_channel = number_channel;
+                }
+                else if (strcmp (ptr_type, "private") == 0)
+                {
+                    if (number_channel > number_last_private)
+                        number_last_private = number_channel;
                 }
             }
         }
-
-        /* use last channel/pv number + 1 */
-        switch (channel_type)
-        {
-            case IRC_CHANNEL_TYPE_CHANNEL:
-                if (number_last_channel > 0)
-                    number_found = number_last_channel + 1;
-                break;
-            case IRC_CHANNEL_TYPE_PRIVATE:
-                if (number_last_private > 0)
-                    number_found = number_last_private + 1;
-                else if (number_last_channel > 0)
-                    number_found = number_last_channel + 1;
-                break;
-        }
+        /* move to next buffer */
+        ptr_buffer = weechat_hdata_move (hdata_buffer, ptr_buffer, 1);
     }
-    else
+
+    /* use last channel/pv number + 1 */
+    switch (channel_type)
     {
-        if (weechat_config_integer (irc_config_look_server_buffer) ==
-            IRC_CONFIG_LOOK_SERVER_BUFFER_INDEPENDENT)
-        {
-            number_found = weechat_buffer_get_integer (server->buffer, "number") + 1;
-        }
+        case IRC_CHANNEL_TYPE_CHANNEL:
+            if (number_last_channel > 0)
+                number_found = number_last_channel + 1;
+            break;
+        case IRC_CHANNEL_TYPE_PRIVATE:
+            if (number_last_private > 0)
+                number_found = number_last_private + 1;
+            else if (number_last_channel > 0)
+                number_found = number_last_channel + 1;
+            break;
+    }
+
+    if ((number_found == 0)
+        && (weechat_config_integer (irc_config_look_server_buffer) ==
+            IRC_CONFIG_LOOK_SERVER_BUFFER_INDEPENDENT))
+    {
+        number_found = weechat_buffer_get_integer (server->buffer, "number") + 1;
     }
 
     /* switch to number found */
@@ -140,37 +150,105 @@ irc_channel_move_near_server (struct t_irc_server *server, int channel_type,
 }
 
 /*
- * Creates a new channel in a server.
+ * Searches for a channel by name.
  *
- * Returns pointer to new channel, NULL if error.
+ * Returns pointer to channel found, NULL if not found.
  */
 
 struct t_irc_channel *
-irc_channel_new (struct t_irc_server *server, int channel_type,
-                 const char *channel_name, int switch_to_channel,
-                 int auto_switch)
+irc_channel_search (struct t_irc_server *server, const char *channel_name)
 {
-    struct t_irc_channel *new_channel;
-    struct t_gui_buffer *new_buffer, *ptr_buffer_for_merge;
-    int buffer_created, current_buffer_number, buffer_position, manual_join;
-    int noswitch;
-    char *buffer_name, str_number[32], *channel_name_lower;
+    struct t_irc_channel *ptr_channel;
 
-    /* alloc memory for new channel */
-    if ((new_channel = malloc (sizeof (*new_channel))) == NULL)
-    {
-        weechat_printf (NULL,
-                        _("%s%s: cannot allocate new channel"),
-                        weechat_prefix ("error"), IRC_PLUGIN_NAME);
+    if (!server || !channel_name)
         return NULL;
+
+    for (ptr_channel = server->channels; ptr_channel;
+         ptr_channel = ptr_channel->next_channel)
+    {
+        if (irc_server_strcasecmp (server, ptr_channel->name, channel_name) == 0)
+            return ptr_channel;
+    }
+    return NULL;
+}
+
+/*
+ * Searches for a channel buffer by channel name.
+ *
+ * Returns pointer to buffer found, NULL if not found.
+ */
+
+struct t_gui_buffer *
+irc_channel_search_buffer (struct t_irc_server *server, int channel_type,
+                           const char *channel_name)
+{
+    struct t_hdata *hdata_buffer;
+    struct t_gui_buffer *ptr_buffer;
+    const char *ptr_type, *ptr_server_name, *ptr_channel_name;
+
+    hdata_buffer = weechat_hdata_get ("buffer");
+    ptr_buffer = weechat_hdata_get_list (hdata_buffer, "gui_buffers");
+
+    while (ptr_buffer)
+    {
+        if (weechat_buffer_get_pointer (ptr_buffer,
+                                        "plugin") == weechat_irc_plugin)
+        {
+            ptr_type = weechat_buffer_get_string (ptr_buffer, "localvar_type");
+            ptr_server_name = weechat_buffer_get_string (ptr_buffer,
+                                                         "localvar_server");
+            ptr_channel_name = weechat_buffer_get_string (ptr_buffer,
+                                                          "localvar_channel");
+            if (ptr_type && ptr_type[0]
+                && ptr_server_name && ptr_server_name[0]
+                && ptr_channel_name && ptr_channel_name[0]
+                && (((channel_type == IRC_CHANNEL_TYPE_CHANNEL)
+                     && (strcmp (ptr_type, "channel") == 0))
+                    || ((channel_type == IRC_CHANNEL_TYPE_PRIVATE)
+                        && (strcmp (ptr_type, "private") == 0)))
+                && (strcmp (ptr_server_name, server->name) == 0)
+                && ((irc_server_strcasecmp (server, ptr_channel_name,
+                                            channel_name) == 0)))
+            {
+                return ptr_buffer;
+            }
+        }
+
+        /* move to next buffer */
+        ptr_buffer = weechat_hdata_move (hdata_buffer, ptr_buffer, 1);
     }
 
-    /* create buffer for channel (or use existing one) */
+    /* buffer not found */
+    return NULL;
+}
+
+/*
+ * Creates a buffer for a channel.
+ */
+
+struct t_gui_buffer *
+irc_channel_create_buffer (struct t_irc_server *server,
+                           int channel_type,
+                           const char *channel_name,
+                           int switch_to_channel,
+                           int auto_switch)
+{
+    struct t_gui_buffer *ptr_buffer, *ptr_buffer_for_merge;
+    int buffer_created, current_buffer_number, buffer_position;
+    int manual_join, noswitch;
+    char str_number[32], *channel_name_lower;
+    const char *buffer_name, *short_name, *localvar_channel;
+
     buffer_created = 0;
+
     buffer_name = irc_buffer_build_name (server->name, channel_name);
-    new_buffer = weechat_buffer_search (IRC_PLUGIN_NAME, buffer_name);
-    if (new_buffer)
-        weechat_nicklist_remove_all (new_buffer);
+
+    ptr_buffer = irc_channel_search_buffer (server, channel_type,
+                                            channel_name);
+    if (ptr_buffer)
+    {
+        weechat_nicklist_remove_all (ptr_buffer);
+    }
     else
     {
         ptr_buffer_for_merge = NULL;
@@ -188,17 +266,16 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
                     break;
             }
         }
-        current_buffer_number = weechat_buffer_get_integer (weechat_current_buffer (),
-                                                            "number");
-        new_buffer = weechat_buffer_new (buffer_name,
+        current_buffer_number = weechat_buffer_get_integer (
+            weechat_current_buffer (), "number");
+
+        ptr_buffer = weechat_buffer_new (buffer_name,
                                          &irc_input_data_cb, NULL,
                                          &irc_buffer_close_cb, NULL);
-        if (!new_buffer)
-        {
-            free (new_channel);
+        if (!ptr_buffer)
             return NULL;
-        }
-        if (weechat_buffer_get_integer (new_buffer, "layout_number") < 1)
+
+        if (weechat_buffer_get_integer (ptr_buffer, "layout_number") < 1)
         {
             buffer_position = (channel_type == IRC_CHANNEL_TYPE_CHANNEL) ?
                 weechat_config_integer (irc_config_look_new_channel_position) :
@@ -212,53 +289,158 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
                     /* move buffer to current number + 1 */
                     snprintf (str_number, sizeof (str_number),
                               "%d", current_buffer_number + 1);
-                    weechat_buffer_set (new_buffer, "number", str_number);
+                    weechat_buffer_set (ptr_buffer, "number", str_number);
                     break;
                 case IRC_CONFIG_LOOK_BUFFER_POSITION_NEAR_SERVER:
                     /* move buffer after last channel/pv of server */
-                    irc_channel_move_near_server (server, channel_type, new_buffer);
+                    irc_channel_move_near_server (server, channel_type,
+                                                  ptr_buffer);
                     break;
             }
             if (ptr_buffer_for_merge)
-                weechat_buffer_merge (new_buffer, ptr_buffer_for_merge);
+                weechat_buffer_merge (ptr_buffer, ptr_buffer_for_merge);
         }
         buffer_created = 1;
     }
 
     if (buffer_created)
     {
-        if (!weechat_buffer_get_integer (new_buffer, "short_name_is_set"))
-            weechat_buffer_set (new_buffer, "short_name", channel_name);
-        weechat_buffer_set (new_buffer, "localvar_set_type",
-                            (channel_type == IRC_CHANNEL_TYPE_CHANNEL) ? "channel" : "private");
-        weechat_buffer_set (new_buffer, "localvar_set_nick", server->nick);
-        weechat_buffer_set (new_buffer, "localvar_set_server", server->name);
-        weechat_buffer_set (new_buffer, "localvar_set_channel", channel_name);
-        if (server->is_away && server->away_message)
-            weechat_buffer_set (new_buffer, "localvar_set_away", server->away_message);
-        weechat_hook_signal_send ("logger_backlog",
-                                  WEECHAT_HOOK_SIGNAL_POINTER, new_buffer);
+        if (!weechat_buffer_get_integer (ptr_buffer, "short_name_is_set"))
+            weechat_buffer_set (ptr_buffer, "short_name", channel_name);
+    }
+    else
+    {
+        short_name = weechat_buffer_get_string (ptr_buffer, "short_name");
+        localvar_channel = weechat_buffer_get_string (ptr_buffer,
+                                                      "localvar_channel");
+        if (!short_name
+            || (localvar_channel
+                && (strcmp (localvar_channel, short_name) == 0)))
+        {
+            /* update the short_name only if it was not changed by the user */
+            weechat_buffer_set (ptr_buffer, "short_name", channel_name);
+        }
+    }
+
+    weechat_buffer_set (ptr_buffer, "name", buffer_name);
+    weechat_buffer_set (ptr_buffer, "localvar_set_type",
+                        (channel_type == IRC_CHANNEL_TYPE_CHANNEL) ? "channel" : "private");
+    weechat_buffer_set (ptr_buffer, "localvar_set_nick", server->nick);
+    weechat_buffer_set (ptr_buffer, "localvar_set_server", server->name);
+    weechat_buffer_set (ptr_buffer, "localvar_set_channel", channel_name);
+    if (server->is_away && server->away_message)
+    {
+        weechat_buffer_set (ptr_buffer, "localvar_set_away",
+                            server->away_message);
+    }
+    else
+    {
+        weechat_buffer_set (ptr_buffer, "localvar_del_away", "");
+    }
+
+    if (buffer_created)
+    {
+        (void) weechat_hook_signal_send ("logger_backlog",
+                                         WEECHAT_HOOK_SIGNAL_POINTER,
+                                         ptr_buffer);
         if (weechat_config_boolean (irc_config_network_send_unknown_commands))
-            weechat_buffer_set (new_buffer, "input_get_unknown_commands", "1");
+            weechat_buffer_set (ptr_buffer, "input_get_unknown_commands", "1");
         if (channel_type == IRC_CHANNEL_TYPE_CHANNEL)
         {
-            weechat_buffer_set (new_buffer, "nicklist", "1");
-            weechat_buffer_set (new_buffer, "nicklist_display_groups", "0");
-            weechat_buffer_set_pointer (new_buffer, "nickcmp_callback",
+            weechat_buffer_set (ptr_buffer, "nicklist", "1");
+            weechat_buffer_set (ptr_buffer, "nicklist_display_groups", "0");
+            weechat_buffer_set_pointer (ptr_buffer, "nickcmp_callback",
                                         &irc_buffer_nickcmp_cb);
+            weechat_buffer_set_pointer (ptr_buffer, "nickcmp_callback_data",
+                                        server);
         }
 
         /* set highlights settings on channel buffer */
-        weechat_buffer_set(new_buffer, "highlight_words_add",
-                           (channel_type == IRC_CHANNEL_TYPE_CHANNEL) ?
-                           weechat_config_string (irc_config_look_highlight_channel) :
-                           weechat_config_string (irc_config_look_highlight_pv));
+        weechat_buffer_set(
+            ptr_buffer,
+            "highlight_words_add",
+            (channel_type == IRC_CHANNEL_TYPE_CHANNEL) ?
+            weechat_config_string (irc_config_look_highlight_channel) :
+            weechat_config_string (irc_config_look_highlight_pv));
         if (weechat_config_string (irc_config_look_highlight_tags_restrict)
             && weechat_config_string (irc_config_look_highlight_tags_restrict)[0])
         {
-            weechat_buffer_set (new_buffer, "highlight_tags_restrict",
-                                weechat_config_string (irc_config_look_highlight_tags_restrict));
+            weechat_buffer_set (
+                ptr_buffer,
+                "highlight_tags_restrict",
+                weechat_config_string (irc_config_look_highlight_tags_restrict));
         }
+
+        /* switch to new buffer (if needed) */
+        manual_join = 0;
+        noswitch = 0;
+        channel_name_lower = NULL;
+        if (channel_type == IRC_CHANNEL_TYPE_CHANNEL)
+        {
+            channel_name_lower = strdup (channel_name);
+            if (channel_name_lower)
+            {
+                weechat_string_tolower (channel_name_lower);
+                manual_join = weechat_hashtable_has_key (server->join_manual,
+                                                         channel_name_lower);
+                noswitch = weechat_hashtable_has_key (server->join_noswitch,
+                                                      channel_name_lower);
+            }
+        }
+        if (switch_to_channel)
+        {
+            if (channel_type == IRC_CHANNEL_TYPE_CHANNEL)
+            {
+                if (noswitch
+                    || (manual_join && !weechat_config_boolean (irc_config_look_buffer_switch_join))
+                    || (!manual_join && !weechat_config_boolean (irc_config_look_buffer_switch_autojoin)))
+                    switch_to_channel = 0;
+            }
+            if (switch_to_channel)
+            {
+                weechat_buffer_set (ptr_buffer, "display",
+                                    (auto_switch && !manual_join) ? "auto" : "1");
+            }
+        }
+        if (channel_name_lower)
+        {
+            weechat_hashtable_remove (server->join_manual, channel_name_lower);
+            weechat_hashtable_remove (server->join_noswitch, channel_name_lower);
+            free (channel_name_lower);
+        }
+    }
+
+    return ptr_buffer;
+}
+
+/*
+ * Creates a new channel in a server.
+ *
+ * Returns pointer to new channel, NULL if error.
+ */
+
+struct t_irc_channel *
+irc_channel_new (struct t_irc_server *server, int channel_type,
+                 const char *channel_name, int switch_to_channel,
+                 int auto_switch)
+{
+    struct t_irc_channel *new_channel;
+    struct t_gui_buffer *ptr_buffer;
+
+    /* create buffer for channel (or use existing one) */
+    ptr_buffer = irc_channel_create_buffer (server, channel_type,
+                                            channel_name, switch_to_channel,
+                                            auto_switch);
+    if (!ptr_buffer)
+        return NULL;
+
+    /* alloc memory for new channel */
+    if ((new_channel = malloc (sizeof (*new_channel))) == NULL)
+    {
+        weechat_printf (NULL,
+                        _("%s%s: cannot allocate new channel"),
+                        weechat_prefix ("error"), IRC_PLUGIN_NAME);
+        return NULL;
     }
 
     /* initialize new channel */
@@ -269,20 +451,21 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
     new_channel->limit = 0;
     if (weechat_hashtable_has_key (server->join_channel_key, channel_name))
     {
-        new_channel->key = strdup (weechat_hashtable_get (server->join_channel_key,
-                                                          channel_name));
+        new_channel->key = strdup (
+            weechat_hashtable_get (server->join_channel_key, channel_name));
         weechat_hashtable_remove (server->join_channel_key, channel_name);
     }
     else
     {
         new_channel->key = NULL;
     }
-    new_channel->join_msg_received = weechat_hashtable_new (32,
-                                                            WEECHAT_HASHTABLE_STRING,
-                                                            WEECHAT_HASHTABLE_STRING,
-                                                            NULL,
-                                                            NULL);
-    new_channel->checking_away = 0;
+    new_channel->join_msg_received = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL,
+        NULL);
+    new_channel->checking_whox = 0;
     new_channel->away_message = NULL;
     new_channel->has_quit_server = 0;
     new_channel->cycle = 0;
@@ -298,7 +481,7 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
     new_channel->nicks_speaking_time = NULL;
     new_channel->last_nick_speaking_time = NULL;
     new_channel->join_smart_filtered = NULL;
-    new_channel->buffer = new_buffer;
+    new_channel->buffer = ptr_buffer;
     new_channel->buffer_as_string = NULL;
 
     /* add new channel to channels list */
@@ -310,56 +493,17 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
         server->channels = new_channel;
     server->last_channel = new_channel;
 
-    manual_join = 0;
-    noswitch = 0;
-    channel_name_lower = NULL;
-    if (channel_type == IRC_CHANNEL_TYPE_CHANNEL)
-    {
-        channel_name_lower = strdup (channel_name);
-        if (channel_name_lower)
-        {
-            weechat_string_tolower (channel_name_lower);
-            manual_join = weechat_hashtable_has_key (server->join_manual,
-                                                     channel_name_lower);
-            noswitch = weechat_hashtable_has_key (server->join_noswitch,
-                                                  channel_name_lower);
-        }
-    }
-
-    if (switch_to_channel)
-    {
-        if (channel_type == IRC_CHANNEL_TYPE_CHANNEL)
-        {
-            if (noswitch
-                || (manual_join && !weechat_config_boolean (irc_config_look_buffer_switch_join))
-                || (!manual_join && !weechat_config_boolean (irc_config_look_buffer_switch_autojoin)))
-                switch_to_channel = 0;
-        }
-
-        if (switch_to_channel)
-        {
-            weechat_buffer_set (new_buffer, "display",
-                                (auto_switch && !manual_join) ? "auto" : "1");
-        }
-    }
-
-    if (channel_name_lower)
-    {
-        weechat_hashtable_remove (server->join_manual, channel_name_lower);
-        weechat_hashtable_remove (server->join_noswitch, channel_name_lower);
-        free (channel_name_lower);
-    }
-
-    weechat_hook_signal_send ((channel_type == IRC_CHANNEL_TYPE_CHANNEL) ?
-                              "irc_channel_opened" : "irc_pv_opened",
-                              WEECHAT_HOOK_SIGNAL_POINTER, new_buffer);
+    (void) weechat_hook_signal_send (
+        (channel_type == IRC_CHANNEL_TYPE_CHANNEL) ?
+        "irc_channel_opened" : "irc_pv_opened",
+        WEECHAT_HOOK_SIGNAL_POINTER, ptr_buffer);
 
     /* all is OK, return address of new channel */
     return new_channel;
 }
 
 /*
- * Add groups in nicklist for a channel.
+ * Adds groups in nicklist for a channel.
  */
 
 void
@@ -387,6 +531,26 @@ irc_channel_add_nicklist_groups (struct t_irc_server *server,
                                 "weechat.color.nicklist_group", 1);
 }
 
+/*
+ * Sets the buffer title with the channel topic.
+ */
+
+void
+irc_channel_set_buffer_title (struct t_irc_channel *channel)
+{
+    char *title_color;
+
+    if (channel->topic)
+    {
+        title_color = irc_color_decode (
+            channel->topic,
+            (weechat_config_boolean (irc_config_look_topic_strip_colors)) ? 0 : 1);
+        weechat_buffer_set (channel->buffer, "title", title_color);
+    }
+    else
+        weechat_buffer_set (channel->buffer, "title", "");
+}
+
 /*
  * Sets topic for a channel.
  */
@@ -396,10 +560,9 @@ irc_channel_set_topic (struct t_irc_channel *channel, const char *topic)
 {
     if (channel->topic)
         free (channel->topic);
-
     channel->topic = (topic) ? strdup (topic) : NULL;
-    weechat_buffer_set (channel->buffer, "title",
-                        (channel->topic) ? channel->topic : "");
+
+    irc_channel_set_buffer_title (channel);
 }
 
 /*
@@ -415,29 +578,6 @@ irc_channel_set_modes (struct t_irc_channel *channel, const char *modes)
     channel->modes = (modes) ? strdup (modes) : NULL;
 }
 
-/*
- * Searches for a channel by name.
- *
- * Returns pointer to channel found, NULL if not found.
- */
-
-struct t_irc_channel *
-irc_channel_search (struct t_irc_server *server, const char *channel_name)
-{
-    struct t_irc_channel *ptr_channel;
-
-    if (!server || !channel_name)
-        return NULL;
-
-    for (ptr_channel = server->channels; ptr_channel;
-         ptr_channel = ptr_channel->next_channel)
-    {
-        if (irc_server_strcasecmp (server, ptr_channel->name, channel_name) == 0)
-            return ptr_channel;
-    }
-    return NULL;
-}
-
 /*
  * Checks if a string is a valid channel name.
  *
@@ -462,6 +602,64 @@ irc_channel_is_channel (struct t_irc_server *server, const char *string)
         1 : 0;
 }
 
+/*
+ * Returns a string with a channel type to add in front of a channel name,
+ * if it doesn't have a valid channel type for the given server.
+ *
+ * It returns an empty string if the channel already has a valid channel type,
+ * or if the option irc.look.join_auto_add_chantype is off.
+ */
+
+const char *
+irc_channel_get_auto_chantype (struct t_irc_server *server,
+                               const char *channel_name)
+{
+    static char chantype[2];
+
+    chantype[0] = '\0';
+    chantype[1] = '\0';
+
+    if (weechat_config_boolean (irc_config_look_join_auto_add_chantype)
+        && !irc_channel_is_channel (server, channel_name)
+        && server->chantypes
+        && server->chantypes[0])
+    {
+        /*
+         * use '#' if it's in chantypes (anywhere in the string), because it is
+         * the most common channel type, and fallback on first channel type
+         */
+        chantype[0] = (strchr (server->chantypes, '#')) ?
+            '#' : server->chantypes[0];
+    }
+
+    return chantype;
+}
+
+/*
+ * Removes account for all nicks on a channel.
+ */
+
+void
+irc_channel_remove_account (struct t_irc_server *server,
+                            struct t_irc_channel *channel)
+{
+    struct t_irc_nick *ptr_nick;
+
+    /* make C compiler happy */
+    (void) server;
+
+    if (channel->type == IRC_CHANNEL_TYPE_CHANNEL)
+    {
+        for (ptr_nick = channel->nicks; ptr_nick;
+             ptr_nick = ptr_nick->next_nick)
+        {
+            if (ptr_nick->account)
+                free (ptr_nick->account);
+            ptr_nick->account = NULL;
+        }
+    }
+}
+
 /*
  * Removes away for all nicks on a channel.
  */
@@ -474,7 +672,8 @@ irc_channel_remove_away (struct t_irc_server *server,
 
     if (channel->type == IRC_CHANNEL_TYPE_CHANNEL)
     {
-        for (ptr_nick = channel->nicks; ptr_nick; ptr_nick = ptr_nick->next_nick)
+        for (ptr_nick = channel->nicks; ptr_nick;
+             ptr_nick = ptr_nick->next_nick)
         {
             irc_nick_set_away (server, channel, ptr_nick, 0);
         }
@@ -482,25 +681,40 @@ irc_channel_remove_away (struct t_irc_server *server,
 }
 
 /*
- * Checks for away on a channel.
+ * Checks for WHOX information on a channel.
  */
 
 void
-irc_channel_check_away (struct t_irc_server *server,
+irc_channel_check_whox (struct t_irc_server *server,
                         struct t_irc_channel *channel)
 {
     if ((channel->type == IRC_CHANNEL_TYPE_CHANNEL) && channel->nicks)
     {
-        if ((IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK) > 0)
-            && ((IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS) == 0)
-                || (channel->nicks_count <= IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS))))
+        if (server->cap_away_notify
+            || server->cap_account_notify
+            || ((IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK) > 0)
+                && ((IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS) == 0)
+                    || (channel->nicks_count <= IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS)))))
         {
-            channel->checking_away++;
-            irc_server_sendf (server, IRC_SERVER_SEND_OUTQ_PRIO_LOW, NULL,
-                              "WHO %s", channel->name);
+            channel->checking_whox++;
+            if (irc_server_get_isupport_value (server, "WHOX"))
+            {
+                /* WHOX is supported */
+                irc_server_sendf (server, IRC_SERVER_SEND_OUTQ_PRIO_LOW, NULL,
+                                  "WHO %s %%cuhsnfdar", channel->name);
+            }
+            else
+            {
+                /* WHOX is NOT supported */
+                irc_server_sendf (server, IRC_SERVER_SEND_OUTQ_PRIO_LOW, NULL,
+                                  "WHO %s", channel->name);
+            }
         }
         else
-            irc_channel_remove_away (server, channel);
+        {
+            irc_channel_remove_account(server, channel);
+            irc_channel_remove_away(server, channel);
+        }
     }
 }
 
@@ -556,8 +770,9 @@ irc_channel_nick_speaking_add_to_list (struct t_irc_channel *channel,
         to_remove = size - IRC_CHANNEL_NICKS_SPEAKING_LIMIT;
         for (i = 0; i < to_remove; i++)
         {
-            weechat_list_remove (channel->nicks_speaking[highlight],
-                                 weechat_list_get (channel->nicks_speaking[highlight], 0));
+            weechat_list_remove (
+                channel->nicks_speaking[highlight],
+                weechat_list_get (channel->nicks_speaking[highlight], 0));
         }
     }
 }
@@ -596,7 +811,8 @@ irc_channel_nick_speaking_rename (struct t_irc_channel *channel,
     {
         if (channel->nicks_speaking[i])
         {
-            ptr_item = weechat_list_search (channel->nicks_speaking[i], old_nick);
+            ptr_item = weechat_list_search (channel->nicks_speaking[i],
+                                            old_nick);
             if (ptr_item)
                 weechat_list_set (ptr_item, new_nick);
         }
@@ -777,7 +993,8 @@ irc_channel_nick_speaking_time_rename (struct t_irc_server *server,
 
     if (channel->nicks_speaking_time)
     {
-        ptr_nick = irc_channel_nick_speaking_time_search (server, channel, old_nick, 0);
+        ptr_nick = irc_channel_nick_speaking_time_search (server, channel,
+                                                          old_nick, 0);
         if (ptr_nick)
         {
             free (ptr_nick->nick);
@@ -803,11 +1020,12 @@ irc_channel_join_smart_filtered_add (struct t_irc_channel *channel,
     /* create hashtable if needed */
     if (!channel->join_smart_filtered)
     {
-        channel->join_smart_filtered = weechat_hashtable_new (64,
-                                                              WEECHAT_HASHTABLE_STRING,
-                                                              WEECHAT_HASHTABLE_TIME,
-                                                              NULL,
-                                                              NULL);
+        channel->join_smart_filtered = weechat_hashtable_new (
+            64,
+            WEECHAT_HASHTABLE_STRING,
+            WEECHAT_HASHTABLE_TIME,
+            NULL,
+            NULL);
     }
     if (!channel->join_smart_filtered)
         return;
@@ -881,7 +1099,8 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
         return;
 
     /* return if unmasking of smart filtered joins is disabled */
-    unmask_delay = weechat_config_integer (irc_config_look_smart_filter_join_unmask);
+    unmask_delay = weechat_config_integer (
+        irc_config_look_smart_filter_join_unmask);
     if (unmask_delay == 0)
         return;
 
@@ -1119,19 +1338,18 @@ irc_channel_display_nick_back_in_pv (struct t_irc_server *server,
         {
             if (weechat_config_boolean (irc_config_look_display_pv_back))
             {
-                weechat_printf_tags (ptr_channel->buffer,
-                                     "irc_nick_back",
-                                     _("%s%s%s %s(%s%s%s)%s is back on server"),
-                                     weechat_prefix ("join"),
-                                     irc_nick_color_for_server_message (server,
-                                                                        nick,
-                                                                        nickname),
-                                     (nick) ? nick->name : nickname,
-                                     IRC_COLOR_CHAT_DELIMITERS,
-                                     IRC_COLOR_CHAT_HOST,
-                                     (nick && nick->host) ? nick->host : "",
-                                     IRC_COLOR_CHAT_DELIMITERS,
-                                     IRC_COLOR_MESSAGE_JOIN);
+                weechat_printf_tags (
+                    ptr_channel->buffer,
+                    "irc_nick_back",
+                    _("%s%s%s %s(%s%s%s)%s is back on server"),
+                    weechat_prefix ("join"),
+                    irc_nick_color_for_msg (server, 1, nick, nickname),
+                    (nick) ? nick->name : nickname,
+                    IRC_COLOR_CHAT_DELIMITERS,
+                    IRC_COLOR_CHAT_HOST,
+                    (nick && nick->host) ? nick->host : "",
+                    IRC_COLOR_CHAT_DELIMITERS,
+                    IRC_COLOR_MESSAGE_JOIN);
             }
             ptr_channel->has_quit_server = 0;
         }
@@ -1235,7 +1453,7 @@ irc_channel_hdata_channel_cb (void *data, const char *hdata_name)
         WEECHAT_HDATA_VAR(struct t_irc_channel, limit, INTEGER, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_irc_channel, key, STRING, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_irc_channel, join_msg_received, HASHTABLE, 0, NULL, NULL);
-        WEECHAT_HDATA_VAR(struct t_irc_channel, checking_away, INTEGER, 0, NULL, NULL);
+        WEECHAT_HDATA_VAR(struct t_irc_channel, checking_whox, INTEGER, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_irc_channel, away_message, STRING, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_irc_channel, has_quit_server, INTEGER, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_irc_channel, cycle, INTEGER, 0, NULL, NULL);
@@ -1332,7 +1550,7 @@ irc_channel_add_to_infolist (struct t_infolist *infolist,
     if (!weechat_infolist_new_var_string (ptr_item, "join_msg_received",
                                           weechat_hashtable_get_string (channel->join_msg_received, "keys")))
         return 0;
-    if (!weechat_infolist_new_var_integer (ptr_item, "checking_away", channel->checking_away))
+    if (!weechat_infolist_new_var_integer (ptr_item, "checking_whox", channel->checking_whox))
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "away_message", channel->away_message))
         return 0;
@@ -1416,7 +1634,7 @@ irc_channel_print_log (struct t_irc_channel *channel)
                         channel->join_msg_received,
                         weechat_hashtable_get_string (channel->join_msg_received,
                                                       "keys_values"));
-    weechat_log_printf ("       checking_away. . . . . . : %d",    channel->checking_away);
+    weechat_log_printf ("       checking_whox. . . . . . : %d",    channel->checking_whox);
     weechat_log_printf ("       away_message . . . . . . : '%s'",  channel->away_message);
     weechat_log_printf ("       has_quit_server. . . . . : %d",    channel->has_quit_server);
     weechat_log_printf ("       cycle. . . . . . . . . . : %d",    channel->cycle);
