@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,19 +17,12 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_COMMAND_H
-#define __WEECHAT_IRC_COMMAND_H 1
+#ifndef WEECHAT_IRC_COMMAND_H
+#define WEECHAT_IRC_COMMAND_H 1
 
 struct t_irc_server;
 struct t_irc_channel;
 
-#define IRC_COMMAND_TOO_FEW_ARGUMENTS(__buffer, __command)              \
-    weechat_printf (__buffer,                                           \
-                    _("%s%s: too few arguments for \"%s\" command"),    \
-                    weechat_prefix ("error"), IRC_PLUGIN_NAME,          \
-                    __command);                                         \
-    return WEECHAT_RC_OK;
-
 #define IRC_COMMAND_CHECK_SERVER(__command, __check_connection)         \
     if (!ptr_server)                                                    \
     {                                                                   \
@@ -50,6 +43,11 @@ struct t_irc_channel;
         return WEECHAT_RC_OK;                                           \
     }
 
+/* list of supported capabilities (for completion in command /cap) */
+#define IRC_COMMAND_CAP_SUPPORTED_COMPLETION \
+    "account-notify|away-notify|cap-notify|extended-join|"              \
+    "multi-prefix|server-time|userhost-in-names|%*"
+
 extern void irc_command_away_server (struct t_irc_server *server,
                                      const char *arguments,
                                      int reset_unread_marker);
@@ -58,6 +56,7 @@ extern void irc_command_join_server (struct t_irc_server *server,
                                      int manual_join,
                                      int noswitch);
 extern void irc_command_mode_server (struct t_irc_server *server,
+                                     const char *command,
                                      struct t_irc_channel *channel,
                                      const char *arguments,
                                      int flags);
@@ -68,4 +67,4 @@ extern void irc_command_quit_server (struct t_irc_server *server,
                                      const char *arguments);
 extern void irc_command_init ();
 
-#endif /* __WEECHAT_IRC_COMMAND_H */
+#endif /* WEECHAT_IRC_COMMAND_H */
