@@ -1,7 +1,7 @@
 /*
  * irc-completion.c - completion for IRC commands
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -93,26 +93,32 @@ irc_completion_server_channels_cb (void *data, const char *completion_item,
                                    struct t_gui_buffer *buffer,
                                    struct t_gui_completion *completion)
 {
-    struct t_irc_channel *ptr_channel;
+    struct t_irc_channel *ptr_channel2;
 
-    IRC_BUFFER_GET_SERVER(buffer);
+    IRC_BUFFER_GET_SERVER_CHANNEL(buffer);
 
     /* make C compiler happy */
     (void) data;
     (void) completion_item;
-    (void) buffer;
 
     if (ptr_server)
     {
-        for (ptr_channel = ptr_server->channels; ptr_channel;
-             ptr_channel = ptr_channel->next_channel)
+        for (ptr_channel2 = ptr_server->channels; ptr_channel2;
+             ptr_channel2 = ptr_channel2->next_channel)
         {
-            if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
+            if (ptr_channel2->type == IRC_CHANNEL_TYPE_CHANNEL)
             {
-                weechat_hook_completion_list_add (completion, ptr_channel->name,
+                weechat_hook_completion_list_add (completion, ptr_channel2->name,
                                                   0, WEECHAT_LIST_POS_SORT);
             }
         }
+
+        /* add current channel first in list */
+        if (ptr_channel)
+        {
+            weechat_hook_completion_list_add (completion, ptr_channel->name,
+                                              0, WEECHAT_LIST_POS_BEGINNING);
+        }
     }
 
     return WEECHAT_RC_OK;
@@ -134,7 +140,6 @@ irc_completion_server_privates_cb (void *data, const char *completion_item,
     /* make C compiler happy */
     (void) data;
     (void) completion_item;
-    (void) buffer;
 
     if (ptr_server)
     {
@@ -262,7 +267,8 @@ irc_completion_channel_nicks_add_speakers (struct t_gui_completion *completion,
         list_size = weechat_list_size (channel->nicks_speaking[highlight]);
         for (i = 0; i < list_size; i++)
         {
-            nick = weechat_list_string (weechat_list_get (channel->nicks_speaking[highlight], i));
+            nick = weechat_list_string (
+                weechat_list_get (channel->nicks_speaking[highlight], i));
             if (nick && irc_nick_search (server, channel, nick))
             {
                 weechat_hook_completion_list_add (completion,
@@ -379,20 +385,16 @@ irc_completion_channel_nicks_hosts_cb (void *data, const char *completion_item,
                         {
                             snprintf (buf, length, "%s!%s",
                                       ptr_nick->name, ptr_nick->host);
-                            weechat_hook_completion_list_add (completion,
-                                                              buf,
-                                                              0,
-                                                              WEECHAT_LIST_POS_SORT);
+                            weechat_hook_completion_list_add (
+                                completion, buf, 0, WEECHAT_LIST_POS_SORT);
                             free (buf);
                         }
                     }
                 }
                 break;
             case IRC_CHANNEL_TYPE_PRIVATE:
-                weechat_hook_completion_list_add (completion,
-                                                  ptr_channel->name,
-                                                  1,
-                                                  WEECHAT_LIST_POS_SORT);
+                weechat_hook_completion_list_add (
+                    completion, ptr_channel->name, 1, WEECHAT_LIST_POS_SORT);
                 break;
         }
     }
@@ -431,8 +433,8 @@ irc_completion_channel_topic_cb (void *data, const char *completion_item,
              * instead of
              *   /topic #test is a test channel
              */
-            length = strlen (ptr_channel->name) + strlen (ptr_channel->topic) + 16;
-            topic = malloc (length + 1);
+            length = strlen (ptr_channel->name) + strlen (ptr_channel->topic) + 16 + 1;
+            topic = malloc (length);
             if (topic)
             {
                 snprintf (topic, length, "%s %s",
@@ -461,28 +463,65 @@ irc_completion_channels_cb (void *data, const char *completion_item,
                             struct t_gui_buffer *buffer,
                             struct t_gui_completion *completion)
 {
-    struct t_irc_server *ptr_server;
-    struct t_irc_channel *ptr_channel;
+    struct t_irc_server *ptr_server2;
+    struct t_irc_channel *ptr_channel2;
+    struct t_weelist *channels_current_server;
+    int i;
+
+    IRC_BUFFER_GET_SERVER_CHANNEL(buffer);
 
     /* make C compiler happy */
     (void) data;
     (void) completion_item;
-    (void) buffer;
 
-    for (ptr_server = irc_servers; ptr_server;
-         ptr_server = ptr_server->next_server)
+    channels_current_server = weechat_list_new ();
+
+    for (ptr_server2 = irc_servers; ptr_server2;
+         ptr_server2 = ptr_server2->next_server)
     {
-        for (ptr_channel = ptr_server->channels; ptr_channel;
-             ptr_channel = ptr_channel->next_channel)
+        for (ptr_channel2 = ptr_server2->channels; ptr_channel2;
+             ptr_channel2 = ptr_channel2->next_channel)
         {
-            if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
+            if (ptr_channel2->type == IRC_CHANNEL_TYPE_CHANNEL)
             {
-                weechat_hook_completion_list_add (completion, ptr_channel->name,
-                                                  0, WEECHAT_LIST_POS_SORT);
+                if (ptr_server2 == ptr_server)
+                {
+                    /* will be added later to completions */
+                    weechat_list_add (channels_current_server,
+                                      ptr_channel2->name,
+                                      WEECHAT_LIST_POS_SORT,
+                                      NULL);
+                }
+                else
+                {
+                    weechat_hook_completion_list_add (completion,
+                                                      ptr_channel2->name,
+                                                      0,
+                                                      WEECHAT_LIST_POS_SORT);
+                }
             }
         }
     }
 
+    /* add channels of current server first in list */
+    for (i = weechat_list_size (channels_current_server) - 1; i >= 0; i--)
+    {
+        weechat_hook_completion_list_add (
+            completion,
+            weechat_list_string (
+                weechat_list_get (channels_current_server, i)),
+            0,
+            WEECHAT_LIST_POS_BEGINNING);
+    }
+    weechat_list_free (channels_current_server);
+
+    /* add current channel first in list */
+    if (ptr_channel)
+    {
+        weechat_hook_completion_list_add (completion, ptr_channel->name,
+                                          0, WEECHAT_LIST_POS_BEGINNING);
+    }
+
     return WEECHAT_RC_OK;
 }
 
