@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_CONFIG_H
-#define __WEECHAT_IRC_CONFIG_H 1
+#ifndef WEECHAT_IRC_CONFIG_H
+#define WEECHAT_IRC_CONFIG_H 1
 
 #define IRC_CONFIG_NAME "irc"
 
@@ -96,6 +96,8 @@ extern struct t_config_section *irc_config_section_ctcp;
 extern struct t_config_section *irc_config_section_server_default;
 extern struct t_config_section *irc_config_section_server;
 
+extern struct t_config_option *irc_config_look_buffer_open_before_autojoin;
+extern struct t_config_option *irc_config_look_buffer_open_before_join;
 extern struct t_config_option *irc_config_look_buffer_switch_autojoin;
 extern struct t_config_option *irc_config_look_buffer_switch_join;
 extern struct t_config_option *irc_config_look_color_nicks_in_names;
@@ -114,25 +116,26 @@ extern struct t_config_option *irc_config_look_display_join_message;
 extern struct t_config_option *irc_config_look_display_old_topic;
 extern struct t_config_option *irc_config_look_display_pv_away_once;
 extern struct t_config_option *irc_config_look_display_pv_back;
-extern struct t_config_option *irc_config_look_highlight_server;
 extern struct t_config_option *irc_config_look_highlight_channel;
 extern struct t_config_option *irc_config_look_highlight_pv;
+extern struct t_config_option *irc_config_look_highlight_server;
 extern struct t_config_option *irc_config_look_highlight_tags_restrict;
 extern struct t_config_option *irc_config_look_item_away_message;
-extern struct t_config_option *irc_config_look_item_channel_modes_hide_key;
+extern struct t_config_option *irc_config_look_item_channel_modes_hide_args;
 extern struct t_config_option *irc_config_look_item_display_server;
 extern struct t_config_option *irc_config_look_item_nick_modes;
 extern struct t_config_option *irc_config_look_item_nick_prefix;
+extern struct t_config_option *irc_config_look_join_auto_add_chantype;
 extern struct t_config_option *irc_config_look_msgbuffer_fallback;
 extern struct t_config_option *irc_config_look_new_channel_position;
 extern struct t_config_option *irc_config_look_new_pv_position;
-extern struct t_config_option *irc_config_look_nicks_hide_password;
 extern struct t_config_option *irc_config_look_nick_color_force;
 extern struct t_config_option *irc_config_look_nick_color_hash;
 extern struct t_config_option *irc_config_look_nick_color_stop_chars;
 extern struct t_config_option *irc_config_look_nick_completion_smart;
 extern struct t_config_option *irc_config_look_nick_mode;
 extern struct t_config_option *irc_config_look_nick_mode_empty;
+extern struct t_config_option *irc_config_look_nicks_hide_password;
 extern struct t_config_option *irc_config_look_notice_as_pv;
 extern struct t_config_option *irc_config_look_notice_welcome_redirect;
 extern struct t_config_option *irc_config_look_notice_welcome_tags;
@@ -150,6 +153,7 @@ extern struct t_config_option *irc_config_look_smart_filter_join_unmask;
 extern struct t_config_option *irc_config_look_smart_filter_mode;
 extern struct t_config_option *irc_config_look_smart_filter_nick;
 extern struct t_config_option *irc_config_look_smart_filter_quit;
+extern struct t_config_option *irc_config_look_temporary_servers;
 extern struct t_config_option *irc_config_look_topic_strip_colors;
 
 extern struct t_config_option *irc_config_color_input_nick;
@@ -157,19 +161,21 @@ extern struct t_config_option *irc_config_color_item_away;
 extern struct t_config_option *irc_config_color_item_channel_modes;
 extern struct t_config_option *irc_config_color_item_lag_counting;
 extern struct t_config_option *irc_config_color_item_lag_finished;
+extern struct t_config_option *irc_config_color_item_nick_modes;
 extern struct t_config_option *irc_config_color_message_join;
 extern struct t_config_option *irc_config_color_message_quit;
 extern struct t_config_option *irc_config_color_mirc_remap;
 extern struct t_config_option *irc_config_color_nick_prefixes;
 extern struct t_config_option *irc_config_color_notice;
 extern struct t_config_option *irc_config_color_reason_quit;
+extern struct t_config_option *irc_config_color_topic_current;
 extern struct t_config_option *irc_config_color_topic_new;
 extern struct t_config_option *irc_config_color_topic_old;
 
-extern struct t_config_option *irc_config_network_alternate_nick;
 extern struct t_config_option *irc_config_network_autoreconnect_delay_growing;
 extern struct t_config_option *irc_config_network_autoreconnect_delay_max;
 extern struct t_config_option *irc_config_network_ban_mask_default;
+extern struct t_config_option *irc_config_network_channel_encode;
 extern struct t_config_option *irc_config_network_colors_receive;
 extern struct t_config_option *irc_config_network_colors_send;
 extern struct t_config_option *irc_config_network_lag_check;
@@ -195,6 +201,7 @@ extern char **irc_config_nicks_hide_password;
 extern int irc_config_num_nicks_hide_password;
 
 extern void irc_config_set_nick_colors ();
+extern int irc_config_display_channel_modes_arguments (const char *modes);
 extern int irc_config_server_check_value_cb (void *data,
                                              struct t_config_option *option,
                                              const char *value);
@@ -219,4 +226,4 @@ extern int irc_config_read ();
 extern int irc_config_write (int write_temp_servers);
 extern void irc_config_free ();
 
-#endif /* __WEECHAT_IRC_CONFIG_H */
+#endif /* WEECHAT_IRC_CONFIG_H */
