@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_CTCP_H
-#define __WEECHAT_IRC_CTCP_H 1
+#ifndef WEECHAT_IRC_CTCP_H
+#define WEECHAT_IRC_CTCP_H 1
 
 struct t_irc_server;
 struct t_irc_channel;
@@ -34,6 +34,7 @@ extern void irc_ctcp_display_reply_from_nick (struct t_irc_server *server,
                                               time_t date,
                                               const char *command,
                                               const char *nick,
+                                              const char *address,
                                               char *arguments);
 extern void irc_ctcp_recv (struct t_irc_server *server, time_t date,
                            const char *command, struct t_irc_channel *channel,
@@ -41,4 +42,4 @@ extern void irc_ctcp_recv (struct t_irc_server *server, time_t date,
                            const char *remote_nick, char *arguments,
                            char *message);
 
-#endif /* __WEECHAT_IRC_CTCP_H */
+#endif /* WEECHAT_IRC_CTCP_H */
