@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_IGNORE_H
-#define __WEECHAT_IRC_IGNORE_H 1
+#ifndef WEECHAT_IRC_IGNORE_H
+#define WEECHAT_IRC_IGNORE_H 1
 
 #include <regex.h>
 
@@ -57,4 +57,4 @@ extern int irc_ignore_add_to_infolist (struct t_infolist *infolist,
                                        struct t_irc_ignore *ignore);
 extern void irc_ignore_print_log ();
 
-#endif /* __WEECHAT_IRC_IGNORE_H */
+#endif /* WEECHAT_IRC_IGNORE_H */
