@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_MESSAGE_H
-#define __WEECHAT_IRC_MESSAGE_H 1
+#ifndef WEECHAT_IRC_MESSAGE_H
+#define WEECHAT_IRC_MESSAGE_H 1
 
 struct t_irc_server;
 struct t_irc_channel;
@@ -26,9 +26,15 @@ struct t_irc_channel;
 extern void irc_message_parse (struct t_irc_server *server, const char *message,
                                char **tags, char **message_without_tags,
                                char **nick, char **host, char **command,
-                               char **channel, char **arguments);
+                               char **channel, char **arguments, char **text,
+                               int *pos_command, int *pos_arguments,
+                               int *pos_channel, int *pos_text);
 extern struct t_hashtable *irc_message_parse_to_hashtable (struct t_irc_server *server,
                                                            const char *message);
+extern char *irc_message_convert_charset (const char *message,
+                                          int pos_start,
+                                          const char *modifier,
+                                          const char *modifier_data);
 extern const char *irc_message_get_nick_from_host (const char *host);
 extern const char *irc_message_get_address_from_host (const char *host);
 extern char *irc_message_replace_vars (struct t_irc_server *server,
@@ -37,4 +43,4 @@ extern char *irc_message_replace_vars (struct t_irc_server *server,
 extern struct t_hashtable *irc_message_split (struct t_irc_server *server,
                                               const char *message);
 
-#endif /* __WEECHAT_IRC_MESSAGE_H */
+#endif /* WEECHAT_IRC_MESSAGE_H */
