@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_NICK_H
-#define __WEECHAT_IRC_NICK_H 1
+#ifndef WEECHAT_IRC_NICK_H
+#define WEECHAT_IRC_NICK_H 1
 
 #define IRC_NICK_VALID_CHARS "abcdefghijklmnopqrstuvwxyzABCDEFGHI"      \
     "JKLMNOPQRSTUVWXYZ0123456789-[]\\`_^{|}"
@@ -38,7 +38,9 @@ struct t_irc_nick
     char prefix[2];                 /* current prefix (higher prefix set in  */
                                     /* prefixes)                             */
     int away;                       /* 1 if nick is away                     */
-    char *color;                    /* color for nickname in chat window     */
+    char *account;                  /* account name of the user              */
+    char *realname;                 /* realname (aka gecos) of the user      */
+    char *color;                    /* color for nickname                    */
     struct t_irc_nick *prev_nick;   /* link to previous nick on channel      */
     struct t_irc_nick *next_nick;   /* link to next nick on channel          */
 };
@@ -64,7 +66,9 @@ extern struct t_irc_nick *irc_nick_new (struct t_irc_server *server,
                                         const char *nickname,
                                         const char *host,
                                         const char *prefixes,
-                                        int away);
+                                        int away,
+                                        const char *account,
+                                        const char *realname);
 extern void irc_nick_change (struct t_irc_server *server,
                              struct t_irc_channel *channel,
                              struct t_irc_nick *nick, const char *new_nick);
@@ -93,12 +97,10 @@ extern const char *irc_nick_as_prefix (struct t_irc_server *server,
                                        struct t_irc_nick *nick,
                                        const char *nickname,
                                        const char *force_color);
-extern const char *irc_nick_color_for_message (struct t_irc_server *server,
-                                               struct t_irc_nick *nick,
-                                               const char *nickname);
-extern const char *irc_nick_color_for_server_message (struct t_irc_server *server,
-                                                      struct t_irc_nick *nick,
-                                                      const char *nickname);
+extern const char *irc_nick_color_for_msg (struct t_irc_server *server,
+                                           int server_message,
+                                           struct t_irc_nick *nick,
+                                           const char *nickname);
 extern const char * irc_nick_color_for_pv (struct t_irc_channel *channel,
                                            const char *nickname);
 extern char *irc_nick_default_ban_mask (struct t_irc_nick *nick);
@@ -108,4 +110,4 @@ extern int irc_nick_add_to_infolist (struct t_infolist *infolist,
                                      struct t_irc_nick *nick);
 extern void irc_nick_print_log (struct t_irc_nick *nick);
 
-#endif /* __WEECHAT_IRC_NICK_H */
+#endif /* WEECHAT_IRC_NICK_H */
