@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,17 +17,20 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_SASL_H
-#define __WEECHAT_IRC_SASL_H 1
+#ifndef WEECHAT_IRC_SASL_H
+#define WEECHAT_IRC_SASL_H 1
+
+struct t_irc_server;
 
 /* SASL authentication mechanisms */
 
 enum t_irc_sasl_mechanism
 {
     IRC_SASL_MECHANISM_PLAIN = 0,
+    IRC_SASL_MECHANISM_ECDSA_NIST256P_CHALLENGE,
+    IRC_SASL_MECHANISM_EXTERNAL,
     IRC_SASL_MECHANISM_DH_BLOWFISH,
     IRC_SASL_MECHANISM_DH_AES,
-    IRC_SASL_MECHANISM_EXTERNAL,
     /* number of SASL mechanisms */
     IRC_NUM_SASL_MECHANISMS,
 };
@@ -36,6 +39,10 @@ extern char *irc_sasl_mechanism_string[];
 
 extern char *irc_sasl_mechanism_plain (const char *sasl_username,
                                        const char *sasl_password);
+extern char *irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
+                                                          const char *data_base64,
+                                                          const char *sasl_username,
+                                                          const char *sasl_key);
 extern char *irc_sasl_mechanism_dh_blowfish (const char *data_base64,
                                              const char *sasl_username,
                                              const char *sasl_password);
@@ -43,4 +50,4 @@ extern char *irc_sasl_mechanism_dh_aes (const char *data_base64,
                                         const char *sasl_username,
                                         const char *sasl_password);
 
-#endif /* __WEECHAT_IRC_SASL_H */
+#endif /* WEECHAT_IRC_SASL_H */
