@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2012 Simon Arlott
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,19 +18,28 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_SERVER_H
-#define __WEECHAT_IRC_SERVER_H 1
+#ifndef WEECHAT_IRC_SERVER_H
+#define WEECHAT_IRC_SERVER_H 1
 
 #include <sys/time.h>
 #include <regex.h>
 
 #ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
-#endif
+#endif /* HAVE_GNUTLS */
 
 #ifndef NI_MAXHOST
 #define NI_MAXHOST 256
-#endif
+#endif /* NI_MAXHOST */
+
+enum t_irc_server_sasl_fail
+{
+    IRC_SERVER_SASL_FAIL_CONTINUE = 0,
+    IRC_SERVER_SASL_FAIL_RECONNECT,
+    IRC_SERVER_SASL_FAIL_DISCONNECT,
+    /* number of SASL fail options */
+    IRC_SERVER_NUM_SASL_FAIL,
+};
 
 enum t_irc_server_option
 {
@@ -48,11 +57,14 @@ enum t_irc_server_option
     IRC_SERVER_OPTION_SASL_MECHANISM,/* mechanism for SASL authentication    */
     IRC_SERVER_OPTION_SASL_USERNAME, /* username for SASL authentication     */
     IRC_SERVER_OPTION_SASL_PASSWORD, /* password for SASL authentication     */
+    IRC_SERVER_OPTION_SASL_KEY,      /* key for ECDSA-NIST256P-CHALLENCE     */
     IRC_SERVER_OPTION_SASL_TIMEOUT,  /* timeout for SASL authentication      */
+    IRC_SERVER_OPTION_SASL_FAIL,     /* action on SASL fail                  */
     IRC_SERVER_OPTION_AUTOCONNECT,   /* autoconnect to server at startup     */
     IRC_SERVER_OPTION_AUTORECONNECT, /* autoreconnect when disconnected      */
     IRC_SERVER_OPTION_AUTORECONNECT_DELAY, /* delay before trying again reco */
     IRC_SERVER_OPTION_NICKS,         /* nicknames (comma separated list)     */
+    IRC_SERVER_OPTION_NICKS_ALTERNATE, /* use alternate nicknames            */
     IRC_SERVER_OPTION_USERNAME,      /* user name                            */
     IRC_SERVER_OPTION_REALNAME,      /* real name                            */
     IRC_SERVER_OPTION_LOCAL_HOSTNAME,/* custom local hostname                */
@@ -163,7 +175,7 @@ struct t_irc_server
     gnutls_session_t gnutls_sess;   /* gnutls session (only if SSL is used)  */
     gnutls_x509_crt_t tls_cert;     /* certificate used if ssl_cert is set   */
     gnutls_x509_privkey_t tls_cert_key; /* key used if ssl_cert is set       */
-#endif
+#endif /* HAVE_GNUTLS */
     char *unterminated_message;     /* beginning of a message in input buf   */
     int nicks_count;                /* number of nicknames                   */
     char **nicks_array;             /* nicknames (after split)               */
@@ -173,6 +185,9 @@ struct t_irc_server
                                     /* (nick____1, nick____2, ...)           */
     char *nick;                     /* current nickname                      */
     char *nick_modes;               /* nick modes                            */
+    int cap_away_notify;            /* 1 if capability away-notify is enabled*/
+    int cap_account_notify;         /* 1 if CAP account-notify is enabled    */
+    int cap_extended_join;          /* 1 if CAP extended-join is enabled     */
     char *isupport;                 /* copy of message 005 (ISUPPORT)        */
     char *prefix_modes;             /* prefix modes from msg 005 (eg "ohv")  */
     char *prefix_chars;             /* prefix chars from msg 005 (eg "@%+")  */
@@ -193,6 +208,7 @@ struct t_irc_server
     char *away_message;             /* away message, NULL if not away        */
     time_t away_time;               /* time() when user marking as away      */
     int lag;                        /* lag (in milliseconds)                 */
+    int lag_displayed;              /* last value displayed for lag          */
     struct timeval lag_check_time;  /* last time lag was checked (ping sent) */
     time_t lag_next_check;          /* time for next check                   */
     time_t lag_last_refresh;        /* last refresh of lag item              */
@@ -228,14 +244,27 @@ struct t_irc_message
     struct t_irc_message *next_message; /* link to next message              */
 };
 
+/* digest algorithms for fingerprint */
+
+#ifdef HAVE_GNUTLS
+enum t_irc_fingerprint_digest_algo
+{
+    IRC_FINGERPRINT_ALGO_SHA1 = 0,
+    IRC_FINGERPRINT_ALGO_SHA256,
+    IRC_FINGERPRINT_ALGO_SHA512,
+    /* number of digest algorithms */
+    IRC_FINGERPRINT_NUM_ALGOS,
+};
+#endif /* HAVE_GNUTLS */
+
 extern struct t_irc_server *irc_servers;
 #ifdef HAVE_GNUTLS
 extern const int gnutls_cert_type_prio[];
 extern const int gnutls_prot_prio[];
-#endif
+#endif /* HAVE_GNUTLS */
 extern struct t_irc_message *irc_recv_msgq, *irc_msgq_last_msg;
-extern char *irc_server_option_string[];
-extern char *irc_server_option_default[];
+extern char *irc_server_sasl_fail_string[];
+extern char *irc_server_options[][2];
 
 extern int irc_server_valid (struct t_irc_server *server);
 extern struct t_irc_server *irc_server_search (const char *server_name);
@@ -279,6 +308,7 @@ extern void irc_server_free_all ();
 extern struct t_irc_server *irc_server_copy (struct t_irc_server *server,
                                              const char *new_name);
 extern int irc_server_rename (struct t_irc_server *server, const char *new_name);
+extern int irc_server_reorder (const char **servers, int num_servers);
 extern void irc_server_send_signal (struct t_irc_server *server,
                                     const char *signal, const char *command,
                                     const char *full_message,
@@ -293,6 +323,10 @@ extern void irc_server_msgq_add_buffer (struct t_irc_server *server,
 extern void irc_server_msgq_flush ();
 extern void irc_server_set_buffer_title (struct t_irc_server *server);
 extern struct t_gui_buffer *irc_server_create_buffer (struct t_irc_server *server);
+#ifdef HAVE_GNUTLS
+int irc_server_fingerprint_search_algo_with_size (int size);
+char *irc_server_fingerprint_str_sizes ();
+#endif /* HAVE_GNUTLS */
 extern int irc_server_connect (struct t_irc_server *server);
 extern void irc_server_auto_connect (int auto_connect);
 extern void irc_server_autojoin_channels ();
@@ -326,4 +360,4 @@ extern int irc_server_add_to_infolist (struct t_infolist *infolist,
                                        struct t_irc_server *server);
 extern void irc_server_print_log ();
 
-#endif /* __WEECHAT_IRC_SERVER_H */
+#endif /* WEECHAT_IRC_SERVER_H */
