@@ -1,7 +1,7 @@
 /*
  * irc-upgrade.c - save/restore IRC plugin data when upgrading WeeChat
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -373,6 +373,7 @@ irc_upgrade_read_cb (void *data,
                         irc_upgrade_current_server->nick_modes = strdup (str);
                     irc_upgrade_current_server->cap_away_notify = weechat_infolist_integer (infolist, "cap_away_notify");
                     irc_upgrade_current_server->cap_account_notify = weechat_infolist_integer (infolist, "cap_account_notify");
+                    irc_upgrade_current_server->cap_extended_join = weechat_infolist_integer (infolist, "cap_extended_join");
                     str = weechat_infolist_string (infolist, "isupport");
                     if (str)
                         irc_upgrade_current_server->isupport = strdup (str);
@@ -574,7 +575,8 @@ irc_upgrade_read_cb (void *data,
                                              weechat_infolist_string (infolist, "host"),
                                              weechat_infolist_string (infolist, "prefixes"),
                                              weechat_infolist_integer (infolist, "away"),
-                                             weechat_infolist_string (infolist, "account"));
+                                             weechat_infolist_string (infolist, "account"),
+                                             weechat_infolist_string (infolist, "realname"));
                     if (ptr_nick)
                     {
                         /*
@@ -740,4 +742,3 @@ irc_upgrade_load ()
 
     return rc;
 }
-
