@@ -1,7 +1,7 @@
 /*
  * irc.c - IRC (Internet Relay Chat) plugin for WeeChat
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -50,6 +50,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("IRC (Internet Relay Chat) protocol"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(5000);
 
 struct t_weechat_plugin *weechat_irc_plugin = NULL;
 
@@ -77,8 +78,9 @@ irc_signal_quit_cb (void *data, const char *signal, const char *type_data,
         for (ptr_server = irc_servers; ptr_server;
              ptr_server = ptr_server->next_server)
         {
-            irc_command_quit_server (ptr_server,
-                                     (signal_data) ? (char *)signal_data : NULL);
+            irc_command_quit_server (
+                ptr_server,
+                (signal_data) ? (char *)signal_data : NULL);
         }
     }
 
@@ -110,20 +112,20 @@ irc_signal_upgrade_cb (void *data, const char *signal, const char *type_data,
          ptr_server = ptr_server->next_server)
     {
         /*
-         * FIXME: it's not possible to upgrade with SSL servers connected (GnuTLS
-         * lib can't reload data after upgrade), so we close connection for
-         * all SSL servers currently connected
+         * FIXME: it's not possible to upgrade with SSL servers connected
+         * (GnuTLS library can't reload data after upgrade), so we close
+         * connection for all SSL servers currently connected
          */
         if (ptr_server->is_connected && (ptr_server->ssl_connected || quit))
         {
             if (!quit)
             {
                 ssl_disconnected++;
-                weechat_printf (ptr_server->buffer,
-                                _("%s%s: disconnecting from server because upgrade "
-                                  "can't work for servers connected via SSL"),
-                                weechat_prefix ("error"),
-                                IRC_PLUGIN_NAME);
+                weechat_printf (
+                    ptr_server->buffer,
+                    _("%s%s: disconnecting from server because upgrade can't "
+                      "work for servers connected via SSL"),
+                    weechat_prefix ("error"), IRC_PLUGIN_NAME);
             }
             irc_server_disconnect (ptr_server, 0, 0);
             /*
@@ -137,13 +139,15 @@ irc_signal_upgrade_cb (void *data, const char *signal, const char *type_data,
     }
     if (ssl_disconnected > 0)
     {
-        weechat_printf (NULL,
-                        /* TRANSLATORS: "%s" after "%d" is "server" or "servers" */
-                        _("%s%s: disconnected from %d %s (SSL connection "
-                          "not supported with upgrade)"),
-                        weechat_prefix ("error"), IRC_PLUGIN_NAME,
-                        ssl_disconnected,
-                        NG_("server", "servers", ssl_disconnected));
+        weechat_printf (
+            NULL,
+            /* TRANSLATORS: "%s" after "%d" is "server" or "servers" */
+            _("%s%s: disconnected from %d %s (SSL connection not supported "
+              "with upgrade)"),
+            weechat_prefix ("error"),
+            IRC_PLUGIN_NAME,
+            ssl_disconnected,
+            NG_("server", "servers", ssl_disconnected));
     }
 
     return WEECHAT_RC_OK;
@@ -189,6 +193,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     /* modifiers */
     weechat_hook_modifier ("irc_color_decode", &irc_color_modifier_cb, NULL);
     weechat_hook_modifier ("irc_color_encode", &irc_color_modifier_cb, NULL);
+    weechat_hook_modifier ("irc_color_decode_ansi", &irc_color_modifier_cb, NULL);
 
     /* hook completions */
     irc_completion_init ();
@@ -209,11 +214,11 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
         {
             if (!irc_server_alloc_with_url (argv[i]))
             {
-                weechat_printf (NULL,
-                                _("%s%s: error with server from URL "
-                                  "(\"%s\"), ignored"),
-                                weechat_prefix ("error"), IRC_PLUGIN_NAME,
-                                argv[i]);
+                weechat_printf (
+                    NULL,
+                    _("%s%s: unable to add temporary server \"%s\" (check "
+                      "if there is already a server with this name)"),
+                    weechat_prefix ("error"), IRC_PLUGIN_NAME, argv[i]);
             }
         }
         else if (weechat_strcasecmp (argv[i], "--upgrade") == 0)
@@ -226,11 +231,12 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     {
         if (!irc_upgrade_load ())
         {
-            weechat_printf (NULL,
-                            _("%s%s: WARNING: some network connections may "
-                              "still be opened and not visible, you should "
-                              "restart WeeChat now (with /quit)."),
-                            weechat_prefix ("error"), IRC_PLUGIN_NAME);
+            weechat_printf (
+                NULL,
+                _("%s%s: WARNING: some network connections may still be "
+                  "opened and not visible, you should restart WeeChat now "
+                  "(with /quit)."),
+                weechat_prefix ("error"), IRC_PLUGIN_NAME);
         }
     }
     else
@@ -280,5 +286,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
 
     irc_redirect_end ();
 
+    irc_color_end ();
+
     return WEECHAT_RC_OK;
 }
