@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_IRC_H
-#define __WEECHAT_IRC_H 1
+#ifndef WEECHAT_IRC_H
+#define WEECHAT_IRC_H 1
 
 #define weechat_plugin weechat_irc_plugin
 #define IRC_PLUGIN_NAME "irc"
@@ -28,4 +28,4 @@ extern struct t_weechat_plugin *weechat_irc_plugin;
 
 extern int irc_signal_upgrade_received;
 
-#endif /* __WEECHAT_IRC_H */
+#endif /* WEECHAT_IRC_H */
