@@ -1,7 +1,7 @@
 /*
  * logger.c - logger plugin for WeeChat: save buffer lines to disk files
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -19,8 +19,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* this define is needed for strptime() (not on OpenBSD) */
-#if !defined(__OpenBSD__)
+/* this define is needed for strptime() (not on OpenBSD/Sun) */
+#if !defined(__OpenBSD__) && !defined(__sun)
 #define _XOPEN_SOURCE 700
 #endif
 
@@ -50,6 +50,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Log buffers to files"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(12000);
 
 struct t_weechat_plugin *weechat_logger_plugin = NULL;
 
@@ -64,69 +65,48 @@ struct t_hook *logger_timer = NULL;    /* timer to flush log files          */
  *   - "~": user home
  *   - date/time specifiers (see man strftime)
  *
- * Note: returned value must freed after use.
+ * Note: result must be freed after use.
  */
 
 char *
 logger_get_file_path ()
 {
-    char *file_path, *file_path2, *file_path3;
-    const char *weechat_dir;
+    char *path, *path2;
     int length;
     time_t seconds;
     struct tm *date_tmp;
 
-    file_path = NULL;
-    file_path2 = NULL;
-    file_path3 = NULL;
+    path = NULL;
+    path2 = NULL;
 
-    weechat_dir = weechat_info_get ("weechat_dir", "");
-    if (!weechat_dir)
-        goto end;
-
-    /* replace "~" with user home */
-    file_path = weechat_string_expand_home (weechat_config_string (logger_config_file_path));
-    if (!file_path)
-        goto end;
-
-    /* replace "%h" with WeeChat home (at beginning of string only) */
-    if (strncmp (file_path, "%h", 2) == 0)
-    {
-        length = strlen (weechat_dir) + strlen (file_path + 2) + 1;
-        file_path2 = malloc (length);
-        if (file_path2)
-            snprintf (file_path2, length, "%s%s", weechat_dir, file_path + 2);
-    }
-    else
-        file_path2 = strdup (file_path);
-    if (!file_path2)
+    /* replace %h and "~", evaluate path */
+    path = weechat_string_eval_path_home (
+        weechat_config_string (logger_config_file_path), NULL, NULL, NULL);
+    if (!path)
         goto end;
 
     /* replace date/time specifiers in path */
-    length = strlen (file_path2) + 256 + 1;
-    file_path3 = malloc (length);
-    if (!file_path3)
+    length = strlen (path) + 256 + 1;
+    path2 = malloc (length);
+    if (!path2)
         goto end;
     seconds = time (NULL);
     date_tmp = localtime (&seconds);
-    file_path3[0] = '\0';
-    strftime (file_path3, length - 1, file_path2, date_tmp);
+    path2[0] = '\0';
+    strftime (path2, length - 1, path, date_tmp);
 
     if (weechat_logger_plugin->debug)
     {
         weechat_printf_tags (NULL,
                              "no_log",
                              "%s: file path = \"%s\"",
-                             LOGGER_PLUGIN_NAME, file_path3);
+                             LOGGER_PLUGIN_NAME, path2);
     }
 
 end:
-    if (file_path)
-        free (file_path);
-    if (file_path2)
-        free (file_path2);
-
-    return file_path3;
+    if (path)
+        free (path);
+    return path2;
 }
 
 /*
@@ -161,7 +141,7 @@ logger_create_directory ()
 /*
  * Builds full name of buffer.
  *
- * Note: value must be freed after use.
+ * Note: result must be freed after use.
  */
 
 char *
@@ -358,7 +338,7 @@ logger_get_mask_expanded (struct t_gui_buffer *buffer, const char *mask)
                                             weechat_config_string (logger_config_file_replacement_char));
 #else
     mask_decoded3 = strdup (mask_decoded2);
-#endif
+#endif /* __CYGWIN__ */
     if (!mask_decoded3)
         goto end;
 
@@ -410,6 +390,8 @@ end:
 
 /*
  * Builds log filename for a buffer.
+ *
+ * Note: result must be freed after use.
  */
 
 char *
@@ -577,11 +559,12 @@ logger_write_line (struct t_logger_buffer *logger_buffer,
             fopen (logger_buffer->log_filename, "a");
         if (!logger_buffer->log_file)
         {
-            weechat_printf_tags (NULL,
-                                 "no_log",
-                                 _("%s%s: unable to write log file \"%s\""),
-                                 weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
-                                 logger_buffer->log_filename);
+            weechat_printf_tags (
+                NULL,
+                "no_log",
+                _("%s%s: unable to write log file \"%s\": %s"),
+                weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
+                logger_buffer->log_filename, strerror (errno));
             logger_buffer_free (logger_buffer);
             return;
         }
@@ -887,28 +870,26 @@ logger_command_cb (void *data, struct t_gui_buffer *buffer,
         return WEECHAT_RC_OK;
     }
 
-    if (argc > 1)
+    if (weechat_strcasecmp (argv[1], "set") == 0)
     {
-        if (weechat_strcasecmp (argv[1], "set") == 0)
-        {
-            if (argc > 2)
-                logger_set_buffer (buffer, argv[2]);
-            return WEECHAT_RC_OK;
-        }
-
-        if (weechat_strcasecmp (argv[1], "flush") == 0)
-        {
-            logger_flush ();
-            return WEECHAT_RC_OK;
-        }
-
-        if (weechat_strcasecmp (argv[1], "disable") == 0)
-        {
-            logger_set_buffer (buffer, "0");
-        }
+        if (argc > 2)
+            logger_set_buffer (buffer, argv[2]);
+        return WEECHAT_RC_OK;
     }
 
-    return WEECHAT_RC_OK;
+    if (weechat_strcasecmp (argv[1], "flush") == 0)
+    {
+        logger_flush ();
+        return WEECHAT_RC_OK;
+    }
+
+    if (weechat_strcasecmp (argv[1], "disable") == 0)
+    {
+        logger_set_buffer (buffer, "0");
+        return WEECHAT_RC_OK;
+    }
+
+    WEECHAT_COMMAND_ERROR;
 }
 
 /*
