@@ -2,7 +2,7 @@
  * weechat-lua.c - lua plugin for WeeChat
  *
  * Copyright (C) 2006-2007 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -39,6 +39,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Support of lua scripts"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(3000);
 
 struct t_weechat_plugin *weechat_lua_plugin;
 
@@ -98,7 +99,7 @@ weechat_lua_hashtable_map_cb (void *data,
 }
 
 /*
- * Puts a WeeChat hashtable on lua stack, as lua table.
+ * Converts a WeeChat hashtable to a lua hash (as lua table on the stack).
  */
 
 void
@@ -112,7 +113,7 @@ weechat_lua_pushhashtable (lua_State *interpreter, struct t_hashtable *hashtable
 }
 
 /*
- * Gets WeeChat hashtable with lua hash (on stack).
+ * Converts a lua hash (on stack) to a WeeChat hashtable.
  *
  * Note: hashtable must be freed after use.
  */
@@ -123,11 +124,8 @@ weechat_lua_tohashtable (lua_State *interpreter, int index, int size,
 {
     struct t_hashtable *hashtable;
 
-    hashtable = weechat_hashtable_new (size,
-                                       type_keys,
-                                       type_values,
-                                       NULL,
-                                       NULL);
+    hashtable = weechat_hashtable_new (size, type_keys, type_values,
+                                       NULL, NULL);
     if (!hashtable)
         return NULL;
 
@@ -144,9 +142,10 @@ weechat_lua_tohashtable (lua_State *interpreter, int index, int size,
         {
             weechat_hashtable_set (hashtable,
                                    lua_tostring (interpreter, -2),
-                                   plugin_script_str2ptr (weechat_lua_plugin,
-                                                          NULL, NULL,
-                                                          lua_tostring (interpreter, -1)));
+                                   plugin_script_str2ptr (
+                                       weechat_lua_plugin,
+                                       NULL, NULL,
+                                       lua_tostring (interpreter, -1)));
         }
         /* remove value from stack (keep key for next iteration) */
         lua_pop (interpreter, 1);
@@ -295,7 +294,7 @@ weechat_lua_register_lib (lua_State *L, const char *libname,
         luaL_setfuncs (L, lua_api_funcs, 0);
 #else
     luaL_register (L, libname, lua_api_funcs);
-#endif
+#endif /* LUA_VERSION_NUM >= 502 */
 
     luaL_newmetatable (L, "weechat");
     lua_pushliteral (L, "__index");
@@ -376,7 +375,7 @@ weechat_lua_load (const char *filename)
     luaopen_math (lua_current_interpreter);
     luaopen_io (lua_current_interpreter);
     luaopen_debug (lua_current_interpreter);
-#endif
+#endif /* LUA_VERSION_NUM */
 
     weechat_lua_register_lib (lua_current_interpreter, "weechat",
                               weechat_lua_api_funcs,
@@ -386,7 +385,7 @@ weechat_lua_load (const char *filename)
     if (luaL_dostring (lua_current_interpreter, weechat_lua_code) != 0)
 #else
     if (lua_dostring (lua_current_interpreter, weechat_lua_code) != 0)
-#endif
+#endif /* LUA_VERSION_NUM */
     {
         weechat_printf (NULL,
                         weechat_gettext ("%s%s: unable to redirect stdout "
@@ -426,8 +425,10 @@ weechat_lua_load (const char *filename)
         /* if script was registered, remove it from list */
         if (lua_current_script)
         {
-            plugin_script_remove (weechat_lua_plugin, &lua_scripts, &last_lua_script,
+            plugin_script_remove (weechat_lua_plugin,
+                                  &lua_scripts, &last_lua_script,
                                   lua_current_script);
+            lua_current_script = NULL;
         }
 
         return 0;
@@ -455,8 +456,9 @@ weechat_lua_load (const char *filename)
                                         &weechat_lua_api_buffer_input_data_cb,
                                         &weechat_lua_api_buffer_close_cb);
 
-    weechat_hook_signal_send ("lua_script_loaded", WEECHAT_HOOK_SIGNAL_STRING,
-                              lua_current_script->filename);
+    (void) weechat_hook_signal_send ("lua_script_loaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING,
+                                     lua_current_script->filename);
 
     return 1;
 }
@@ -514,8 +516,11 @@ weechat_lua_unload (struct t_plugin_script *script)
     if (interpreter)
         lua_close (interpreter);
 
-    weechat_hook_signal_send ("lua_script_unloaded",
-                              WEECHAT_HOOK_SIGNAL_STRING, filename);
+    if (lua_current_script)
+        lua_current_interpreter = lua_current_script->interpreter;
+
+    (void) weechat_hook_signal_send ("lua_script_unloaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING, filename);
     if (filename)
         free (filename);
 }
@@ -640,6 +645,8 @@ weechat_lua_command_cb (void *data, struct t_gui_buffer *buffer,
         {
             weechat_lua_unload_all ();
         }
+        else
+            WEECHAT_COMMAND_ERROR;
     }
     else
     {
@@ -689,12 +696,7 @@ weechat_lua_command_cb (void *data, struct t_gui_buffer *buffer,
             lua_quiet = 0;
         }
         else
-        {
-            weechat_printf (NULL,
-                            weechat_gettext ("%s%s: unknown option for "
-                                             "command \"%s\""),
-                            weechat_prefix ("error"), LUA_PLUGIN_NAME, "lua");
-        }
+            WEECHAT_COMMAND_ERROR;
     }
 
     return WEECHAT_RC_OK;
@@ -798,7 +800,7 @@ weechat_lua_signal_debug_libs_cb (void *data, const char *signal,
     weechat_printf (NULL, "  %s: %s", LUA_PLUGIN_NAME, LUA_VERSION);
 #else
     weechat_printf (NULL, "  %s: (?)", LUA_PLUGIN_NAME);
-#endif
+#endif /* LUA_VERSION */
 
     return WEECHAT_RC_OK;
 }
