@@ -1,7 +1,7 @@
 /*
  * weechat-perl.c - perl plugin for WeeChat
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2008 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -37,6 +37,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Support of perl scripts"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(3000);
 
 struct t_weechat_plugin *weechat_perl_plugin = NULL;
 
@@ -48,7 +49,7 @@ struct t_plugin_script *perl_registered_script = NULL;
 const char *perl_current_script_filename = NULL;
 #ifdef MULTIPLICITY
 PerlInterpreter *perl_current_interpreter = NULL;
-#endif
+#endif /* MULTIPLICITY */
 int perl_quit_or_upgrade = 0;
 
 /*
@@ -77,13 +78,13 @@ char *perl_action_autoload_list = NULL;
 
 #ifdef NO_PERL_MULTIPLICITY
 #undef MULTIPLICITY
-#endif
+#endif /* NO_PERL_MULTIPLICITY */
 
 #ifndef MULTIPLICITY
 #define PKG_NAME_PREFIX "WeechatPerlPackage"
 static PerlInterpreter *perl_main = NULL;
 int perl_num = 0;
-#endif
+#endif /* MULTIPLICITY */
 
 char *perl_args[] = { "", "-e", "0", "-w", NULL };
 int perl_args_count = 4;
@@ -92,7 +93,7 @@ char *perl_weechat_code =
 {
 #ifndef MULTIPLICITY
     "package %s;"
-#endif
+#endif /* MULTIPLICITY */
     "$SIG{__WARN__} = sub { weechat::print('', 'perl\twarning: '.$_[0]) };"
     "$SIG{__DIE__} = sub { weechat::print('', 'perl\terror: '.$_[0]) };"
     "do '%s';"
@@ -119,7 +120,7 @@ weechat_perl_hashtable_map_cb (void *data,
 }
 
 /*
- * Gets perl hash with a WeeChat hashtable.
+ * Converts a WeeChat hashtable to a perl hash.
  */
 
 HV *
@@ -139,7 +140,7 @@ weechat_perl_hashtable_to_hash (struct t_hashtable *hashtable)
 }
 
 /*
- * Gets WeeChat hashtable with perl hash.
+ * Converts a perl hash to a WeeChat hashtable.
  *
  * Note: hashtable must be freed after use.
  */
@@ -154,28 +155,30 @@ weechat_perl_hash_to_hashtable (SV *hash, int size, const char *type_keys,
     char *str_key;
     I32 retlen;
 
-    hashtable = weechat_hashtable_new (size,
-                                       type_keys,
-                                       type_values,
-                                       NULL,
-                                       NULL);
+    hashtable = weechat_hashtable_new (size, type_keys, type_values,
+                                       NULL, NULL);
     if (!hashtable)
         return NULL;
 
-    if ((hash) && SvROK(hash) && SvRV(hash) && (SvTYPE(SvRV(hash)) == SVt_PVHV))
+    if ((hash) && SvROK(hash) && SvRV(hash)
+        && (SvTYPE(SvRV(hash)) == SVt_PVHV))
     {
-        hash2 = (HV *) SvRV(hash);
+        hash2 = (HV *)SvRV(hash);
         hv_iterinit (hash2);
         while ((value = hv_iternextsv (hash2, &str_key, &retlen)))
         {
             if (strcmp (type_values, WEECHAT_HASHTABLE_STRING) == 0)
-                weechat_hashtable_set (hashtable, str_key, SvPV (value, PL_na));
+            {
+                weechat_hashtable_set (hashtable, str_key,
+                                       SvPV (value, PL_na));
+            }
             else if (strcmp (type_values, WEECHAT_HASHTABLE_POINTER) == 0)
             {
                 weechat_hashtable_set (hashtable, str_key,
-                                       plugin_script_str2ptr (weechat_perl_plugin,
-                                                              NULL, NULL,
-                                                              SvPV (value, PL_na)));
+                                       plugin_script_str2ptr (
+                                           weechat_perl_plugin,
+                                           NULL, NULL,
+                                           SvPV (value, PL_na)));
             }
         }
     }
@@ -201,7 +204,7 @@ weechat_perl_exec (struct t_plugin_script *script,
     struct t_plugin_script *old_perl_current_script;
 #ifdef MULTIPLICITY
     void *old_context;
-#endif
+#endif /* MULTIPLICITY */
 
     old_perl_current_script = perl_current_script;
     perl_current_script = script;
@@ -221,7 +224,7 @@ weechat_perl_exec (struct t_plugin_script *script,
     snprintf (func, length, "%s::%s",
               (char *) ((script->interpreter) ? script->interpreter : perl_main),
               function);
-#endif
+#endif /* MULTIPLICITY */
 
     dSP;
     ENTER;
@@ -319,7 +322,7 @@ weechat_perl_exec (struct t_plugin_script *script,
     PERL_SET_CONTEXT (old_context);
 #else
     free (func);
-#endif
+#endif /* MULTIPLICITY */
 
     if (!ret_value && (mem_err == 1))
     {
@@ -350,7 +353,7 @@ weechat_perl_load (const char *filename)
     int length;
 #ifndef MULTIPLICITY
     char pkgname[64];
-#endif
+#endif /* MULTIPLICITY */
 
     temp_script.filename = NULL;
     temp_script.interpreter = NULL;
@@ -411,7 +414,7 @@ weechat_perl_load (const char *filename)
     if (!perl_code)
         return 0;
     snprintf (perl_code, length, perl_weechat_code, pkgname, filename);
-#endif
+#endif /* MULTIPLICITY */
     eval_pv (perl_code, TRUE);
     free (perl_code);
 
@@ -429,12 +432,13 @@ weechat_perl_load (const char *filename)
 #ifdef MULTIPLICITY
         perl_destruct (perl_current_interpreter);
         perl_free (perl_current_interpreter);
-#endif
+#endif /* MULTIPLICITY */
         if (perl_current_script && (perl_current_script != &temp_script))
         {
             plugin_script_remove (weechat_perl_plugin,
                                   &perl_scripts, &last_perl_script,
                                   perl_current_script);
+            perl_current_script = NULL;
         }
 
         return 0;
@@ -449,14 +453,14 @@ weechat_perl_load (const char *filename)
 #ifdef MULTIPLICITY
         perl_destruct (perl_current_interpreter);
         perl_free (perl_current_interpreter);
-#endif
+#endif /* MULTIPLICITY */
         return 0;
     }
     perl_current_script = perl_registered_script;
 
 #ifndef MULTIPLICITY
     perl_current_script->interpreter = strdup (pkgname);
-#endif
+#endif /* MULTIPLICITY */
 
     /*
      * set input/close callbacks for buffers created by this script
@@ -468,8 +472,9 @@ weechat_perl_load (const char *filename)
                                         &weechat_perl_api_buffer_input_data_cb,
                                         &weechat_perl_api_buffer_close_cb);
 
-    weechat_hook_signal_send ("perl_script_loaded", WEECHAT_HOOK_SIGNAL_STRING,
-                              perl_current_script->filename);
+    (void) weechat_hook_signal_send ("perl_script_loaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING,
+                                     perl_current_script->filename);
 
     return 1;
 }
@@ -507,7 +512,7 @@ weechat_perl_unload (struct t_plugin_script *script)
 
 #ifdef MULTIPLICITY
     PERL_SET_CONTEXT (script->interpreter);
-#endif
+#endif /* MULTIPLICITY */
 
     if (script->shutdown_func && script->shutdown_func[0])
     {
@@ -537,13 +542,17 @@ weechat_perl_unload (struct t_plugin_script *script)
         perl_destruct (interpreter);
         perl_free (interpreter);
     }
+    if (perl_current_script)
+    {
+        PERL_SET_CONTEXT (perl_current_script->interpreter);
+    }
 #else
     if (interpreter)
         free (interpreter);
-#endif
+#endif /* MULTIPLICITY */
 
-    weechat_hook_signal_send ("perl_script_unloaded",
-                              WEECHAT_HOOK_SIGNAL_STRING, filename);
+    (void) weechat_hook_signal_send ("perl_script_unloaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING, filename);
     if (filename)
         free (filename);
 }
@@ -668,6 +677,8 @@ weechat_perl_command_cb (void *data, struct t_gui_buffer *buffer,
         {
             weechat_perl_unload_all ();
         }
+        else
+            WEECHAT_COMMAND_ERROR;
     }
     else
     {
@@ -717,12 +728,7 @@ weechat_perl_command_cb (void *data, struct t_gui_buffer *buffer,
             perl_quiet = 0;
         }
         else
-        {
-            weechat_printf (NULL,
-                            weechat_gettext ("%s%s: unknown option for "
-                                             "command \"%s\""),
-                            weechat_prefix ("error"), PERL_PLUGIN_NAME, "perl");
-        }
+            WEECHAT_COMMAND_ERROR;
     }
 
     return WEECHAT_RC_OK;
@@ -826,7 +832,7 @@ weechat_perl_signal_debug_libs_cb (void *data, const char *signal,
     weechat_printf (NULL, "  %s: %s", PERL_PLUGIN_NAME, PERL_VERSION_STRING);
 #else
     weechat_printf (NULL, "  %s: (?)", PERL_PLUGIN_NAME);
-#endif
+#endif /* PERL_VERSION_STRING */
 
     return WEECHAT_RC_OK;
 }
@@ -965,13 +971,11 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     int a;
     char **perl_args_local;
     char *perl_env[] = {};
-#endif
-#ifdef PERL_SYS_INIT3
     a = perl_args_count;
     perl_args_local = perl_args;
     (void) perl_env;
     PERL_SYS_INIT3 (&a, (char ***)&perl_args_local, (char ***)&perl_env);
-#endif
+#endif /* PERL_SYS_INIT3 */
 
     weechat_perl_plugin = plugin;
 
@@ -990,7 +994,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     perl_construct (perl_main);
     perl_parse (perl_main, weechat_perl_api_init, perl_args_count,
                 perl_args, NULL);
-#endif
+#endif /* MULTIPLICITY */
 
     init.callback_command = &weechat_perl_command_cb;
     init.callback_completion = &weechat_perl_completion_cb;
@@ -1036,7 +1040,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
         perl_free (perl_main);
         perl_main = NULL;
     }
-#endif
+#endif /* MULTIPLICITY */
 
 #if defined(PERL_SYS_TERM) && !defined(__FreeBSD__) && !defined(WIN32) && !defined(__CYGWIN__) && !(defined(__APPLE__) && defined(__MACH__))
     /*
