@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_PERL_H
-#define __WEECHAT_PERL_H 1
+#ifndef WEECHAT_PERL_H
+#define WEECHAT_PERL_H 1
 
 #define weechat_plugin weechat_perl_plugin
 #define PERL_PLUGIN_NAME "perl"
@@ -35,7 +35,7 @@ extern struct t_plugin_script *perl_registered_script;
 extern const char *perl_current_script_filename;
 #ifdef MULTIPLICITY
 extern PerlInterpreter *perl_current_interpreter;
-#endif
+#endif /* MULTIPLICITY */
 
 extern HV *weechat_perl_hashtable_to_hash (struct t_hashtable *hashtable);
 extern struct t_hashtable *weechat_perl_hash_to_hashtable (SV *hash, int size,
@@ -45,4 +45,4 @@ extern void *weechat_perl_exec (struct t_plugin_script *script,
                                 int ret_type, const char *function,
                                 const char *format, void **argv);
 
-#endif /* __WEECHAT_PERL_H */
+#endif /* WEECHAT_PERL_H */
