@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_PLUGIN_API_H
-#define __WEECHAT_PLUGIN_API_H 1
+#ifndef WEECHAT_PLUGIN_API_H
+#define WEECHAT_PLUGIN_API_H 1
 
 struct t_plugin_api_hdata
 {
@@ -53,8 +53,9 @@ extern const char *plugin_api_prefix (const char *prefix);
 extern const char *plugin_api_color (const char *color_name);
 
 /* command */
-extern void plugin_api_command (struct t_weechat_plugin *plugin,
-                                struct t_gui_buffer *buffer, const char *command);
+extern int plugin_api_command (struct t_weechat_plugin *plugin,
+                               struct t_gui_buffer *buffer,
+                               const char *command);
 
 /* infolist */
 extern int plugin_api_infolist_next (struct t_infolist *infolist);
@@ -75,4 +76,4 @@ extern void plugin_api_infolist_free (struct t_infolist *infolist);
 
 extern void plugin_api_init ();
 
-#endif /* __WEECHAT_PLUGIN_API_H */
+#endif /* WEECHAT_PLUGIN_API_H */
