@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2012 Simon Arlott
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_PLUGIN_SCRIPT_API_H
-#define __WEECHAT_PLUGIN_SCRIPT_API_H 1
+#ifndef WEECHAT_PLUGIN_SCRIPT_API_H
+#define WEECHAT_PLUGIN_SCRIPT_API_H 1
 
 extern void plugin_script_api_charset_set (struct t_plugin_script *script,
                                            const char *charset);
@@ -330,10 +330,10 @@ extern struct t_gui_bar_item *plugin_script_api_bar_item_new (struct t_weechat_p
 extern void plugin_script_api_bar_item_remove (struct t_weechat_plugin *weechat_plugin,
                                                struct t_plugin_script *script,
                                                struct t_gui_bar_item *item);
-extern void plugin_script_api_command (struct t_weechat_plugin *weechat_plugin,
-                                       struct t_plugin_script *script,
-                                       struct t_gui_buffer *buffer,
-                                       const char *command);
+extern int plugin_script_api_command (struct t_weechat_plugin *weechat_plugin,
+                                      struct t_plugin_script *script,
+                                      struct t_gui_buffer *buffer,
+                                      const char *command);
 extern const char *plugin_script_api_config_get_plugin (struct t_weechat_plugin *weechat_plugin,
                                                         struct t_plugin_script *script,
                                                         const char *option);
@@ -360,4 +360,4 @@ extern int plugin_script_api_upgrade_read (struct t_weechat_plugin *weechat_plug
                                            const char *function,
                                            const char *data);
 
-#endif /* __WEECHAT_PLUGIN_SCRIPT_API_H */
+#endif /* WEECHAT_PLUGIN_SCRIPT_API_H */
