@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_PLUGIN_SCRIPT_H
-#define __WEECHAT_PLUGIN_SCRIPT_H 1
+#ifndef WEECHAT_PLUGIN_SCRIPT_H
+#define WEECHAT_PLUGIN_SCRIPT_H 1
 
 /* constants which defines return types for weechat_<lang>_exec functions */
 
@@ -173,4 +173,4 @@ extern void plugin_script_end (struct t_weechat_plugin *weechat_plugin,
 extern void plugin_script_print_log (struct t_weechat_plugin *weechat_plugin,
                                      struct t_plugin_script *scripts);
 
-#endif /* __WEECHAT_PLUGIN_SCRIPT_H */
+#endif /* WEECHAT_PLUGIN_SCRIPT_H */
