@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_PYTHON_API_H
-#define __WEECHAT_PYTHON_API_H 1
+#ifndef WEECHAT_PYTHON_API_H
+#define WEECHAT_PYTHON_API_H 1
 
 extern PyMethodDef weechat_python_funcs[];
 
@@ -29,4 +29,4 @@ extern int weechat_python_api_buffer_input_data_cb (void *data,
 extern int weechat_python_api_buffer_close_cb (void *data,
                                                struct t_gui_buffer *buffer);
 
-#endif /* __WEECHAT_PYTHON_API_H */
+#endif /* WEECHAT_PYTHON_API_H */
