@@ -1,7 +1,7 @@
 /*
  * relay-client.c - client functions for relay plugin
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -46,10 +46,14 @@
 #include "relay-websocket.h"
 
 
-char *relay_client_status_string[] =   /* strings for status                */
+char *relay_client_status_string[] =   /* status strings for display        */
 { N_("connecting"), N_("waiting auth"),
   N_("connected"), N_("auth failed"), N_("disconnected")
 };
+char *relay_client_status_name[] =     /* name of status (for signal/info)  */
+{ "connecting", "waiting_auth",
+  "connected", "auth_failed", "disconnected"
+};
 
 char *relay_client_data_type_string[] = /* strings for data types           */
 { "text", "binary" };
@@ -133,6 +137,42 @@ relay_client_search_by_id (int id)
     return NULL;
 }
 
+/*
+ * Searches for a client status.
+ *
+ * Returns index of status in enum t_relay_status, -1 if status is not found.
+ */
+
+int
+relay_client_status_search (const char *name)
+{
+    int i;
+
+    for (i = 0; i < RELAY_NUM_STATUS; i++)
+    {
+        if (strcmp (relay_client_status_name[i], name) == 0)
+            return i;
+    }
+
+    /* status not found */
+    return -1;
+}
+
+/*
+ * Sends a signal with the status of client ("relay_client_xxx").
+ */
+
+void
+relay_client_send_signal (struct t_relay_client *client)
+{
+    char signal[128];
+
+    snprintf (signal, sizeof (signal),
+              "relay_client_%s",
+              relay_client_status_name[client->status]);
+    weechat_hook_signal_send (signal, WEECHAT_HOOK_SIGNAL_POINTER, client);
+}
+
 /*
  * Sets description for a client.
  */
@@ -177,6 +217,7 @@ relay_client_handshake_timer_cb (void *data, int remaining_calls)
         /* handshake OK, set status to "connected" */
         weechat_unhook (client->hook_timer_handshake);
         client->hook_timer_handshake = NULL;
+        client->gnutls_handshake_ok = 1;
         relay_client_set_status (client, RELAY_STATUS_CONNECTED);
         return WEECHAT_RC_OK;
     }
@@ -219,7 +260,7 @@ relay_client_handshake_timer_cb (void *data, int remaining_calls)
     /* handshake in progress, we will try again on next call to timer */
     return WEECHAT_RC_OK;
 }
-#endif
+#endif /* HAVE_GNUTLS */
 
 /*
  * Reads text data from a client: splits data on '\n' and keep a partial message
@@ -230,6 +271,7 @@ void
 relay_client_recv_text (struct t_relay_client *client, const char *data)
 {
     char *new_partial, *raw_msg, **lines, *pos, *tmp, *handshake;
+    const char *ptr_real_ip;
     int i, num_lines, length, rc;
 
     if (client->partial_message)
@@ -338,6 +380,21 @@ relay_client_recv_text (struct t_relay_client *client, const char *data)
                             relay_client_set_status (client, RELAY_STATUS_DISCONNECTED);
                         }
 
+                        ptr_real_ip = weechat_hashtable_get (
+                            client->http_headers, "X-Real-IP");
+                        if (ptr_real_ip)
+                        {
+                            weechat_printf_tags (
+                                NULL, "relay_client",
+                                _("%s: websocket client %s%s%s has real IP "
+                                  "address \"%s\""),
+                                RELAY_PLUGIN_NAME,
+                                RELAY_COLOR_CHAT_CLIENT,
+                                client->desc,
+                                RELAY_COLOR_CHAT,
+                                ptr_real_ip);
+                        }
+
                         /* remove HTTP headers */
                         weechat_hashtable_free (client->http_headers);
                         client->http_headers = NULL;
@@ -348,6 +405,7 @@ relay_client_recv_text (struct t_relay_client *client, const char *data)
                          */
                         free (client->partial_message);
                         client->partial_message = NULL;
+                        weechat_string_free_split (lines);
                         return;
                     }
                 }
@@ -409,7 +467,7 @@ relay_client_recv_cb (void *arg_client, int fd)
         num_read = gnutls_record_recv (client->gnutls_sess, buffer,
                                        sizeof (buffer) - 1);
     else
-#endif
+#endif /* HAVE_GNUTLS */
         num_read = recv (client->sock, buffer, sizeof (buffer) - 1, 0);
 
     if (num_read > 0)
@@ -448,7 +506,21 @@ relay_client_recv_cb (void *arg_client, int fd)
                                                (unsigned long long)num_read,
                                                (unsigned char *)decoded,
                                                &decoded_length);
-            if (!rc || (decoded_length == 0))
+            if (decoded_length == 0)
+            {
+                /*
+                 * When decoded length is 0, assume client sent a PONG frame.
+                 *
+                 * RFC 6455 Section 5.5.3:
+                 *
+                 *   "A Pong frame MAY be sent unsolicited.  This serves as a
+                 *   unidirectional heartbeat.  A response to an unsolicited
+                 *   Pong
+                 *   frame is not expected."
+                 */
+                return WEECHAT_RC_OK;
+            }
+            if (!rc)
             {
                 /* error when decoding frame: close connection */
                 weechat_printf_tags (NULL, "relay_client",
@@ -462,7 +534,6 @@ relay_client_recv_cb (void *arg_client, int fd)
                 return WEECHAT_RC_OK;
             }
             ptr_buffer = decoded;
-            num_read = (int)decoded_length;
         }
 
         if ((client->websocket == 1)
@@ -500,7 +571,7 @@ relay_client_recv_cb (void *arg_client, int fd)
             }
         }
         else
-#endif
+#endif /* HAVE_GNUTLS */
         {
             if ((num_read == 0)
                 || ((errno != EAGAIN) && (errno != EWOULDBLOCK)))
@@ -730,7 +801,7 @@ relay_client_send (struct t_relay_client *client, const char *data,
         if (client->ssl)
             num_sent = gnutls_record_send (client->gnutls_sess, ptr_data, data_size);
         else
-#endif
+#endif /* HAVE_GNUTLS */
             num_sent = send (client->sock, ptr_data, data_size, 0);
 
         if (num_sent >= 0)
@@ -784,7 +855,7 @@ relay_client_send (struct t_relay_client *client, const char *data,
                 }
             }
             else
-#endif
+#endif /* HAVE_GNUTLS */
             {
                 if ((errno == EAGAIN) || (errno == EWOULDBLOCK))
                 {
@@ -823,18 +894,34 @@ relay_client_send (struct t_relay_client *client, const char *data,
 int
 relay_client_timer_cb (void *data, int remaining_calls)
 {
-    struct t_relay_client *ptr_client;
-    int num_sent, i;
+    struct t_relay_client *ptr_client, *ptr_next_client;
+    int num_sent, i, purge_delay;
     char *buf;
+    time_t current_time;
 
     /* make C compiler happy */
     (void) data;
     (void) remaining_calls;
 
-    for (ptr_client = relay_clients; ptr_client;
-         ptr_client = ptr_client->next_client)
+    purge_delay = weechat_config_integer (relay_config_network_clients_purge_delay);
+
+    current_time = time (NULL);
+
+    ptr_client = relay_clients;
+    while (ptr_client)
     {
-        if (ptr_client->sock >= 0)
+        ptr_next_client = ptr_client->next_client;
+
+        if (RELAY_CLIENT_HAS_ENDED(ptr_client))
+        {
+            if ((purge_delay >= 0)
+                && (current_time >= ptr_client->end_time + (purge_delay * 60)))
+            {
+                relay_client_free (ptr_client);
+                relay_buffer_refresh (NULL);
+            }
+        }
+        else if (ptr_client->sock >= 0)
         {
             while (ptr_client->outqueue)
             {
@@ -846,7 +933,7 @@ relay_client_timer_cb (void *data, int remaining_calls)
                                                    ptr_client->outqueue->data_size);
                 }
                 else
-#endif
+#endif /* HAVE_GNUTLS */
                 {
                     num_sent = send (ptr_client->sock,
                                      ptr_client->outqueue->data,
@@ -856,8 +943,7 @@ relay_client_timer_cb (void *data, int remaining_calls)
                 {
                     for (i = 0; i < 2; i++)
                     {
-                        if (ptr_client->outqueue->raw_message
-                            && ptr_client->outqueue->raw_message[i])
+                        if (ptr_client->outqueue->raw_message[i])
                         {
                             /*
                              * print raw message and remove it from outqueue
@@ -935,7 +1021,7 @@ relay_client_timer_cb (void *data, int remaining_calls)
                         }
                     }
                     else
-#endif
+#endif /* HAVE_GNUTLS */
                     {
                         if ((errno == EAGAIN) || (errno == EWOULDBLOCK))
                         {
@@ -961,6 +1047,8 @@ relay_client_timer_cb (void *data, int remaining_calls)
                 }
             }
         }
+
+        ptr_client = ptr_next_client;
     }
 
     return WEECHAT_RC_OK;
@@ -979,7 +1067,7 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
 #ifdef HAVE_GNUTLS
     int bits;
     struct t_config_option *ptr_option;
-#endif
+#endif /* HAVE_GNUTLS */
 
     new_client = malloc (sizeof (*new_client));
     if (new_client)
@@ -990,7 +1078,8 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
         new_client->ssl = server->ssl;
 #ifdef HAVE_GNUTLS
         new_client->hook_timer_handshake = NULL;
-#endif
+        new_client->gnutls_handshake_ok = 0;
+#endif /* HAVE_GNUTLS */
         new_client->websocket = 0;
         new_client->http_headers = NULL;
         new_client->address = strdup ((address) ? address : "?");
@@ -1047,14 +1136,13 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
                 if (relay_gnutls_dh_params)
                 {
                     gnutls_dh_params_init (relay_gnutls_dh_params);
-#if LIBGNUTLS_VERSION_NUMBER >= 0x020c00
-                    /* for gnutls >= 2.12.0 */
+#if LIBGNUTLS_VERSION_NUMBER >= 0x020c00 /* 2.12.0 */
                     bits = gnutls_sec_param_to_pk_bits (GNUTLS_PK_DH,
                                                         GNUTLS_SEC_PARAM_LOW);
 #else
                     /* default for old gnutls */
                     bits = 1024;
-#endif
+#endif /* LIBGNUTLS_VERSION_NUMBER >= 0x020c00 */
                     gnutls_dh_params_generate2 (*relay_gnutls_dh_params, bits);
                     gnutls_certificate_set_dh_params (relay_gnutls_x509_cred,
                                                       *relay_gnutls_dh_params);
@@ -1075,7 +1163,7 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
                                                                    &relay_client_handshake_timer_cb,
                                                                    new_client);
         }
-#endif
+#endif /* HAVE_GNUTLS */
 
         new_client->protocol_data = NULL;
         switch (new_client->protocol)
@@ -1122,6 +1210,8 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
             relay_buffer_open ();
         }
 
+        relay_client_send_signal (new_client);
+
         relay_buffer_refresh (WEECHAT_HOTLIST_PRIVATE);
     }
     else
@@ -1156,7 +1246,8 @@ relay_client_new_with_infolist (struct t_infolist *infolist)
 #ifdef HAVE_GNUTLS
         new_client->gnutls_sess = NULL;
         new_client->hook_timer_handshake = NULL;
-#endif
+        new_client->gnutls_handshake_ok = 0;
+#endif /* HAVE_GNUTLS */
         new_client->websocket = weechat_infolist_integer (infolist, "websocket");
         new_client->http_headers = NULL;
         new_client->address = strdup (weechat_infolist_string (infolist, "address"));
@@ -1180,9 +1271,9 @@ relay_client_new_with_infolist (struct t_infolist *infolist)
             new_client->hook_fd = NULL;
         new_client->last_activity = weechat_infolist_time (infolist, "last_activity");
         sscanf (weechat_infolist_string (infolist, "bytes_recv"),
-                "%lu", &(new_client->bytes_recv));
+                "%llu", &(new_client->bytes_recv));
         sscanf (weechat_infolist_string (infolist, "bytes_sent"),
-                "%lu", &(new_client->bytes_sent));
+                "%llu", &(new_client->bytes_sent));
         new_client->recv_data_type = weechat_infolist_integer (infolist, "recv_data_type");
         new_client->send_data_type = weechat_infolist_integer (infolist, "send_data_type");
         str = weechat_infolist_string (infolist, "partial_message");
@@ -1247,6 +1338,14 @@ relay_client_set_status (struct t_relay_client *client,
 
         relay_client_outqueue_free_all (client);
 
+#ifdef HAVE_GNUTLS
+        if (client->hook_timer_handshake)
+        {
+            weechat_unhook (client->hook_timer_handshake);
+            client->hook_timer_handshake = NULL;
+        }
+        client->gnutls_handshake_ok = 0;
+#endif /* HAVE_GNUTLS */
         if (client->hook_fd)
         {
             weechat_unhook (client->hook_fd);
@@ -1290,18 +1389,20 @@ relay_client_set_status (struct t_relay_client *client,
         if (client->sock >= 0)
         {
 #ifdef HAVE_GNUTLS
-            if (client->ssl)
+            if (client->ssl && client->gnutls_handshake_ok)
                 gnutls_bye (client->gnutls_sess, GNUTLS_SHUT_WR);
-#endif
+#endif /* HAVE_GNUTLS */
             close (client->sock);
             client->sock = -1;
 #ifdef HAVE_GNUTLS
             if (client->ssl)
                 gnutls_deinit (client->gnutls_sess);
-#endif
+#endif /* HAVE_GNUTLS */
         }
     }
 
+    relay_client_send_signal (client);
+
     relay_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
 }
 
@@ -1342,7 +1443,7 @@ relay_client_free (struct t_relay_client *client)
 #ifdef HAVE_GNUTLS
     if (client->hook_timer_handshake)
         weechat_unhook (client->hook_timer_handshake);
-#endif
+#endif /* HAVE_GNUTLS */
     if (client->http_headers)
         weechat_hashtable_free (client->http_headers);
     if (client->hook_fd)
@@ -1452,7 +1553,9 @@ relay_client_add_to_infolist (struct t_infolist *infolist,
 #ifdef HAVE_GNUTLS
     if (!weechat_infolist_new_var_pointer (ptr_item, "hook_timer_handshake", client->hook_timer_handshake))
         return 0;
-#endif
+    if (!weechat_infolist_new_var_integer (ptr_item, "gnutls_handshake_ok", client->gnutls_handshake_ok))
+        return 0;
+#endif /* HAVE_GNUTLS */
     if (!weechat_infolist_new_var_integer (ptr_item, "websocket", client->websocket))
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "address", client->address))
@@ -1479,10 +1582,10 @@ relay_client_add_to_infolist (struct t_infolist *infolist,
         return 0;
     if (!weechat_infolist_new_var_time (ptr_item, "last_activity", client->last_activity))
         return 0;
-    snprintf (value, sizeof (value), "%lu", client->bytes_recv);
+    snprintf (value, sizeof (value), "%llu", client->bytes_recv);
     if (!weechat_infolist_new_var_string (ptr_item, "bytes_recv", value))
         return 0;
-    snprintf (value, sizeof (value), "%lu", client->bytes_sent);
+    snprintf (value, sizeof (value), "%llu", client->bytes_sent);
     if (!weechat_infolist_new_var_string (ptr_item, "bytes_sent", value))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "recv_data_type", client->recv_data_type))
@@ -1528,7 +1631,8 @@ relay_client_print_log ()
 #ifdef HAVE_GNUTLS
         weechat_log_printf ("  gnutls_sess . . . . . : 0x%lx", ptr_client->gnutls_sess);
         weechat_log_printf ("  hook_timer_handshake. : 0x%lx", ptr_client->hook_timer_handshake);
-#endif
+        weechat_log_printf ("  gnutls_handshake_ok . : 0x%lx", ptr_client->gnutls_handshake_ok);
+#endif /* HAVE_GNUTLS */
         weechat_log_printf ("  websocket . . . . . . : %d",   ptr_client->websocket);
         weechat_log_printf ("  http_headers. . . . . : 0x%lx (hashtable: '%s')",
                             ptr_client->http_headers,
@@ -1547,8 +1651,8 @@ relay_client_print_log ()
         weechat_log_printf ("  end_time. . . . . . . : %ld",   ptr_client->end_time);
         weechat_log_printf ("  hook_fd . . . . . . . : 0x%lx", ptr_client->hook_fd);
         weechat_log_printf ("  last_activity . . . . : %ld",   ptr_client->last_activity);
-        weechat_log_printf ("  bytes_recv. . . . . . : %lu",   ptr_client->bytes_recv);
-        weechat_log_printf ("  bytes_sent. . . . . . : %lu",   ptr_client->bytes_sent);
+        weechat_log_printf ("  bytes_recv. . . . . . : %llu",  ptr_client->bytes_recv);
+        weechat_log_printf ("  bytes_sent. . . . . . : %llu",  ptr_client->bytes_sent);
         weechat_log_printf ("  recv_data_type. . . . : %d (%s)",
                             ptr_client->recv_data_type,
                             relay_client_data_type_string[ptr_client->recv_data_type]);
