@@ -1,7 +1,7 @@
 /*
  * relay-command.c - relay command
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -82,7 +82,7 @@ relay_command_client_list (int full)
         {
             weechat_printf (NULL,
                             _("  %s%s%s (%s%s%s), started on: %s, last activity: %s, "
-                              "bytes: %lu recv, %lu sent"),
+                              "bytes: %llu recv, %llu sent"),
                             RELAY_COLOR_CHAT_CLIENT,
                             ptr_client->desc,
                             RELAY_COLOR_CHAT,
@@ -137,24 +137,40 @@ relay_command_server_list ()
         for (ptr_server = relay_servers; ptr_server;
              ptr_server = ptr_server->next_server)
         {
-            date_start[0] = '\0';
-            date_tmp = localtime (&(ptr_server->start_time));
-            if (date_tmp)
+            if (ptr_server->sock < 0)
             {
-                strftime (date_start, sizeof (date_start),
-                          "%a, %d %b %Y %H:%M:%S", date_tmp);
+                weechat_printf (
+                    NULL,
+                    _("  port %s%d%s, relay: %s%s%s, %s (not started)"),
+                    RELAY_COLOR_CHAT_BUFFER,
+                    ptr_server->port,
+                    RELAY_COLOR_CHAT,
+                    RELAY_COLOR_CHAT_BUFFER,
+                    ptr_server->protocol_string,
+                    RELAY_COLOR_CHAT,
+                    ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : "IPv4")));
+            }
+            else
+            {
+                date_start[0] = '\0';
+                date_tmp = localtime (&(ptr_server->start_time));
+                if (date_tmp)
+                {
+                    strftime (date_start, sizeof (date_start),
+                              "%a, %d %b %Y %H:%M:%S", date_tmp);
+                }
+                weechat_printf (
+                    NULL,
+                    _("  port %s%d%s, relay: %s%s%s, %s, started on: %s"),
+                    RELAY_COLOR_CHAT_BUFFER,
+                    ptr_server->port,
+                    RELAY_COLOR_CHAT,
+                    RELAY_COLOR_CHAT_BUFFER,
+                    ptr_server->protocol_string,
+                    RELAY_COLOR_CHAT,
+                    ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : "IPv4")),
+                    date_start);
             }
-
-            weechat_printf (NULL,
-                            _("  port %s%d%s, relay: %s%s%s, %s, started on: %s"),
-                            RELAY_COLOR_CHAT_BUFFER,
-                            ptr_server->port,
-                            RELAY_COLOR_CHAT,
-                            RELAY_COLOR_CHAT_BUFFER,
-                            ptr_server->protocol_string,
-                            RELAY_COLOR_CHAT,
-                            ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : "IPv4")),
-                            date_start);
             i++;
         }
     }
@@ -197,80 +213,126 @@ relay_command_relay (void *data, struct t_gui_buffer *buffer, int argc,
             relay_command_server_list ();
             return WEECHAT_RC_OK;
         }
+
         if (weechat_strcasecmp (argv[1], "add") == 0)
         {
-            if (argc >= 4)
-            {
-                if (relay_config_create_option_port (NULL,
-                                                     relay_config_file,
-                                                     relay_config_section_port,
-                                                     argv[2],
-                                                     argv_eol[3]) != WEECHAT_CONFIG_OPTION_SET_ERROR)
-                {
-                    weechat_printf (NULL,
-                                    _("%s: relay \"%s\" (port %s) added"),
-                                    RELAY_PLUGIN_NAME,
-                                    argv[2], argv_eol[3]);
-                }
-            }
-            else
+            WEECHAT_COMMAND_MIN_ARGS(4, "add");
+            if (relay_config_create_option_port (NULL,
+                                                 relay_config_file,
+                                                 relay_config_section_port,
+                                                 argv[2],
+                                                 argv_eol[3]) != WEECHAT_CONFIG_OPTION_SET_ERROR)
             {
                 weechat_printf (NULL,
-                                _("%s%s: missing arguments for \"%s\" "
-                                  "command"),
-                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                                "relay add");
+                                _("%s: relay \"%s\" (port %s) added"),
+                                RELAY_PLUGIN_NAME,
+                                argv[2], argv_eol[3]);
             }
             return WEECHAT_RC_OK;
         }
+
         if (weechat_strcasecmp (argv[1], "del") == 0)
         {
-            if (argc >= 3)
+            WEECHAT_COMMAND_MIN_ARGS(3, "del");
+            ptr_server = relay_server_search (argv_eol[2]);
+            if (ptr_server)
             {
-                ptr_server = relay_server_search (argv_eol[2]);
-                if (ptr_server)
-                {
-                    port = ptr_server->port;
-                    relay_server_free (ptr_server);
-                    ptr_option = weechat_config_search_option (relay_config_file,
-                                                               relay_config_section_port,
-                                                               argv_eol[2]);
-                    if (ptr_option)
-                        weechat_config_option_free (ptr_option);
-                    weechat_printf (NULL,
-                                    _("%s: relay \"%s\" (port %d) removed"),
-                                    RELAY_PLUGIN_NAME,
-                                    argv[2], port);
-                }
-                else
-                {
-                    weechat_printf (NULL,
-                                    _("%s%s: relay \"%s\" not found"),
-                                    weechat_prefix ("error"),
-                                    RELAY_PLUGIN_NAME,
-                                    argv_eol[2]);
-                }
+                port = ptr_server->port;
+                relay_server_free (ptr_server);
+                ptr_option = weechat_config_search_option (relay_config_file,
+                                                           relay_config_section_port,
+                                                           argv_eol[2]);
+                if (ptr_option)
+                    weechat_config_option_free (ptr_option);
+                weechat_printf (NULL,
+                                _("%s: relay \"%s\" (port %d) removed"),
+                                RELAY_PLUGIN_NAME,
+                                argv[2], port);
             }
             else
             {
                 weechat_printf (NULL,
-                                _("%s%s: missing arguments for \"%s\" "
-                                  "command"),
-                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                                "relay del");
+                                _("%s%s: relay \"%s\" not found"),
+                                weechat_prefix ("error"),
+                                RELAY_PLUGIN_NAME,
+                                argv_eol[2]);
             }
             return WEECHAT_RC_OK;
         }
+
+        if (weechat_strcasecmp (argv[1], "stop") == 0)
+        {
+            WEECHAT_COMMAND_MIN_ARGS(3, "stop");
+            ptr_server = relay_server_search (argv_eol[2]);
+            if (ptr_server)
+            {
+                relay_server_close_socket (ptr_server);
+            }
+            else
+            {
+                weechat_printf (NULL,
+                                _("%s%s: relay \"%s\" not found"),
+                                weechat_prefix ("error"),
+                                RELAY_PLUGIN_NAME,
+                                argv_eol[2]);
+            }
+            return WEECHAT_RC_OK;
+        }
+
+        if (weechat_strcasecmp (argv[1], "restart") == 0)
+        {
+            WEECHAT_COMMAND_MIN_ARGS(3, "restart");
+            ptr_server = relay_server_search (argv_eol[2]);
+            if (ptr_server)
+            {
+                relay_server_close_socket (ptr_server);
+                relay_server_create_socket (ptr_server);
+            }
+            else
+            {
+                weechat_printf (NULL,
+                                _("%s%s: relay \"%s\" not found"),
+                                weechat_prefix ("error"),
+                                RELAY_PLUGIN_NAME,
+                                argv_eol[2]);
+            }
+            return WEECHAT_RC_OK;
+        }
+
         if (weechat_strcasecmp (argv[1], "raw") == 0)
         {
             relay_raw_open (1);
             return WEECHAT_RC_OK;
         }
+
         if (weechat_strcasecmp (argv[1], "sslcertkey") == 0)
         {
             relay_network_set_ssl_cert_key (1);
             return WEECHAT_RC_OK;
         }
+
+        if (weechat_strcasecmp (argv[1], "up") == 0)
+        {
+            if (relay_buffer && (relay_buffer_selected_line > 0))
+            {
+                relay_buffer_selected_line--;
+                relay_buffer_refresh (NULL);
+            }
+            return WEECHAT_RC_OK;
+        }
+
+        if (weechat_strcasecmp (argv[1], "down") == 0)
+        {
+            if (relay_buffer
+                && relay_buffer_selected_line < relay_client_count - 1)
+            {
+                relay_buffer_selected_line++;
+                relay_buffer_refresh (NULL);
+            }
+            return WEECHAT_RC_OK;
+        }
+
+        WEECHAT_COMMAND_ERROR;
     }
 
     if (!relay_buffer)
@@ -279,24 +341,9 @@ relay_command_relay (void *data, struct t_gui_buffer *buffer, int argc,
     if (relay_buffer)
     {
         weechat_buffer_set (relay_buffer, "display", "1");
-
-        if (argc > 1)
-        {
-            if (strcmp (argv[1], "up") == 0)
-            {
-                if (relay_buffer_selected_line > 0)
-                    relay_buffer_selected_line--;
-            }
-            else if (strcmp (argv[1], "down") == 0)
-            {
-                if (relay_buffer_selected_line < relay_client_count - 1)
-                    relay_buffer_selected_line++;
-            }
-        }
+        relay_buffer_refresh (NULL);
     }
 
-    relay_buffer_refresh (NULL);
-
     return WEECHAT_RC_OK;
 }
 
@@ -311,15 +358,25 @@ relay_command_init ()
         "relay",
         N_("relay control"),
         N_("list|listfull|listrelay"
-           " || add [ipv4.][ipv6.][ssl.]<protocol.name> <port>"
-           " || del [ipv4.][ipv6.][ssl.]<protocol.name>"
+           " || add <name> <port>"
+           " || del|stop|restart <name>"
            " || raw"
            " || sslcertkey"),
         N_("         list: list relay clients (only active relays)\n"
            "     listfull: list relay clients (verbose, all relays)\n"
            "    listrelay: list relays (name and port)\n"
-           "          add: add relay for a protocol + name\n"
-           "          del: remove relay for a protocol + name\n"
+           "          add: add a relay (listen on a port)\n"
+           "          del: remove a relay (clients remain connected)\n"
+           "         stop: close the server socket (clients remain connected)\n"
+           "      restart: close the server socket and listen again on port "
+           "(clients remain connected)\n"
+           "         name: relay name (see format below)\n"
+           "         port: port used for relay\n"
+           "          raw: open buffer with raw Relay data\n"
+           "   sslcertkey: set SSL certificate/key using path in option "
+           "relay.network.ssl_cert_key\n"
+           "\n"
+           "Relay name is: [ipv4.][ipv6.][ssl.]<protocol.name>\n"
            "         ipv4: force use of IPv4\n"
            "         ipv6: force use of IPv6\n"
            "          ssl: enable SSL\n"
@@ -328,10 +385,11 @@ relay_command_init ()
            "(optional, if not given, the server name must be sent by client in "
            "command \"PASS\", with format: \"PASS server:password\")\n"
            "                 - protocol \"weechat\" (name is not used)\n"
-           "         port: port used for relay\n"
-           "          raw: open buffer with raw Relay data\n"
-           "   sslcertkey: set SSL certificate/key using path in option "
-           "relay.network.ssl_cert_key\n"
+           "\n"
+           "The \"irc\" protocol allows any IRC client (including WeeChat "
+           "itself) to connect on the port.\n"
+           "The \"weechat\" protocol allows a remote interface to connect on "
+           "the port, see the list here: https://weechat.org/download/\n"
            "\n"
            "Without argument, this command opens buffer with list of relay "
            "clients.\n"
@@ -358,6 +416,8 @@ relay_command_init ()
         " || listrelay"
         " || add %(relay_protocol_name) %(relay_free_port)"
         " || del %(relay_relays)"
+        " || stop %(relay_relays)"
+        " || restart %(relay_relays)"
         " || raw"
         " || sslcertkey",
         &relay_command_relay, NULL);
