@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,7 +22,7 @@
 
 #ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
-#endif
+#endif /* HAVE_GNUTLS */
 
 extern int relay_network_init_ok;
 extern int relay_network_init_ssl_cert_key_ok;
@@ -31,7 +31,7 @@ extern int relay_network_init_ssl_cert_key_ok;
 extern gnutls_certificate_credentials_t relay_gnutls_x509_cred;
 extern gnutls_priority_t *relay_gnutls_priority_cache;
 extern gnutls_dh_params_t *relay_gnutls_dh_params;
-#endif
+#endif /* HAVE_GNUTLS */
 
 extern void relay_network_set_ssl_cert_key (int verbose);
 extern void relay_network_set_priority ();
