@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,12 +17,12 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_RELAY_SERVER_H
-#define __WEECHAT_RELAY_SERVER_H 1
+#ifndef WEECHAT_RELAY_SERVER_H
+#define WEECHAT_RELAY_SERVER_H 1
 
 #ifdef HAVE_GNUTLS
 #define RELAY_SERVER_GNUTLS_DH_BITS 1024
-#endif
+#endif /* HAVE_GNUTLS */
 
 struct t_relay_server
 {
@@ -66,4 +66,4 @@ extern int relay_server_add_to_infolist (struct t_infolist *infolist,
                                          struct t_relay_server *server);
 extern void relay_server_print_log ();
 
-#endif /* __WEECHAT_RELAY_SERVER_H */
+#endif /* WEECHAT_RELAY_SERVER_H */
