@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_RELAY_WEECHAT_PROTOCOL_H
-#define __WEECHAT_RELAY_WEECHAT_PROTOCOL_H 1
+#ifndef WEECHAT_RELAY_WEECHAT_PROTOCOL_H
+#define WEECHAT_RELAY_WEECHAT_PROTOCOL_H 1
 
 #define RELAY_WEECHAT_PROTOCOL_SYNC_BUFFER   1
 #define RELAY_WEECHAT_PROTOCOL_SYNC_NICKLIST 2
@@ -101,4 +101,4 @@ extern int relay_weechat_protocol_timer_nicklist_cb (void *data,
 extern void relay_weechat_protocol_recv (struct t_relay_client *client,
                                          const char *data);
 
-#endif /* __WEECHAT_RELAY_WEECHAT_PROTOCOL_H */
+#endif /* WEECHAT_RELAY_WEECHAT_PROTOCOL_H */
