@@ -1,7 +1,7 @@
 /*
  * weechat-ruby.c - ruby plugin for WeeChat
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -61,6 +61,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Support of ruby scripts"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(3000);
 
 struct t_weechat_plugin *weechat_ruby_plugin = NULL;
 
@@ -133,7 +134,7 @@ weechat_ruby_hashtable_map_cb (void *data,
 }
 
 /*
- * Gets ruby hash with a WeeChat hashtable.
+ * Converts a WeeChat hashtable to a ruby hash.
  */
 
 VALUE
@@ -163,6 +164,7 @@ weechat_ruby_hash_foreach_cb (VALUE key, VALUE value, void *arg)
     const char *type_values;
 
     hashtable = (struct t_hashtable *)arg;
+
     if ((TYPE(key) == T_STRING) && (TYPE(value) == T_STRING))
     {
         type_values = weechat_hashtable_get_string (hashtable, "type_values");
@@ -174,16 +176,18 @@ weechat_ruby_hash_foreach_cb (VALUE key, VALUE value, void *arg)
         else if (strcmp (type_values, WEECHAT_HASHTABLE_POINTER) == 0)
         {
             weechat_hashtable_set (hashtable, StringValuePtr(key),
-                                   plugin_script_str2ptr (weechat_ruby_plugin,
-                                                          NULL, NULL,
-                                                          StringValuePtr(value)));
+                                   plugin_script_str2ptr (
+                                       weechat_ruby_plugin,
+                                       NULL, NULL,
+                                       StringValuePtr(value)));
         }
     }
+
     return 0;
 }
 
 /*
- * Gets WeeChat hashtable with ruby hashtable.
+ * Converts a ruby hash to a WeeChat hashtable.
  *
  * Note: hashtable must be freed after use.
  */
@@ -194,11 +198,8 @@ weechat_ruby_hash_to_hashtable (VALUE hash, int size, const char *type_keys,
 {
     struct t_hashtable *hashtable;
 
-    hashtable = weechat_hashtable_new (size,
-                                       type_keys,
-                                       type_values,
-                                       NULL,
-                                       NULL);
+    hashtable = weechat_hashtable_new (size, type_keys, type_values,
+                                       NULL, NULL);
     if (!hashtable)
         return NULL;
 
@@ -435,14 +436,14 @@ weechat_ruby_exec (struct t_plugin_script *script,
 static VALUE
 weechat_ruby_output (VALUE self, VALUE str)
 {
-    if (ruby_hide_errors)
-        return Qnil;
-
     char *msg, *p, *m;
 
     /* make C compiler happy */
     (void) self;
 
+    if (ruby_hide_errors)
+        return Qnil;
+
     msg = strdup(StringValuePtr(str));
 
     m = msg;
@@ -572,10 +573,10 @@ weechat_ruby_load (const char *filename)
                 break;
         }
 
-        if (NUM2INT(ruby_retcode) == 1 || NUM2INT(ruby_retcode) == 2)
+        if (NUM2INT(ruby_retcode) == 2)
         {
-            weechat_ruby_print_exception(rb_iv_get (ruby_current_module,
-                                                    "@load_eval_file_error"));
+            weechat_ruby_print_exception (rb_iv_get (ruby_current_module,
+                                                     "@load_eval_file_error"));
         }
 
         return 0;
@@ -594,11 +595,12 @@ weechat_ruby_load (const char *filename)
         err = rb_gv_get("$!");
         weechat_ruby_print_exception(err);
 
-        if (ruby_current_script != NULL)
+        if (ruby_current_script)
         {
             plugin_script_remove (weechat_ruby_plugin,
                                   &ruby_scripts, &last_ruby_script,
                                   ruby_current_script);
+            ruby_current_script = NULL;
         }
 
         return 0;
@@ -626,8 +628,9 @@ weechat_ruby_load (const char *filename)
                                         &weechat_ruby_api_buffer_input_data_cb,
                                         &weechat_ruby_api_buffer_close_cb);
 
-    weechat_hook_signal_send ("ruby_script_loaded", WEECHAT_HOOK_SIGNAL_STRING,
-                              ruby_current_script->filename);
+    (void) weechat_hook_signal_send ("ruby_script_loaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING,
+                                     ruby_current_script->filename);
 
     return 1;
 }
@@ -686,8 +689,8 @@ weechat_ruby_unload (struct t_plugin_script *script)
     if (interpreter)
         rb_gc_unregister_address (interpreter);
 
-    weechat_hook_signal_send ("ruby_script_unloaded",
-                              WEECHAT_HOOK_SIGNAL_STRING, filename);
+    (void) weechat_hook_signal_send ("ruby_script_unloaded",
+                                     WEECHAT_HOOK_SIGNAL_STRING, filename);
     if (filename)
         free (filename);
 }
@@ -812,6 +815,8 @@ weechat_ruby_command_cb (void *data, struct t_gui_buffer *buffer,
         {
             weechat_ruby_unload_all ();
         }
+        else
+            WEECHAT_COMMAND_ERROR;
     }
     else
     {
@@ -861,12 +866,7 @@ weechat_ruby_command_cb (void *data, struct t_gui_buffer *buffer,
             ruby_quiet = 0;
         }
         else
-        {
-            weechat_printf (NULL,
-                            weechat_gettext ("%s%s: unknown option for "
-                                             "command \"%s\""),
-                            weechat_prefix ("error"), RUBY_PLUGIN_NAME, "ruby");
-        }
+            WEECHAT_COMMAND_ERROR;
     }
 
     return WEECHAT_RC_OK;
@@ -970,7 +970,7 @@ weechat_ruby_signal_debug_libs_cb (void *data, const char *signal,
     weechat_printf (NULL, "  %s: %s", RUBY_PLUGIN_NAME, ruby_version);
 #else
     weechat_printf (NULL, "  %s: (?)", RUBY_PLUGIN_NAME);
-#endif
+#endif /* HAVE_RUBY_VERSION_H */
 
     return WEECHAT_RC_OK;
 }
@@ -1093,9 +1093,6 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
         "  if RUBY_VERSION.split('.')[0] == '1' and RUBY_VERSION.split('.')[1] <= '8'\n"
         "    require 'rubygems'\n"
         "  else\n"
-        "    require 'enc/encdb.so'\n"
-        "    require 'enc/trans/transdb.so'\n"
-        "\n"
         "    require 'thread'\n"
         "    class ::Mutex\n"
         "      def synchronize(*args)\n"
@@ -1118,6 +1115,8 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
         "    end\n"
         "\n"
         "    begin\n"
+        "      require 'enc/encdb.so'\n"
+        "      require 'enc/trans/transdb.so'\n"
         "      module_eval(lines)\n"
         "    rescue Exception => e\n"
         "      @load_eval_file_error = e\n"
@@ -1153,38 +1152,38 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     RUBY_INIT_STACK;
 #endif
 
-    ruby_hide_errors = 1;
     ruby_init ();
-    ruby_init_loadpath ();
-    ruby_script ("__weechat_plugin__");
-
-    ruby_mWeechat = rb_define_module("Weechat");
-    weechat_ruby_api_init (ruby_mWeechat);
 
     /* redirect stdin and stdout */
-    ruby_mWeechatOutputs = rb_define_module("WeechatOutputs");
-    rb_define_singleton_method(ruby_mWeechatOutputs, "write",
-                               weechat_ruby_output, 1);
-    rb_define_singleton_method(ruby_mWeechatOutputs, "puts",
-                               weechat_ruby_output, 1);
-    rb_define_singleton_method(ruby_mWeechatOutputs, "p",
-                               weechat_ruby_output, 1);
-    rb_define_singleton_method(ruby_mWeechatOutputs, "flush",
-                               weechat_ruby_output_flush, 0);
-    ruby_hide_errors = 0;
+    ruby_mWeechatOutputs = rb_define_module ("WeechatOutputs");
+    rb_define_singleton_method (ruby_mWeechatOutputs, "write",
+                                weechat_ruby_output, 1);
+    rb_define_singleton_method (ruby_mWeechatOutputs, "puts",
+                                weechat_ruby_output, 1);
+    rb_define_singleton_method (ruby_mWeechatOutputs, "p",
+                                weechat_ruby_output, 1);
+    rb_define_singleton_method (ruby_mWeechatOutputs, "flush",
+                                weechat_ruby_output_flush, 0);
 
-    rb_eval_string_protect(weechat_ruby_code, &ruby_error);
+    ruby_script ("__weechat_plugin__");
+
+    ruby_mWeechat = rb_define_module ("Weechat");
+    weechat_ruby_api_init (ruby_mWeechat);
+
+    rb_eval_string_protect (weechat_ruby_code, &ruby_error);
     if (ruby_error)
     {
         weechat_printf (NULL,
                         weechat_gettext ("%s%s: unable to eval WeeChat ruby "
                                          "internal code"),
                         weechat_prefix ("error"), RUBY_PLUGIN_NAME);
-        VALUE err = rb_gv_get("$!");
-        weechat_ruby_print_exception(err);
+        VALUE err = rb_gv_get ("$!");
+        weechat_ruby_print_exception (err);
         return WEECHAT_RC_ERROR;
     }
 
+    ruby_init_loadpath ();
+
     init.callback_command = &weechat_ruby_command_cb;
     init.callback_completion = &weechat_ruby_completion_cb;
     init.callback_hdata = &weechat_ruby_hdata_cb;
@@ -1218,12 +1217,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
     plugin_script_end (plugin, &ruby_scripts, &weechat_ruby_unload_all);
     ruby_quiet = 0;
 
-    /*
-     * Do not cleanup ruby because this causes a crash when plugin is reloaded
-     * again. This causes a memory leak, but I don't know better solution to
-     * this problem :(
-     */
-    /*ruby_cleanup (0);*/
+    ruby_cleanup (0);
 
     /* free some data */
     if (ruby_action_install_list)
