@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2007 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_RUBY_H
-#define __WEECHAT_RUBY_H 1
+#ifndef WEECHAT_RUBY_H
+#define WEECHAT_RUBY_H 1
 
 #define weechat_plugin weechat_ruby_plugin
 #define RUBY_PLUGIN_NAME "ruby"
@@ -45,4 +45,4 @@ void *weechat_ruby_exec (struct t_plugin_script *script,
                          int ret_type, const char *function,
                          const char *format, void **argv);
 
-#endif /* __WEECHAT_RUBY_H */
+#endif /* WEECHAT_RUBY_H */
