@@ -1,7 +1,7 @@
 /*
  * script-buffer.c - display scripts on script buffer
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -742,10 +742,10 @@ script_buffer_refresh (int clear)
     {
         snprintf (str_title, sizeof (str_title),
                   _("%d/%d scripts (filter: %s) | Sort: %s | "
-                    "Alt+key/input: i=install r=remove l=load L=reload "
-                    "u=unload A=autoload h=(un)hold v=view script | "
-                    "Input: q=close $=refresh s:x,y=sort words=filter "
-                    "*=reset filter | Mouse: left=select right=install/remove"),
+                    "Alt+key/input: i=install, r=remove, l=load, L=reload, "
+                    "u=unload, A=autoload, h=(un)hold, v=view script | "
+                    "Input: q=close, $=refresh, s:x,y=sort, words=filter, "
+                    "*=reset filter | Mouse: left=select, right=install/remove"),
                   script_repo_count_displayed,
                   script_repo_count,
                   (script_repo_filter) ? script_repo_filter : "*",
@@ -977,7 +977,8 @@ script_buffer_input_cb (void *data, struct t_gui_buffer *buffer,
         /* refresh buffer */
         if (strcmp (input_data, "$") == 0)
         {
-            script_get_loaded_plugins_and_scripts ();
+            script_get_loaded_plugins ();
+            script_get_scripts ();
             script_repo_remove_all ();
             script_repo_file_read (1);
             script_buffer_refresh (1);
