@@ -1,7 +1,7 @@
 /*
  * script-command.c - script command
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -124,7 +124,7 @@ int
 script_command_script (void *data, struct t_gui_buffer *buffer, int argc,
                        char **argv, char **argv_eol)
 {
-    char *error;
+    char *error, command[128];
     long value;
     int line;
 
@@ -207,11 +207,9 @@ script_command_script (void *data, struct t_gui_buffer *buffer, int argc,
         return WEECHAT_RC_OK;
     }
 
-    if ((argc > 1) && script_buffer && !script_buffer_detail_script
-        && (script_buffer_selected_line >= 0)
-        && (script_repo_count_displayed > 0))
+    if (weechat_strcasecmp (argv[1], "up") == 0)
     {
-        if (weechat_strcasecmp (argv[1], "up") == 0)
+        if (script_buffer)
         {
             value = 1;
             if (argc > 2)
@@ -221,43 +219,67 @@ script_command_script (void *data, struct t_gui_buffer *buffer, int argc,
                 if (!error || error[0])
                     value = 1;
             }
-            line = script_buffer_selected_line - value;
-            if (line < 0)
-                line = 0;
-            if (line != script_buffer_selected_line)
+            if (script_buffer_detail_script)
             {
-                script_buffer_set_current_line (line);
-                script_buffer_check_line_outside_window ();
+                snprintf (command, sizeof (command),
+                          "/window scroll -%d", (int)value);
+                weechat_command (script_buffer, command);
             }
-            return WEECHAT_RC_OK;
-        }
-        else if (weechat_strcasecmp (argv[1], "down") == 0)
-        {
-            value = 1;
-            if (argc > 2)
+            else if ((script_buffer_selected_line >= 0)
+                     && (script_repo_count_displayed > 0))
             {
-                error = NULL;
-                value = strtol (argv[2], &error, 10);
-                if (!error || error[0])
-                    value = 1;
+                line = script_buffer_selected_line - value;
+                if (line < 0)
+                    line = 0;
+                if (line != script_buffer_selected_line)
+                {
+                    script_buffer_set_current_line (line);
+                    script_buffer_check_line_outside_window ();
+                }
             }
-            line = script_buffer_selected_line + value;
-            if (line >= script_repo_count_displayed)
-                line = script_repo_count_displayed - 1;
-            if (line != script_buffer_selected_line)
-            {
-                script_buffer_set_current_line (line);
-                script_buffer_check_line_outside_window ();
-            }
-            return WEECHAT_RC_OK;
         }
+        return WEECHAT_RC_OK;
     }
 
-    return WEECHAT_RC_OK;
+    if (weechat_strcasecmp (argv[1], "down") == 0)
+    {
+        if (script_buffer)
+        {
+            value = 1;
+            if (argc > 2)
+            {
+                error = NULL;
+                value = strtol (argv[2], &error, 10);
+                if (!error || error[0])
+                    value = 1;
+            }
+            if (script_buffer_detail_script)
+            {
+                snprintf (command, sizeof (command),
+                          "/window scroll +%d", (int)value);
+                weechat_command (script_buffer, command);
+            }
+            else if ((script_buffer_selected_line >= 0)
+                     && (script_repo_count_displayed > 0))
+            {
+                line = script_buffer_selected_line + value;
+                if (line >= script_repo_count_displayed)
+                    line = script_repo_count_displayed - 1;
+                if (line != script_buffer_selected_line)
+                {
+                    script_buffer_set_current_line (line);
+                    script_buffer_check_line_outside_window ();
+                }
+            }
+        }
+        return WEECHAT_RC_OK;
+    }
+
+    WEECHAT_COMMAND_ERROR;
 }
 
 /*
- * Hook command.
+ * Hooks script command.
  */
 
 void
@@ -278,8 +300,9 @@ script_command_init ()
            "            -o: send list of loaded scripts to buffer\n"
            "            -i: copy list of loaded scripts in command line (for "
            "sending to buffer)\n"
-           "        search: search scripts by tags or text and display result "
-           "on scripts buffer\n"
+           "        search: search scripts by tags, language (python, "
+           "perl, ...), filename extension (py, pl, ...) or text; result is "
+           "displayed on scripts buffer\n"
            "          show: show detailed info about a script\n"
            "          load: load script(s)\n"
            "        unload: unload script(s)\n"
@@ -344,13 +367,13 @@ script_command_init ()
            "  /script reload urlserver\n"
            "  /script upgrade"),
         "list -o|-i"
-        " || search %(script_tags)"
+        " || search %(script_tags)|%(script_languages)|%(script_extensions)"
         " || show %(script_scripts)"
         " || load %(script_files)|%*"
         " || unload %(python_script)|%(perl_script)|%(ruby_script)|"
-        "%(tcl_script)|%(lua_script)|%(guile_script)|%*"
+        "%(tcl_script)|%(lua_script)|%(guile_script)|%(javascript_script)|%*"
         " || reload %(python_script)|%(perl_script)|%(ruby_script)|"
-        "%(tcl_script)|%(lua_script)|%(guile_script)|%*"
+        "%(tcl_script)|%(lua_script)|%(guile_script)|%(javascript_script)|%*"
         " || autoload %(script_scripts_installed)|%*"
         " || noautoload %(script_scripts_installed)|%*"
         " || toggleautoload %(script_scripts_installed)|%*"
