@@ -1,7 +1,7 @@
 /*
  * script-config.c - script configuration options (file script.conf)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -82,9 +82,11 @@ struct t_config_option *script_config_color_text_version_selected;
 
 struct t_config_option *script_config_scripts_autoload;
 struct t_config_option *script_config_scripts_cache_expire;
-struct t_config_option *script_config_scripts_dir;
+struct t_config_option *script_config_scripts_download_timeout;
+struct t_config_option *script_config_scripts_path;
 struct t_config_option *script_config_scripts_hold;
 struct t_config_option *script_config_scripts_url;
+struct t_config_option *script_config_scripts_url_force_https;
 
 
 /*
@@ -141,38 +143,6 @@ script_config_get_diff_command ()
     return diff_command;
 }
 
-/*
- * Gets local directory for script.
- *
- * Note: result must be freed after use.
- */
-
-char *
-script_config_get_dir ()
-{
-    const char *weechat_home;
-    char *path, *path2;
-
-    weechat_home = weechat_info_get ("weechat_dir", NULL);
-
-    path = weechat_string_expand_home (weechat_config_string (script_config_scripts_dir));
-    path2 = weechat_string_replace ((path) ?
-                                    path : weechat_config_string (script_config_scripts_dir),
-                                    "%h", weechat_home);
-
-    if (path && path2)
-    {
-        free (path);
-        path = NULL;
-    }
-
-    if (path2)
-        return path2;
-    if (path)
-        return path;
-    return strdup (weechat_config_string (script_config_scripts_dir));
-}
-
 /*
  * Gets filename with script
  * (by default "/home/xxx/.weechat/script/plugins.xml.gz").
@@ -186,7 +156,8 @@ script_config_get_xml_filename ()
     char *path, *filename;
     int length;
 
-    path = script_config_get_dir ();
+    path = weechat_string_eval_path_home (
+        weechat_config_string (script_config_scripts_path), NULL, NULL, NULL);
     length = strlen (path) + 64;
     filename = malloc (length);
     if (filename)
@@ -212,7 +183,8 @@ script_config_get_script_download_filename (struct t_script_repo *script,
     char *path, *filename;
     int length;
 
-    path = script_config_get_dir ();
+    path = weechat_string_eval_path_home (
+        weechat_config_string (script_config_scripts_path), NULL, NULL, NULL);
     length = strlen (path) + 1 + strlen (script->name_with_extension)
         + ((suffix) ? strlen (suffix) : 0) + 1;
     filename = malloc (length);
@@ -683,12 +655,20 @@ script_config_init ()
         "cache_expire", "integer",
         N_("local cache expiration time, in minutes (-1 = never expires, "
            "0 = always expire)"),
-        NULL, -1, 525600, "60", NULL, 0, NULL, NULL,
+        NULL, -1, 525600, "1440", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
-    script_config_scripts_dir = weechat_config_new_option (
+    script_config_scripts_download_timeout = weechat_config_new_option (
         script_config_file, ptr_section,
-        "dir", "string",
-        N_("local cache directory for scripts"),
+        "download_timeout", "integer",
+        N_("timeout (in seconds) for download of scripts and list of scripts"),
+        NULL, 1, 3600, "30", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
+    script_config_scripts_path = weechat_config_new_option (
+        script_config_file, ptr_section,
+        "path", "string",
+        N_("local cache directory for scripts; \"%h\" at beginning of string "
+           "is replaced by WeeChat home (\"~/.weechat\" by default) "
+           "(note: content is evaluated, see /help eval)"),
         NULL, 0, 0, "%h/script", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
     script_config_scripts_hold = weechat_config_new_option (
@@ -702,8 +682,17 @@ script_config_init ()
     script_config_scripts_url = weechat_config_new_option (
         script_config_file, ptr_section,
         "url", "string",
-        N_("URL for file with list of scripts"),
-        NULL, 0, 0, "http://www.weechat.org/files/plugins.xml.gz", NULL, 0, NULL, NULL,
+        N_("URL for file with list of scripts; by default HTTPS is forced, "
+           "see option script.scripts.url_force_https"),
+        NULL, 0, 0, "http://weechat.org/files/plugins.xml.gz", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
+    script_config_scripts_url_force_https = weechat_config_new_option (
+        script_config_file, ptr_section,
+        "url_force_https", "boolean",
+        N_("force use of HTTPS for downloads (index and scripts); "
+           "you should disable this option only if you have problems with "
+           "the downloads"),
+        NULL, 0, 0, "on", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
 
     return 1;
