@@ -1,7 +1,7 @@
 /*
  * script-repo.c - download and read repository file (plugins.xml.gz)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -652,6 +652,10 @@ script_repo_remove (struct t_script_repo *script)
 {
     struct t_script_repo *new_scripts_repo;
 
+    /* unlink script from buffer (if it is used) */
+    if (script_buffer_detail_script == script)
+        script_buffer_detail_script = NULL;
+
     /* remove script from list */
     if (last_script_repo == script)
         last_script_repo = script->prev_script;
@@ -944,13 +948,33 @@ script_repo_match_filter (struct t_script_repo *script)
             if (!has_tag)
             {
                 match = 0;
+
                 if (script->name_with_extension
-                    && weechat_strcasestr (script->name_with_extension, words[i]))
+                    && weechat_strcasestr (script->name_with_extension,
+                                           words[i]))
+                {
                     match = 1;
+                }
+
+                if (!match
+                    && (weechat_strcasecmp (script_language[script->language],
+                                            words[i]) == 0))
+                {
+                    match = 1;
+                }
+
+                if (!match
+                    && (weechat_strcasecmp (script_extension[script->language],
+                                            words[i]) == 0))
+                {
+                    match = 1;
+                }
 
                 if (!match && script->description
                     && weechat_strcasestr (script->description, words[i]))
+                {
                     match = 1;
+                }
 
                 if (!match)
                 {
@@ -1109,7 +1133,8 @@ script_repo_file_read (int quiet)
     struct tm tm_script;
     struct t_hashtable *descriptions;
 
-    script_get_loaded_plugins_and_scripts ();
+    script_get_loaded_plugins ();
+    script_get_scripts ();
 
     script_repo_remove_all ();
 
@@ -1441,7 +1466,6 @@ void
 script_repo_file_update (int quiet)
 {
     char *filename, *url;
-    int length;
     struct t_hashtable *options;
 
     script_repo_remove_all ();
@@ -1457,8 +1481,8 @@ script_repo_file_update (int quiet)
                                      NULL);
     if (options)
     {
-        length = 4 + strlen (weechat_config_string (script_config_scripts_url)) + 1;
-        url = malloc (length);
+        url = script_build_download_url (
+            weechat_config_string (script_config_scripts_url));
         if (url)
         {
             if (!quiet)
@@ -1467,13 +1491,13 @@ script_repo_file_update (int quiet)
                                 _("%s: downloading list of scripts..."),
                                 SCRIPT_PLUGIN_NAME);
             }
-
-            snprintf (url, length, "url:%s",
-                      weechat_config_string (script_config_scripts_url));
             weechat_hashtable_set (options, "file_out", filename);
-            weechat_hook_process_hashtable (url, options, 30000,
-                                            &script_repo_file_update_process_cb,
-                                            (quiet) ? (void *)1 : (void *)0);
+            weechat_hook_process_hashtable (
+                url,
+                options,
+                weechat_config_integer (script_config_scripts_download_timeout) * 1000,
+                &script_repo_file_update_process_cb,
+                (quiet) ? (void *)1 : (void *)0);
             free (url);
         }
         weechat_hashtable_free (options);
