@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_SCRIPT_REPO_H
-#define __WEECHAT_SCRIPT_REPO_H 1
+#ifndef WEECHAT_SCRIPT_REPO_H
+#define WEECHAT_SCRIPT_REPO_H 1
 
 /* status for script */
 #define SCRIPT_STATUS_INSTALLED   1
@@ -85,4 +85,4 @@ extern int script_repo_add_to_infolist (struct t_infolist *infolist,
                                         struct t_script_repo *script);
 extern void script_repo_print_log ();
 
-#endif /* __WEECHAT_SCRIPT_REPO_H */
+#endif /* WEECHAT_SCRIPT_REPO_H */
