@@ -2,7 +2,7 @@
  * weechat-tcl.c - tcl plugin for WeeChat
  *
  * Copyright (C) 2008-2010 Dmitry Kobylin <fnfal@academ.tsc.ru>
- * Copyright (C) 2008-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2008-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -40,6 +40,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Support of tcl scripts"));
 WEECHAT_PLUGIN_AUTHOR("Dmitry Kobylin <fnfal@academ.tsc.ru>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(3000);
 
 struct t_weechat_plugin *weechat_tcl_plugin = NULL;
 
@@ -104,7 +105,7 @@ weechat_tcl_hashtable_map_cb (void *data,
 }
 
 /*
- * Gets tcl dict with a WeeChat hashtable.
+ * Converts a WeeChat hashtable to a tcl dict.
  */
 
 Tcl_Obj *
@@ -129,7 +130,7 @@ weechat_tcl_hashtable_to_dict (Tcl_Interp *interp,
 }
 
 /*
- * Gets WeeChat hashtable with tcl dict.
+ * Converts a tcl dict to a WeeChat hashtable.
  *
  * Note: hashtable must be freed after use.
  */
@@ -144,11 +145,8 @@ weechat_tcl_dict_to_hashtable (Tcl_Interp *interp, Tcl_Obj *dict,
     Tcl_Obj *key, *value;
     int done;
 
-    hashtable = weechat_hashtable_new (size,
-                                       type_keys,
-                                       type_values,
-                                       NULL,
-                                       NULL);
+    hashtable = weechat_hashtable_new (size, type_keys, type_values,
+                                       NULL, NULL);
     if (!hashtable)
         return NULL;
 
@@ -166,13 +164,15 @@ weechat_tcl_dict_to_hashtable (Tcl_Interp *interp, Tcl_Obj *dict,
             {
                 weechat_hashtable_set (hashtable,
                                        Tcl_GetString (key),
-                                       plugin_script_str2ptr (weechat_tcl_plugin,
-                                                              NULL, NULL,
-                                                              Tcl_GetString (value)));
+                                       plugin_script_str2ptr (
+                                           weechat_tcl_plugin,
+                                           NULL, NULL,
+                                           Tcl_GetString (value)));
             }
         }
     }
-    Tcl_DictObjDone(&search);
+
+    Tcl_DictObjDone (&search);
 
     return hashtable;
 }
@@ -339,8 +339,17 @@ weechat_tcl_load (const char *filename)
                                          "parsing file \"%s\": %s"),
                         weechat_prefix ("error"), TCL_PLUGIN_NAME, filename,
                         Tcl_GetStringFromObj (Tcl_GetObjResult (interp), &i));
-        /* this OK, maybe "register" was called, so not return */
-        /* return 0; */
+
+        /* if script was registered, remove it from list */
+        if (tcl_current_script)
+        {
+            plugin_script_remove (weechat_tcl_plugin,
+                                  &tcl_scripts, &last_tcl_script,
+                                  tcl_current_script);
+            tcl_current_script = NULL;
+        }
+
+        return 0;
     }
 
     if (!tcl_registered_script)
@@ -704,7 +713,7 @@ weechat_tcl_signal_debug_libs_cb (void *data, const char *signal,
     weechat_printf (NULL, "  %s: %s", TCL_PLUGIN_NAME, TCL_VERSION);
 #else
     weechat_printf (NULL, "  %s: (?)", TCL_PLUGIN_NAME);
-#endif
+#endif /* TCL_VERSION */
 
     return WEECHAT_RC_OK;
 }
