@@ -1,7 +1,7 @@
 /*
  * xfer-config.c - xfer configuration options (file xfer.conf)
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -307,20 +307,22 @@ xfer_config_init ()
     xfer_config_file_convert_spaces = weechat_config_new_option (
         xfer_config_file, ptr_section,
         "convert_spaces", "boolean",
-        N_("convert spaces to underscores when sending files"),
+        N_("convert spaces to underscores when sending and receiving files"),
         NULL, 0, 0, "on", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     xfer_config_file_download_path = weechat_config_new_option (
         xfer_config_file, ptr_section,
         "download_path", "string",
-        N_("path for writing incoming files (\"%h\" will be replaced by "
-           "WeeChat home, \"~/.weechat\" by default)"),
+        N_("path for writing incoming files: \"%h\" at beginning of string is "
+           "replaced by WeeChat home (\"~/.weechat\" by default) "
+           "(note: content is evaluated, see /help eval)"),
         NULL, 0, 0, "%h/xfer", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     xfer_config_file_upload_path = weechat_config_new_option (
         xfer_config_file, ptr_section,
         "upload_path", "string",
-        N_("path for reading files when sending (when no path is "
-           "specified by user) (\"%h\" will be replaced by "
-           "WeeChat home, \"~/.weechat\" by default)"),
+        N_("path for reading files when sending (when no path is specified "
+           "by user): \"%h\" at beginning of string is replaced by WeeChat "
+           "home (\"~/.weechat\" by default) "
+           "(note: content is evaluated, see /help eval)"),
         NULL, 0, 0, "~", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     xfer_config_file_use_nick_in_filename = weechat_config_new_option (
         xfer_config_file, ptr_section,
