@@ -1,7 +1,7 @@
 /*
  * xfer-dcc.c - file transfer via DCC protocol
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,7 +26,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
-#include <sys/select.h>
+#include <poll.h>
 #include <netinet/in.h>
 #include <fcntl.h>
 #include <time.h>
@@ -54,6 +54,14 @@ xfer_dcc_send_file_child (struct t_xfer *xfer)
     time_t last_sent, new_time, last_second, sent_ok;
     unsigned long long sent_last_second;
 
+    /* empty file? just return immediately */
+    if (xfer->pos >= xfer->size)
+    {
+        xfer_network_write_pipe (xfer, XFER_STATUS_DONE,
+                                 XFER_NO_ERROR);
+        return;
+    }
+
     blocksize = xfer->blocksize;
     if (weechat_config_integer (xfer_config_network_speed_limit) > 0)
     {
@@ -304,7 +312,7 @@ xfer_dcc_recv_file_child (struct t_xfer *xfer)
     static char buffer[XFER_BLOCKSIZE_MAX];
     time_t last_sent, new_time;
     unsigned long long pos_last_ack;
-    fd_set read_fds, write_fds, except_fds;
+    struct pollfd poll_fd;
     ssize_t written, total_written;
     unsigned char *bin_hash;
     char hash[9];
@@ -354,12 +362,11 @@ xfer_dcc_recv_file_child (struct t_xfer *xfer)
     while (1)
     {
         /* wait until there is something to read on socket (or error) */
-        FD_ZERO (&read_fds);
-        FD_ZERO (&write_fds);
-        FD_ZERO (&except_fds);
-        FD_SET (xfer->sock, &read_fds);
-        ready = select (xfer->sock + 1, &read_fds, &write_fds, &except_fds, NULL);
-        if (ready == 0)
+        poll_fd.fd = xfer->sock;
+        poll_fd.events = POLLIN;
+        poll_fd.revents = 0;
+        ready = poll (&poll_fd, 1, -1);
+        if (ready <= 0)
         {
             xfer_network_write_pipe (xfer, XFER_STATUS_FAILED,
                                      XFER_ERROR_RECV_BLOCK);
@@ -386,9 +393,7 @@ xfer_dcc_recv_file_child (struct t_xfer *xfer)
             }
             else
             {
-                total_written = 0;
-
-                if (num_read == 0)
+                if ((num_read == 0) && (xfer->pos < xfer->size))
                 {
                     xfer_network_write_pipe (xfer, XFER_STATUS_FAILED,
                                              XFER_ERROR_RECV_BLOCK);
@@ -396,6 +401,7 @@ xfer_dcc_recv_file_child (struct t_xfer *xfer)
                 }
 
                 /* bytes received, write to disk */
+                total_written = 0;
                 while (total_written < num_read)
                 {
                     written = write (xfer->file,
@@ -433,7 +439,7 @@ xfer_dcc_recv_file_child (struct t_xfer *xfer)
                         bin_hash = gcry_md_read (*xfer->hash_handle, 0);
                         if (bin_hash)
                         {
-                            snprintf (hash, 9, "%.2X%.2X%.2X%.2X",
+                            snprintf (hash, sizeof (hash), "%.2X%.2X%.2X%.2X",
                                       bin_hash[0], bin_hash[1], bin_hash[2],
                                       bin_hash[3]);
                             if (weechat_strcasecmp (hash,
