@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_XFER_NETWORK_H
-#define __WEECHAT_XFER_NETWORK_H 1
+#ifndef WEECHAT_XFER_NETWORK_H
+#define WEECHAT_XFER_NETWORK_H 1
 
 extern void xfer_network_write_pipe (struct t_xfer *xfer, int status,
                                      int error);
@@ -27,4 +27,4 @@ extern void xfer_network_child_kill (struct t_xfer *xfer);
 extern int xfer_network_connect (struct t_xfer *xfer);
 extern void xfer_network_accept (struct t_xfer *xfer);
 
-#endif /* __WEECHAT_XFER_NETWORK_H */
+#endif /* WEECHAT_XFER_NETWORK_H */
