@@ -1,7 +1,7 @@
 /*
  * xfer.c - file transfer and direct chat plugin for WeeChat
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -50,6 +50,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("DCC file transfer and direct chat"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
+WEECHAT_PLUGIN_PRIORITY(6000);
 
 struct t_weechat_plugin *weechat_xfer_plugin = NULL;
 
@@ -139,21 +140,26 @@ xfer_signal_upgrade_cb (void *data, const char *signal, const char *type_data,
 void
 xfer_create_directories ()
 {
-    const char *weechat_dir;
-    char *dir1, *dir2;
+    char *path;
 
     /* create download directory */
-    weechat_dir = weechat_info_get ("weechat_dir", "");
-    if (weechat_dir)
+    path = weechat_string_eval_path_home (
+        weechat_config_string (xfer_config_file_download_path),
+        NULL, NULL, NULL);
+    if (path)
     {
-        dir1 = weechat_string_expand_home (weechat_config_string (xfer_config_file_download_path));
-        dir2 = weechat_string_replace (dir1, "%h", weechat_dir);
-        if (dir2)
-            (void) weechat_mkdir (dir2, 0700);
-        if (dir1)
-            free (dir1);
-        if (dir2)
-            free (dir2);
+        (void) weechat_mkdir_parents (path, 0700);
+        free (path);
+    }
+
+    /* create upload directory */
+    path = weechat_string_eval_path_home (
+        weechat_config_string (xfer_config_file_upload_path),
+        NULL, NULL, NULL);
+    if (path)
+    {
+        (void) weechat_mkdir_parents (path, 0700);
+        free (path);
     }
 }
 
@@ -298,6 +304,11 @@ xfer_close (struct t_xfer *xfer, enum t_xfer_status status)
             weechat_unhook (xfer->hook_timer);
             xfer->hook_timer = NULL;
         }
+        if (xfer->hook_connect)
+        {
+            weechat_unhook (xfer->hook_connect);
+            xfer->hook_connect = NULL;
+        }
         if (XFER_IS_FILE(xfer->type))
         {
             weechat_printf (NULL,
@@ -424,8 +435,9 @@ xfer_send_signal (struct t_xfer *xfer, const char *signal)
     {
         if (xfer_add_to_infolist (infolist, xfer))
         {
-            weechat_hook_signal_send (signal, WEECHAT_HOOK_SIGNAL_POINTER,
-                                      infolist);
+            (void) weechat_hook_signal_send (signal,
+                                             WEECHAT_HOOK_SIGNAL_POINTER,
+                                             infolist);
         }
         weechat_infolist_free (infolist);
     }
@@ -478,6 +490,7 @@ xfer_alloc ()
     new_xfer->child_write = -1;
     new_xfer->hook_fd = NULL;
     new_xfer->hook_timer = NULL;
+    new_xfer->hook_connect = NULL;
     new_xfer->unterminated_message = NULL;
     new_xfer->file = -1;
     new_xfer->local_filename = NULL;
@@ -526,7 +539,7 @@ xfer_nick_auto_accepted (const char *server, const char *nick)
     {
         for (i = 0; i < num_nicks; i++)
         {
-            pos = strchr (nicks[i], '.');
+            pos = strrchr (nicks[i], '.');
             if (pos)
             {
                 if ((weechat_strncasecmp (server, nicks[i], pos - nicks[i]) == 0)
@@ -668,21 +681,14 @@ xfer_new (const char *plugin_name, const char *plugin_id,
         snprintf (str_address, sizeof (str_address), "?");
     }
 
-    new_xfer->local_address = calloc (1, sizeof (struct sockaddr_storage));
-    new_xfer->local_address_length = sizeof (struct sockaddr_storage);
-    new_xfer->remote_address = calloc (1, sizeof (struct sockaddr_storage));
-    new_xfer->remote_address_length = sizeof (struct sockaddr_storage);
-
     if (XFER_IS_RECV(type))
     {
         new_xfer->local_address_str = strdup ("");
-        new_xfer->remote_address_str = strdup (str_address);
-        memcpy (new_xfer->remote_address, address, address_length);
+        xfer_set_remote_address(new_xfer, address, address_length, str_address);
     }
     else
     {
-        new_xfer->local_address_str = strdup (str_address);
-        memcpy (new_xfer->local_address, address, address_length);
+        xfer_set_local_address(new_xfer, address, address_length, str_address);
         new_xfer->remote_address_str = strdup ("");
     }
 
@@ -834,12 +840,12 @@ xfer_new (const char *plugin_name, const char *plugin_id,
  */
 
 void
-xfer_set_remote_address (struct t_xfer *xfer, struct sockaddr *address,
-                         socklen_t length, char *address_str)
+xfer_set_remote_address (struct t_xfer *xfer, const struct sockaddr *address,
+                         socklen_t length, const char *address_str)
 {
     if (xfer->remote_address)
         free (xfer->remote_address);
-    xfer->remote_address = calloc (1, length);
+    xfer->remote_address = malloc (length);
     xfer->remote_address_length = length;
     memcpy (xfer->remote_address, address, length);
 
@@ -848,6 +854,24 @@ xfer_set_remote_address (struct t_xfer *xfer, struct sockaddr *address,
     xfer->remote_address_str = strdup ((address_str) ? address_str : "");
 }
 
+/*
+ * Sets the local address field.
+ */
+void
+xfer_set_local_address (struct t_xfer *xfer, const struct sockaddr *address,
+                         socklen_t length, const char *address_str)
+{
+    if (xfer->local_address)
+        free (xfer->local_address);
+    xfer->local_address = malloc (length);
+    xfer->local_address_length = length;
+    memcpy (xfer->local_address, address, length);
+
+    if (xfer->local_address_str)
+        free (xfer->local_address_str);
+    xfer->local_address_str = strdup ((address_str) ? address_str : "");
+}
+
 /*
  * Frees xfer struct and removes it from list.
  */
@@ -915,6 +939,59 @@ xfer_free (struct t_xfer *xfer)
         xfer_buffer_selected_line = (xfer_count == 0) ? 0 : xfer_count - 1;
 }
 
+
+/*
+ * Resolves address.
+ *
+ * Returns:
+ *   1: OK
+ *   0: error
+ */
+
+int
+xfer_resolve_addr (const char *str_address, const char *str_port,
+                   struct sockaddr *addr, socklen_t *addr_len, int ai_flags)
+{
+    struct addrinfo *ainfo, hints;
+    int rc;
+
+    memset (&hints, 0, sizeof (struct addrinfo));
+    hints.ai_flags = ai_flags;
+    hints.ai_family = AF_UNSPEC;
+    hints.ai_socktype = SOCK_STREAM;
+    hints.ai_protocol = 0;
+    hints.ai_canonname = NULL;
+    hints.ai_addr = NULL;
+    hints.ai_next = NULL;
+
+    rc = getaddrinfo (str_address, str_port, &hints, &ainfo);
+    if ((rc == 0) && ainfo && ainfo->ai_addr)
+    {
+        if (ainfo->ai_addrlen > *addr_len)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: address \"%s\" resolved to a larger "
+                              "sockaddr than expected"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME,
+                            str_address);
+            freeaddrinfo (ainfo);
+            return 0;
+        }
+        memcpy (addr, ainfo->ai_addr, ainfo->ai_addrlen);
+        *addr_len = ainfo->ai_addrlen;
+        freeaddrinfo (ainfo);
+        return 1;
+    }
+
+    weechat_printf (NULL,
+                    _("%s%s: invalid address \"%s\": error %d %s"),
+                    weechat_prefix ("error"), XFER_PLUGIN_NAME,
+                    str_address, rc, gai_strerror (rc));
+    if ((rc == 0) && ainfo)
+        freeaddrinfo (ainfo);
+    return 0;
+}
+
 /*
  * Callback for signal "xfer_add".
  */
@@ -926,13 +1003,13 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
     struct t_infolist *infolist;
     const char *plugin_name, *plugin_id, *str_type, *str_protocol;
     const char *remote_nick, *local_nick, *charset_modifier, *filename, *proxy;
-    const char *weechat_dir, *str_address, *str_port;
-    int type, protocol, args, port_start, port_end, sock, port, rc, own_ip_used;
-    char *dir1, *dir2, *filename2, *short_filename, *pos, str_port_temp[16];
+    const char *str_address, *str_port;
+    int type, protocol, args, port_start, port_end, sock, port;
+    char *path, *filename2, *short_filename, *pos, str_port_temp[16];
     struct stat st;
-    struct addrinfo *ainfo, hints;
-    struct sockaddr_storage addr;
-    socklen_t length;
+    struct sockaddr_storage addr, own_ip_addr, bind_addr;
+    struct sockaddr *out_addr = (struct sockaddr*)&addr;
+    socklen_t length, bind_addr_len;
     unsigned long long file_size;
     struct t_xfer *ptr_xfer;
 
@@ -964,7 +1041,6 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
     file_size = 0;
 
     sock = -1;
-    port = 0;
 
     plugin_name = weechat_infolist_string (infolist, "plugin_name");
     plugin_id = weechat_infolist_string (infolist, "plugin_id");
@@ -1033,43 +1109,32 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
             filename2 = weechat_string_expand_home (filename);
         else
         {
-            dir1 = weechat_string_expand_home (weechat_config_string (xfer_config_file_upload_path));
-            if (!dir1)
+            path = weechat_string_eval_path_home (
+                weechat_config_string (xfer_config_file_upload_path),
+                NULL, NULL, NULL);
+            if (!path)
             {
                 weechat_printf (NULL,
                                 _("%s%s: not enough memory"),
                                 weechat_prefix ("error"), XFER_PLUGIN_NAME);
                 goto error;
             }
-
-            weechat_dir = weechat_info_get ("weechat_dir", "");
-            dir2 = weechat_string_replace (dir1, "%h", weechat_dir);
-            if (!dir2)
-            {
-                weechat_printf (NULL,
-                                _("%s%s: not enough memory"),
-                                weechat_prefix ("error"), XFER_PLUGIN_NAME);
-                free (dir1);
-                goto error;
-            }
-            filename2 = malloc (strlen (dir2) + strlen (filename) + 4);
+            filename2 = malloc (strlen (path) + strlen (filename) + 4);
             if (!filename2)
             {
                 weechat_printf (NULL,
                                 _("%s%s: not enough memory"),
                                 weechat_prefix ("error"), XFER_PLUGIN_NAME);
-                free (dir1);
-                free (dir2);
+                free (path);
                 goto error;
             }
-            strcpy (filename2, dir2);
+            strcpy (filename2, path);
             if (filename2[strlen (filename2) - 1] != DIR_SEPARATOR_CHAR)
                 strcat (filename2, DIR_SEPARATOR);
             strcat (filename2, filename);
-            free (dir1);
-            free (dir2);
+            free (path);
         }
-#endif
+#endif /* _WIN32 */
         /* check if file exists */
         if (stat (filename2, &st) == -1)
         {
@@ -1083,63 +1148,74 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
     }
     port = weechat_infolist_integer (infolist, "port");
 
-    /* set address */
-    memset (&hints, 0, sizeof (struct addrinfo));
-    hints.ai_flags = AI_NUMERICHOST | AI_NUMERICSERV;
-    hints.ai_family = AF_UNSPEC;  /* allow IPv4 or IPv6 */
-    hints.ai_socktype = SOCK_STREAM;
-    hints.ai_protocol = 0;
-    hints.ai_canonname = NULL;
-    hints.ai_addr = NULL;
-    hints.ai_next = NULL;
-
-    own_ip_used = 0;
-
+    /* resolve address */
     if (XFER_IS_RECV(type))
     {
         str_address = weechat_infolist_string (infolist, "remote_address");
         snprintf (str_port_temp, sizeof (str_port_temp), "%d", port);
         str_port = str_port_temp;
+        length = sizeof (addr);
+        if (!xfer_resolve_addr (str_address, str_port,
+                                (struct sockaddr*)&addr, &length,
+                                AI_NUMERICSERV | AI_NUMERICHOST))
+        {
+            goto error;
+        }
     }
     else
     {
-        str_port = NULL;
+        memset(&bind_addr, 0, sizeof(bind_addr));
+
+        /* determine bind_addr family from either own_ip or default */
         if (weechat_config_string (xfer_config_network_own_ip)
             && weechat_config_string (xfer_config_network_own_ip)[0])
         {
+            /* resolve own_ip to a numeric address */
             str_address = weechat_config_string (xfer_config_network_own_ip);
-            hints.ai_flags = AI_NUMERICSERV;
-            own_ip_used = 1;
+            length = sizeof (own_ip_addr);
+
+            if (!xfer_resolve_addr (str_address, NULL,
+                                    (struct sockaddr*)&own_ip_addr, &length,
+                                    AI_NUMERICSERV))
+            {
+                goto error;
+            }
+
+            /* set the advertised address to own_ip */
+            out_addr = (struct sockaddr*)&own_ip_addr;
+
+            /* bind_addr's family should be the advertised family */
+            bind_addr.ss_family = own_ip_addr.ss_family;
         }
         else
+        {
+            /* no own_ip, so bind_addr's family comes from irc connection  */
             str_address = weechat_infolist_string (infolist, "local_address");
-    }
+            length = sizeof (addr);
+            if (!xfer_resolve_addr (str_address, NULL,
+                                    (struct sockaddr*)&addr, &length,
+                                    AI_NUMERICSERV | AI_NUMERICHOST))
+            {
+                goto error;
+            }
+            bind_addr.ss_family = addr.ss_family;
+        }
 
-    rc = getaddrinfo (str_address, str_port, &hints, &ainfo);
-    if ((rc == 0) && ainfo && ainfo->ai_addr)
-    {
-        memset (&addr,  0, sizeof (addr));
-        memcpy (&addr, ainfo->ai_addr, ainfo->ai_addrlen);
-        length = ainfo->ai_addrlen;
-        freeaddrinfo (ainfo);
-    }
-    else
-    {
-        weechat_printf (NULL,
-                        (own_ip_used) ?
-                        _("%s%s: invalid address \"%s\" (option "
-                          "xfer.network.own_ip): error %d %s") :
-                        _("%s%s: unable to find address for \"%s\": "
-                          "error %d %s"),
-                        weechat_prefix ("error"), XFER_PLUGIN_NAME,
-                        str_address, rc, gai_strerror (rc));
-        goto error;
-    }
+        /* determine bind wildcard address */
+        if (bind_addr.ss_family == AF_INET)
+        {
+            ((struct sockaddr_in*)&bind_addr)->sin_addr.s_addr = INADDR_ANY;
+            bind_addr_len = sizeof (struct sockaddr_in);
+        }
+        else
+        {
+            memcpy (&((struct sockaddr_in6*)&bind_addr)->sin6_addr,
+                    &in6addr_any, sizeof (in6addr_any));
+            bind_addr_len = sizeof (struct sockaddr_in6);
+        }
 
-    if (XFER_IS_SEND(type))
-    {
         /* open socket for xfer */
-        sock = socket (addr.ss_family, SOCK_STREAM, 0);
+        sock = socket (bind_addr.ss_family, SOCK_STREAM, 0);
         if (sock < 0)
         {
             weechat_printf (NULL,
@@ -1170,11 +1246,11 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
                     if (!xfer_port_in_use (port))
                     {
                         /* attempt to bind to the free port */
-                        if (addr.ss_family == AF_INET)
-                            ((struct sockaddr_in *)&addr)->sin_port = htons (port);
+                        if (bind_addr.ss_family == AF_INET)
+                            ((struct sockaddr_in *)&bind_addr)->sin_port = htons (port);
                         else
-                            ((struct sockaddr_in6 *)&addr)->sin6_port = htons (port);
-                        if (bind (sock, (struct sockaddr *)&addr, length) == 0)
+                            ((struct sockaddr_in6 *)&bind_addr)->sin6_port = htons (port);
+                        if (bind (sock, (struct sockaddr *)&bind_addr, bind_addr_len) == 0)
                             break;
                     }
                     port++;
@@ -1188,13 +1264,13 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
         if (port == 0)
         {
             /* find port automatically */
-            if (bind (sock, (struct sockaddr *)&addr, length) == 0)
+            if (bind (sock, (struct sockaddr *)&bind_addr, bind_addr_len) == 0)
             {
-                getsockname (sock, (struct sockaddr *)&addr, &length);
-                if (addr.ss_family == AF_INET)
-                    port = ntohs (((struct sockaddr_in *)&addr)->sin_port);
+                getsockname (sock, (struct sockaddr *)&bind_addr, &bind_addr_len);
+                if (bind_addr.ss_family == AF_INET)
+                    port = ntohs (((struct sockaddr_in *)&bind_addr)->sin_port);
                 else
-                    port = ntohs (((struct sockaddr_in6 *)&addr)->sin6_port);
+                    port = ntohs (((struct sockaddr_in6 *)&bind_addr)->sin6_port);
             }
             else
                 port = -1;
@@ -1248,15 +1324,13 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
         ptr_xfer = xfer_new (plugin_name, plugin_id, type, protocol,
                              remote_nick, local_nick, charset_modifier,
                              short_filename, file_size, proxy,
-                             (struct sockaddr *)&addr, length, port, sock,
-                             filename2);
+                             out_addr, length, port, sock, filename2);
     }
     else
     {
         ptr_xfer = xfer_new (plugin_name, plugin_id, type, protocol,
                              remote_nick, local_nick, charset_modifier, NULL,
-                             0, proxy, (struct sockaddr *)&addr, length,
-                             port, sock, NULL);
+                             0, proxy, out_addr, length, port, sock, NULL);
     }
 
     if (!ptr_xfer)
@@ -1544,6 +1618,8 @@ xfer_add_to_infolist (struct t_infolist *infolist, struct t_xfer *xfer)
         return 0;
     if (!weechat_infolist_new_var_pointer (ptr_item, "hook_timer", xfer->hook_timer))
         return 0;
+    if (!weechat_infolist_new_var_pointer (ptr_item, "hook_connect", xfer->hook_connect))
+        return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "unterminated_message", xfer->unterminated_message))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "file", xfer->file))
@@ -1634,6 +1710,7 @@ xfer_print_log ()
         weechat_log_printf ("  child_write . . . . . . : %d",    ptr_xfer->child_write);
         weechat_log_printf ("  hook_fd . . . . . . . . : 0x%lx", ptr_xfer->hook_fd);
         weechat_log_printf ("  hook_timer. . . . . . . : 0x%lx", ptr_xfer->hook_timer);
+        weechat_log_printf ("  hook_connect. . . . . . : 0x%lx", ptr_xfer->hook_connect);
         weechat_log_printf ("  unterminated_message. . : '%s'",  ptr_xfer->unterminated_message);
         weechat_log_printf ("  file. . . . . . . . . . : %d",    ptr_xfer->file);
         weechat_log_printf ("  local_filename. . . . . : '%s'",  ptr_xfer->local_filename);
