@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_XFER_H
-#define __WEECHAT_XFER_H 1
+#ifndef WEECHAT_XFER_H
+#define WEECHAT_XFER_H 1
 
 #include <unistd.h>
 #include <gcrypt.h>
@@ -110,7 +110,7 @@ enum t_xfer_hash_status
 #else
     #define DIR_SEPARATOR       "/"
     #define DIR_SEPARATOR_CHAR  '/'
-#endif
+#endif /* _WIN32 */
 
 /* macros for type/status */
 
@@ -163,6 +163,7 @@ struct t_xfer
     int child_write;                   /* to write into child pipe          */
     struct t_hook *hook_fd;            /* hook for socket or child pipe     */
     struct t_hook *hook_timer;         /* timeout for receiver accept       */
+    struct t_hook *hook_connect;       /* hook for connection to chat recv  */
     char *unterminated_message;        /* beginning of a message            */
     int file;                          /* local file (read or write)        */
     char *local_filename;              /* local filename (with path)        */
@@ -196,10 +197,13 @@ extern struct t_xfer *xfer_search_by_buffer (struct t_gui_buffer *buffer);
 extern void xfer_close (struct t_xfer *xfer, enum t_xfer_status status);
 extern void xfer_send_signal (struct t_xfer *xfer, const char *signal);
 extern void xfer_set_remote_address (struct t_xfer *xfer,
-                                     struct sockaddr *address, socklen_t length,
-                                     char *address_str);
+                                     const struct sockaddr *address,
+                                     socklen_t length, const char *address_str);
+extern void xfer_set_local_address (struct t_xfer *xfer,
+                                    const struct sockaddr *address,
+                                    socklen_t length, const char *address_str);
 extern void xfer_free (struct t_xfer *xfer);
 extern int xfer_add_to_infolist (struct t_infolist *infolist,
                                  struct t_xfer *xfer);
 
-#endif /* __WEECHAT_XFER_H */
+#endif /* WEECHAT_XFER_H */
