@@ -1,7 +1,7 @@
 /*
  * tests.cpp - run WeeChat tests
  *
- * Copyright (C) 2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -32,13 +32,13 @@ extern "C"
 #ifndef HAVE_CONFIG_H
 #define HAVE_CONFIG_H
 #endif
-#include "../src/core/weechat.h"
-#include "../src/core/wee-hook.h"
-#include "../src/core/wee-input.h"
-#include "../src/core/wee-string.h"
-#include "../src/plugins/plugin.h"
-#include "../src/gui/gui-main.h"
-#include "../src/gui/gui-buffer.h"
+#include "src/core/weechat.h"
+#include "src/core/wee-hook.h"
+#include "src/core/wee-input.h"
+#include "src/core/wee-string.h"
+#include "src/plugins/plugin.h"
+#include "src/gui/gui-main.h"
+#include "src/gui/gui-buffer.h"
 
     extern void gui_main_init ();
     extern void gui_main_loop ();
@@ -47,6 +47,8 @@ extern "C"
 #include "CppUTest/CommandLineTestRunner.h"
 
 /* import tests from libs */
+IMPORT_TEST_GROUP(Plugins);
+IMPORT_TEST_GROUP(Arraylist);
 IMPORT_TEST_GROUP(Eval);
 IMPORT_TEST_GROUP(Hashtable);
 IMPORT_TEST_GROUP(Hdata);
@@ -123,7 +125,7 @@ main (int argc, char *argv[])
     char *weechat_tests_args, *args, **weechat_argv;
 
     /* setup environment: default language, no specific timezone */
-    setenv ("LANG", "C", 1);
+    setenv ("LC_ALL", "C", 1);
     setenv ("TZ", "", 1);
 
     /* build arguments for WeeChat */
@@ -149,6 +151,9 @@ main (int argc, char *argv[])
     /* init WeeChat */
     printf ("------------------------------------------------------------\n");
     weechat_init (weechat_argc, weechat_argv, &test_gui_init);
+    if (weechat_argv)
+        string_free_split (weechat_argv);
+    free (args);
 
     /* display WeeChat version */
     input_data (gui_buffer_search_main (), "/command core version");
@@ -170,7 +175,5 @@ main (int argc, char *argv[])
             (rc == 0) ? 32 : 31,  /* 32 = green (OK), 31 = red (error) */
             (rc == 0) ? "OK" : "ERROR");
 
-    string_free_split (weechat_argv);
-
     return rc;
 }
