@@ -1,7 +1,7 @@
 /*
  * test-string.cpp - test string functions
  *
- * Copyright (C) 2014-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -460,6 +460,7 @@ TEST(String, ConvertEscapedChars)
 
     WEE_TEST_STR(NULL, string_convert_escaped_chars (NULL));
     WEE_TEST_STR("", string_convert_escaped_chars (""));
+    WEE_TEST_STR("", string_convert_escaped_chars ("\\"));
     WEE_TEST_STR("\"", string_convert_escaped_chars ("\\\""));
     WEE_TEST_STR("\\", string_convert_escaped_chars ("\\\\"));
     WEE_TEST_STR("\a", string_convert_escaped_chars ("\\a"));
@@ -1123,6 +1124,76 @@ TEST(String, BaseN)
     }
 }
 
+/*
+ * Tests functions:
+ *    string_hex_dump
+ */
+
+TEST(String, Hex_dump)
+{
+    const char *noel_utf8 = "no\xc3\xabl";  /* noël */
+    const char *noel_iso = "no\xebl";
+    char *str;
+
+    POINTERS_EQUAL(NULL, string_hex_dump (NULL, 0, 0, NULL, NULL));
+    POINTERS_EQUAL(NULL, string_hex_dump ("abc", 0, 0, NULL, NULL));
+    POINTERS_EQUAL(NULL, string_hex_dump ("abc", 3, 0, NULL, NULL));
+    POINTERS_EQUAL(NULL, string_hex_dump ("abc", 0, 5, NULL, NULL));
+
+    str = string_hex_dump ("abc", 3, 3, NULL, NULL);
+    STRCMP_EQUAL("61 62 63   a b c ", str);
+
+    str = string_hex_dump ("abc", 3, 3, "", "");
+    STRCMP_EQUAL("61 62 63   a b c ", str);
+
+    str = string_hex_dump ("abc", 3, 3, "(( ", NULL);
+    STRCMP_EQUAL("(( 61 62 63   a b c ", str);
+
+    str = string_hex_dump ("abc", 3, 3, NULL, " ))");
+    STRCMP_EQUAL("61 62 63   a b c  ))", str);
+
+    str = string_hex_dump ("abc", 3, 3, "(( ", " ))");
+    STRCMP_EQUAL("(( 61 62 63   a b c  ))", str);
+
+    str = string_hex_dump ("abc", 3, 5, NULL, NULL);
+    STRCMP_EQUAL("61 62 63         a b c     ", str);
+
+    str = string_hex_dump ("abc", 3, 10, NULL, NULL);
+    STRCMP_EQUAL("61 62 63                        a b c               ", str);
+
+    str = string_hex_dump ("abc", 3, 2, NULL, NULL);
+    STRCMP_EQUAL("61 62   a b \n"
+                 "63      c   ",
+                 str);
+
+    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 5, NULL, NULL);
+    STRCMP_EQUAL("6E 6F C3 AB 6C   n o . . l ", str);
+
+    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 2, NULL, NULL);
+    STRCMP_EQUAL("6E 6F   n o \n"
+                 "C3 AB   . . \n"
+                 "6C      l   ",
+                 str);
+    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 2, "( ", NULL);
+    STRCMP_EQUAL("( 6E 6F   n o \n"
+                 "( C3 AB   . . \n"
+                 "( 6C      l   ",
+                 str);
+    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 2, "( ", " )");
+    STRCMP_EQUAL("( 6E 6F   n o  )\n"
+                 "( C3 AB   . .  )\n"
+                 "( 6C      l    )",
+                 str);
+
+    str = string_hex_dump (noel_iso, strlen (noel_iso), 5, NULL, NULL);
+    STRCMP_EQUAL("6E 6F EB 6C      n o . l   ", str);
+
+    str = string_hex_dump (noel_iso, strlen (noel_iso), 2, NULL, NULL);
+    STRCMP_EQUAL("6E 6F   n o \n"
+                 "EB 6C   . l ",
+                 str);
+}
+
 /*
  * Tests functions:
  *    string_is_command_char
@@ -1143,11 +1214,25 @@ TEST(String, Input)
 
     /* string_input_for_buffer */
     POINTERS_EQUAL(NULL, string_input_for_buffer (NULL));
-    POINTERS_EQUAL(NULL, string_input_for_buffer ("/"));
     POINTERS_EQUAL(NULL, string_input_for_buffer ("/abc"));
     str = strdup ("");
     STRCMP_EQUAL(str, string_input_for_buffer (str));
     free (str);
+    str = strdup ("/");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("/ ");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("/ abc");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("/ /");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("/*");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
     str = strdup ("abc");
     STRCMP_EQUAL(str, string_input_for_buffer (str));
     free (str);
