@@ -1,7 +1,7 @@
 /*
  * test-url.cpp - test URL functions
  *
- * Copyright (C) 2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2016 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -23,7 +23,7 @@
 
 extern "C"
 {
-#include "../src/core/wee-url.h"
+#include "src/core/wee-url.h"
 }
 
 TEST_GROUP(Url)
